/*! For license information please see chunk.a4b0643900e34ff2dc19.js.LICENSE.txt */
(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[3278],{83278:function(e,n,t){"use strict";t.d(n,{r:function(){return v}});var r=t(94707);function o(e,n){var t;if("undefined"==typeof Symbol||null==e[Symbol.iterator]){if(Array.isArray(e)||(t=function(e,n){if(!e)return;if("string"==typeof e)return a(e,n);var t=Object.prototype.toString.call(e).slice(8,-1);"Object"===t&&e.constructor&&(t=e.constructor.name);if("Map"===t||"Set"===t)return Array.from(e);if("Arguments"===t||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t))return a(e,n)}(e))||n&&e&&"number"==typeof e.length){t&&(e=t);var r=0,o=function(){};return{s:o,n:function(){return r>=e.length?{done:!0}:{done:!1,value:e[r++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,f=!0,u=!1;return{s:function(){t=e[Symbol.iterator]()},n:function(){var e=t.next();return f=e.done,e},e:function(e){u=!0,i=e},f:function(){try{f||null==t.return||t.return()}finally{if(u)throw i}}}}function a(e,n){(null==n||n>e.length)&&(n=e.length);for(var t=0,r=new Array(n);t<n;t++)r[t]=e[t];return r}var i=function(e,n){var t=e.startNode.parentNode,o=void 0===n?e.endNode:n.startNode,a=t.insertBefore((0,r.IW)(),o);t.insertBefore((0,r.IW)(),o);var i=new r.nt(e.options);return i.insertAfterNode(a),i},f=function(e,n){return e.setValue(n),e.commit(),e},u=function(e,n,t){var o=e.startNode.parentNode,a=t?t.startNode:e.endNode,i=n.endNode.nextSibling;i!==a&&(0,r.V)(o,n.startNode,i,a)},l=function(e){(0,r.r4)(e.startNode.parentNode,e.startNode,e.endNode.nextSibling)},s=function(e,n,t){for(var r=new Map,o=n;o<=t;o++)r.set(e[o],o);return r},d=new WeakMap,c=new WeakMap,v=(0,r.XM)((function(e,n,t){var a;return void 0===t?t=n:void 0!==n&&(a=n),function(n){if(!(n instanceof r.nt))throw new Error("repeat can only be used in text bindings");var v,h,p,y=d.get(n)||[],b=c.get(n)||[],m=[],g=[],N=[],w=0,S=o(e);try{for(S.s();!(v=S.n()).done;){var A=v.value;N[w]=a?a(A,w):w,g[w]=t(A,w),w++}}catch(E){S.e(E)}finally{S.f()}for(var k=0,I=y.length-1,M=0,x=g.length-1;k<=I&&M<=x;)if(null===y[k])k++;else if(null===y[I])I--;else if(b[k]===N[M])m[M]=f(y[k],g[M]),k++,M++;else if(b[I]===N[x])m[x]=f(y[I],g[x]),I--,x--;else if(b[k]===N[x])m[x]=f(y[k],g[x]),u(n,y[k],m[x+1]),k++,x--;else if(b[I]===N[M])m[M]=f(y[I],g[M]),u(n,y[I],y[k]),I--,M++;else if(void 0===h&&(h=s(N,M,x),p=s(b,k,I)),h.has(b[k]))if(h.has(b[I])){var W=p.get(N[M]),_=void 0!==W?y[W]:null;if(null===_){var j=i(n,y[k]);f(j,g[M]),m[M]=j}else m[M]=f(_,g[M]),u(n,_,y[k]),y[W]=null;M++}else l(y[I]),I--;else l(y[k]),k++;for(;M<=x;){var C=i(n,m[x+1]);f(C,g[M]),m[M++]=C}for(;k<=I;){var B=y[k++];null!==B&&l(B)}d.set(n,m),c.set(n,N)}}))}}]);
//# sourceMappingURL=chunk.a4b0643900e34ff2dc19.js.map