(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[7770],{79109:(t,a,e)=>{"use strict";e.r(a),e.d(a,{default:()=>n});var s=e(69438),i=e.n(s);e(9680);i().Interaction.modes.neareach=function(t,a,e){const s={x:(t,a)=>Math.abs(t.x-a.x),y:(t,a)=>Math.abs(t.y-a.y),xy:(t,a)=>Math.pow(t.x-a.x,2)+Math.pow(t.y-a.y,2)};let n;n=a.native?{x:a.x,y:a.y}:i().helpers.getRelativePosition(a,t);const o=[],x=[],h=t.data.datasets;let r;e.axis=e.axis||"xy";const d=s[e.axis],l={x:t=>t,y:t=>t,xy:t=>t*t}[e.axis];for(let i=0,c=h.length;i<c;++i)if(t.isDatasetVisible(i)){r=t.getDatasetMeta(i);for(let t=0,a=r.data.length;t<a;++t){const a=r.data[t];if(!a._view.skip){const t=a._view,e=d(t,n),s=x[i];e<l(t.radius+t.hitRadius)&&(void 0===s||s>e)&&(x[i]=e,o[i]=a)}}}return o.filter((t=>void 0!==t))};const n=i()}}]);
//# sourceMappingURL=chunk.a769873393b2614ee3e8.js.map