/*! For license information please see onboarding.55147b52.js.LICENSE.txt */
(()=>{var e,t,n={27815:(e,t)=>{"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.shouldPolyfill=void 0,t.shouldPolyfill=function(){return"undefined"==typeof Intl||!("PluralRules"in Intl)||"one"===new Intl.PluralRules("en",{minimumFractionDigits:2}).select(1)}},72774:(e,t,n)=>{"use strict";n.d(t,{K:()=>r});var r=function(){function e(e){void 0===e&&(e={}),this.adapter=e}return Object.defineProperty(e,"cssClasses",{get:function(){return{}},enumerable:!0,configurable:!0}),Object.defineProperty(e,"strings",{get:function(){return{}},enumerable:!0,configurable:!0}),Object.defineProperty(e,"numbers",{get:function(){return{}},enumerable:!0,configurable:!0}),Object.defineProperty(e,"defaultAdapter",{get:function(){return{}},enumerable:!0,configurable:!0}),e.prototype.init=function(){},e.prototype.destroy=function(){},e}()},58014:(e,t,n)=>{"use strict";function r(e,t){if(e.closest)return e.closest(t);for(var n=e;n;){if(i(n,t))return n;n=n.parentElement}return null}function i(e,t){return(e.matches||e.webkitMatchesSelector||e.msMatchesSelector).call(e,t)}n.d(t,{oq:()=>r,wB:()=>i})},78220:(e,t,n)=>{"use strict";n.d(t,{q:()=>i.qN,H:()=>o});var r=n(15652),i=n(82612);class o extends r.oi{click(){if(this.mdcRoot)return this.mdcRoot.focus(),void this.mdcRoot.click();super.click()}createFoundation(){void 0!==this.mdcFoundation&&this.mdcFoundation.destroy(),this.mdcFoundationClass&&(this.mdcFoundation=new this.mdcFoundationClass(this.createAdapter()),this.mdcFoundation.init())}firstUpdated(){this.createFoundation()}}},82612:(e,t,n)=>{"use strict";n.d(t,{OE:()=>i,f6:()=>o,qN:()=>s,Mh:()=>d,WU:()=>u});var r=n(58014);const i=e=>e.nodeType===Node.ELEMENT_NODE;function o(e,t){for(const n of e.assignedNodes({flatten:!0}))if(i(n)){const e=n;if((0,r.wB)(e,t))return e}return null}function s(e){return{addClass:t=>{e.classList.add(t)},removeClass:t=>{e.classList.remove(t)},hasClass:t=>e.classList.contains(t)}}let a=!1;const l=()=>{},c={get passive(){return a=!0,!1}};document.addEventListener("x",l,c),document.removeEventListener("x",l);const d=(e=window.document)=>{let t=e.activeElement;const n=[];if(!t)return n;for(;t&&(n.push(t),t.shadowRoot);)t=t.shadowRoot.activeElement;return n},u=e=>{const t=d();if(!t.length)return!1;const n=t[t.length-1],r=new Event("check-if-focused",{bubbles:!0,composed:!0});let i=[];const o=e=>{i=e.composedPath()};return document.body.addEventListener("check-if-focused",o),n.dispatchEvent(r),document.body.removeEventListener("check-if-focused",o),-1!==i.indexOf(e)}},3071:(e,t,n)=>{"use strict";n.d(t,{X:()=>a});var r=n(87480),i=(n(70475),n(66702),n(98734)),o=n(15652),s=n(81471);class a extends o.oi{constructor(){super(...arguments),this.raised=!1,this.unelevated=!1,this.outlined=!1,this.dense=!1,this.disabled=!1,this.trailingIcon=!1,this.fullwidth=!1,this.icon="",this.label="",this.expandContent=!1,this.shouldRenderRipple=!1,this.rippleHandlers=new i.A((()=>(this.shouldRenderRipple=!0,this.ripple)))}renderRipple(){const e=this.raised||this.unelevated;return this.shouldRenderRipple?o.dy`<mwc-ripple .primary="${!e}" .disabled="${this.disabled}"></mwc-ripple>`:""}createRenderRoot(){return this.attachShadow({mode:"open",delegatesFocus:!0})}focus(){const e=this.buttonElement;e&&(this.rippleHandlers.startFocus(),e.focus())}blur(){const e=this.buttonElement;e&&(this.rippleHandlers.endFocus(),e.blur())}getRenderClasses(){return(0,s.$)({"mdc-button--raised":this.raised,"mdc-button--unelevated":this.unelevated,"mdc-button--outlined":this.outlined,"mdc-button--dense":this.dense})}render(){return o.dy`
      <button
          id="button"
          class="mdc-button ${this.getRenderClasses()}"
          ?disabled="${this.disabled}"
          aria-label="${this.label||this.icon}"
          @focus="${this.handleRippleFocus}"
          @blur="${this.handleRippleBlur}"
          @mousedown="${this.handleRippleActivate}"
          @mouseenter="${this.handleRippleMouseEnter}"
          @mouseleave="${this.handleRippleMouseLeave}"
          @touchstart="${this.handleRippleActivate}"
          @touchend="${this.handleRippleDeactivate}"
          @touchcancel="${this.handleRippleDeactivate}">
        ${this.renderRipple()}
        <span class="leading-icon">
          <slot name="icon">
            ${this.icon&&!this.trailingIcon?this.renderIcon():""}
          </slot>
        </span>
        <span class="mdc-button__label">${this.label}</span>
        <span class="slot-container ${(0,s.$)({flex:this.expandContent})}">
          <slot></slot>
        </span>
        <span class="trailing-icon">
          <slot name="trailingIcon">
            ${this.icon&&this.trailingIcon?this.renderIcon():""}
          </slot>
        </span>
      </button>`}renderIcon(){return o.dy`
    <mwc-icon class="mdc-button__icon">
      ${this.icon}
    </mwc-icon>`}handleRippleActivate(e){const t=()=>{window.removeEventListener("mouseup",t),this.handleRippleDeactivate()};window.addEventListener("mouseup",t),this.rippleHandlers.startPress(e)}handleRippleDeactivate(){this.rippleHandlers.endPress()}handleRippleMouseEnter(){this.rippleHandlers.startHover()}handleRippleMouseLeave(){this.rippleHandlers.endHover()}handleRippleFocus(){this.rippleHandlers.startFocus()}handleRippleBlur(){this.rippleHandlers.endFocus()}}(0,r.gn)([(0,o.Cb)({type:Boolean})],a.prototype,"raised",void 0),(0,r.gn)([(0,o.Cb)({type:Boolean})],a.prototype,"unelevated",void 0),(0,r.gn)([(0,o.Cb)({type:Boolean})],a.prototype,"outlined",void 0),(0,r.gn)([(0,o.Cb)({type:Boolean})],a.prototype,"dense",void 0),(0,r.gn)([(0,o.Cb)({type:Boolean,reflect:!0})],a.prototype,"disabled",void 0),(0,r.gn)([(0,o.Cb)({type:Boolean,attribute:"trailingicon"})],a.prototype,"trailingIcon",void 0),(0,r.gn)([(0,o.Cb)({type:Boolean,reflect:!0})],a.prototype,"fullwidth",void 0),(0,r.gn)([(0,o.Cb)({type:String})],a.prototype,"icon",void 0),(0,r.gn)([(0,o.Cb)({type:String})],a.prototype,"label",void 0),(0,r.gn)([(0,o.Cb)({type:Boolean})],a.prototype,"expandContent",void 0),(0,r.gn)([(0,o.IO)("#button")],a.prototype,"buttonElement",void 0),(0,r.gn)([(0,o.GC)("mwc-ripple")],a.prototype,"ripple",void 0),(0,r.gn)([(0,o.sz)()],a.prototype,"shouldRenderRipple",void 0),(0,r.gn)([(0,o.hO)({passive:!0})],a.prototype,"handleRippleActivate",null)},53918:(e,t,n)=>{"use strict";var r=n(87480),i=n(15652),o=n(3071),s=n(97591);let a=class extends o.X{};a.styles=s.o,a=(0,r.gn)([(0,i.Mo)("mwc-button")],a)},97591:(e,t,n)=>{"use strict";n.d(t,{o:()=>r});const r=n(15652).iv`.mdc-touch-target-wrapper{display:inline}.mdc-elevation-overlay{position:absolute;border-radius:inherit;pointer-events:none;opacity:0;opacity:var(--mdc-elevation-overlay-opacity, 0);transition:opacity 280ms cubic-bezier(0.4, 0, 0.2, 1);background-color:#fff;background-color:var(--mdc-elevation-overlay-color, #fff)}.mdc-button{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:Roboto, sans-serif;font-family:var(--mdc-typography-button-font-family, var(--mdc-typography-font-family, Roboto, sans-serif));font-size:0.875rem;font-size:var(--mdc-typography-button-font-size, 0.875rem);line-height:2.25rem;line-height:var(--mdc-typography-button-line-height, 2.25rem);font-weight:500;font-weight:var(--mdc-typography-button-font-weight, 500);letter-spacing:0.0892857143em;letter-spacing:var(--mdc-typography-button-letter-spacing, 0.0892857143em);text-decoration:none;text-decoration:var(--mdc-typography-button-text-decoration, none);text-transform:uppercase;text-transform:var(--mdc-typography-button-text-transform, uppercase);padding:0 8px 0 8px;position:relative;display:inline-flex;align-items:center;justify-content:center;box-sizing:border-box;min-width:64px;border:none;outline:none;line-height:inherit;user-select:none;-webkit-appearance:none;overflow:visible;vertical-align:middle;border-radius:4px;border-radius:var(--mdc-shape-small, 4px);height:36px}.mdc-button .mdc-elevation-overlay{width:100%;height:100%;top:0;left:0}.mdc-button::-moz-focus-inner{padding:0;border:0}.mdc-button:active{outline:none}.mdc-button:hover{cursor:pointer}.mdc-button:disabled{cursor:default;pointer-events:none}.mdc-button .mdc-button__ripple{border-radius:4px;border-radius:var(--mdc-shape-small, 4px)}.mdc-button:not(:disabled){background-color:transparent}.mdc-button:disabled{background-color:transparent}.mdc-button .mdc-button__icon{margin-left:0;margin-right:8px;display:inline-block;width:18px;height:18px;font-size:18px;vertical-align:top}[dir=rtl] .mdc-button .mdc-button__icon,.mdc-button .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:0}.mdc-button .mdc-button__touch{position:absolute;top:50%;right:0;height:48px;left:0;transform:translateY(-50%)}.mdc-button:not(:disabled){color:#6200ee;color:var(--mdc-theme-primary, #6200ee)}.mdc-button:disabled{color:rgba(0, 0, 0, 0.38)}.mdc-button__label+.mdc-button__icon{margin-left:8px;margin-right:0}[dir=rtl] .mdc-button__label+.mdc-button__icon,.mdc-button__label+.mdc-button__icon[dir=rtl]{margin-left:0;margin-right:8px}svg.mdc-button__icon{fill:currentColor}.mdc-button--raised .mdc-button__icon,.mdc-button--unelevated .mdc-button__icon,.mdc-button--outlined .mdc-button__icon{margin-left:-4px;margin-right:8px}[dir=rtl] .mdc-button--raised .mdc-button__icon,.mdc-button--raised .mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--unelevated .mdc-button__icon,.mdc-button--unelevated .mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--outlined .mdc-button__icon,.mdc-button--outlined .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:-4px}.mdc-button--raised .mdc-button__label+.mdc-button__icon,.mdc-button--unelevated .mdc-button__label+.mdc-button__icon,.mdc-button--outlined .mdc-button__label+.mdc-button__icon{margin-left:8px;margin-right:-4px}[dir=rtl] .mdc-button--raised .mdc-button__label+.mdc-button__icon,.mdc-button--raised .mdc-button__label+.mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--unelevated .mdc-button__label+.mdc-button__icon,.mdc-button--unelevated .mdc-button__label+.mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--outlined .mdc-button__label+.mdc-button__icon,.mdc-button--outlined .mdc-button__label+.mdc-button__icon[dir=rtl]{margin-left:-4px;margin-right:8px}.mdc-button--raised,.mdc-button--unelevated{padding:0 16px 0 16px}.mdc-button--raised:not(:disabled),.mdc-button--unelevated:not(:disabled){background-color:#6200ee;background-color:var(--mdc-theme-primary, #6200ee)}.mdc-button--raised:not(:disabled),.mdc-button--unelevated:not(:disabled){color:#fff;color:var(--mdc-theme-on-primary, #fff)}.mdc-button--raised:disabled,.mdc-button--unelevated:disabled{background-color:rgba(0, 0, 0, 0.12)}.mdc-button--raised:disabled,.mdc-button--unelevated:disabled{color:rgba(0, 0, 0, 0.38)}.mdc-button--raised{box-shadow:0px 3px 1px -2px rgba(0, 0, 0, 0.2),0px 2px 2px 0px rgba(0, 0, 0, 0.14),0px 1px 5px 0px rgba(0,0,0,.12);transition:box-shadow 280ms cubic-bezier(0.4, 0, 0.2, 1)}.mdc-button--raised:hover,.mdc-button--raised:focus{box-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2),0px 4px 5px 0px rgba(0, 0, 0, 0.14),0px 1px 10px 0px rgba(0,0,0,.12)}.mdc-button--raised:active{box-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),0px 8px 10px 1px rgba(0, 0, 0, 0.14),0px 3px 14px 2px rgba(0,0,0,.12)}.mdc-button--raised:disabled{box-shadow:0px 0px 0px 0px rgba(0, 0, 0, 0.2),0px 0px 0px 0px rgba(0, 0, 0, 0.14),0px 0px 0px 0px rgba(0,0,0,.12)}.mdc-button--outlined{padding:0 15px 0 15px;border-width:1px;border-style:solid}.mdc-button--outlined .mdc-button__ripple{top:-1px;left:-1px;border:1px solid transparent}.mdc-button--outlined .mdc-button__touch{left:-1px;width:calc(100% + 2 * 1px)}.mdc-button--outlined:not(:disabled){border-color:rgba(0, 0, 0, 0.12)}.mdc-button--outlined:disabled{border-color:rgba(0, 0, 0, 0.12)}.mdc-button--touch{margin-top:6px;margin-bottom:6px}:host{display:inline-flex;outline:none;vertical-align:top}:host([fullwidth]){width:100%}:host([raised]),:host([unelevated]){--mdc-ripple-color: #fff;--mdc-ripple-focus-opacity: 0.24;--mdc-ripple-hover-opacity: 0.08;--mdc-ripple-press-opacity: 0.24}.trailing-icon ::slotted(*),.trailing-icon .mdc-button__icon,.leading-icon ::slotted(*),.leading-icon .mdc-button__icon{margin-left:0;margin-right:8px;display:inline-block;width:18px;height:18px;font-size:18px;vertical-align:top}[dir=rtl] .trailing-icon ::slotted(*),.trailing-icon ::slotted(*)[dir=rtl],[dir=rtl] .trailing-icon .mdc-button__icon,.trailing-icon .mdc-button__icon[dir=rtl],[dir=rtl] .leading-icon ::slotted(*),.leading-icon ::slotted(*)[dir=rtl],[dir=rtl] .leading-icon .mdc-button__icon,.leading-icon .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:0}.trailing-icon ::slotted(*),.trailing-icon .mdc-button__icon{margin-left:8px;margin-right:0}[dir=rtl] .trailing-icon ::slotted(*),.trailing-icon ::slotted(*)[dir=rtl],[dir=rtl] .trailing-icon .mdc-button__icon,.trailing-icon .mdc-button__icon[dir=rtl]{margin-left:0;margin-right:8px}.slot-container{display:inline-flex;align-items:center;justify-content:center}.slot-container.flex{flex:auto}.mdc-button{flex:auto;overflow:hidden;padding-left:8px;padding-left:var(--mdc-button-horizontal-padding, 8px);padding-right:8px;padding-right:var(--mdc-button-horizontal-padding, 8px)}.mdc-button--raised{box-shadow:0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow, 0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised:hover,.mdc-button--raised:focus{box-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-hover, 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised:active{box-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2), 0px 8px 10px 1px rgba(0, 0, 0, 0.14), 0px 3px 14px 2px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-active, 0px 5px 5px -3px rgba(0, 0, 0, 0.2), 0px 8px 10px 1px rgba(0, 0, 0, 0.14), 0px 3px 14px 2px rgba(0, 0, 0, 0.12))}.mdc-button--raised:disabled{box-shadow:0px 0px 0px 0px rgba(0, 0, 0, 0.2), 0px 0px 0px 0px rgba(0, 0, 0, 0.14), 0px 0px 0px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-disabled, 0px 0px 0px 0px rgba(0, 0, 0, 0.2), 0px 0px 0px 0px rgba(0, 0, 0, 0.14), 0px 0px 0px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised,.mdc-button--unelevated{padding-left:16px;padding-left:var(--mdc-button-horizontal-padding, 16px);padding-right:16px;padding-right:var(--mdc-button-horizontal-padding, 16px)}.mdc-button--outlined{border-width:1px;border-width:var(--mdc-button-outline-width, 1px);padding-left:calc(16px - 1px);padding-left:calc(var(--mdc-button-horizontal-padding, 16px) - var(--mdc-button-outline-width, 1px));padding-right:calc(16px - 1px);padding-right:calc(var(--mdc-button-horizontal-padding, 16px) - var(--mdc-button-outline-width, 1px))}.mdc-button--outlined:not(:disabled){border-color:rgba(0, 0, 0, 0.12);border-color:var(--mdc-button-outline-color, rgba(0, 0, 0, 0.12))}.mdc-button--outlined mwc-ripple{top:calc(-1 * 1px);top:calc(-1 * var(--mdc-button-outline-width, 1px));left:calc(-1 * 1px);left:calc(-1 * var(--mdc-button-outline-width, 1px));right:initial;border-width:1px;border-width:var(--mdc-button-outline-width, 1px);border-style:solid;border-color:transparent}[dir=rtl] .mdc-button--outlined mwc-ripple,.mdc-button--outlined mwc-ripple[dir=rtl]{left:initial;right:calc(-1 * 1px);right:calc(-1 * var(--mdc-button-outline-width, 1px))}.mdc-button--dense{height:28px;margin-top:0;margin-bottom:0}.mdc-button--dense .mdc-button__touch{display:none}:host([disabled]){pointer-events:none}:host([disabled]) .mdc-button{color:rgba(0, 0, 0, 0.38);color:var(--mdc-button-disabled-ink-color, rgba(0, 0, 0, 0.38))}:host([disabled]) .mdc-button--raised,:host([disabled]) .mdc-button--unelevated{background-color:rgba(0, 0, 0, 0.12);background-color:var(--mdc-button-disabled-fill-color, rgba(0, 0, 0, 0.12))}:host([disabled]) .mdc-button--outlined{border-color:rgba(0, 0, 0, 0.12);border-color:var(--mdc-button-disabled-outline-color, rgba(0, 0, 0, 0.12))}`},82110:(e,t,n)=>{"use strict";n.d(t,{o:()=>r});const r=n(15652).iv`:host{font-family:var(--mdc-icon-font, "Material Icons");font-weight:normal;font-style:normal;font-size:var(--mdc-icon-size, 24px);line-height:1;letter-spacing:normal;text-transform:none;display:inline-block;white-space:nowrap;word-wrap:normal;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:"liga"}`},70475:(e,t,n)=>{"use strict";var r=n(87480),i=n(15652),o=n(82110);let s=class extends i.oi{render(){return i.dy`<slot></slot>`}};s.styles=o.o,s=(0,r.gn)([(0,i.Mo)("mwc-icon")],s)},80927:(e,t,n)=>{"use strict";n.d(t,{L:()=>c});var r=n(87480),i=n(78220),o=n(9698),s=n(15652),a=n(81471),l=n(79865);class c extends i.H{constructor(){super(...arguments),this.primary=!1,this.accent=!1,this.unbounded=!1,this.disabled=!1,this.activated=!1,this.selected=!1,this.hovering=!1,this.bgFocused=!1,this.fgActivation=!1,this.fgDeactivation=!1,this.fgScale="",this.fgSize="",this.translateStart="",this.translateEnd="",this.leftPos="",this.topPos="",this.mdcFoundationClass=o.Z}get isActive(){return(this.parentElement||this).matches(":active")}createAdapter(){return{browserSupportsCssVars:()=>!0,isUnbounded:()=>this.unbounded,isSurfaceActive:()=>this.isActive,isSurfaceDisabled:()=>this.disabled,addClass:e=>{switch(e){case"mdc-ripple-upgraded--background-focused":this.bgFocused=!0;break;case"mdc-ripple-upgraded--foreground-activation":this.fgActivation=!0;break;case"mdc-ripple-upgraded--foreground-deactivation":this.fgDeactivation=!0}},removeClass:e=>{switch(e){case"mdc-ripple-upgraded--background-focused":this.bgFocused=!1;break;case"mdc-ripple-upgraded--foreground-activation":this.fgActivation=!1;break;case"mdc-ripple-upgraded--foreground-deactivation":this.fgDeactivation=!1}},containsEventTarget:()=>!0,registerInteractionHandler:()=>{},deregisterInteractionHandler:()=>{},registerDocumentInteractionHandler:()=>{},deregisterDocumentInteractionHandler:()=>{},registerResizeHandler:()=>{},deregisterResizeHandler:()=>{},updateCssVariable:(e,t)=>{switch(e){case"--mdc-ripple-fg-scale":this.fgScale=t;break;case"--mdc-ripple-fg-size":this.fgSize=t;break;case"--mdc-ripple-fg-translate-end":this.translateEnd=t;break;case"--mdc-ripple-fg-translate-start":this.translateStart=t;break;case"--mdc-ripple-left":this.leftPos=t;break;case"--mdc-ripple-top":this.topPos=t}},computeBoundingRect:()=>(this.parentElement||this).getBoundingClientRect(),getWindowPageOffset:()=>({x:window.pageXOffset,y:window.pageYOffset})}}startPress(e){this.waitForFoundation((()=>{this.mdcFoundation.activate(e)}))}endPress(){this.waitForFoundation((()=>{this.mdcFoundation.deactivate()}))}startFocus(){this.waitForFoundation((()=>{this.mdcFoundation.handleFocus()}))}endFocus(){this.waitForFoundation((()=>{this.mdcFoundation.handleBlur()}))}startHover(){this.hovering=!0}endHover(){this.hovering=!1}waitForFoundation(e){this.mdcFoundation?e():this.updateComplete.then(e)}render(){const e={"mdc-ripple-upgraded--unbounded":this.unbounded,"mdc-ripple-upgraded--background-focused":this.bgFocused,"mdc-ripple-upgraded--foreground-activation":this.fgActivation,"mdc-ripple-upgraded--foreground-deactivation":this.fgDeactivation,hover:this.hovering,primary:this.primary,accent:this.accent,disabled:this.disabled,activated:this.activated,selected:this.selected};return s.dy`
        <div class="mdc-ripple-surface mdc-ripple-upgraded ${(0,a.$)(e)}"
          style="${(0,l.V)({"--mdc-ripple-fg-scale":this.fgScale,"--mdc-ripple-fg-size":this.fgSize,"--mdc-ripple-fg-translate-end":this.translateEnd,"--mdc-ripple-fg-translate-start":this.translateStart,"--mdc-ripple-left":this.leftPos,"--mdc-ripple-top":this.topPos})}"></div>`}}(0,r.gn)([(0,s.IO)(".mdc-ripple-surface")],c.prototype,"mdcRoot",void 0),(0,r.gn)([(0,s.Cb)({type:Boolean})],c.prototype,"primary",void 0),(0,r.gn)([(0,s.Cb)({type:Boolean})],c.prototype,"accent",void 0),(0,r.gn)([(0,s.Cb)({type:Boolean})],c.prototype,"unbounded",void 0),(0,r.gn)([(0,s.Cb)({type:Boolean})],c.prototype,"disabled",void 0),(0,r.gn)([(0,s.Cb)({type:Boolean})],c.prototype,"activated",void 0),(0,r.gn)([(0,s.Cb)({type:Boolean})],c.prototype,"selected",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"hovering",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"bgFocused",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"fgActivation",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"fgDeactivation",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"fgScale",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"fgSize",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"translateStart",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"translateEnd",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"leftPos",void 0),(0,r.gn)([(0,s.sz)()],c.prototype,"topPos",void 0)},85032:(e,t,n)=>{"use strict";n.d(t,{o:()=>r});const r=n(15652).iv`:host{display:block;position:absolute;top:0;bottom:0;left:0;right:0;width:100%;height:100%;pointer-events:none}@keyframes mdc-ripple-fg-radius-in{from{animation-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transform:translate(var(--mdc-ripple-fg-translate-start, 0)) scale(1)}to{transform:translate(var(--mdc-ripple-fg-translate-end, 0)) scale(var(--mdc-ripple-fg-scale, 1))}}@keyframes mdc-ripple-fg-opacity-in{from{animation-timing-function:linear;opacity:0}to{opacity:var(--mdc-ripple-fg-opacity, 0)}}@keyframes mdc-ripple-fg-opacity-out{from{animation-timing-function:linear;opacity:var(--mdc-ripple-fg-opacity, 0)}to{opacity:0}}:host .primary{--mdc-ripple-color: var(--mdc-theme-primary, #6200ee)}:host .accent{--mdc-ripple-color: var( --mdc-theme-secondary, #018786 )}:host .mdc-ripple-surface{top:0;bottom:0;left:0;right:0;width:100%;height:100%;pointer-events:none;--mdc-ripple-fg-size: 0;--mdc-ripple-left: 0;--mdc-ripple-top: 0;--mdc-ripple-fg-scale: 1;--mdc-ripple-fg-translate-end: 0;--mdc-ripple-fg-translate-start: 0;-webkit-tap-highlight-color:rgba(0,0,0,0);will-change:transform,opacity;position:relative;outline:none;overflow:hidden;--mdc-ripple-fg-opacity: var( --mdc-ripple-press-opacity, 0.12 )}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{position:absolute;border-radius:50%;opacity:0;pointer-events:none;content:""}:host .mdc-ripple-surface::before{transition:opacity 15ms linear,background-color 15ms linear;z-index:1}:host .mdc-ripple-surface.mdc-ripple-upgraded::before{transform:scale(var(--mdc-ripple-fg-scale, 1))}:host .mdc-ripple-surface.mdc-ripple-upgraded::after{top:0;left:0;transform:scale(0);transform-origin:center center}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded::after{top:var(--mdc-ripple-top, 0);left:var(--mdc-ripple-left, 0)}:host .mdc-ripple-surface.mdc-ripple-upgraded--foreground-activation::after{animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards}:host .mdc-ripple-surface.mdc-ripple-upgraded--foreground-deactivation::after{animation:mdc-ripple-fg-opacity-out 150ms;transform:translate(var(--mdc-ripple-fg-translate-end, 0)) scale(var(--mdc-ripple-fg-scale, 1))}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{top:calc(50% - 100%);left:calc(50% - 100%);width:200%;height:200%}:host .mdc-ripple-surface.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded{overflow:visible}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded::before,:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded::after{top:calc(50% - 50%);left:calc(50% - 50%);width:100%;height:100%}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::before,:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::after{top:var(--mdc-ripple-top, calc(50% - 50%));left:var(--mdc-ripple-left, calc(50% - 50%));width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}:host .mdc-ripple-surface.hover::before{opacity:0.04;opacity:var(--mdc-ripple-hover-opacity, 0.04)}:host .mdc-ripple-surface.mdc-ripple-upgraded--background-focused::before{opacity:0.12;opacity:var(--mdc-ripple-focus-opacity, 0.12)}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{background-color:#000;background-color:var(--mdc-ripple-color, #000)}:host .mdc-ripple-surface.activated{--mdc-ripple-press-opacity: calc( var(--mdc-ripple-press-opacity, 0.12) + 0.12 )}:host .mdc-ripple-surface.activated::before{opacity:0.12;opacity:var(--mdc-ripple-activated-opacity, 0.12)}:host .mdc-ripple-surface.activated.hover::before{opacity:.16;opacity:calc( var(--mdc-ripple-hover-opacity, 0.04) + var(--mdc-ripple-activated-opacity, 0.12) )}:host .mdc-ripple-surface.activated.mdc-ripple-upgraded--background-focused::before{opacity:.24;opacity:calc( var(--mdc-ripple-focus-opacity, 0.12) + var(--mdc-ripple-activated-opacity, 0.12) )}:host .mdc-ripple-surface.selected{--mdc-ripple-press-opacity: calc( var(--mdc-ripple-press-opacity, 0.12) + 0.08 )}:host .mdc-ripple-surface.selected::before{opacity:0.08;opacity:var(--mdc-ripple-selected-opacity, 0.08)}:host .mdc-ripple-surface.selected.hover::before{opacity:.12;opacity:calc( var(--mdc-ripple-hover-opacity, 0.04) + var(--mdc-ripple-selected-opacity, 0.08) )}:host .mdc-ripple-surface.selected.mdc-ripple-upgraded--background-focused::before{opacity:.2;opacity:calc( var(--mdc-ripple-focus-opacity, 0.12) + var(--mdc-ripple-selected-opacity, 0.08) )}:host .mdc-ripple-surface.disabled{--mdc-ripple-color: transparent}:host .mdc-ripple-surface::before{z-index:1;z-index:var(--m-ripple-z-index, 1)}:host .mdc-ripple-surface::after{z-index:0;z-index:var(--m-ripple-z-index, 0)}`},66702:(e,t,n)=>{"use strict";var r=n(87480),i=n(15652),o=n(80927),s=n(85032);let a=class extends o.L{};a.styles=s.o,a=(0,r.gn)([(0,i.Mo)("mwc-ripple")],a)},98734:(e,t,n)=>{"use strict";n.d(t,{A:()=>r});class r{constructor(e){this.startPress=t=>{e().then((e=>{e&&e.startPress(t)}))},this.endPress=()=>{e().then((e=>{e&&e.endPress()}))},this.startFocus=()=>{e().then((e=>{e&&e.startFocus()}))},this.endFocus=()=>{e().then((e=>{e&&e.endFocus()}))},this.startHover=()=>{e().then((e=>{e&&e.startHover()}))},this.endHover=()=>{e().then((e=>{e&&e.endHover()}))}}}},56071:(e,t,n)=>{"use strict";n.d(t,{UX:()=>r,j2:()=>i,KT:()=>o});var r={BG_FOCUSED:"mdc-ripple-upgraded--background-focused",FG_ACTIVATION:"mdc-ripple-upgraded--foreground-activation",FG_DEACTIVATION:"mdc-ripple-upgraded--foreground-deactivation",ROOT:"mdc-ripple-upgraded",UNBOUNDED:"mdc-ripple-upgraded--unbounded"},i={VAR_FG_SCALE:"--mdc-ripple-fg-scale",VAR_FG_SIZE:"--mdc-ripple-fg-size",VAR_FG_TRANSLATE_END:"--mdc-ripple-fg-translate-end",VAR_FG_TRANSLATE_START:"--mdc-ripple-fg-translate-start",VAR_LEFT:"--mdc-ripple-left",VAR_TOP:"--mdc-ripple-top"},o={DEACTIVATION_TIMEOUT_MS:225,FG_DEACTIVATION_MS:150,INITIAL_ORIGIN_SCALE:.6,PADDING:10,TAP_DELAY_MS:300}},9698:(e,t,n)=>{"use strict";n.d(t,{Z:()=>d});var r=n(87480),i=n(72774),o=n(56071),s=n(84445),a=["touchstart","pointerdown","mousedown","keydown"],l=["touchend","pointerup","mouseup","contextmenu"],c=[];const d=function(e){function t(n){var i=e.call(this,(0,r.pi)((0,r.pi)({},t.defaultAdapter),n))||this;return i.activationAnimationHasEnded_=!1,i.activationTimer_=0,i.fgDeactivationRemovalTimer_=0,i.fgScale_="0",i.frame_={width:0,height:0},i.initialSize_=0,i.layoutFrame_=0,i.maxRadius_=0,i.unboundedCoords_={left:0,top:0},i.activationState_=i.defaultActivationState_(),i.activationTimerCallback_=function(){i.activationAnimationHasEnded_=!0,i.runDeactivationUXLogicIfReady_()},i.activateHandler_=function(e){return i.activate_(e)},i.deactivateHandler_=function(){return i.deactivate_()},i.focusHandler_=function(){return i.handleFocus()},i.blurHandler_=function(){return i.handleBlur()},i.resizeHandler_=function(){return i.layout()},i}return(0,r.ZT)(t,e),Object.defineProperty(t,"cssClasses",{get:function(){return o.UX},enumerable:!0,configurable:!0}),Object.defineProperty(t,"strings",{get:function(){return o.j2},enumerable:!0,configurable:!0}),Object.defineProperty(t,"numbers",{get:function(){return o.KT},enumerable:!0,configurable:!0}),Object.defineProperty(t,"defaultAdapter",{get:function(){return{addClass:function(){},browserSupportsCssVars:function(){return!0},computeBoundingRect:function(){return{top:0,right:0,bottom:0,left:0,width:0,height:0}},containsEventTarget:function(){return!0},deregisterDocumentInteractionHandler:function(){},deregisterInteractionHandler:function(){},deregisterResizeHandler:function(){},getWindowPageOffset:function(){return{x:0,y:0}},isSurfaceActive:function(){return!0},isSurfaceDisabled:function(){return!0},isUnbounded:function(){return!0},registerDocumentInteractionHandler:function(){},registerInteractionHandler:function(){},registerResizeHandler:function(){},removeClass:function(){},updateCssVariable:function(){}}},enumerable:!0,configurable:!0}),t.prototype.init=function(){var e=this,n=this.supportsPressRipple_();if(this.registerRootHandlers_(n),n){var r=t.cssClasses,i=r.ROOT,o=r.UNBOUNDED;requestAnimationFrame((function(){e.adapter.addClass(i),e.adapter.isUnbounded()&&(e.adapter.addClass(o),e.layoutInternal_())}))}},t.prototype.destroy=function(){var e=this;if(this.supportsPressRipple_()){this.activationTimer_&&(clearTimeout(this.activationTimer_),this.activationTimer_=0,this.adapter.removeClass(t.cssClasses.FG_ACTIVATION)),this.fgDeactivationRemovalTimer_&&(clearTimeout(this.fgDeactivationRemovalTimer_),this.fgDeactivationRemovalTimer_=0,this.adapter.removeClass(t.cssClasses.FG_DEACTIVATION));var n=t.cssClasses,r=n.ROOT,i=n.UNBOUNDED;requestAnimationFrame((function(){e.adapter.removeClass(r),e.adapter.removeClass(i),e.removeCssVars_()}))}this.deregisterRootHandlers_(),this.deregisterDeactivationHandlers_()},t.prototype.activate=function(e){this.activate_(e)},t.prototype.deactivate=function(){this.deactivate_()},t.prototype.layout=function(){var e=this;this.layoutFrame_&&cancelAnimationFrame(this.layoutFrame_),this.layoutFrame_=requestAnimationFrame((function(){e.layoutInternal_(),e.layoutFrame_=0}))},t.prototype.setUnbounded=function(e){var n=t.cssClasses.UNBOUNDED;e?this.adapter.addClass(n):this.adapter.removeClass(n)},t.prototype.handleFocus=function(){var e=this;requestAnimationFrame((function(){return e.adapter.addClass(t.cssClasses.BG_FOCUSED)}))},t.prototype.handleBlur=function(){var e=this;requestAnimationFrame((function(){return e.adapter.removeClass(t.cssClasses.BG_FOCUSED)}))},t.prototype.supportsPressRipple_=function(){return this.adapter.browserSupportsCssVars()},t.prototype.defaultActivationState_=function(){return{activationEvent:void 0,hasDeactivationUXRun:!1,isActivated:!1,isProgrammatic:!1,wasActivatedByPointer:!1,wasElementMadeActive:!1}},t.prototype.registerRootHandlers_=function(e){var t=this;e&&(a.forEach((function(e){t.adapter.registerInteractionHandler(e,t.activateHandler_)})),this.adapter.isUnbounded()&&this.adapter.registerResizeHandler(this.resizeHandler_)),this.adapter.registerInteractionHandler("focus",this.focusHandler_),this.adapter.registerInteractionHandler("blur",this.blurHandler_)},t.prototype.registerDeactivationHandlers_=function(e){var t=this;"keydown"===e.type?this.adapter.registerInteractionHandler("keyup",this.deactivateHandler_):l.forEach((function(e){t.adapter.registerDocumentInteractionHandler(e,t.deactivateHandler_)}))},t.prototype.deregisterRootHandlers_=function(){var e=this;a.forEach((function(t){e.adapter.deregisterInteractionHandler(t,e.activateHandler_)})),this.adapter.deregisterInteractionHandler("focus",this.focusHandler_),this.adapter.deregisterInteractionHandler("blur",this.blurHandler_),this.adapter.isUnbounded()&&this.adapter.deregisterResizeHandler(this.resizeHandler_)},t.prototype.deregisterDeactivationHandlers_=function(){var e=this;this.adapter.deregisterInteractionHandler("keyup",this.deactivateHandler_),l.forEach((function(t){e.adapter.deregisterDocumentInteractionHandler(t,e.deactivateHandler_)}))},t.prototype.removeCssVars_=function(){var e=this,n=t.strings;Object.keys(n).forEach((function(t){0===t.indexOf("VAR_")&&e.adapter.updateCssVariable(n[t],null)}))},t.prototype.activate_=function(e){var t=this;if(!this.adapter.isSurfaceDisabled()){var n=this.activationState_;if(!n.isActivated){var r=this.previousActivationEvent_;if(!(r&&void 0!==e&&r.type!==e.type))n.isActivated=!0,n.isProgrammatic=void 0===e,n.activationEvent=e,n.wasActivatedByPointer=!n.isProgrammatic&&(void 0!==e&&("mousedown"===e.type||"touchstart"===e.type||"pointerdown"===e.type)),void 0!==e&&c.length>0&&c.some((function(e){return t.adapter.containsEventTarget(e)}))?this.resetActivationState_():(void 0!==e&&(c.push(e.target),this.registerDeactivationHandlers_(e)),n.wasElementMadeActive=this.checkElementMadeActive_(e),n.wasElementMadeActive&&this.animateActivation_(),requestAnimationFrame((function(){c=[],n.wasElementMadeActive||void 0===e||" "!==e.key&&32!==e.keyCode||(n.wasElementMadeActive=t.checkElementMadeActive_(e),n.wasElementMadeActive&&t.animateActivation_()),n.wasElementMadeActive||(t.activationState_=t.defaultActivationState_())})))}}},t.prototype.checkElementMadeActive_=function(e){return void 0===e||"keydown"!==e.type||this.adapter.isSurfaceActive()},t.prototype.animateActivation_=function(){var e=this,n=t.strings,r=n.VAR_FG_TRANSLATE_START,i=n.VAR_FG_TRANSLATE_END,o=t.cssClasses,s=o.FG_DEACTIVATION,a=o.FG_ACTIVATION,l=t.numbers.DEACTIVATION_TIMEOUT_MS;this.layoutInternal_();var c="",d="";if(!this.adapter.isUnbounded()){var u=this.getFgTranslationCoordinates_(),p=u.startPoint,h=u.endPoint;c=p.x+"px, "+p.y+"px",d=h.x+"px, "+h.y+"px"}this.adapter.updateCssVariable(r,c),this.adapter.updateCssVariable(i,d),clearTimeout(this.activationTimer_),clearTimeout(this.fgDeactivationRemovalTimer_),this.rmBoundedActivationClasses_(),this.adapter.removeClass(s),this.adapter.computeBoundingRect(),this.adapter.addClass(a),this.activationTimer_=setTimeout((function(){return e.activationTimerCallback_()}),l)},t.prototype.getFgTranslationCoordinates_=function(){var e,t=this.activationState_,n=t.activationEvent;return{startPoint:e={x:(e=t.wasActivatedByPointer?(0,s.Y)(n,this.adapter.getWindowPageOffset(),this.adapter.computeBoundingRect()):{x:this.frame_.width/2,y:this.frame_.height/2}).x-this.initialSize_/2,y:e.y-this.initialSize_/2},endPoint:{x:this.frame_.width/2-this.initialSize_/2,y:this.frame_.height/2-this.initialSize_/2}}},t.prototype.runDeactivationUXLogicIfReady_=function(){var e=this,n=t.cssClasses.FG_DEACTIVATION,r=this.activationState_,i=r.hasDeactivationUXRun,s=r.isActivated;(i||!s)&&this.activationAnimationHasEnded_&&(this.rmBoundedActivationClasses_(),this.adapter.addClass(n),this.fgDeactivationRemovalTimer_=setTimeout((function(){e.adapter.removeClass(n)}),o.KT.FG_DEACTIVATION_MS))},t.prototype.rmBoundedActivationClasses_=function(){var e=t.cssClasses.FG_ACTIVATION;this.adapter.removeClass(e),this.activationAnimationHasEnded_=!1,this.adapter.computeBoundingRect()},t.prototype.resetActivationState_=function(){var e=this;this.previousActivationEvent_=this.activationState_.activationEvent,this.activationState_=this.defaultActivationState_(),setTimeout((function(){return e.previousActivationEvent_=void 0}),t.numbers.TAP_DELAY_MS)},t.prototype.deactivate_=function(){var e=this,t=this.activationState_;if(t.isActivated){var n=(0,r.pi)({},t);t.isProgrammatic?(requestAnimationFrame((function(){return e.animateDeactivation_(n)})),this.resetActivationState_()):(this.deregisterDeactivationHandlers_(),requestAnimationFrame((function(){e.activationState_.hasDeactivationUXRun=!0,e.animateDeactivation_(n),e.resetActivationState_()})))}},t.prototype.animateDeactivation_=function(e){var t=e.wasActivatedByPointer,n=e.wasElementMadeActive;(t||n)&&this.runDeactivationUXLogicIfReady_()},t.prototype.layoutInternal_=function(){var e=this;this.frame_=this.adapter.computeBoundingRect();var n=Math.max(this.frame_.height,this.frame_.width);this.maxRadius_=this.adapter.isUnbounded()?n:Math.sqrt(Math.pow(e.frame_.width,2)+Math.pow(e.frame_.height,2))+t.numbers.PADDING;var r=Math.floor(n*t.numbers.INITIAL_ORIGIN_SCALE);this.adapter.isUnbounded()&&r%2!=0?this.initialSize_=r-1:this.initialSize_=r,this.fgScale_=""+this.maxRadius_/this.initialSize_,this.updateLayoutCssVars_()},t.prototype.updateLayoutCssVars_=function(){var e=t.strings,n=e.VAR_FG_SIZE,r=e.VAR_LEFT,i=e.VAR_TOP,o=e.VAR_FG_SCALE;this.adapter.updateCssVariable(n,this.initialSize_+"px"),this.adapter.updateCssVariable(o,this.fgScale_),this.adapter.isUnbounded()&&(this.unboundedCoords_={left:Math.round(this.frame_.width/2-this.initialSize_/2),top:Math.round(this.frame_.height/2-this.initialSize_/2)},this.adapter.updateCssVariable(r,this.unboundedCoords_.left+"px"),this.adapter.updateCssVariable(i,this.unboundedCoords_.top+"px"))},t}(i.K)},84445:(e,t,n)=>{"use strict";var r;function i(e,t){void 0===t&&(t=!1);var n,i=e.CSS;if("boolean"==typeof r&&!t)return r;if(!(i&&"function"==typeof i.supports))return!1;var o=i.supports("--css-vars","yes"),s=i.supports("(--css-vars: yes)")&&i.supports("color","#00000000");return n=o||s,t||(r=n),n}function o(e,t,n){if(!e)return{x:0,y:0};var r,i,o=t.x,s=t.y,a=o+n.left,l=s+n.top;if("touchstart"===e.type){var c=e;r=c.changedTouches[0].pageX-a,i=c.changedTouches[0].pageY-l}else{var d=e;r=d.pageX-a,i=d.pageY-l}return{x:r,y:i}}n.d(t,{x:()=>i,Y:()=>o})},23916:(e,t,n)=>{"use strict";n.d(t,{N:()=>o});n(43437);var r=n(9672),i=n(50856);const o=(0,r.k)({_template:i.d`
    <style>
      :host {
        display: inline-block;
        position: fixed;
        clip: rect(0px,0px,0px,0px);
      }
    </style>
    <div aria-live$="[[mode]]">[[_text]]</div>
`,is:"iron-a11y-announcer",properties:{mode:{type:String,value:"polite"},_text:{type:String,value:""}},created:function(){o.instance||(o.instance=this),document.body.addEventListener("iron-announce",this._onIronAnnounce.bind(this))},announce:function(e){this._text="",this.async((function(){this._text=e}),100)},_onIronAnnounce:function(e){e.detail&&e.detail.text&&this.announce(e.detail.text)}});o.instance=null,o.requestAvailability=function(){o.instance||(o.instance=document.createElement("iron-a11y-announcer")),document.body.appendChild(o.instance)}},8621:(e,t,n)=>{"use strict";n.d(t,{G:()=>m});n(43437);var r={"U+0008":"backspace","U+0009":"tab","U+001B":"esc","U+0020":"space","U+007F":"del"},i={8:"backspace",9:"tab",13:"enter",27:"esc",33:"pageup",34:"pagedown",35:"end",36:"home",32:"space",37:"left",38:"up",39:"right",40:"down",46:"del",106:"*"},o={shift:"shiftKey",ctrl:"ctrlKey",alt:"altKey",meta:"metaKey"},s=/[a-z0-9*]/,a=/U\+/,l=/^arrow/,c=/^space(bar)?/,d=/^escape$/;function u(e,t){var n="";if(e){var r=e.toLowerCase();" "===r||c.test(r)?n="space":d.test(r)?n="esc":1==r.length?t&&!s.test(r)||(n=r):n=l.test(r)?r.replace("arrow",""):"multiply"==r?"*":r}return n}function p(e,t){return e.key?u(e.key,t):e.detail&&e.detail.key?u(e.detail.key,t):(n=e.keyIdentifier,o="",n&&(n in r?o=r[n]:a.test(n)?(n=parseInt(n.replace("U+","0x"),16),o=String.fromCharCode(n).toLowerCase()):o=n.toLowerCase()),o||function(e){var t="";return Number(e)&&(t=e>=65&&e<=90?String.fromCharCode(32+e):e>=112&&e<=123?"f"+(e-112+1):e>=48&&e<=57?String(e-48):e>=96&&e<=105?String(e-96):i[e]),t}(e.keyCode)||"");var n,o}function h(e,t){return p(t,e.hasModifiers)===e.key&&(!e.hasModifiers||!!t.shiftKey==!!e.shiftKey&&!!t.ctrlKey==!!e.ctrlKey&&!!t.altKey==!!e.altKey&&!!t.metaKey==!!e.metaKey)}function f(e){return e.trim().split(" ").map((function(e){return function(e){return 1===e.length?{combo:e,key:e,event:"keydown"}:e.split("+").reduce((function(e,t){var n=t.split(":"),r=n[0],i=n[1];return r in o?(e[o[r]]=!0,e.hasModifiers=!0):(e.key=r,e.event=i||"keydown"),e}),{combo:e.split(":").shift()})}(e)}))}const m={properties:{keyEventTarget:{type:Object,value:function(){return this}},stopKeyboardEventPropagation:{type:Boolean,value:!1},_boundKeyHandlers:{type:Array,value:function(){return[]}},_imperativeKeyBindings:{type:Object,value:function(){return{}}}},observers:["_resetKeyEventListeners(keyEventTarget, _boundKeyHandlers)"],keyBindings:{},registered:function(){this._prepKeyBindings()},attached:function(){this._listenKeyEventListeners()},detached:function(){this._unlistenKeyEventListeners()},addOwnKeyBinding:function(e,t){this._imperativeKeyBindings[e]=t,this._prepKeyBindings(),this._resetKeyEventListeners()},removeOwnKeyBindings:function(){this._imperativeKeyBindings={},this._prepKeyBindings(),this._resetKeyEventListeners()},keyboardEventMatchesKeys:function(e,t){for(var n=f(t),r=0;r<n.length;++r)if(h(n[r],e))return!0;return!1},_collectKeyBindings:function(){var e=this.behaviors.map((function(e){return e.keyBindings}));return-1===e.indexOf(this.keyBindings)&&e.push(this.keyBindings),e},_prepKeyBindings:function(){for(var e in this._keyBindings={},this._collectKeyBindings().forEach((function(e){for(var t in e)this._addKeyBinding(t,e[t])}),this),this._imperativeKeyBindings)this._addKeyBinding(e,this._imperativeKeyBindings[e]);for(var t in this._keyBindings)this._keyBindings[t].sort((function(e,t){var n=e[0].hasModifiers;return n===t[0].hasModifiers?0:n?-1:1}))},_addKeyBinding:function(e,t){f(e).forEach((function(e){this._keyBindings[e.event]=this._keyBindings[e.event]||[],this._keyBindings[e.event].push([e,t])}),this)},_resetKeyEventListeners:function(){this._unlistenKeyEventListeners(),this.isAttached&&this._listenKeyEventListeners()},_listenKeyEventListeners:function(){this.keyEventTarget&&Object.keys(this._keyBindings).forEach((function(e){var t=this._keyBindings[e],n=this._onKeyBindingEvent.bind(this,t);this._boundKeyHandlers.push([this.keyEventTarget,e,n]),this.keyEventTarget.addEventListener(e,n)}),this)},_unlistenKeyEventListeners:function(){for(var e,t,n,r;this._boundKeyHandlers.length;)t=(e=this._boundKeyHandlers.pop())[0],n=e[1],r=e[2],t.removeEventListener(n,r)},_onKeyBindingEvent:function(e,t){if(this.stopKeyboardEventPropagation&&t.stopPropagation(),!t.defaultPrevented)for(var n=0;n<e.length;n++){var r=e[n][0],i=e[n][1];if(h(r,t)&&(this._triggerKeyHandler(r,i,t),t.defaultPrevented))return}},_triggerKeyHandler:function(e,t,n){var r=Object.create(e);r.keyboardEvent=n;var i=new CustomEvent(e.event,{detail:r,cancelable:!0});this[t].call(this,i),i.defaultPrevented&&n.preventDefault()}}},26110:(e,t,n)=>{"use strict";n.d(t,{a:()=>r});n(43437),n(87156);const r={properties:{focused:{type:Boolean,value:!1,notify:!0,readOnly:!0,reflectToAttribute:!0},disabled:{type:Boolean,value:!1,notify:!0,observer:"_disabledChanged",reflectToAttribute:!0},_oldTabIndex:{type:String},_boundFocusBlurHandler:{type:Function,value:function(){return this._focusBlurHandler.bind(this)}}},observers:["_changedControlState(focused, disabled)"],ready:function(){this.addEventListener("focus",this._boundFocusBlurHandler,!0),this.addEventListener("blur",this._boundFocusBlurHandler,!0)},_focusBlurHandler:function(e){this._setFocused("focus"===e.type)},_disabledChanged:function(e,t){this.setAttribute("aria-disabled",e?"true":"false"),this.style.pointerEvents=e?"none":"",e?(this._oldTabIndex=this.getAttribute("tabindex"),this._setFocused(!1),this.tabIndex=-1,this.blur()):void 0!==this._oldTabIndex&&(null===this._oldTabIndex?this.removeAttribute("tabindex"):this.setAttribute("tabindex",this._oldTabIndex))},_changedControlState:function(){this._controlStateChanged&&this._controlStateChanged()}}},65660:(e,t,n)=>{"use strict";n(43437);const r=n(50856).d`
<custom-style>
  <style is="custom-style">
    [hidden] {
      display: none !important;
    }
  </style>
</custom-style>
<custom-style>
  <style is="custom-style">
    html {

      --layout: {
        display: -ms-flexbox;
        display: -webkit-flex;
        display: flex;
      };

      --layout-inline: {
        display: -ms-inline-flexbox;
        display: -webkit-inline-flex;
        display: inline-flex;
      };

      --layout-horizontal: {
        @apply --layout;

        -ms-flex-direction: row;
        -webkit-flex-direction: row;
        flex-direction: row;
      };

      --layout-horizontal-reverse: {
        @apply --layout;

        -ms-flex-direction: row-reverse;
        -webkit-flex-direction: row-reverse;
        flex-direction: row-reverse;
      };

      --layout-vertical: {
        @apply --layout;

        -ms-flex-direction: column;
        -webkit-flex-direction: column;
        flex-direction: column;
      };

      --layout-vertical-reverse: {
        @apply --layout;

        -ms-flex-direction: column-reverse;
        -webkit-flex-direction: column-reverse;
        flex-direction: column-reverse;
      };

      --layout-wrap: {
        -ms-flex-wrap: wrap;
        -webkit-flex-wrap: wrap;
        flex-wrap: wrap;
      };

      --layout-wrap-reverse: {
        -ms-flex-wrap: wrap-reverse;
        -webkit-flex-wrap: wrap-reverse;
        flex-wrap: wrap-reverse;
      };

      --layout-flex-auto: {
        -ms-flex: 1 1 auto;
        -webkit-flex: 1 1 auto;
        flex: 1 1 auto;
      };

      --layout-flex-none: {
        -ms-flex: none;
        -webkit-flex: none;
        flex: none;
      };

      --layout-flex: {
        -ms-flex: 1 1 0.000000001px;
        -webkit-flex: 1;
        flex: 1;
        -webkit-flex-basis: 0.000000001px;
        flex-basis: 0.000000001px;
      };

      --layout-flex-2: {
        -ms-flex: 2;
        -webkit-flex: 2;
        flex: 2;
      };

      --layout-flex-3: {
        -ms-flex: 3;
        -webkit-flex: 3;
        flex: 3;
      };

      --layout-flex-4: {
        -ms-flex: 4;
        -webkit-flex: 4;
        flex: 4;
      };

      --layout-flex-5: {
        -ms-flex: 5;
        -webkit-flex: 5;
        flex: 5;
      };

      --layout-flex-6: {
        -ms-flex: 6;
        -webkit-flex: 6;
        flex: 6;
      };

      --layout-flex-7: {
        -ms-flex: 7;
        -webkit-flex: 7;
        flex: 7;
      };

      --layout-flex-8: {
        -ms-flex: 8;
        -webkit-flex: 8;
        flex: 8;
      };

      --layout-flex-9: {
        -ms-flex: 9;
        -webkit-flex: 9;
        flex: 9;
      };

      --layout-flex-10: {
        -ms-flex: 10;
        -webkit-flex: 10;
        flex: 10;
      };

      --layout-flex-11: {
        -ms-flex: 11;
        -webkit-flex: 11;
        flex: 11;
      };

      --layout-flex-12: {
        -ms-flex: 12;
        -webkit-flex: 12;
        flex: 12;
      };

      /* alignment in cross axis */

      --layout-start: {
        -ms-flex-align: start;
        -webkit-align-items: flex-start;
        align-items: flex-start;
      };

      --layout-center: {
        -ms-flex-align: center;
        -webkit-align-items: center;
        align-items: center;
      };

      --layout-end: {
        -ms-flex-align: end;
        -webkit-align-items: flex-end;
        align-items: flex-end;
      };

      --layout-baseline: {
        -ms-flex-align: baseline;
        -webkit-align-items: baseline;
        align-items: baseline;
      };

      /* alignment in main axis */

      --layout-start-justified: {
        -ms-flex-pack: start;
        -webkit-justify-content: flex-start;
        justify-content: flex-start;
      };

      --layout-center-justified: {
        -ms-flex-pack: center;
        -webkit-justify-content: center;
        justify-content: center;
      };

      --layout-end-justified: {
        -ms-flex-pack: end;
        -webkit-justify-content: flex-end;
        justify-content: flex-end;
      };

      --layout-around-justified: {
        -ms-flex-pack: distribute;
        -webkit-justify-content: space-around;
        justify-content: space-around;
      };

      --layout-justified: {
        -ms-flex-pack: justify;
        -webkit-justify-content: space-between;
        justify-content: space-between;
      };

      --layout-center-center: {
        @apply --layout-center;
        @apply --layout-center-justified;
      };

      /* self alignment */

      --layout-self-start: {
        -ms-align-self: flex-start;
        -webkit-align-self: flex-start;
        align-self: flex-start;
      };

      --layout-self-center: {
        -ms-align-self: center;
        -webkit-align-self: center;
        align-self: center;
      };

      --layout-self-end: {
        -ms-align-self: flex-end;
        -webkit-align-self: flex-end;
        align-self: flex-end;
      };

      --layout-self-stretch: {
        -ms-align-self: stretch;
        -webkit-align-self: stretch;
        align-self: stretch;
      };

      --layout-self-baseline: {
        -ms-align-self: baseline;
        -webkit-align-self: baseline;
        align-self: baseline;
      };

      /* multi-line alignment in main axis */

      --layout-start-aligned: {
        -ms-flex-line-pack: start;  /* IE10 */
        -ms-align-content: flex-start;
        -webkit-align-content: flex-start;
        align-content: flex-start;
      };

      --layout-end-aligned: {
        -ms-flex-line-pack: end;  /* IE10 */
        -ms-align-content: flex-end;
        -webkit-align-content: flex-end;
        align-content: flex-end;
      };

      --layout-center-aligned: {
        -ms-flex-line-pack: center;  /* IE10 */
        -ms-align-content: center;
        -webkit-align-content: center;
        align-content: center;
      };

      --layout-between-aligned: {
        -ms-flex-line-pack: justify;  /* IE10 */
        -ms-align-content: space-between;
        -webkit-align-content: space-between;
        align-content: space-between;
      };

      --layout-around-aligned: {
        -ms-flex-line-pack: distribute;  /* IE10 */
        -ms-align-content: space-around;
        -webkit-align-content: space-around;
        align-content: space-around;
      };

      /*******************************
                Other Layout
      *******************************/

      --layout-block: {
        display: block;
      };

      --layout-invisible: {
        visibility: hidden !important;
      };

      --layout-relative: {
        position: relative;
      };

      --layout-fit: {
        position: absolute;
        top: 0;
        right: 0;
        bottom: 0;
        left: 0;
      };

      --layout-scroll: {
        -webkit-overflow-scrolling: touch;
        overflow: auto;
      };

      --layout-fullbleed: {
        margin: 0;
        height: 100vh;
      };

      /* fixed position */

      --layout-fixed-top: {
        position: fixed;
        top: 0;
        left: 0;
        right: 0;
      };

      --layout-fixed-right: {
        position: fixed;
        top: 0;
        right: 0;
        bottom: 0;
      };

      --layout-fixed-bottom: {
        position: fixed;
        right: 0;
        bottom: 0;
        left: 0;
      };

      --layout-fixed-left: {
        position: fixed;
        top: 0;
        bottom: 0;
        left: 0;
      };

    }
  </style>
</custom-style>`;r.setAttribute("style","display: none;"),document.head.appendChild(r.content);var i=document.createElement("style");i.textContent="[hidden] { display: none !important; }",document.head.appendChild(i)},21006:(e,t,n)=>{"use strict";n.d(t,{V:()=>r});n(43437);const r={properties:{name:{type:String},value:{notify:!0,type:String},required:{type:Boolean,value:!1}},attached:function(){},detached:function(){}}},87772:(e,t,n)=>{"use strict";n(43437);var r=n(23916),i=n(98235),o=n(9672),s=n(87156),a=n(50856);(0,o.k)({_template:a.d`
    <style>
      :host {
        display: inline-block;
      }
    </style>
    <slot id="content"></slot>
`,is:"iron-input",behaviors:[i.x],properties:{bindValue:{type:String,value:""},value:{type:String,computed:"_computeValue(bindValue)"},allowedPattern:{type:String},autoValidate:{type:Boolean,value:!1},_inputElement:Object},observers:["_bindValueChanged(bindValue, _inputElement)"],listeners:{input:"_onInput",keypress:"_onKeypress"},created:function(){r.N.requestAvailability(),this._previousValidInput="",this._patternAlreadyChecked=!1},attached:function(){this._observer=(0,s.vz)(this).observeNodes(function(e){this._initSlottedInput()}.bind(this))},detached:function(){this._observer&&((0,s.vz)(this).unobserveNodes(this._observer),this._observer=null)},get inputElement(){return this._inputElement},_initSlottedInput:function(){this._inputElement=this.getEffectiveChildren()[0],this.inputElement&&this.inputElement.value&&(this.bindValue=this.inputElement.value),this.fire("iron-input-ready")},get _patternRegExp(){var e;if(this.allowedPattern)e=new RegExp(this.allowedPattern);else switch(this.inputElement.type){case"number":e=/[0-9.,e-]/}return e},_bindValueChanged:function(e,t){t&&(void 0===e?t.value=null:e!==t.value&&(this.inputElement.value=e),this.autoValidate&&this.validate(),this.fire("bind-value-changed",{value:e}))},_onInput:function(){this.allowedPattern&&!this._patternAlreadyChecked&&(this._checkPatternValidity()||(this._announceInvalidCharacter("Invalid string of characters not entered."),this.inputElement.value=this._previousValidInput));this.bindValue=this._previousValidInput=this.inputElement.value,this._patternAlreadyChecked=!1},_isPrintable:function(e){var t=8==e.keyCode||9==e.keyCode||13==e.keyCode||27==e.keyCode,n=19==e.keyCode||20==e.keyCode||45==e.keyCode||46==e.keyCode||144==e.keyCode||145==e.keyCode||e.keyCode>32&&e.keyCode<41||e.keyCode>111&&e.keyCode<124;return!(t||0==e.charCode&&n)},_onKeypress:function(e){if(this.allowedPattern||"number"===this.inputElement.type){var t=this._patternRegExp;if(t&&!(e.metaKey||e.ctrlKey||e.altKey)){this._patternAlreadyChecked=!0;var n=String.fromCharCode(e.charCode);this._isPrintable(e)&&!t.test(n)&&(e.preventDefault(),this._announceInvalidCharacter("Invalid character "+n+" not entered."))}}},_checkPatternValidity:function(){var e=this._patternRegExp;if(!e)return!0;for(var t=0;t<this.inputElement.value.length;t++)if(!e.test(this.inputElement.value[t]))return!1;return!0},validate:function(){if(!this.inputElement)return this.invalid=!1,!0;var e=this.inputElement.checkValidity();return e&&(this.required&&""===this.bindValue?e=!1:this.hasValidator()&&(e=i.x.validate.call(this,this.bindValue))),this.invalid=!e,this.fire("iron-input-validate"),e},_announceInvalidCharacter:function(e){this.fire("iron-announce",{text:e})},_computeValue:function(e){return e}})},15112:(e,t,n)=>{"use strict";n.d(t,{P:()=>i});n(43437);var r=n(9672);class i{constructor(e){i[" "](e),this.type=e&&e.type||"default",this.key=e&&e.key,e&&"value"in e&&(this.value=e.value)}get value(){var e=this.type,t=this.key;if(e&&t)return i.types[e]&&i.types[e][t]}set value(e){var t=this.type,n=this.key;t&&n&&(t=i.types[t]=i.types[t]||{},null==e?delete t[n]:t[n]=e)}get list(){if(this.type){var e=i.types[this.type];return e?Object.keys(e).map((function(e){return o[this.type][e]}),this):[]}}byKey(e){return this.key=e,this.value}}i[" "]=function(){},i.types={};var o=i.types;(0,r.k)({is:"iron-meta",properties:{type:{type:String,value:"default"},key:{type:String},value:{type:String,notify:!0},self:{type:Boolean,observer:"_selfChanged"},__meta:{type:Boolean,computed:"__computeMeta(type, key, value)"}},hostAttributes:{hidden:!0},__computeMeta:function(e,t,n){var r=new i({type:e,key:t});return void 0!==n&&n!==r.value?r.value=n:this.value!==r.value&&(this.value=r.value),r},get list(){return this.__meta&&this.__meta.list},_selfChanged:function(e){e&&(this.value=this)},byKey:function(e){return new i({type:this.type,key:e}).value}})},98235:(e,t,n)=>{"use strict";n.d(t,{x:()=>o});n(43437);var r=n(15112);let i=null;const o={properties:{validator:{type:String},invalid:{notify:!0,reflectToAttribute:!0,type:Boolean,value:!1,observer:"_invalidChanged"}},registered:function(){i=new r.P({type:"validator"})},_invalidChanged:function(){this.invalid?this.setAttribute("aria-invalid","true"):this.removeAttribute("aria-invalid")},get _validator(){return i&&i.byKey(this.validator)},hasValidator:function(){return null!=this._validator},validate:function(e){return void 0===e&&void 0!==this.value?this.invalid=!this._getValidity(this.value):this.invalid=!this._getValidity(e),!this.invalid},_getValidity:function(e){return!this.hasValidator()||this._validator.validate(e)}}},71765:(e,t,n)=>{"use strict";n.d(t,{o:()=>r});n(43437);const r={attached:function(){this.fire("addon-attached")},update:function(e){}}},66668:(e,t,n)=>{"use strict";n.d(t,{d0:()=>c});n(43437);var r=n(8621),i=n(26110),o=n(87156),s=n(28426);const a={NextLabelID:1,NextAddonID:1,NextInputID:1},l={properties:{label:{type:String},value:{notify:!0,type:String},disabled:{type:Boolean,value:!1},invalid:{type:Boolean,value:!1,notify:!0},allowedPattern:{type:String},type:{type:String},list:{type:String},pattern:{type:String},required:{type:Boolean,value:!1},errorMessage:{type:String},charCounter:{type:Boolean,value:!1},noLabelFloat:{type:Boolean,value:!1},alwaysFloatLabel:{type:Boolean,value:!1},autoValidate:{type:Boolean,value:!1},validator:{type:String},autocomplete:{type:String,value:"off"},autofocus:{type:Boolean,observer:"_autofocusChanged"},inputmode:{type:String},minlength:{type:Number},maxlength:{type:Number},min:{type:String},max:{type:String},step:{type:String},name:{type:String},placeholder:{type:String,value:""},readonly:{type:Boolean,value:!1},size:{type:Number},autocapitalize:{type:String,value:"none"},autocorrect:{type:String,value:"off"},autosave:{type:String},results:{type:Number},accept:{type:String},multiple:{type:Boolean},_ariaDescribedBy:{type:String,value:""},_ariaLabelledBy:{type:String,value:""},_inputId:{type:String,value:""}},listeners:{"addon-attached":"_onAddonAttached"},keyBindings:{"shift+tab:keydown":"_onShiftTabDown"},hostAttributes:{tabindex:0},get inputElement(){return this.$||(this.$={}),this.$.input||(this._generateInputId(),this.$.input=this.$$("#"+this._inputId)),this.$.input},get _focusableElement(){return this.inputElement},created:function(){this._typesThatHaveText=["date","datetime","datetime-local","month","time","week","file"]},attached:function(){this._updateAriaLabelledBy(),!s.H3&&this.inputElement&&-1!==this._typesThatHaveText.indexOf(this.inputElement.type)&&(this.alwaysFloatLabel=!0)},_appendStringWithSpace:function(e,t){return e=e?e+" "+t:t},_onAddonAttached:function(e){var t=(0,o.vz)(e).rootTarget;if(t.id)this._ariaDescribedBy=this._appendStringWithSpace(this._ariaDescribedBy,t.id);else{var n="paper-input-add-on-"+a.NextAddonID++;t.id=n,this._ariaDescribedBy=this._appendStringWithSpace(this._ariaDescribedBy,n)}},validate:function(){return this.inputElement.validate()},_focusBlurHandler:function(e){i.a._focusBlurHandler.call(this,e),this.focused&&!this._shiftTabPressed&&this._focusableElement&&this._focusableElement.focus()},_onShiftTabDown:function(e){var t=this.getAttribute("tabindex");this._shiftTabPressed=!0,this.setAttribute("tabindex","-1"),this.async((function(){this.setAttribute("tabindex",t),this._shiftTabPressed=!1}),1)},_handleAutoValidate:function(){this.autoValidate&&this.validate()},updateValueAndPreserveCaret:function(e){try{var t=this.inputElement.selectionStart;this.value=e,this.inputElement.selectionStart=t,this.inputElement.selectionEnd=t}catch(n){this.value=e}},_computeAlwaysFloatLabel:function(e,t){return t||e},_updateAriaLabelledBy:function(){var e,t=(0,o.vz)(this.root).querySelector("label");t?(t.id?e=t.id:(e="paper-input-label-"+a.NextLabelID++,t.id=e),this._ariaLabelledBy=e):this._ariaLabelledBy=""},_generateInputId:function(){this._inputId&&""!==this._inputId||(this._inputId="input-"+a.NextInputID++)},_onChange:function(e){this.shadowRoot&&this.fire(e.type,{sourceEvent:e},{node:this,bubbles:e.bubbles,cancelable:e.cancelable})},_autofocusChanged:function(){if(this.autofocus&&this._focusableElement){var e=document.activeElement;e instanceof HTMLElement&&e!==document.body&&e!==document.documentElement||this._focusableElement.focus()}}},c=[i.a,r.G,l]},2178:(e,t,n)=>{"use strict";n(43437),n(70019);var r=n(9672),i=n(50856),o=n(71765);(0,r.k)({_template:i.d`
    <style>
      :host {
        display: inline-block;
        float: right;

        @apply --paper-font-caption;
        @apply --paper-input-char-counter;
      }

      :host([hidden]) {
        display: none !important;
      }

      :host(:dir(rtl)) {
        float: left;
      }
    </style>

    <span>[[_charCounterStr]]</span>
`,is:"paper-input-char-counter",behaviors:[o.o],properties:{_charCounterStr:{type:String,value:"0"}},update:function(e){if(e.inputElement){e.value=e.value||"";var t=e.value.toString().length.toString();e.inputElement.hasAttribute("maxlength")&&(t+="/"+e.inputElement.getAttribute("maxlength")),this._charCounterStr=t}}})},98121:(e,t,n)=>{"use strict";n(43437),n(65660),n(70019);var r=n(9672),i=n(87156),o=n(67130),s=n(50856);const a=s.d`
<custom-style>
  <style is="custom-style">
    html {
      --paper-input-container-shared-input-style: {
        position: relative; /* to make a stacking context */
        outline: none;
        box-shadow: none;
        padding: 0;
        margin: 0;
        width: 100%;
        max-width: 100%;
        background: transparent;
        border: none;
        color: var(--paper-input-container-input-color, var(--primary-text-color));
        -webkit-appearance: none;
        text-align: inherit;
        vertical-align: var(--paper-input-container-input-align, bottom);

        @apply --paper-font-subhead;
      };
    }
  </style>
</custom-style>
`;a.setAttribute("style","display: none;"),document.head.appendChild(a.content),(0,r.k)({_template:s.d`
    <style>
      :host {
        display: block;
        padding: 8px 0;
        @apply --paper-input-container;
      }

      :host([inline]) {
        display: inline-block;
      }

      :host([disabled]) {
        pointer-events: none;
        opacity: 0.33;

        @apply --paper-input-container-disabled;
      }

      :host([hidden]) {
        display: none !important;
      }

      [hidden] {
        display: none !important;
      }

      .floated-label-placeholder {
        @apply --paper-font-caption;
      }

      .underline {
        height: 2px;
        position: relative;
      }

      .focused-line {
        @apply --layout-fit;
        border-bottom: 2px solid var(--paper-input-container-focus-color, var(--primary-color));

        -webkit-transform-origin: center center;
        transform-origin: center center;
        -webkit-transform: scale3d(0,1,1);
        transform: scale3d(0,1,1);

        @apply --paper-input-container-underline-focus;
      }

      .underline.is-highlighted .focused-line {
        -webkit-transform: none;
        transform: none;
        -webkit-transition: -webkit-transform 0.25s;
        transition: transform 0.25s;

        @apply --paper-transition-easing;
      }

      .underline.is-invalid .focused-line {
        border-color: var(--paper-input-container-invalid-color, var(--error-color));
        -webkit-transform: none;
        transform: none;
        -webkit-transition: -webkit-transform 0.25s;
        transition: transform 0.25s;

        @apply --paper-transition-easing;
      }

      .unfocused-line {
        @apply --layout-fit;
        border-bottom: 1px solid var(--paper-input-container-color, var(--secondary-text-color));
        @apply --paper-input-container-underline;
      }

      :host([disabled]) .unfocused-line {
        border-bottom: 1px dashed;
        border-color: var(--paper-input-container-color, var(--secondary-text-color));
        @apply --paper-input-container-underline-disabled;
      }

      .input-wrapper {
        @apply --layout-horizontal;
        @apply --layout-center;
        position: relative;
      }

      .input-content {
        @apply --layout-flex-auto;
        @apply --layout-relative;
        max-width: 100%;
      }

      .input-content ::slotted(label),
      .input-content ::slotted(.paper-input-label) {
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        font: inherit;
        color: var(--paper-input-container-color, var(--secondary-text-color));
        -webkit-transition: -webkit-transform 0.25s, width 0.25s;
        transition: transform 0.25s, width 0.25s;
        -webkit-transform-origin: left top;
        transform-origin: left top;
        /* Fix for safari not focusing 0-height date/time inputs with -webkit-apperance: none; */
        min-height: 1px;

        @apply --paper-font-common-nowrap;
        @apply --paper-font-subhead;
        @apply --paper-input-container-label;
        @apply --paper-transition-easing;
      }

      .input-content.label-is-floating ::slotted(label),
      .input-content.label-is-floating ::slotted(.paper-input-label) {
        -webkit-transform: translateY(-75%) scale(0.75);
        transform: translateY(-75%) scale(0.75);

        /* Since we scale to 75/100 of the size, we actually have 100/75 of the
        original space now available */
        width: 133%;

        @apply --paper-input-container-label-floating;
      }

      :host(:dir(rtl)) .input-content.label-is-floating ::slotted(label),
      :host(:dir(rtl)) .input-content.label-is-floating ::slotted(.paper-input-label) {
        right: 0;
        left: auto;
        -webkit-transform-origin: right top;
        transform-origin: right top;
      }

      .input-content.label-is-highlighted ::slotted(label),
      .input-content.label-is-highlighted ::slotted(.paper-input-label) {
        color: var(--paper-input-container-focus-color, var(--primary-color));

        @apply --paper-input-container-label-focus;
      }

      .input-content.is-invalid ::slotted(label),
      .input-content.is-invalid ::slotted(.paper-input-label) {
        color: var(--paper-input-container-invalid-color, var(--error-color));
      }

      .input-content.label-is-hidden ::slotted(label),
      .input-content.label-is-hidden ::slotted(.paper-input-label) {
        visibility: hidden;
      }

      .input-content ::slotted(input),
      .input-content ::slotted(iron-input),
      .input-content ::slotted(textarea),
      .input-content ::slotted(iron-autogrow-textarea),
      .input-content ::slotted(.paper-input-input) {
        @apply --paper-input-container-shared-input-style;
        /* The apply shim doesn't apply the nested color custom property,
          so we have to re-apply it here. */
        color: var(--paper-input-container-input-color, var(--primary-text-color));
        @apply --paper-input-container-input;
      }

      .input-content ::slotted(input)::-webkit-outer-spin-button,
      .input-content ::slotted(input)::-webkit-inner-spin-button {
        @apply --paper-input-container-input-webkit-spinner;
      }

      .input-content.focused ::slotted(input),
      .input-content.focused ::slotted(iron-input),
      .input-content.focused ::slotted(textarea),
      .input-content.focused ::slotted(iron-autogrow-textarea),
      .input-content.focused ::slotted(.paper-input-input) {
        @apply --paper-input-container-input-focus;
      }

      .input-content.is-invalid ::slotted(input),
      .input-content.is-invalid ::slotted(iron-input),
      .input-content.is-invalid ::slotted(textarea),
      .input-content.is-invalid ::slotted(iron-autogrow-textarea),
      .input-content.is-invalid ::slotted(.paper-input-input) {
        @apply --paper-input-container-input-invalid;
      }

      .prefix ::slotted(*) {
        display: inline-block;
        @apply --paper-font-subhead;
        @apply --layout-flex-none;
        @apply --paper-input-prefix;
      }

      .suffix ::slotted(*) {
        display: inline-block;
        @apply --paper-font-subhead;
        @apply --layout-flex-none;

        @apply --paper-input-suffix;
      }

      /* Firefox sets a min-width on the input, which can cause layout issues */
      .input-content ::slotted(input) {
        min-width: 0;
      }

      .input-content ::slotted(textarea) {
        resize: none;
      }

      .add-on-content {
        position: relative;
      }

      .add-on-content.is-invalid ::slotted(*) {
        color: var(--paper-input-container-invalid-color, var(--error-color));
      }

      .add-on-content.is-highlighted ::slotted(*) {
        color: var(--paper-input-container-focus-color, var(--primary-color));
      }
    </style>

    <div class="floated-label-placeholder" aria-hidden="true" hidden="[[noLabelFloat]]">&nbsp;</div>

    <div class="input-wrapper">
      <span class="prefix"><slot name="prefix"></slot></span>

      <div class$="[[_computeInputContentClass(noLabelFloat,alwaysFloatLabel,focused,invalid,_inputHasContent)]]" id="labelAndInputContainer">
        <slot name="label"></slot>
        <slot name="input"></slot>
      </div>

      <span class="suffix"><slot name="suffix"></slot></span>
    </div>

    <div class$="[[_computeUnderlineClass(focused,invalid)]]">
      <div class="unfocused-line"></div>
      <div class="focused-line"></div>
    </div>

    <div class$="[[_computeAddOnContentClass(focused,invalid)]]">
      <slot name="add-on"></slot>
    </div>
`,is:"paper-input-container",properties:{noLabelFloat:{type:Boolean,value:!1},alwaysFloatLabel:{type:Boolean,value:!1},attrForValue:{type:String,value:"bind-value"},autoValidate:{type:Boolean,value:!1},invalid:{observer:"_invalidChanged",type:Boolean,value:!1},focused:{readOnly:!0,type:Boolean,value:!1,notify:!0},_addons:{type:Array},_inputHasContent:{type:Boolean,value:!1},_inputSelector:{type:String,value:"input,iron-input,textarea,.paper-input-input"},_boundOnFocus:{type:Function,value:function(){return this._onFocus.bind(this)}},_boundOnBlur:{type:Function,value:function(){return this._onBlur.bind(this)}},_boundOnInput:{type:Function,value:function(){return this._onInput.bind(this)}},_boundValueChanged:{type:Function,value:function(){return this._onValueChanged.bind(this)}}},listeners:{"addon-attached":"_onAddonAttached","iron-input-validate":"_onIronInputValidate"},get _valueChangedEvent(){return this.attrForValue+"-changed"},get _propertyForValue(){return(0,o.z)(this.attrForValue)},get _inputElement(){return(0,i.vz)(this).querySelector(this._inputSelector)},get _inputElementValue(){return this._inputElement[this._propertyForValue]||this._inputElement.value},ready:function(){this.__isFirstValueUpdate=!0,this._addons||(this._addons=[]),this.addEventListener("focus",this._boundOnFocus,!0),this.addEventListener("blur",this._boundOnBlur,!0)},attached:function(){this.attrForValue?this._inputElement.addEventListener(this._valueChangedEvent,this._boundValueChanged):this.addEventListener("input",this._onInput),this._inputElementValue&&""!=this._inputElementValue?this._handleValueAndAutoValidate(this._inputElement):this._handleValue(this._inputElement)},_onAddonAttached:function(e){this._addons||(this._addons=[]);var t=e.target;-1===this._addons.indexOf(t)&&(this._addons.push(t),this.isAttached&&this._handleValue(this._inputElement))},_onFocus:function(){this._setFocused(!0)},_onBlur:function(){this._setFocused(!1),this._handleValueAndAutoValidate(this._inputElement)},_onInput:function(e){this._handleValueAndAutoValidate(e.target)},_onValueChanged:function(e){var t=e.target;this.__isFirstValueUpdate&&(this.__isFirstValueUpdate=!1,void 0===t.value||""===t.value)||this._handleValueAndAutoValidate(e.target)},_handleValue:function(e){var t=this._inputElementValue;t||0===t||"number"===e.type&&!e.checkValidity()?this._inputHasContent=!0:this._inputHasContent=!1,this.updateAddons({inputElement:e,value:t,invalid:this.invalid})},_handleValueAndAutoValidate:function(e){var t;this.autoValidate&&e&&(t=e.validate?e.validate(this._inputElementValue):e.checkValidity(),this.invalid=!t);this._handleValue(e)},_onIronInputValidate:function(e){this.invalid=this._inputElement.invalid},_invalidChanged:function(){this._addons&&this.updateAddons({invalid:this.invalid})},updateAddons:function(e){for(var t,n=0;t=this._addons[n];n++)t.update(e)},_computeInputContentClass:function(e,t,n,r,i){var o="input-content";if(e)i&&(o+=" label-is-hidden"),r&&(o+=" is-invalid");else{var s=this.querySelector("label");t||i?(o+=" label-is-floating",this.$.labelAndInputContainer.style.position="static",r?o+=" is-invalid":n&&(o+=" label-is-highlighted")):(s&&(this.$.labelAndInputContainer.style.position="relative"),r&&(o+=" is-invalid"))}return n&&(o+=" focused"),o},_computeUnderlineClass:function(e,t){var n="underline";return t?n+=" is-invalid":e&&(n+=" is-highlighted"),n},_computeAddOnContentClass:function(e,t){var n="add-on-content";return t?n+=" is-invalid":e&&(n+=" is-highlighted"),n}})},65911:(e,t,n)=>{"use strict";n(43437),n(70019);var r=n(9672),i=n(50856),o=n(71765);(0,r.k)({_template:i.d`
    <style>
      :host {
        display: inline-block;
        visibility: hidden;

        color: var(--paper-input-container-invalid-color, var(--error-color));

        @apply --paper-font-caption;
        @apply --paper-input-error;
        position: absolute;
        left:0;
        right:0;
      }

      :host([invalid]) {
        visibility: visible;
      }

      #a11yWrapper {
        visibility: hidden;
      }

      :host([invalid]) #a11yWrapper {
        visibility: visible;
      }
    </style>

    <!--
    If the paper-input-error element is directly referenced by an
    \`aria-describedby\` attribute, such as when used as a paper-input add-on,
    then applying \`visibility: hidden;\` to the paper-input-error element itself
    does not hide the error.

    For more information, see:
    https://www.w3.org/TR/accname-1.1/#mapping_additional_nd_description
    -->
    <div id="a11yWrapper">
      <slot></slot>
    </div>
`,is:"paper-input-error",behaviors:[o.o],properties:{invalid:{readOnly:!0,reflectToAttribute:!0,type:Boolean}},update:function(e){this._setInvalid(e.invalid)}})},30879:(e,t,n)=>{"use strict";n(43437),n(87772),n(2178),n(98121),n(65911);var r=n(21006),i=(n(21384),n(9672)),o=n(50856),s=n(66668);(0,i.k)({is:"paper-input",_template:o.d`
    <style>
      :host {
        display: block;
      }

      :host([focused]) {
        outline: none;
      }

      :host([hidden]) {
        display: none !important;
      }

      input {
        /* Firefox sets a min-width on the input, which can cause layout issues */
        min-width: 0;
      }

      /* In 1.x, the <input> is distributed to paper-input-container, which styles it.
      In 2.x the <iron-input> is distributed to paper-input-container, which styles
      it, but in order for this to work correctly, we need to reset some
      of the native input's properties to inherit (from the iron-input) */
      iron-input > input {
        @apply --paper-input-container-shared-input-style;
        font-family: inherit;
        font-weight: inherit;
        font-size: inherit;
        letter-spacing: inherit;
        word-spacing: inherit;
        line-height: inherit;
        text-shadow: inherit;
        color: inherit;
        cursor: inherit;
      }

      input:disabled {
        @apply --paper-input-container-input-disabled;
      }

      input::-webkit-outer-spin-button,
      input::-webkit-inner-spin-button {
        @apply --paper-input-container-input-webkit-spinner;
      }

      input::-webkit-clear-button {
        @apply --paper-input-container-input-webkit-clear;
      }

      input::-webkit-calendar-picker-indicator {
        @apply --paper-input-container-input-webkit-calendar-picker-indicator;
      }

      input::-webkit-input-placeholder {
        color: var(--paper-input-container-color, var(--secondary-text-color));
      }

      input:-moz-placeholder {
        color: var(--paper-input-container-color, var(--secondary-text-color));
      }

      input::-moz-placeholder {
        color: var(--paper-input-container-color, var(--secondary-text-color));
      }

      input::-ms-clear {
        @apply --paper-input-container-ms-clear;
      }

      input::-ms-reveal {
        @apply --paper-input-container-ms-reveal;
      }

      input:-ms-input-placeholder {
        color: var(--paper-input-container-color, var(--secondary-text-color));
      }

      label {
        pointer-events: none;
      }
    </style>

    <paper-input-container id="container" no-label-float="[[noLabelFloat]]" always-float-label="[[_computeAlwaysFloatLabel(alwaysFloatLabel,placeholder)]]" auto-validate$="[[autoValidate]]" disabled$="[[disabled]]" invalid="[[invalid]]">

      <slot name="prefix" slot="prefix"></slot>

      <label hidden$="[[!label]]" aria-hidden="true" for$="[[_inputId]]" slot="label">[[label]]</label>

      <!-- Need to bind maxlength so that the paper-input-char-counter works correctly -->
      <iron-input bind-value="{{value}}" slot="input" class="input-element" id$="[[_inputId]]" maxlength$="[[maxlength]]" allowed-pattern="[[allowedPattern]]" invalid="{{invalid}}" validator="[[validator]]">
        <input aria-labelledby$="[[_ariaLabelledBy]]" aria-describedby$="[[_ariaDescribedBy]]" disabled$="[[disabled]]" title$="[[title]]" type$="[[type]]" pattern$="[[pattern]]" required$="[[required]]" autocomplete$="[[autocomplete]]" autofocus$="[[autofocus]]" inputmode$="[[inputmode]]" minlength$="[[minlength]]" maxlength$="[[maxlength]]" min$="[[min]]" max$="[[max]]" step$="[[step]]" name$="[[name]]" placeholder$="[[placeholder]]" readonly$="[[readonly]]" list$="[[list]]" size$="[[size]]" autocapitalize$="[[autocapitalize]]" autocorrect$="[[autocorrect]]" on-change="_onChange" tabindex$="[[tabIndex]]" autosave$="[[autosave]]" results$="[[results]]" accept$="[[accept]]" multiple$="[[multiple]]">
      </iron-input>

      <slot name="suffix" slot="suffix"></slot>

      <template is="dom-if" if="[[errorMessage]]">
        <paper-input-error aria-live="assertive" slot="add-on">[[errorMessage]]</paper-input-error>
      </template>

      <template is="dom-if" if="[[charCounter]]">
        <paper-input-char-counter slot="add-on"></paper-input-char-counter>
      </template>

    </paper-input-container>
  `,behaviors:[s.d0,r.V],properties:{value:{type:String}},get _focusableElement(){return this.inputElement._inputElement},listeners:{"iron-input-ready":"_onIronInputReady"},_onIronInputReady:function(){this.$.nativeInput||(this.$.nativeInput=this.$$("input")),this.inputElement&&-1!==this._typesThatHaveText.indexOf(this.$.nativeInput.type)&&(this.alwaysFloatLabel=!0),this.inputElement.bindValue&&this.$.container._handleValueAndAutoValidate(this.inputElement)}})},54242:(e,t,n)=>{"use strict";n(43437);const r=n(50856).d`
<custom-style>
  <style is="custom-style">
    html {

      --shadow-transition: {
        transition: box-shadow 0.28s cubic-bezier(0.4, 0, 0.2, 1);
      };

      --shadow-none: {
        box-shadow: none;
      };

      /* from http://codepen.io/shyndman/pen/c5394ddf2e8b2a5c9185904b57421cdb */

      --shadow-elevation-2dp: {
        box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14),
                    0 1px 5px 0 rgba(0, 0, 0, 0.12),
                    0 3px 1px -2px rgba(0, 0, 0, 0.2);
      };

      --shadow-elevation-3dp: {
        box-shadow: 0 3px 4px 0 rgba(0, 0, 0, 0.14),
                    0 1px 8px 0 rgba(0, 0, 0, 0.12),
                    0 3px 3px -2px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-4dp: {
        box-shadow: 0 4px 5px 0 rgba(0, 0, 0, 0.14),
                    0 1px 10px 0 rgba(0, 0, 0, 0.12),
                    0 2px 4px -1px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-6dp: {
        box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14),
                    0 1px 18px 0 rgba(0, 0, 0, 0.12),
                    0 3px 5px -1px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-8dp: {
        box-shadow: 0 8px 10px 1px rgba(0, 0, 0, 0.14),
                    0 3px 14px 2px rgba(0, 0, 0, 0.12),
                    0 5px 5px -3px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-12dp: {
        box-shadow: 0 12px 16px 1px rgba(0, 0, 0, 0.14),
                    0 4px 22px 3px rgba(0, 0, 0, 0.12),
                    0 6px 7px -4px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-16dp: {
        box-shadow: 0 16px 24px 2px rgba(0, 0, 0, 0.14),
                    0  6px 30px 5px rgba(0, 0, 0, 0.12),
                    0  8px 10px -5px rgba(0, 0, 0, 0.4);
      };

      --shadow-elevation-24dp: {
        box-shadow: 0 24px 38px 3px rgba(0, 0, 0, 0.14),
                    0 9px 46px 8px rgba(0, 0, 0, 0.12),
                    0 11px 15px -7px rgba(0, 0, 0, 0.4);
      };
    }
  </style>
</custom-style>`;r.setAttribute("style","display: none;"),document.head.appendChild(r.content)},70019:(e,t,n)=>{"use strict";n(43437);const r=n(50856).d`<custom-style>
  <style is="custom-style">
    html {

      /* Shared Styles */
      --paper-font-common-base: {
        font-family: 'Roboto', 'Noto', sans-serif;
        -webkit-font-smoothing: antialiased;
      };

      --paper-font-common-code: {
        font-family: 'Roboto Mono', 'Consolas', 'Menlo', monospace;
        -webkit-font-smoothing: antialiased;
      };

      --paper-font-common-expensive-kerning: {
        text-rendering: optimizeLegibility;
      };

      --paper-font-common-nowrap: {
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
      };

      /* Material Font Styles */

      --paper-font-display4: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 112px;
        font-weight: 300;
        letter-spacing: -.044em;
        line-height: 120px;
      };

      --paper-font-display3: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 56px;
        font-weight: 400;
        letter-spacing: -.026em;
        line-height: 60px;
      };

      --paper-font-display2: {
        @apply --paper-font-common-base;

        font-size: 45px;
        font-weight: 400;
        letter-spacing: -.018em;
        line-height: 48px;
      };

      --paper-font-display1: {
        @apply --paper-font-common-base;

        font-size: 34px;
        font-weight: 400;
        letter-spacing: -.01em;
        line-height: 40px;
      };

      --paper-font-headline: {
        @apply --paper-font-common-base;

        font-size: 24px;
        font-weight: 400;
        letter-spacing: -.012em;
        line-height: 32px;
      };

      --paper-font-title: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 20px;
        font-weight: 500;
        line-height: 28px;
      };

      --paper-font-subhead: {
        @apply --paper-font-common-base;

        font-size: 16px;
        font-weight: 400;
        line-height: 24px;
      };

      --paper-font-body2: {
        @apply --paper-font-common-base;

        font-size: 14px;
        font-weight: 500;
        line-height: 24px;
      };

      --paper-font-body1: {
        @apply --paper-font-common-base;

        font-size: 14px;
        font-weight: 400;
        line-height: 20px;
      };

      --paper-font-caption: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 12px;
        font-weight: 400;
        letter-spacing: 0.011em;
        line-height: 20px;
      };

      --paper-font-menu: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 13px;
        font-weight: 500;
        line-height: 24px;
      };

      --paper-font-button: {
        @apply --paper-font-common-base;
        @apply --paper-font-common-nowrap;

        font-size: 14px;
        font-weight: 500;
        letter-spacing: 0.018em;
        line-height: 24px;
        text-transform: uppercase;
      };

      --paper-font-code2: {
        @apply --paper-font-common-code;

        font-size: 14px;
        font-weight: 700;
        line-height: 20px;
      };

      --paper-font-code1: {
        @apply --paper-font-common-code;

        font-size: 14px;
        font-weight: 500;
        line-height: 20px;
      };

    }

  </style>
</custom-style>`;r.setAttribute("style","display: none;"),document.head.appendChild(r.content)},5618:(e,t,n)=>{"use strict";var r=n(34816),i=n(10868),o=n(26539);const s=new r.ZP;window.ShadyCSS||(window.ShadyCSS={prepareTemplate(e,t,n){},prepareTemplateDom(e,t){},prepareTemplateStyles(e,t,n){},styleSubtree(e,t){s.processStyles(),(0,i.wW)(e,t)},styleElement(e){s.processStyles()},styleDocument(e){s.processStyles(),(0,i.wW)(document.body,e)},getComputedStyleValue:(e,t)=>(0,i.B7)(e,t),flushCustomStyles(){},nativeCss:o.rd,nativeShadow:o.WA,cssBuild:o.Cp,disableRuntime:o.jF}),window.ShadyCSS.CustomStyleInterface=s;var a=n(15392);const l="include",c=window.ShadyCSS.CustomStyleInterface;class d extends HTMLElement{constructor(){super(),this._style=null,c.addCustomStyle(this)}getStyle(){if(this._style)return this._style;const e=this.querySelector("style");if(!e)return null;this._style=e;const t=e.getAttribute(l);return t&&(e.removeAttribute(l),e.textContent=(0,a.jv)(t)+e.textContent),this.ownerDocument!==window.document&&window.document.head.appendChild(this),this._style}}window.customElements.define("custom-style",d)},26047:(e,t,n)=>{"use strict";var r=n(28426),i=n(52521),o=n(78956),s=n(93252),a=n(21683),l=n(4059);class c extends r.H3{static get is(){return"dom-if"}static get template(){return null}static get properties(){return{if:{type:Boolean,observer:"__debounceRender"},restamp:{type:Boolean,observer:"__debounceRender"}}}constructor(){super(),this.__renderDebouncer=null,this.__invalidProps=null,this.__instance=null,this._lastIf=!1,this.__ctor=null,this.__hideTemplateChildren__=!1}__debounceRender(){this.__renderDebouncer=o.d.debounce(this.__renderDebouncer,a.YA,(()=>this.__render())),(0,s.E)(this.__renderDebouncer)}disconnectedCallback(){super.disconnectedCallback(),this.parentNode&&(this.parentNode.nodeType!=Node.DOCUMENT_FRAGMENT_NODE||this.parentNode.host)||this.__teardownInstance()}connectedCallback(){super.connectedCallback(),this.style.display="none",this.if&&this.__debounceRender()}render(){(0,s.y)()}__render(){if(this.if){if(!this.__ensureInstance())return;this._showHideChildren()}else this.restamp&&this.__teardownInstance();!this.restamp&&this.__instance&&this._showHideChildren(),this.if!=this._lastIf&&(this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0})),this._lastIf=this.if)}__ensureInstance(){let e=this.parentNode;if(e){if(!this.__ctor){let e=this.querySelector("template");if(!e){let e=new MutationObserver((()=>{if(!this.querySelector("template"))throw new Error("dom-if requires a <template> child");e.disconnect(),this.__render()}));return e.observe(this,{childList:!0}),!1}this.__ctor=(0,i.Uv)(e,this,{mutableData:!0,forwardHostProp:function(e,t){this.__instance&&(this.if?this.__instance.forwardHostProp(e,t):(this.__invalidProps=this.__invalidProps||Object.create(null),this.__invalidProps[(0,l.Jz)(e)]=!0))}})}if(this.__instance){this.__syncHostProperties();let t=this.__instance.children;if(t&&t.length){if(this.previousSibling!==t[t.length-1])for(let n,r=0;r<t.length&&(n=t[r]);r++)e.insertBefore(n,this)}}else this.__instance=new this.__ctor,e.insertBefore(this.__instance.root,this)}return!0}__syncHostProperties(){let e=this.__invalidProps;if(e){for(let t in e)this.__instance._setPendingProperty(t,this.__dataHost[t]);this.__invalidProps=null,this.__instance._flushProperties()}}__teardownInstance(){if(this.__instance){let e=this.__instance.children;if(e&&e.length){let t=e[0].parentNode;if(t)for(let n,r=0;r<e.length&&(n=e[r]);r++)t.removeChild(n)}this.__instance=null,this.__invalidProps=null}}_showHideChildren(){let e=this.__hideTemplateChildren__||!this.if;this.__instance&&this.__instance._showHideChildren(e)}}customElements.define(c.is,c)},21384:(e,t,n)=>{"use strict";n.d(t,{t:()=>c});n(56646);var r=n(42687),i=n(74460);let o={},s={};function a(e,t){o[e]=s[e.toLowerCase()]=t}function l(e){return o[e]||s[e.toLowerCase()]}class c extends HTMLElement{static get observedAttributes(){return["id"]}static import(e,t){if(e){let n=l(e);return n&&t?n.querySelector(t):n}return null}attributeChangedCallback(e,t,n,r){t!==n&&this.register()}get assetpath(){if(!this.__assetpath){const e=window.HTMLImports&&HTMLImports.importForElement?HTMLImports.importForElement(this)||document:this.ownerDocument,t=(0,r.Kk)(this.getAttribute("assetpath")||"",e.baseURI);this.__assetpath=(0,r.iY)(t)}return this.__assetpath}register(e){if(e=e||this.id){if(i.XN&&void 0!==l(e))throw a(e,null),new Error(`strictTemplatePolicy: dom-module ${e} re-registered`);this.id=e,a(e,this),(t=this).querySelector("style")&&console.warn("dom-module %s has style outside template",t.id)}var t}}c.prototype.modules=o,customElements.define("dom-module",c)},42173:(e,t,n)=>{"use strict";var r=n(28426),i=n(52521),o=n(78956),s=n(93252),a=n(18691),l=n(4059),c=n(21683);const d=(0,a.w)(r.H3);class u extends d{static get is(){return"dom-repeat"}static get template(){return null}static get properties(){return{items:{type:Array},as:{type:String,value:"item"},indexAs:{type:String,value:"index"},itemsIndexAs:{type:String,value:"itemsIndex"},sort:{type:Function,observer:"__sortChanged"},filter:{type:Function,observer:"__filterChanged"},observe:{type:String,observer:"__observeChanged"},delay:Number,renderedItemCount:{type:Number,notify:!0,readOnly:!0},initialCount:{type:Number,observer:"__initializeChunking"},targetFramerate:{type:Number,value:20},_targetFrameTime:{type:Number,computed:"__computeFrameTime(targetFramerate)"}}}static get observers(){return["__itemsChanged(items.*)"]}constructor(){super(),this.__instances=[],this.__limit=1/0,this.__pool=[],this.__renderDebouncer=null,this.__itemsIdxToInstIdx={},this.__chunkCount=null,this.__lastChunkTime=null,this.__sortFn=null,this.__filterFn=null,this.__observePaths=null,this.__ctor=null,this.__isDetached=!0,this.template=null}disconnectedCallback(){super.disconnectedCallback(),this.__isDetached=!0;for(let e=0;e<this.__instances.length;e++)this.__detachInstance(e)}connectedCallback(){if(super.connectedCallback(),this.style.display="none",this.__isDetached){this.__isDetached=!1;let e=this.parentNode;for(let t=0;t<this.__instances.length;t++)this.__attachInstance(t,e)}}__ensureTemplatized(){if(!this.__ctor){let e=this.template=this.querySelector("template");if(!e){let e=new MutationObserver((()=>{if(!this.querySelector("template"))throw new Error("dom-repeat requires a <template> child");e.disconnect(),this.__render()}));return e.observe(this,{childList:!0}),!1}let t={};t[this.as]=!0,t[this.indexAs]=!0,t[this.itemsIndexAs]=!0,this.__ctor=(0,i.Uv)(e,this,{mutableData:this.mutableData,parentModel:!0,instanceProps:t,forwardHostProp:function(e,t){let n=this.__instances;for(let r,i=0;i<n.length&&(r=n[i]);i++)r.forwardHostProp(e,t)},notifyInstanceProp:function(e,t,n){if((0,l.wB)(this.as,t)){let r=e[this.itemsIndexAs];t==this.as&&(this.items[r]=n);let i=(0,l.Iu)(this.as,"items."+r,t);this.notifyPath(i,n)}}})}return!0}__getMethodHost(){return this.__dataHost._methodHost||this.__dataHost}__functionFromPropertyValue(e){if("string"==typeof e){let t=e,n=this.__getMethodHost();return function(){return n[t].apply(n,arguments)}}return e}__sortChanged(e){this.__sortFn=this.__functionFromPropertyValue(e),this.items&&this.__debounceRender(this.__render)}__filterChanged(e){this.__filterFn=this.__functionFromPropertyValue(e),this.items&&this.__debounceRender(this.__render)}__computeFrameTime(e){return Math.ceil(1e3/e)}__initializeChunking(){this.initialCount&&(this.__limit=this.initialCount,this.__chunkCount=this.initialCount,this.__lastChunkTime=performance.now())}__tryRenderChunk(){this.items&&this.__limit<this.items.length&&this.__debounceRender(this.__requestRenderChunk)}__requestRenderChunk(){requestAnimationFrame((()=>this.__renderChunk()))}__renderChunk(){let e=performance.now(),t=this._targetFrameTime/(e-this.__lastChunkTime);this.__chunkCount=Math.round(this.__chunkCount*t)||1,this.__limit+=this.__chunkCount,this.__lastChunkTime=e,this.__debounceRender(this.__render)}__observeChanged(){this.__observePaths=this.observe&&this.observe.replace(".*",".").split(" ")}__itemsChanged(e){this.items&&!Array.isArray(this.items)&&console.warn("dom-repeat expected array for `items`, found",this.items),this.__handleItemPath(e.path,e.value)||(this.__initializeChunking(),this.__debounceRender(this.__render))}__handleObservedPaths(e){if(this.__sortFn||this.__filterFn)if(e){if(this.__observePaths){let t=this.__observePaths;for(let n=0;n<t.length;n++)0===e.indexOf(t[n])&&this.__debounceRender(this.__render,this.delay)}}else this.__debounceRender(this.__render,this.delay)}__debounceRender(e,t=0){this.__renderDebouncer=o.d.debounce(this.__renderDebouncer,t>0?c.Wc.after(t):c.YA,e.bind(this)),(0,s.E)(this.__renderDebouncer)}render(){this.__debounceRender(this.__render),(0,s.y)()}__render(){this.__ensureTemplatized()&&(this.__applyFullRefresh(),this.__pool.length=0,this._setRenderedItemCount(this.__instances.length),this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0})),this.__tryRenderChunk())}__applyFullRefresh(){let e=this.items||[],t=new Array(e.length);for(let o=0;o<e.length;o++)t[o]=o;this.__filterFn&&(t=t.filter(((t,n,r)=>this.__filterFn(e[t],n,r)))),this.__sortFn&&t.sort(((t,n)=>this.__sortFn(e[t],e[n])));const n=this.__itemsIdxToInstIdx={};let r=0;const i=Math.min(t.length,this.__limit);for(;r<i;r++){let i=this.__instances[r],o=t[r],s=e[o];n[o]=r,i?(i._setPendingProperty(this.as,s),i._setPendingProperty(this.indexAs,r),i._setPendingProperty(this.itemsIndexAs,o),i._flushProperties()):this.__insertInstance(s,r,o)}for(let o=this.__instances.length-1;o>=r;o--)this.__detachAndRemoveInstance(o)}__detachInstance(e){let t=this.__instances[e];for(let n=0;n<t.children.length;n++){let e=t.children[n];t.root.appendChild(e)}return t}__attachInstance(e,t){let n=this.__instances[e];t.insertBefore(n.root,this)}__detachAndRemoveInstance(e){let t=this.__detachInstance(e);t&&this.__pool.push(t),this.__instances.splice(e,1)}__stampInstance(e,t,n){let r={};return r[this.as]=e,r[this.indexAs]=t,r[this.itemsIndexAs]=n,new this.__ctor(r)}__insertInstance(e,t,n){let r=this.__pool.pop();r?(r._setPendingProperty(this.as,e),r._setPendingProperty(this.indexAs,t),r._setPendingProperty(this.itemsIndexAs,n),r._flushProperties()):r=this.__stampInstance(e,t,n);let i=this.__instances[t+1],o=i?i.children[0]:this;return this.parentNode.insertBefore(r.root,o),this.__instances[t]=r,r}_showHideChildren(e){for(let t=0;t<this.__instances.length;t++)this.__instances[t]._showHideChildren(e)}__handleItemPath(e,t){let n=e.slice(6),r=n.indexOf("."),i=r<0?n:n.substring(0,r);if(i==parseInt(i,10)){let e=r<0?"":n.substring(r+1);this.__handleObservedPaths(e);let o=this.__itemsIdxToInstIdx[i],s=this.__instances[o];if(s){let n=this.as+(e?"."+e:"");s._setPendingPropertyOrPath(n,t,!1,!0),s._flushProperties()}return!0}}itemForElement(e){let t=this.modelForElement(e);return t&&t[this.as]}indexForElement(e){let t=this.modelForElement(e);return t&&t[this.indexAs]}modelForElement(e){return(0,i.GJ)(this.template,e)}}customElements.define(u.is,u)},33367:(e,t,n)=>{"use strict";n.d(t,{P:()=>o,w:()=>c});var r=n(81850);let i={attached:!0,detached:!0,ready:!0,created:!0,beforeRegister:!0,registered:!0,attributeChanged:!0,behaviors:!0};function o(e,t){if(!e)return t=t;t=(0,r.x)(t),Array.isArray(e)||(e=[e]);let n=t.prototype.behaviors;return t=s(e=a(e,null,n),t),n&&(e=n.concat(e)),t.prototype.behaviors=e,t}function s(e,t){for(let n=0;n<e.length;n++){let r=e[n];r&&(t=Array.isArray(r)?s(r,t):l(r,t))}return t}function a(e,t,n){t=t||[];for(let r=e.length-1;r>=0;r--){let i=e[r];i?Array.isArray(i)?a(i,t):t.indexOf(i)<0&&(!n||n.indexOf(i)<0)&&t.unshift(i):console.warn("behavior is null, check for missing or 404 import")}return t}function l(e,t){class n extends t{static get properties(){return e.properties}static get observers(){return e.observers}created(){super.created(),e.created&&e.created.call(this)}_registered(){super._registered(),e.beforeRegister&&e.beforeRegister.call(Object.getPrototypeOf(this)),e.registered&&e.registered.call(Object.getPrototypeOf(this))}_applyListeners(){if(super._applyListeners(),e.listeners)for(let t in e.listeners)this._addMethodEventListenerToNode(this,t,e.listeners[t])}_ensureAttributes(){if(e.hostAttributes)for(let t in e.hostAttributes)this._ensureAttribute(t,e.hostAttributes[t]);super._ensureAttributes()}ready(){super.ready(),e.ready&&e.ready.call(this)}attached(){super.attached(),e.attached&&e.attached.call(this)}detached(){super.detached(),e.detached&&e.detached.call(this)}attributeChanged(t,n,r){super.attributeChanged(t,n,r),e.attributeChanged&&e.attributeChanged.call(this,t,n,r)}}n.generatedFrom=e;for(let r in e)if(!(r in i)){let t=Object.getOwnPropertyDescriptor(e,r);t&&Object.defineProperty(n.prototype,r,t)}return n}const c=function(e,t){e||console.warn("Polymer's Class function requires `info` argument");const n=e.behaviors?o(e.behaviors,HTMLElement):(0,r.x)(HTMLElement),i=l(e,t?t(n):n);return i.is=e.is,i}},81850:(e,t,n)=>{"use strict";n.d(t,{x:()=>he});var r=n(26539);class i{constructor(){this.start=0,this.end=0,this.previous=null,this.parent=null,this.rules=null,this.parsedCssText="",this.cssText="",this.atRule=!1,this.type=0,this.keyframesName="",this.selector="",this.parsedSelector=""}}function o(e){return s(function(e){let t=new i;t.start=0,t.end=e.length;let n=t;for(let r=0,o=e.length;r<o;r++)if(e[r]===c){n.rules||(n.rules=[]);let e=n,t=e.rules[e.rules.length-1]||null;n=new i,n.start=r+1,n.parent=e,n.previous=t,e.rules.push(n)}else e[r]===d&&(n.end=r+1,n=n.parent||t);return t}(e=e.replace(u.comments,"").replace(u.port,"")),e)}function s(e,t){let n=t.substring(e.start,e.end-1);if(e.parsedCssText=e.cssText=n.trim(),e.parent){let r=e.previous?e.previous.end:e.parent.start;n=t.substring(r,e.start-1),n=function(e){return e.replace(/\\([0-9a-f]{1,6})\s/gi,(function(){let e=arguments[1],t=6-e.length;for(;t--;)e="0"+e;return"\\"+e}))}(n),n=n.replace(u.multipleSpaces," "),n=n.substring(n.lastIndexOf(";")+1);let i=e.parsedSelector=e.selector=n.trim();e.atRule=0===i.indexOf(f),e.atRule?0===i.indexOf(h)?e.type=l.MEDIA_RULE:i.match(u.keyframesRule)&&(e.type=l.KEYFRAMES_RULE,e.keyframesName=e.selector.split(u.multipleSpaces).pop()):0===i.indexOf(p)?e.type=l.MIXIN_RULE:e.type=l.STYLE_RULE}let r=e.rules;if(r)for(let i,o=0,a=r.length;o<a&&(i=r[o]);o++)s(i,t);return e}function a(e,t,n=""){let r="";if(e.cssText||e.rules){let n=e.rules;if(n&&!function(e){let t=e[0];return Boolean(t)&&Boolean(t.selector)&&0===t.selector.indexOf(p)}(n))for(let e,i=0,o=n.length;i<o&&(e=n[i]);i++)r=a(e,t,r);else r=t?e.cssText:function(e){return function(e){return e.replace(u.mixinApply,"").replace(u.varApply,"")}(e=function(e){return e.replace(u.customProp,"").replace(u.mixinProp,"")}(e))}(e.cssText),r=r.trim(),r&&(r="  "+r+"\n")}return r&&(e.selector&&(n+=e.selector+" "+c+"\n"),n+=r,e.selector&&(n+=d+"\n\n")),n}const l={STYLE_RULE:1,KEYFRAMES_RULE:7,MEDIA_RULE:4,MIXIN_RULE:1e3},c="{",d="}",u={comments:/\/\*[^*]*\*+([^/*][^*]*\*+)*\//gim,port:/@import[^;]*;/gim,customProp:/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?(?:[;\n]|$)/gim,mixinProp:/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?{[^}]*?}(?:[;\n]|$)?/gim,mixinApply:/@apply\s*\(?[^);]*\)?\s*(?:[;\n]|$)?/gim,varApply:/[^;:]*?:[^;]*?var\([^;]*\)(?:[;\n]|$)?/gim,keyframesRule:/^@[^\s]*keyframes/,multipleSpaces:/\s+/g},p="--",h="@media",f="@";var m=n(60309);const y=new Set;function g(e){const t=e.textContent;if(!y.has(t)){y.add(t);const n=e.cloneNode(!0);document.head.appendChild(n)}}function b(e){return e.hasAttribute("shady-unscoped")}function _(e,t){return e?("string"==typeof e&&(e=o(e)),t&&w(e,t),a(e,r.rd)):""}function v(e){return!e.__cssRules&&e.textContent&&(e.__cssRules=o(e.textContent)),e.__cssRules||null}function w(e,t,n,r){if(!e)return;let i=!1,o=e.type;if(r&&o===l.MEDIA_RULE){let t=e.selector.match(m.mA);t&&(window.matchMedia(t[1]).matches||(i=!0))}o===l.STYLE_RULE?t(e):n&&o===l.KEYFRAMES_RULE?n(e):o===l.MIXIN_RULE&&(i=!0);let s=e.rules;if(s&&!i)for(let a,l=0,c=s.length;l<c&&(a=s[l]);l++)w(a,t,n,r)}function x(e,t){let n=0;for(let r=t,i=e.length;r<i;r++)if("("===e[r])n++;else if(")"===e[r]&&0==--n)return r;return-1}function k(e,t){let n=e.indexOf("var(");if(-1===n)return t(e,"","","");let r=x(e,n+3),i=e.substring(n+4,r),o=e.substring(0,n),s=k(e.substring(r+1),t),a=i.indexOf(",");return-1===a?t(o,i.trim(),"",s):t(o,i.substring(0,a).trim(),i.substring(a+1).trim(),s)}window.ShadyDOM&&window.ShadyDOM.wrap;const C="css-build";function E(e){if(void 0!==r.Cp)return r.Cp;if(void 0===e.__cssBuild){const t=e.getAttribute(C);if(t)e.__cssBuild=t;else{const t=function(e){const t="template"===e.localName?e.content.firstChild:e.firstChild;if(t instanceof Comment){const e=t.textContent.trim().split(":");if(e[0]===C)return e[1]}return""}(e);""!==t&&function(e){const t="template"===e.localName?e.content.firstChild:e.firstChild;t.parentNode.removeChild(t)}(e),e.__cssBuild=t}}return e.__cssBuild||""}function S(e){return""!==E(e)}var P=n(10868);const A=/;\s*/m,T=/^\s*(initial)|(inherit)\s*$/,O=/\s*!important/,N="_-_";class I{constructor(){this._map={}}set(e,t){e=e.trim(),this._map[e]={properties:t,dependants:{}}}get(e){return e=e.trim(),this._map[e]||null}}let R=null;class D{constructor(){this._currentElement=null,this._measureElement=null,this._map=new I}detectMixin(e){return(0,P.OH)(e)}gatherStyles(e){const t=function(e){const t=[],n=e.querySelectorAll("style");for(let i=0;i<n.length;i++){const e=n[i];b(e)?r.WA||(g(e),e.parentNode.removeChild(e)):(t.push(e.textContent),e.parentNode.removeChild(e))}return t.join("").trim()}(e.content);if(t){const n=document.createElement("style");return n.textContent=t,e.content.insertBefore(n,e.content.firstChild),n}return null}transformTemplate(e,t){void 0===e._gatheredStyle&&(e._gatheredStyle=this.gatherStyles(e));const n=e._gatheredStyle;return n?this.transformStyle(n,t):null}transformStyle(e,t=""){let n=v(e);return this.transformRules(n,t),e.textContent=_(n),n}transformCustomStyle(e){let t=v(e);return w(t,(e=>{":root"===e.selector&&(e.selector="html"),this.transformRule(e)})),e.textContent=_(t),t}transformRules(e,t){this._currentElement=t,w(e,(e=>{this.transformRule(e)})),this._currentElement=null}transformRule(e){e.cssText=this.transformCssText(e.parsedCssText,e),":root"===e.selector&&(e.selector=":host > *")}transformCssText(e,t){return e=e.replace(m.CN,((e,n,r,i)=>this._produceCssProperties(e,n,r,i,t))),this._consumeCssProperties(e,t)}_getInitialValueForProperty(e){return this._measureElement||(this._measureElement=document.createElement("meta"),this._measureElement.setAttribute("apply-shim-measure",""),this._measureElement.style.all="initial",document.head.appendChild(this._measureElement)),window.getComputedStyle(this._measureElement).getPropertyValue(e)}_fallbacksFromPreviousRules(e){let t=e;for(;t.parent;)t=t.parent;const n={};let r=!1;return w(t,(t=>{r=r||t===e,r||t.selector===e.selector&&Object.assign(n,this._cssTextToMap(t.parsedCssText))})),n}_consumeCssProperties(e,t){let n=null;for(;n=m.$T.exec(e);){let r=n[0],i=n[1],o=n.index,s=o+r.indexOf("@apply"),a=o+r.length,l=e.slice(0,s),c=e.slice(a),d=t?this._fallbacksFromPreviousRules(t):{};Object.assign(d,this._cssTextToMap(l));let u=this._atApplyToCssProperties(i,d);e=`${l}${u}${c}`,m.$T.lastIndex=o+u.length}return e}_atApplyToCssProperties(e,t){e=e.replace(A,"");let n=[],r=this._map.get(e);if(r||(this._map.set(e,{}),r=this._map.get(e)),r){let i,o,s;this._currentElement&&(r.dependants[this._currentElement]=!0);const a=r.properties;for(i in a)s=t&&t[i],o=[i,": var(",e,N,i],s&&o.push(",",s.replace(O,"")),o.push(")"),O.test(a[i])&&o.push(" !important"),n.push(o.join(""))}return n.join("; ")}_replaceInitialOrInherit(e,t){let n=T.exec(t);return n&&(t=n[1]?this._getInitialValueForProperty(e):"apply-shim-inherit"),t}_cssTextToMap(e,t=!1){let n,r,i=e.split(";"),o={};for(let s,a,l=0;l<i.length;l++)s=i[l],s&&(a=s.split(":"),a.length>1&&(n=a[0].trim(),r=a.slice(1).join(":"),t&&(r=this._replaceInitialOrInherit(n,r)),o[n]=r));return o}_invalidateMixinEntry(e){if(R)for(let t in e.dependants)t!==this._currentElement&&R(t)}_produceCssProperties(e,t,n,r,i){if(n&&k(n,((e,t)=>{t&&this._map.get(t)&&(r=`@apply ${t};`)})),!r)return e;let o=this._consumeCssProperties(""+r,i),s=e.slice(0,e.indexOf("--")),a=this._cssTextToMap(o,!0),l=a,c=this._map.get(t),d=c&&c.properties;d?l=Object.assign(Object.create(d),a):this._map.set(t,l);let u,p,h=[],f=!1;for(u in l)p=a[u],void 0===p&&(p="initial"),d&&!(u in d)&&(f=!0),h.push(`${t}_-_${u}: ${p}`);return f&&this._invalidateMixinEntry(c),c&&(c.properties=l),n&&(s=`${e};${s}`),`${s}${h.join("; ")};`}}D.prototype.detectMixin=D.prototype.detectMixin,D.prototype.transformStyle=D.prototype.transformStyle,D.prototype.transformCustomStyle=D.prototype.transformCustomStyle,D.prototype.transformRules=D.prototype.transformRules,D.prototype.transformRule=D.prototype.transformRule,D.prototype.transformTemplate=D.prototype.transformTemplate,D.prototype._separator=N,Object.defineProperty(D.prototype,"invalidCallback",{get:()=>R,set(e){R=e}});const z=D,F={},L="_applyShimCurrentVersion",M="_applyShimNextVersion",H="_applyShimValidatingVersion",j=Promise.resolve();function B(e){let t=F[e];t&&function(e){e[L]=e[L]||0,e[H]=e[H]||0,e[M]=(e[M]||0)+1}(t)}function V(e){return e[L]===e[M]}function $(e){return!V(e)&&e[H]===e[M]}function U(e){e[H]=e[M],e._validating||(e._validating=!0,j.then((function(){e[L]=e[M],e._validating=!1})))}n(34816);const q=new z;class Y{constructor(){this.customStyleInterface=null,q.invalidCallback=B}ensure(){this.customStyleInterface||window.ShadyCSS.CustomStyleInterface&&(this.customStyleInterface=window.ShadyCSS.CustomStyleInterface,this.customStyleInterface.transformCallback=e=>{q.transformCustomStyle(e)},this.customStyleInterface.validateCallback=()=>{requestAnimationFrame((()=>{this.customStyleInterface.enqueued&&this.flushCustomStyles()}))})}prepareTemplate(e,t){if(this.ensure(),S(e))return;F[t]=e;let n=q.transformTemplate(e,t);e._styleAst=n}flushCustomStyles(){if(this.ensure(),!this.customStyleInterface)return;let e=this.customStyleInterface.processStyles();if(this.customStyleInterface.enqueued){for(let t=0;t<e.length;t++){let n=e[t],r=this.customStyleInterface.getStyleForCustomStyle(n);r&&q.transformCustomStyle(r)}this.customStyleInterface.enqueued=!1}}styleSubtree(e,t){if(this.ensure(),t&&(0,P.wW)(e,t),e.shadowRoot){this.styleElement(e);let t=e.shadowRoot.children||e.shadowRoot.childNodes;for(let e=0;e<t.length;e++)this.styleSubtree(t[e])}else{let t=e.children||e.childNodes;for(let e=0;e<t.length;e++)this.styleSubtree(t[e])}}styleElement(e){this.ensure();let{is:t}=function(e){let t=e.localName,n="",r="";return t?t.indexOf("-")>-1?n=t:(r=t,n=e.getAttribute&&e.getAttribute("is")||""):(n=e.is,r=e.extends),{is:n,typeExtension:r}}(e),n=F[t];if((!n||!S(n))&&n&&!V(n)){$(n)||(this.prepareTemplate(n,t),U(n));let r=e.shadowRoot;if(r){let e=r.querySelector("style");e&&(e.__cssRules=n._styleAst,e.textContent=_(n._styleAst))}}}styleDocument(e){this.ensure(),this.styleSubtree(document.body,e)}}if(!window.ShadyCSS||!window.ShadyCSS.ScopingShim){const e=new Y;let t=window.ShadyCSS&&window.ShadyCSS.CustomStyleInterface;window.ShadyCSS={prepareTemplate(t,n,r){e.flushCustomStyles(),e.prepareTemplate(t,n)},prepareTemplateStyles(e,t,n){window.ShadyCSS.prepareTemplate(e,t,n)},prepareTemplateDom(e,t){},styleSubtree(t,n){e.flushCustomStyles(),e.styleSubtree(t,n)},styleElement(t){e.flushCustomStyles(),e.styleElement(t)},styleDocument(t){e.flushCustomStyles(),e.styleDocument(t)},getComputedStyleValue:(e,t)=>(0,P.B7)(e,t),flushCustomStyles(){e.flushCustomStyles()},nativeCss:r.rd,nativeShadow:r.WA,cssBuild:r.Cp,disableRuntime:r.jF},t&&(window.ShadyCSS.CustomStyleInterface=t)}window.ShadyCSS.ApplyShim=q;var K=n(36608),J=n(60995),W=n(63933),G=n(76389);const X=/:host\(:dir\((ltr|rtl)\)\)/g,Z=/([\s\w-#\.\[\]\*]*):dir\((ltr|rtl)\)/g,Q=[];let ee=null,te="";function ne(){te=document.documentElement.getAttribute("dir")}function re(e){if(!e.__autoDirOptOut){e.setAttribute("dir",te)}}function ie(){ne(),te=document.documentElement.getAttribute("dir");for(let e=0;e<Q.length;e++)re(Q[e])}const oe=(0,G.o)((e=>{ee||(ne(),ee=new MutationObserver(ie),ee.observe(document.documentElement,{attributes:!0,attributeFilter:["dir"]}));const t=(0,W.Q)(e);class n extends t{static _processStyleText(e,t){return e=super._processStyleText(e,t),e=this._replaceDirInCssText(e)}static _replaceDirInCssText(e){let t=e;return t=t.replace(X,':host([dir="$1"])'),t=t.replace(Z,':host([dir="$2"]) $1'),e!==t&&(this.__activateDir=!0),t}constructor(){super(),this.__autoDirOptOut=!1}ready(){super.ready(),this.__autoDirOptOut=this.hasAttribute("dir")}connectedCallback(){t.prototype.connectedCallback&&super.connectedCallback(),this.constructor.__activateDir&&(ee&&ee.takeRecords().length&&ie(),Q.push(this),re(this))}disconnectedCallback(){if(t.prototype.disconnectedCallback&&super.disconnectedCallback(),this.constructor.__activateDir){const e=Q.indexOf(this);e>-1&&Q.splice(e,1)}}}return n.__activateDir=!1,n}));n(87529);function se(){document.body.removeAttribute("unresolved")}"interactive"===document.readyState||"complete"===document.readyState?se():window.addEventListener("DOMContentLoaded",se);var ae=n(87156),le=n(81668),ce=n(78956),de=n(21683),ue=n(4059);let pe=window.ShadyCSS;const he=(0,G.o)((e=>{const t=oe((0,J._)((0,K.SH)(e))),n={x:"pan-x",y:"pan-y",none:"none",all:"auto"};class r extends t{constructor(){super(),this.isAttached,this.__boundListeners,this._debouncers,this._applyListeners()}static get importMeta(){return this.prototype.importMeta}created(){}connectedCallback(){super.connectedCallback(),this.isAttached=!0,this.attached()}attached(){}disconnectedCallback(){super.disconnectedCallback(),this.isAttached=!1,this.detached()}detached(){}attributeChangedCallback(e,t,n,r){t!==n&&(super.attributeChangedCallback(e,t,n,r),this.attributeChanged(e,t,n))}attributeChanged(e,t,n){}_initializeProperties(){let e=Object.getPrototypeOf(this);e.hasOwnProperty("__hasRegisterFinished")||(e.__hasRegisterFinished=!0,this._registered()),super._initializeProperties(),this.root=this,this.created()}_registered(){}ready(){this._ensureAttributes(),super.ready()}_ensureAttributes(){}_applyListeners(){}serialize(e){return this._serializeValue(e)}deserialize(e,t){return this._deserializeValue(e,t)}reflectPropertyToAttribute(e,t,n){this._propertyToAttribute(e,t,n)}serializeValueToAttribute(e,t,n){this._valueToNodeAttribute(n||this,e,t)}extend(e,t){if(!e||!t)return e||t;let n=Object.getOwnPropertyNames(t);for(let r,i=0;i<n.length&&(r=n[i]);i++){let n=Object.getOwnPropertyDescriptor(t,r);n&&Object.defineProperty(e,r,n)}return e}mixin(e,t){for(let n in t)e[n]=t[n];return e}chainObject(e,t){return e&&t&&e!==t&&(e.__proto__=t),e}instanceTemplate(e){let t=this.constructor._contentForTemplate(e);return document.importNode(t,!0)}fire(e,t,n){n=n||{},t=null==t?{}:t;let r=new Event(e,{bubbles:void 0===n.bubbles||n.bubbles,cancelable:Boolean(n.cancelable),composed:void 0===n.composed||n.composed});return r.detail=t,(n.node||this).dispatchEvent(r),r}listen(e,t,n){e=e||this;let r=this.__boundListeners||(this.__boundListeners=new WeakMap),i=r.get(e);i||(i={},r.set(e,i));let o=t+n;i[o]||(i[o]=this._addMethodEventListenerToNode(e,t,n,this))}unlisten(e,t,n){e=e||this;let r=this.__boundListeners&&this.__boundListeners.get(e),i=t+n,o=r&&r[i];o&&(this._removeEventListenerFromNode(e,t,o),r[i]=null)}setScrollDirection(e,t){(0,le.BP)(t||this,n[e]||"auto")}$$(e){return this.root.querySelector(e)}get domHost(){let e=this.getRootNode();return e instanceof DocumentFragment?e.host:e}distributeContent(){window.ShadyDOM&&this.shadowRoot&&ShadyDOM.flush()}getEffectiveChildNodes(){return(0,ae.vz)(this).getEffectiveChildNodes()}queryDistributedElements(e){return(0,ae.vz)(this).queryDistributedElements(e)}getEffectiveChildren(){return this.getEffectiveChildNodes().filter((function(e){return e.nodeType===Node.ELEMENT_NODE}))}getEffectiveTextContent(){let e=this.getEffectiveChildNodes(),t=[];for(let n,r=0;n=e[r];r++)n.nodeType!==Node.COMMENT_NODE&&t.push(n.textContent);return t.join("")}queryEffectiveChildren(e){let t=this.queryDistributedElements(e);return t&&t[0]}queryAllEffectiveChildren(e){return this.queryDistributedElements(e)}getContentChildNodes(e){let t=this.root.querySelector(e||"slot");return t?(0,ae.vz)(t).getDistributedNodes():[]}getContentChildren(e){return this.getContentChildNodes(e).filter((function(e){return e.nodeType===Node.ELEMENT_NODE}))}isLightDescendant(e){const t=this;return t!==e&&t.contains(e)&&t.getRootNode()===e.getRootNode()}isLocalDescendant(e){return this.root===e.getRootNode()}scopeSubtree(e,t){}getComputedStyleValue(e){return pe.getComputedStyleValue(this,e)}debounce(e,t,n){return this._debouncers=this._debouncers||{},this._debouncers[e]=ce.d.debounce(this._debouncers[e],n>0?de.Wc.after(n):de.YA,t.bind(this))}isDebouncerActive(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];return!(!t||!t.isActive())}flushDebouncer(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];t&&t.flush()}cancelDebouncer(e){this._debouncers=this._debouncers||{};let t=this._debouncers[e];t&&t.cancel()}async(e,t){return t>0?de.Wc.run(e.bind(this),t):~de.YA.run(e.bind(this))}cancelAsync(e){e<0?de.YA.cancel(~e):de.Wc.cancel(e)}create(e,t){let n=document.createElement(e);if(t)if(n.setProperties)n.setProperties(t);else for(let r in t)n[r]=t[r];return n}elementMatches(e,t){return(0,ae.Ku)(t||this,e)}toggleAttribute(e,t){let n=this;return 3===arguments.length&&(n=arguments[2]),1==arguments.length&&(t=!n.hasAttribute(e)),t?(n.setAttribute(e,""),!0):(n.removeAttribute(e),!1)}toggleClass(e,t,n){n=n||this,1==arguments.length&&(t=!n.classList.contains(e)),t?n.classList.add(e):n.classList.remove(e)}transform(e,t){(t=t||this).style.webkitTransform=e,t.style.transform=e}translate3d(e,t,n,r){r=r||this,this.transform("translate3d("+e+","+t+","+n+")",r)}arrayDelete(e,t){let n;if(Array.isArray(e)){if(n=e.indexOf(t),n>=0)return e.splice(n,1)}else{if(n=(0,ue.U2)(this,e).indexOf(t),n>=0)return this.splice(e,n,1)}return null}_logger(e,t){switch(Array.isArray(t)&&1===t.length&&Array.isArray(t[0])&&(t=t[0]),e){case"log":case"warn":case"error":console[e](...t)}}_log(...e){this._logger("log",e)}_warn(...e){this._logger("warn",e)}_error(...e){this._logger("error",e)}_logf(e,...t){return["[%s::%s]",this.is,e,...t]}}return r.prototype.is="",r}))},72419:(e,t,n)=>{"use strict";n.d(t,{x:()=>o});var r=n(18691);let i;i=r.E._mutablePropertyChange;const o={properties:{mutableData:Boolean},_shouldPropertyChange(e,t,n){return i(this,e,t,n,this.mutableData)}}},9672:(e,t,n)=>{"use strict";n.d(t,{k:()=>i});var r=n(33367);n(56646);const i=function(e){let t;return t="function"==typeof e?e:i.Class(e),customElements.define(t.is,t),t};i.Class=r.w},87156:(e,t,n)=>{"use strict";n.d(t,{Ku:()=>s,vz:()=>c});n(56646),n(74460);var r=n(20723);n(93252),n(78956);const i=Element.prototype,o=i.matches||i.matchesSelector||i.mozMatchesSelector||i.msMatchesSelector||i.oMatchesSelector||i.webkitMatchesSelector,s=function(e,t){return o.call(e,t)};class a{constructor(e){this.node=e}observeNodes(e){return new r.o(this.node,e)}unobserveNodes(e){e.disconnect()}notifyObserver(){}deepContains(e){if(this.node.contains(e))return!0;let t=e,n=e.ownerDocument;for(;t&&t!==n&&t!==this.node;)t=t.parentNode||t.host;return t===this.node}getOwnerRoot(){return this.node.getRootNode()}getDistributedNodes(){return"slot"===this.node.localName?this.node.assignedNodes({flatten:!0}):[]}getDestinationInsertionPoints(){let e=[],t=this.node.assignedSlot;for(;t;)e.push(t),t=t.assignedSlot;return e}importNode(e,t){return(this.node instanceof Document?this.node:this.node.ownerDocument).importNode(e,t)}getEffectiveChildNodes(){return r.o.getFlattenedNodes(this.node)}queryDistributedElements(e){let t=this.getEffectiveChildNodes(),n=[];for(let r,i=0,o=t.length;i<o&&(r=t[i]);i++)r.nodeType===Node.ELEMENT_NODE&&s(r,e)&&n.push(r);return n}get activeElement(){let e=this.node;return void 0!==e._activeElement?e._activeElement:e.activeElement}}class l{constructor(e){this.event=e}get rootTarget(){return this.event.composedPath()[0]}get localTarget(){return this.event.target}get path(){return this.event.composedPath()}}a.prototype.cloneNode,a.prototype.appendChild,a.prototype.insertBefore,a.prototype.removeChild,a.prototype.replaceChild,a.prototype.setAttribute,a.prototype.removeAttribute,a.prototype.querySelector,a.prototype.querySelectorAll,a.prototype.parentNode,a.prototype.firstChild,a.prototype.lastChild,a.prototype.nextSibling,a.prototype.previousSibling,a.prototype.firstElementChild,a.prototype.lastElementChild,a.prototype.nextElementSibling,a.prototype.previousElementSibling,a.prototype.childNodes,a.prototype.children,a.prototype.classList,a.prototype.textContent,a.prototype.innerHTML,function(e,t){for(let n=0;n<t.length;n++){let r=t[n];e[r]=function(){return this.node[r].apply(this.node,arguments)}}}(a.prototype,["cloneNode","appendChild","insertBefore","removeChild","replaceChild","setAttribute","removeAttribute","querySelector","querySelectorAll"]),function(e,t){for(let n=0;n<t.length;n++){let r=t[n];Object.defineProperty(e,r,{get:function(){return this.node[r]},configurable:!0})}}(a.prototype,["parentNode","firstChild","lastChild","nextSibling","previousSibling","firstElementChild","lastElementChild","nextElementSibling","previousElementSibling","childNodes","children","classList"]),function(e,t){for(let n=0;n<t.length;n++){let r=t[n];Object.defineProperty(e,r,{get:function(){return this.node[r]},set:function(e){this.node[r]=e},configurable:!0})}}(a.prototype,["textContent","innerHTML"]);const c=function(e){if(!(e=e||document).__domApi){let t;t=e instanceof Event?new l(e):new a(e),e.__domApi=t}return e.__domApi}},37692:(e,t,n)=>{"use strict";n.d(t,{F:()=>i});var r=n(52521);const i={templatize(e,t){this._templatizerTemplate=e,this.ctor=(0,r.Uv)(e,this,{mutableData:Boolean(t),parentModel:this._parentModel,instanceProps:this._instanceProps,forwardHostProp:this._forwardHostPropV2,notifyInstanceProp:this._notifyInstancePropV2})},stamp(e){return new this.ctor(e)},modelForElement(e){return(0,r.GJ)(this._templatizerTemplate,e)}}},36608:(e,t,n)=>{"use strict";n.d(t,{SH:()=>u});n(56646);var r=n(74460),i=n(76389),o=n(15392),s=n(42687),a=n(21384),l=n(40729),c=n(24072);const d=(0,i.o)((e=>{const t=(0,c.e)(e);function n(e){const t=Object.getPrototypeOf(e);return t.prototype instanceof i?t:null}function r(e){if(!e.hasOwnProperty(JSCompiler_renameProperty("__ownProperties",e))){let t=null;if(e.hasOwnProperty(JSCompiler_renameProperty("properties",e))){const n=e.properties;n&&(t=function(e){const t={};for(let n in e){const r=e[n];t[n]="function"==typeof r?{type:r}:r}return t}(n))}e.__ownProperties=t}return e.__ownProperties}class i extends t{static get observedAttributes(){const e=this._properties;return e?Object.keys(e).map((e=>this.attributeNameForProperty(e))):[]}static finalize(){if(!this.hasOwnProperty(JSCompiler_renameProperty("__finalized",this))){const e=n(this);e&&e.finalize(),this.__finalized=!0,this._finalizeClass()}}static _finalizeClass(){const e=r(this);e&&this.createProperties(e)}static get _properties(){if(!this.hasOwnProperty(JSCompiler_renameProperty("__properties",this))){const e=n(this);this.__properties=Object.assign({},e&&e._properties,r(this))}return this.__properties}static typeForProperty(e){const t=this._properties[e];return t&&t.type}_initializeProperties(){this.constructor.finalize(),super._initializeProperties()}connectedCallback(){super.connectedCallback&&super.connectedCallback(),this._enableProperties()}disconnectedCallback(){super.disconnectedCallback&&super.disconnectedCallback()}}return i})),u=(0,i.o)((e=>{const t=d((0,l.q)(e));return class extends t{static get polymerElementVersion(){return"3.0.5"}static _finalizeClass(){var e;super._finalizeClass(),this.hasOwnProperty(JSCompiler_renameProperty("is",this))&&this.is&&(e=this.prototype,p.push(e));const t=((n=this).hasOwnProperty(JSCompiler_renameProperty("__ownObservers",n))||(n.__ownObservers=n.hasOwnProperty(JSCompiler_renameProperty("observers",n))?n.observers:null),n.__ownObservers);var n;t&&this.createObservers(t,this._properties);let r=this.template;r&&("string"==typeof r?(console.error("template getter must return HTMLTemplateElement"),r=null):r=r.cloneNode(!0)),this.prototype._template=r}static createProperties(e){for(let o in e)t=this.prototype,n=o,r=e[o],i=e,r.computed&&(r.readOnly=!0),r.computed&&!t._hasReadOnlyEffect(n)&&t._createComputedProperty(n,r.computed,i),r.readOnly&&!t._hasReadOnlyEffect(n)&&t._createReadOnlyProperty(n,!r.computed),r.reflectToAttribute&&!t._hasReflectEffect(n)&&t._createReflectedProperty(n),r.notify&&!t._hasNotifyEffect(n)&&t._createNotifyingProperty(n),r.observer&&t._createPropertyObserver(n,r.observer,i[r.observer]),t._addPropertyToAttributeMap(n);var t,n,r,i}static createObservers(e,t){const n=this.prototype;for(let r=0;r<e.length;r++)n._createMethodObserver(e[r],t)}static get template(){return this.hasOwnProperty(JSCompiler_renameProperty("_template",this))||(this._template=this.prototype.hasOwnProperty(JSCompiler_renameProperty("_template",this.prototype))?this.prototype._template:function(e){let t=null;if(e&&(!r.XN||r.ZN)&&(t=a.t.import(e,"template"),r.XN&&!t))throw new Error("strictTemplatePolicy: expecting dom-module or null template for "+e);return t}(this.is)||Object.getPrototypeOf(this.prototype).constructor.template),this._template}static set template(e){this._template=e}static get importPath(){if(!this.hasOwnProperty(JSCompiler_renameProperty("_importPath",this))){const e=this.importMeta;if(e)this._importPath=(0,s.iY)(e.url);else{const e=a.t.import(this.is);this._importPath=e&&e.assetpath||Object.getPrototypeOf(this.prototype).constructor.importPath}}return this._importPath}constructor(){super(),this._template,this._importPath,this.rootPath,this.importPath,this.root,this.$}_initializeProperties(){this.constructor.finalize(),this.constructor._finalizeTemplate(this.localName),super._initializeProperties(),this.rootPath=r.sM,this.importPath=this.constructor.importPath;let e=function(e){if(!e.hasOwnProperty(JSCompiler_renameProperty("__propertyDefaults",e))){e.__propertyDefaults=null;let t=e._properties;for(let n in t){let r=t[n];"value"in r&&(e.__propertyDefaults=e.__propertyDefaults||{},e.__propertyDefaults[n]=r)}}return e.__propertyDefaults}(this.constructor);if(e)for(let t in e){let n=e[t];if(!this.hasOwnProperty(t)){let e="function"==typeof n.value?n.value.call(this):n.value;this._hasAccessor(t)?this._setPendingProperty(t,e,!0):this[t]=e}}}static _processStyleText(e,t){return(0,s.Rq)(e,t)}static _finalizeTemplate(e){const t=this.prototype._template;if(t&&!t.__polymerFinalized){t.__polymerFinalized=!0;const n=this.importPath;!function(e,t,n,r){const i=t.content.querySelectorAll("style"),s=(0,o.uT)(t),a=(0,o.lx)(n),l=t.content.firstElementChild;for(let o=0;o<a.length;o++){let n=a[o];n.textContent=e._processStyleText(n.textContent,r),t.content.insertBefore(n,l)}let c=0;for(let o=0;o<s.length;o++){let t=s[o],n=i[c];n!==t?(t=t.cloneNode(!0),n.parentNode.insertBefore(t,n)):c++,t.textContent=e._processStyleText(t.textContent,r)}window.ShadyCSS&&window.ShadyCSS.prepareTemplate(t,n)}(this,t,e,n?(0,s.Kk)(n):""),this.prototype._bindTemplate(t)}}connectedCallback(){window.ShadyCSS&&this._template&&window.ShadyCSS.styleElement(this),super.connectedCallback()}ready(){this._template&&(this.root=this._stampTemplate(this._template),this.$=this.root.$),super.ready()}_readyClients(){this._template&&(this.root=this._attachDom(this.root)),super._readyClients()}_attachDom(e){if(this.attachShadow)return e?(this.shadowRoot||this.attachShadow({mode:"open"}),this.shadowRoot.appendChild(e),this.shadowRoot):null;throw new Error("ShadowDOM not available. PolymerElement can create dom as children instead of in ShadowDOM by setting `this.root = this;` before `ready`.")}updateStyles(e){window.ShadyCSS&&window.ShadyCSS.styleSubtree(this,e)}resolveUrl(e,t){return!t&&this.importPath&&(t=(0,s.Kk)(this.importPath)),(0,s.Kk)(e,t)}static _parseTemplateContent(e,t,n){return t.dynamicFns=t.dynamicFns||this._properties,super._parseTemplateContent(e,t,n)}}}));const p=[]},60995:(e,t,n)=>{"use strict";n.d(t,{_:()=>o});n(56646);var r=n(76389),i=n(81668);const o=(0,r.o)((e=>class extends e{_addEventListenerToNode(e,t,n){(0,i.NH)(e,t,n)||super._addEventListenerToNode(e,t,n)}_removeEventListenerFromNode(e,t,n){(0,i.ys)(e,t,n)||super._removeEventListenerFromNode(e,t,n)}}))},18691:(e,t,n)=>{"use strict";n.d(t,{E:()=>o,w:()=>s});var r=n(76389);function i(e,t,n,r,i){let o;i&&(o="object"==typeof n&&null!==n,o&&(r=e.__dataTemp[t]));let s=r!==n&&(r==r||n==n);return o&&s&&(e.__dataTemp[t]=n),s}const o=(0,r.o)((e=>class extends e{_shouldPropertyChange(e,t,n){return i(this,e,t,n,!0)}})),s=(0,r.o)((e=>class extends e{static get properties(){return{mutableData:Boolean}}_shouldPropertyChange(e,t,n){return i(this,e,t,n,this.mutableData)}}));o._mutablePropertyChange=i},24072:(e,t,n)=>{"use strict";n.d(t,{e:()=>o});n(56646);var r=n(76389);const i=n(21683).YA,o=(0,r.o)((e=>class extends e{static createProperties(e){const t=this.prototype;for(let n in e)n in t||t._createPropertyAccessor(n)}static attributeNameForProperty(e){return e.toLowerCase()}static typeForProperty(e){}_createPropertyAccessor(e,t){this._addPropertyToAttributeMap(e),this.hasOwnProperty("__dataHasAccessor")||(this.__dataHasAccessor=Object.assign({},this.__dataHasAccessor)),this.__dataHasAccessor[e]||(this.__dataHasAccessor[e]=!0,this._definePropertyAccessor(e,t))}_addPropertyToAttributeMap(e){if(this.hasOwnProperty("__dataAttributes")||(this.__dataAttributes=Object.assign({},this.__dataAttributes)),!this.__dataAttributes[e]){const t=this.constructor.attributeNameForProperty(e);this.__dataAttributes[t]=e}}_definePropertyAccessor(e,t){Object.defineProperty(this,e,{get(){return this._getProperty(e)},set:t?function(){}:function(t){this._setProperty(e,t)}})}constructor(){super(),this.__dataEnabled=!1,this.__dataReady=!1,this.__dataInvalid=!1,this.__data={},this.__dataPending=null,this.__dataOld=null,this.__dataInstanceProps=null,this.__serializing=!1,this._initializeProperties()}ready(){this.__dataReady=!0,this._flushProperties()}_initializeProperties(){for(let e in this.__dataHasAccessor)this.hasOwnProperty(e)&&(this.__dataInstanceProps=this.__dataInstanceProps||{},this.__dataInstanceProps[e]=this[e],delete this[e])}_initializeInstanceProperties(e){Object.assign(this,e)}_setProperty(e,t){this._setPendingProperty(e,t)&&this._invalidateProperties()}_getProperty(e){return this.__data[e]}_setPendingProperty(e,t,n){let r=this.__data[e],i=this._shouldPropertyChange(e,t,r);return i&&(this.__dataPending||(this.__dataPending={},this.__dataOld={}),this.__dataOld&&!(e in this.__dataOld)&&(this.__dataOld[e]=r),this.__data[e]=t,this.__dataPending[e]=t),i}_invalidateProperties(){!this.__dataInvalid&&this.__dataReady&&(this.__dataInvalid=!0,i.run((()=>{this.__dataInvalid&&(this.__dataInvalid=!1,this._flushProperties())})))}_enableProperties(){this.__dataEnabled||(this.__dataEnabled=!0,this.__dataInstanceProps&&(this._initializeInstanceProperties(this.__dataInstanceProps),this.__dataInstanceProps=null),this.ready())}_flushProperties(){const e=this.__data,t=this.__dataPending,n=this.__dataOld;this._shouldPropertiesChange(e,t,n)&&(this.__dataPending=null,this.__dataOld=null,this._propertiesChanged(e,t,n))}_shouldPropertiesChange(e,t,n){return Boolean(t)}_propertiesChanged(e,t,n){}_shouldPropertyChange(e,t,n){return n!==t&&(n==n||t==t)}attributeChangedCallback(e,t,n,r){t!==n&&this._attributeToProperty(e,n),super.attributeChangedCallback&&super.attributeChangedCallback(e,t,n,r)}_attributeToProperty(e,t,n){if(!this.__serializing){const r=this.__dataAttributes,i=r&&r[e]||e;this[i]=this._deserializeValue(t,n||this.constructor.typeForProperty(i))}}_propertyToAttribute(e,t,n){this.__serializing=!0,n=arguments.length<3?this[e]:n,this._valueToNodeAttribute(this,n,t||this.constructor.attributeNameForProperty(e)),this.__serializing=!1}_valueToNodeAttribute(e,t,n){const r=this._serializeValue(t);void 0===r?e.removeAttribute(n):e.setAttribute(n,r)}_serializeValue(e){switch(typeof e){case"boolean":return e?"":void 0;default:return null!=e?e.toString():void 0}}_deserializeValue(e,t){switch(t){case Boolean:return null!==e;case Number:return Number(e);default:return e}}}))},63933:(e,t,n)=>{"use strict";n.d(t,{Q:()=>l});n(56646);var r=n(76389),i=n(67130),o=n(24072);const s={};let a=HTMLElement.prototype;for(;a;){let e=Object.getOwnPropertyNames(a);for(let t=0;t<e.length;t++)s[e[t]]=!0;a=Object.getPrototypeOf(a)}const l=(0,r.o)((e=>{const t=(0,o.e)(e);return class extends t{static createPropertiesForAttributes(){let e=this.observedAttributes;for(let t=0;t<e.length;t++)this.prototype._createPropertyAccessor((0,i.z)(e[t]))}static attributeNameForProperty(e){return(0,i.n)(e)}_initializeProperties(){this.__dataProto&&(this._initializeProtoProperties(this.__dataProto),this.__dataProto=null),super._initializeProperties()}_initializeProtoProperties(e){for(let t in e)this._setProperty(t,e[t])}_ensureAttribute(e,t){const n=this;n.hasAttribute(e)||this._valueToNodeAttribute(n,t,e)}_serializeValue(e){switch(typeof e){case"object":if(e instanceof Date)return e.toString();if(e)try{return JSON.stringify(e)}catch(t){return""}default:return super._serializeValue(e)}}_deserializeValue(e,t){let n;switch(t){case Object:try{n=JSON.parse(e)}catch(r){n=e}break;case Array:try{n=JSON.parse(e)}catch(r){n=null,console.warn("Polymer::Attributes: couldn't decode Array as JSON: "+e)}break;case Date:n=isNaN(e)?String(e):Number(e),n=new Date(n);break;default:n=super._deserializeValue(e,t)}return n}_definePropertyAccessor(e,t){!function(e,t){if(!s[t]){let n=e[t];void 0!==n&&(e.__data?e._setPendingProperty(t,n):(e.__dataProto?e.hasOwnProperty(JSCompiler_renameProperty("__dataProto",e))||(e.__dataProto=Object.create(e.__dataProto)):e.__dataProto={},e.__dataProto[t]=n))}}(this,e),super._definePropertyAccessor(e,t)}_hasAccessor(e){return this.__dataHasAccessor&&this.__dataHasAccessor[e]}_isPropertyPending(e){return Boolean(this.__dataPending&&e in this.__dataPending)}}}))},40729:(e,t,n)=>{"use strict";n.d(t,{q:()=>$});n(56646);var r=n(76389),i=n(4059),o=n(67130),s=n(63933);const a={"dom-if":!0,"dom-repeat":!0};function l(e){let t=e.getAttribute("is");if(t&&a[t]){let n=e;for(n.removeAttribute("is"),e=n.ownerDocument.createElement(t),n.parentNode.replaceChild(e,n),e.appendChild(n);n.attributes.length;)e.setAttribute(n.attributes[0].name,n.attributes[0].value),n.removeAttribute(n.attributes[0].name)}return e}function c(e,t){let n=t.parentInfo&&c(e,t.parentInfo);if(!n)return e;for(let r=n.firstChild,i=0;r;r=r.nextSibling)if(t.parentIndex===i++)return r}function d(e,t,n,r){r.id&&(t[r.id]=n)}function u(e,t,n){if(n.events&&n.events.length)for(let r,i=0,o=n.events;i<o.length&&(r=o[i]);i++)e._addMethodEventListenerToNode(t,r.name,r.value,e)}function p(e,t,n){n.templateInfo&&(t._templateInfo=n.templateInfo)}const h=(0,r.o)((e=>class extends e{static _parseTemplate(e,t){if(!e._templateInfo){let n=e._templateInfo={};n.nodeInfoList=[],n.stripWhiteSpace=t&&t.stripWhiteSpace||e.hasAttribute("strip-whitespace"),this._parseTemplateContent(e,n,{parent:null})}return e._templateInfo}static _parseTemplateContent(e,t,n){return this._parseTemplateNode(e.content,t,n)}static _parseTemplateNode(e,t,n){let r,i=e;return"template"!=i.localName||i.hasAttribute("preserve-content")?"slot"===i.localName&&(t.hasInsertionPoint=!0):r=this._parseTemplateNestedTemplate(i,t,n)||r,i.firstChild&&(r=this._parseTemplateChildNodes(i,t,n)||r),i.hasAttributes&&i.hasAttributes()&&(r=this._parseTemplateNodeAttributes(i,t,n)||r),r}static _parseTemplateChildNodes(e,t,n){if("script"!==e.localName&&"style"!==e.localName)for(let r,i=e.firstChild,o=0;i;i=r){if("template"==i.localName&&(i=l(i)),r=i.nextSibling,i.nodeType===Node.TEXT_NODE){let n=r;for(;n&&n.nodeType===Node.TEXT_NODE;)i.textContent+=n.textContent,r=n.nextSibling,e.removeChild(n),n=r;if(t.stripWhiteSpace&&!i.textContent.trim()){e.removeChild(i);continue}}let s={parentIndex:o,parentInfo:n};this._parseTemplateNode(i,t,s)&&(s.infoIndex=t.nodeInfoList.push(s)-1),i.parentNode&&o++}}static _parseTemplateNestedTemplate(e,t,n){let r=this._parseTemplate(e,t);return(r.content=e.content.ownerDocument.createDocumentFragment()).appendChild(e.content),n.templateInfo=r,!0}static _parseTemplateNodeAttributes(e,t,n){let r=!1,i=Array.from(e.attributes);for(let o,s=i.length-1;o=i[s];s--)r=this._parseTemplateNodeAttribute(e,t,n,o.name,o.value)||r;return r}static _parseTemplateNodeAttribute(e,t,n,r,i){return"on-"===r.slice(0,3)?(e.removeAttribute(r),n.events=n.events||[],n.events.push({name:r.slice(3),value:i}),!0):"id"===r&&(n.id=i,!0)}static _contentForTemplate(e){let t=e._templateInfo;return t&&t.content||e.content}_stampTemplate(e){e&&!e.content&&window.HTMLTemplateElement&&HTMLTemplateElement.decorate&&HTMLTemplateElement.decorate(e);let t=this.constructor._parseTemplate(e),n=t.nodeInfoList,r=t.content||e.content,i=document.importNode(r,!0);i.__noInsertionPoint=!t.hasInsertionPoint;let o=i.nodeList=new Array(n.length);i.$={};for(let s,a=0,l=n.length;a<l&&(s=n[a]);a++){let e=o[a]=c(i,s);d(0,i.$,e,s),p(0,e,s),u(this,e,s)}return i=i,i}_addMethodEventListenerToNode(e,t,n,r){let i=function(e,t,n){return e=e._methodHost||e,function(t){e[n]?e[n](t,t.detail):console.warn("listener method `"+n+"` not defined")}}(r=r||e,0,n);return this._addEventListenerToNode(e,t,i),i}_addEventListenerToNode(e,t,n){e.addEventListener(t,n)}_removeEventListenerFromNode(e,t,n){e.removeEventListener(t,n)}}));var f=n(74460);let m=0;const y={COMPUTE:"__computeEffects",REFLECT:"__reflectEffects",NOTIFY:"__notifyEffects",PROPAGATE:"__propagateEffects",OBSERVE:"__observeEffects",READ_ONLY:"__readOnly"},g=/[A-Z]/;let b;function _(e,t){let n=e[t];if(n){if(!e.hasOwnProperty(t)){n=e[t]=Object.create(e[t]);for(let e in n){let t=n[e],r=n[e]=Array(t.length);for(let e=0;e<t.length;e++)r[e]=t[e]}}}else n=e[t]={};return n}function v(e,t,n,r,i,o){if(t){let s=!1,a=m++;for(let l in n)w(e,t,a,l,n,r,i,o)&&(s=!0);return s}return!1}function w(e,t,n,r,o,s,a,l){let c=!1,d=t[a?(0,i.Jz)(r):r];if(d)for(let i,u=0,p=d.length;u<p&&(i=d[u]);u++)i.info&&i.info.lastRun===n||a&&!x(r,i.trigger)||(i.info&&(i.info.lastRun=n),i.fn(e,r,o,s,i.info,a,l),c=!0);return c}function x(e,t){if(t){let n=t.name;return n==e||t.structured&&(0,i.jg)(n,e)||t.wildcard&&(0,i.SG)(n,e)}return!0}function k(e,t,n,r,i){let o="string"==typeof i.method?e[i.method]:i.method,s=i.property;o?o.call(e,e.__data[s],r[s]):i.dynamicFn||console.warn("observer method `"+i.method+"` not defined")}function C(e,t,n){let r=(0,i.Jz)(t);if(r!==t){return E(e,(0,o.n)(r)+"-changed",n[t],t),!0}return!1}function E(e,t,n,r){let i={value:n,queueProperty:!0};r&&(i.path=r),e.dispatchEvent(new CustomEvent(t,{detail:i}))}function S(e,t,n,r,o,s){let a=(s?(0,i.Jz)(t):t)!=t?t:null,l=a?(0,i.U2)(e,a):e.__data[t];a&&void 0===l&&(l=n[t]),E(e,o.eventName,l,a)}function P(e,t,n,r,i){let o=e.__data[t];f.v1&&(o=(0,f.v1)(o,i.attrName,"attribute",e)),e._propertyToAttribute(t,i.attrName,o)}function A(e,t,n,r,i){let o=z(e,t,n,r,i),s=i.methodInfo;e.__dataHasAccessor&&e.__dataHasAccessor[s]?e._setPendingProperty(s,o,!0):e[s]=o}function T(e,t,n,r,i,s,a){n.bindings=n.bindings||[];let l={kind:r,target:i,parts:s,literal:a,isCompound:1!==s.length};if(n.bindings.push(l),function(e){return Boolean(e.target)&&"attribute"!=e.kind&&"text"!=e.kind&&!e.isCompound&&"{"===e.parts[0].mode}(l)){let{event:e,negate:t}=l.parts[0];l.listenerEvent=e||(0,o.n)(i)+"-changed",l.listenerNegate=t}let c=t.nodeInfoList.length;for(let o=0;o<l.parts.length;o++){let n=l.parts[o];n.compoundIndex=o,O(e,t,l,n,c)}}function O(e,t,n,r,i){if(!r.literal)if("attribute"===n.kind&&"-"===n.target[0])console.warn("Cannot set attribute "+n.target+' because "-" is not a valid attribute starting character');else{let o=r.dependencies,s={index:i,binding:n,part:r,evaluator:e};for(let n=0;n<o.length;n++){let r=o[n];"string"==typeof r&&(r=j(r),r.wildcard=!0),e._addTemplatePropertyEffect(t,r.rootProperty,{fn:N,info:s,trigger:r})}}}function N(e,t,n,r,o,s,a){let l=a[o.index],c=o.binding,d=o.part;if(s&&d.source&&t.length>d.source.length&&"property"==c.kind&&!c.isCompound&&l.__isPropertyEffectsClient&&l.__dataHasAccessor&&l.__dataHasAccessor[c.target]){let r=n[t];t=(0,i.Iu)(d.source,c.target,t),l._setPendingPropertyOrPath(t,r,!1,!0)&&e._enqueueClient(l)}else{!function(e,t,n,r,i){i=function(e,t,n,r){if(n.isCompound){let i=e.__dataCompoundStorage[n.target];i[r.compoundIndex]=t,t=i.join("")}"attribute"!==n.kind&&("textContent"!==n.target&&("value"!==n.target||"input"!==e.localName&&"textarea"!==e.localName)||(t=null==t?"":t));return t}(t,i,n,r),f.v1&&(i=(0,f.v1)(i,n.target,n.kind,t));if("attribute"==n.kind)e._valueToNodeAttribute(t,i,n.target);else{let r=n.target;t.__isPropertyEffectsClient&&t.__dataHasAccessor&&t.__dataHasAccessor[r]?t[y.READ_ONLY]&&t[y.READ_ONLY][r]||t._setPendingProperty(r,i)&&e._enqueueClient(t):e._setUnmanagedPropertyToNode(t,r,i)}}(e,l,c,d,o.evaluator._evaluateBinding(e,d,t,n,r,s))}}function I(e,t){if(t.isCompound){let n=e.__dataCompoundStorage||(e.__dataCompoundStorage={}),r=t.parts,i=new Array(r.length);for(let e=0;e<r.length;e++)i[e]=r[e].literal;let o=t.target;n[o]=i,t.literal&&"property"==t.kind&&(e[o]=t.literal)}}function R(e,t,n){if(n.listenerEvent){let r=n.parts[0];e.addEventListener(n.listenerEvent,(function(e){!function(e,t,n,r,o){let s,a=e.detail,l=a&&a.path;l?(r=(0,i.Iu)(n,r,l),s=a&&a.value):s=e.currentTarget[n],s=o?!s:s,t[y.READ_ONLY]&&t[y.READ_ONLY][r]||!t._setPendingPropertyOrPath(r,s,!0,Boolean(l))||a&&a.queueProperty||t._invalidateProperties()}(e,t,n.target,r.source,r.negate)}))}}function D(e,t,n,r,i,o){o=t.static||o&&("object"!=typeof o||o[t.methodName]);let s={methodName:t.methodName,args:t.args,methodInfo:i,dynamicFn:o};for(let a,l=0;l<t.args.length&&(a=t.args[l]);l++)a.literal||e._addPropertyEffect(a.rootProperty,n,{fn:r,info:s,trigger:a});o&&e._addPropertyEffect(t.methodName,n,{fn:r,info:s})}function z(e,t,n,r,i){let o=e._methodHost||e,s=o[i.methodName];if(s){let r=e._marshalArgs(i.args,t,n);return s.apply(o,r)}i.dynamicFn||console.warn("method `"+i.methodName+"` not defined")}const F=[],L=new RegExp("(\\[\\[|{{)\\s*(?:(!)\\s*)?((?:[a-zA-Z_$][\\w.:$\\-*]*)\\s*(?:\\(\\s*(?:(?:(?:((?:[a-zA-Z_$][\\w.:$\\-*]*)|(?:[-+]?[0-9]*\\.?[0-9]+(?:[eE][-+]?[0-9]+)?)|(?:(?:'(?:[^'\\\\]|\\\\.)*')|(?:\"(?:[^\"\\\\]|\\\\.)*\")))\\s*)(?:,\\s*(?:((?:[a-zA-Z_$][\\w.:$\\-*]*)|(?:[-+]?[0-9]*\\.?[0-9]+(?:[eE][-+]?[0-9]+)?)|(?:(?:'(?:[^'\\\\]|\\\\.)*')|(?:\"(?:[^\"\\\\]|\\\\.)*\")))\\s*))*)?)\\)\\s*)?)(?:]]|}})","g");function M(e){let t="";for(let n=0;n<e.length;n++){t+=e[n].literal||""}return t}function H(e){let t=e.match(/([^\s]+?)\(([\s\S]*)\)/);if(t){let e={methodName:t[1],static:!0,args:F};if(t[2].trim()){return function(e,t){return t.args=e.map((function(e){let n=j(e);return n.literal||(t.static=!1),n}),this),t}(t[2].replace(/\\,/g,"&comma;").split(","),e)}return e}return null}function j(e){let t=e.trim().replace(/&comma;/g,",").replace(/\\(.)/g,"$1"),n={name:t,value:"",literal:!1},r=t[0];switch("-"===r&&(r=t[1]),r>="0"&&r<="9"&&(r="#"),r){case"'":case'"':n.value=t.slice(1,-1),n.literal=!0;break;case"#":n.value=Number(t),n.literal=!0}return n.literal||(n.rootProperty=(0,i.Jz)(t),n.structured=(0,i.AZ)(t),n.structured&&(n.wildcard=".*"==t.slice(-2),n.wildcard&&(n.name=t.slice(0,-2)))),n}function B(e,t,n,r){let i=n+".splices";e.notifyPath(i,{indexSplices:r}),e.notifyPath(n+".length",t.length),e.__data[i]={indexSplices:null}}function V(e,t,n,r,i,o){B(e,t,n,[{index:r,addedCount:i,removed:o,object:t,type:"splice"}])}const $=(0,r.o)((e=>{const t=h((0,s.Q)(e));class n extends t{constructor(){super(),this.__isPropertyEffectsClient=!0,this.__dataCounter=0,this.__dataClientsReady,this.__dataPendingClients,this.__dataToNotify,this.__dataLinkedPaths,this.__dataHasPaths,this.__dataCompoundStorage,this.__dataHost,this.__dataTemp,this.__dataClientsInitialized,this.__data,this.__dataPending,this.__dataOld,this.__computeEffects,this.__reflectEffects,this.__notifyEffects,this.__propagateEffects,this.__observeEffects,this.__readOnly,this.__templateInfo}get PROPERTY_EFFECT_TYPES(){return y}_initializeProperties(){super._initializeProperties(),U.registerHost(this),this.__dataClientsReady=!1,this.__dataPendingClients=null,this.__dataToNotify=null,this.__dataLinkedPaths=null,this.__dataHasPaths=!1,this.__dataCompoundStorage=this.__dataCompoundStorage||null,this.__dataHost=this.__dataHost||null,this.__dataTemp={},this.__dataClientsInitialized=!1}_initializeProtoProperties(e){this.__data=Object.create(e),this.__dataPending=Object.create(e),this.__dataOld={}}_initializeInstanceProperties(e){let t=this[y.READ_ONLY];for(let n in e)t&&t[n]||(this.__dataPending=this.__dataPending||{},this.__dataOld=this.__dataOld||{},this.__data[n]=this.__dataPending[n]=e[n])}_addPropertyEffect(e,t,n){this._createPropertyAccessor(e,t==y.READ_ONLY);let r=_(this,t)[e];r||(r=this[t][e]=[]),r.push(n)}_removePropertyEffect(e,t,n){let r=_(this,t)[e],i=r.indexOf(n);i>=0&&r.splice(i,1)}_hasPropertyEffect(e,t){let n=this[t];return Boolean(n&&n[e])}_hasReadOnlyEffect(e){return this._hasPropertyEffect(e,y.READ_ONLY)}_hasNotifyEffect(e){return this._hasPropertyEffect(e,y.NOTIFY)}_hasReflectEffect(e){return this._hasPropertyEffect(e,y.REFLECT)}_hasComputedEffect(e){return this._hasPropertyEffect(e,y.COMPUTE)}_setPendingPropertyOrPath(e,t,n,r){if(r||(0,i.Jz)(Array.isArray(e)?e[0]:e)!==e){if(!r){let n=(0,i.U2)(this,e);if(!(e=(0,i.t8)(this,e,t))||!super._shouldPropertyChange(e,t,n))return!1}if(this.__dataHasPaths=!0,this._setPendingProperty(e,t,n))return function(e,t,n){let r=e.__dataLinkedPaths;if(r){let o;for(let s in r){let a=r[s];(0,i.SG)(s,t)?(o=(0,i.Iu)(s,a,t),e._setPendingPropertyOrPath(o,n,!0,!0)):(0,i.SG)(a,t)&&(o=(0,i.Iu)(a,s,t),e._setPendingPropertyOrPath(o,n,!0,!0))}}}(this,e,t),!0}else{if(this.__dataHasAccessor&&this.__dataHasAccessor[e])return this._setPendingProperty(e,t,n);this[e]=t}return!1}_setUnmanagedPropertyToNode(e,t,n){n===e[t]&&"object"!=typeof n||(e[t]=n)}_setPendingProperty(e,t,n){let r=this.__dataHasPaths&&(0,i.AZ)(e),o=r?this.__dataTemp:this.__data;return!!this._shouldPropertyChange(e,t,o[e])&&(this.__dataPending||(this.__dataPending={},this.__dataOld={}),e in this.__dataOld||(this.__dataOld[e]=this.__data[e]),r?this.__dataTemp[e]=t:this.__data[e]=t,this.__dataPending[e]=t,(r||this[y.NOTIFY]&&this[y.NOTIFY][e])&&(this.__dataToNotify=this.__dataToNotify||{},this.__dataToNotify[e]=n),!0)}_setProperty(e,t){this._setPendingProperty(e,t,!0)&&this._invalidateProperties()}_invalidateProperties(){this.__dataReady&&this._flushProperties()}_enqueueClient(e){this.__dataPendingClients=this.__dataPendingClients||[],e!==this&&this.__dataPendingClients.push(e)}_flushProperties(){this.__dataCounter++,super._flushProperties(),this.__dataCounter--}_flushClients(){this.__dataClientsReady?this.__enableOrFlushClients():(this.__dataClientsReady=!0,this._readyClients(),this.__dataReady=!0)}__enableOrFlushClients(){let e=this.__dataPendingClients;if(e){this.__dataPendingClients=null;for(let t=0;t<e.length;t++){let n=e[t];n.__dataEnabled?n.__dataPending&&n._flushProperties():n._enableProperties()}}}_readyClients(){this.__enableOrFlushClients()}setProperties(e,t){for(let n in e)!t&&this[y.READ_ONLY]&&this[y.READ_ONLY][n]||this._setPendingPropertyOrPath(n,e[n],!0);this._invalidateProperties()}ready(){this._flushProperties(),this.__dataClientsReady||this._flushClients(),this.__dataPending&&this._flushProperties()}_propertiesChanged(e,t,n){let r=this.__dataHasPaths;this.__dataHasPaths=!1,function(e,t,n,r){let i=e[y.COMPUTE];if(i){let o=t;for(;v(e,i,o,n,r);)Object.assign(n,e.__dataOld),Object.assign(t,e.__dataPending),o=e.__dataPending,e.__dataPending=null}}(this,t,n,r);let i=this.__dataToNotify;this.__dataToNotify=null,this._propagatePropertyChanges(t,n,r),this._flushClients(),v(this,this[y.REFLECT],t,n,r),v(this,this[y.OBSERVE],t,n,r),i&&function(e,t,n,r,i){let o,s,a=e[y.NOTIFY],l=m++;for(let c in t)t[c]&&(a&&w(e,a,l,c,n,r,i)||i&&C(e,c,n))&&(o=!0);o&&(s=e.__dataHost)&&s._invalidateProperties&&s._invalidateProperties()}(this,i,t,n,r),1==this.__dataCounter&&(this.__dataTemp={})}_propagatePropertyChanges(e,t,n){this[y.PROPAGATE]&&v(this,this[y.PROPAGATE],e,t,n);let r=this.__templateInfo;for(;r;)v(this,r.propertyEffects,e,t,n,r.nodeList),r=r.nextTemplateInfo}linkPaths(e,t){e=(0,i.Fv)(e),t=(0,i.Fv)(t),this.__dataLinkedPaths=this.__dataLinkedPaths||{},this.__dataLinkedPaths[e]=t}unlinkPaths(e){e=(0,i.Fv)(e),this.__dataLinkedPaths&&delete this.__dataLinkedPaths[e]}notifySplices(e,t){let n={path:""};B(this,(0,i.U2)(this,e,n),n.path,t)}get(e,t){return(0,i.U2)(t||this,e)}set(e,t,n){n?(0,i.t8)(n,e,t):this[y.READ_ONLY]&&this[y.READ_ONLY][e]||this._setPendingPropertyOrPath(e,t,!0)&&this._invalidateProperties()}push(e,...t){let n={path:""},r=(0,i.U2)(this,e,n),o=r.length,s=r.push(...t);return t.length&&V(this,r,n.path,o,t.length,[]),s}pop(e){let t={path:""},n=(0,i.U2)(this,e,t),r=Boolean(n.length),o=n.pop();return r&&V(this,n,t.path,n.length,0,[o]),o}splice(e,t,n,...r){let o,s={path:""},a=(0,i.U2)(this,e,s);return t<0?t=a.length-Math.floor(-t):t&&(t=Math.floor(t)),o=2===arguments.length?a.splice(t):a.splice(t,n,...r),(r.length||o.length)&&V(this,a,s.path,t,r.length,o),o}shift(e){let t={path:""},n=(0,i.U2)(this,e,t),r=Boolean(n.length),o=n.shift();return r&&V(this,n,t.path,0,0,[o]),o}unshift(e,...t){let n={path:""},r=(0,i.U2)(this,e,n),o=r.unshift(...t);return t.length&&V(this,r,n.path,0,t.length,[]),o}notifyPath(e,t){let n;if(1==arguments.length){let r={path:""};t=(0,i.U2)(this,e,r),n=r.path}else n=Array.isArray(e)?(0,i.Fv)(e):e;this._setPendingPropertyOrPath(n,t,!0,!0)&&this._invalidateProperties()}_createReadOnlyProperty(e,t){var n;this._addPropertyEffect(e,y.READ_ONLY),t&&(this["_set"+(n=e,n[0].toUpperCase()+n.substring(1))]=function(t){this._setProperty(e,t)})}_createPropertyObserver(e,t,n){let r={property:e,method:t,dynamicFn:Boolean(n)};this._addPropertyEffect(e,y.OBSERVE,{fn:k,info:r,trigger:{name:e}}),n&&this._addPropertyEffect(t,y.OBSERVE,{fn:k,info:r,trigger:{name:t}})}_createMethodObserver(e,t){let n=H(e);if(!n)throw new Error("Malformed observer expression '"+e+"'");D(this,n,y.OBSERVE,z,null,t)}_createNotifyingProperty(e){this._addPropertyEffect(e,y.NOTIFY,{fn:S,info:{eventName:(0,o.n)(e)+"-changed",property:e}})}_createReflectedProperty(e){let t=this.constructor.attributeNameForProperty(e);"-"===t[0]?console.warn("Property "+e+" cannot be reflected to attribute "+t+' because "-" is not a valid starting attribute name. Use a lowercase first letter for the property instead.'):this._addPropertyEffect(e,y.REFLECT,{fn:P,info:{attrName:t}})}_createComputedProperty(e,t,n){let r=H(t);if(!r)throw new Error("Malformed computed expression '"+t+"'");D(this,r,y.COMPUTE,A,e,n)}_marshalArgs(e,t,n){const r=this.__data;let o=[];for(let s=0,a=e.length;s<a;s++){let a,l=e[s],c=l.name;if(l.literal?a=l.value:l.structured?(a=(0,i.U2)(r,c),void 0===a&&(a=n[c])):a=r[c],l.wildcard){let e=0===c.indexOf(t+"."),r=0===t.indexOf(c)&&!e;o[s]={path:r?t:c,value:r?n[t]:a,base:a}}else o[s]=a}return o}static addPropertyEffect(e,t,n){this.prototype._addPropertyEffect(e,t,n)}static createPropertyObserver(e,t,n){this.prototype._createPropertyObserver(e,t,n)}static createMethodObserver(e,t){this.prototype._createMethodObserver(e,t)}static createNotifyingProperty(e){this.prototype._createNotifyingProperty(e)}static createReadOnlyProperty(e,t){this.prototype._createReadOnlyProperty(e,t)}static createReflectedProperty(e){this.prototype._createReflectedProperty(e)}static createComputedProperty(e,t,n){this.prototype._createComputedProperty(e,t,n)}static bindTemplate(e){return this.prototype._bindTemplate(e)}_bindTemplate(e,t){let n=this.constructor._parseTemplate(e),r=this.__templateInfo==n;if(!r)for(let i in n.propertyEffects)this._createPropertyAccessor(i);if(t&&(n=Object.create(n),n.wasPreBound=r,!r&&this.__templateInfo)){let e=this.__templateInfoLast||this.__templateInfo;return this.__templateInfoLast=e.nextTemplateInfo=n,n.previousTemplateInfo=e,n}return this.__templateInfo=n}static _addTemplatePropertyEffect(e,t,n){(e.hostProps=e.hostProps||{})[t]=!0;let r=e.propertyEffects=e.propertyEffects||{};(r[t]=r[t]||[]).push(n)}_stampTemplate(e){U.beginHosting(this);let t=super._stampTemplate(e);U.endHosting(this);let n=this._bindTemplate(e,!0);if(n.nodeList=t.nodeList,!n.wasPreBound){let e=n.childNodes=[];for(let n=t.firstChild;n;n=n.nextSibling)e.push(n)}return t.templateInfo=n,function(e,t){let{nodeList:n,nodeInfoList:r}=t;if(r.length)for(let i=0;i<r.length;i++){let t=r[i],o=n[i],s=t.bindings;if(s)for(let n=0;n<s.length;n++){let t=s[n];I(o,t),R(o,e,t)}o.__dataHost=e}}(this,n),this.__dataReady&&v(this,n.propertyEffects,this.__data,null,!1,n.nodeList),t}_removeBoundDom(e){let t=e.templateInfo;t.previousTemplateInfo&&(t.previousTemplateInfo.nextTemplateInfo=t.nextTemplateInfo),t.nextTemplateInfo&&(t.nextTemplateInfo.previousTemplateInfo=t.previousTemplateInfo),this.__templateInfoLast==t&&(this.__templateInfoLast=t.previousTemplateInfo),t.previousTemplateInfo=t.nextTemplateInfo=null;let n=t.childNodes;for(let r=0;r<n.length;r++){let e=n[r];e.parentNode.removeChild(e)}}static _parseTemplateNode(e,t,n){let r=super._parseTemplateNode(e,t,n);if(e.nodeType===Node.TEXT_NODE){let i=this._parseBindings(e.textContent,t);i&&(e.textContent=M(i)||" ",T(this,t,n,"text","textContent",i),r=!0)}return r}static _parseTemplateNodeAttribute(e,t,n,r,i){let s=this._parseBindings(i,t);if(s){let i=r,a="property";g.test(r)?a="attribute":"$"==r[r.length-1]&&(r=r.slice(0,-1),a="attribute");let l=M(s);return l&&"attribute"==a&&e.setAttribute(r,l),"input"===e.localName&&"value"===i&&e.setAttribute(i,""),e.removeAttribute(i),"property"===a&&(r=(0,o.z)(r)),T(this,t,n,a,r,s,l),!0}return super._parseTemplateNodeAttribute(e,t,n,r,i)}static _parseTemplateNestedTemplate(e,t,n){let r=super._parseTemplateNestedTemplate(e,t,n),i=n.templateInfo.hostProps;for(let o in i){T(this,t,n,"property","_host_"+o,[{mode:"{",source:o,dependencies:[o]}])}return r}static _parseBindings(e,t){let n,r=[],i=0;for(;null!==(n=L.exec(e));){n.index>i&&r.push({literal:e.slice(i,n.index)});let o=n[1][0],s=Boolean(n[2]),a=n[3].trim(),l=!1,c="",d=-1;"{"==o&&(d=a.indexOf("::"))>0&&(c=a.substring(d+2),a=a.substring(0,d),l=!0);let u=H(a),p=[];if(u){let{args:e,methodName:n}=u;for(let t=0;t<e.length;t++){let n=e[t];n.literal||p.push(n)}let r=t.dynamicFns;(r&&r[n]||u.static)&&(p.push(n),u.dynamicFn=!0)}else p.push(a);r.push({source:a,mode:o,negate:s,customEvent:l,signature:u,dependencies:p,event:c}),i=L.lastIndex}if(i&&i<e.length){let t=e.substring(i);t&&r.push({literal:t})}return r.length?r:null}static _evaluateBinding(e,t,n,r,o,s){let a;return a=t.signature?z(e,n,r,0,t.signature):n!=t.source?(0,i.U2)(e,t.source):s&&(0,i.AZ)(n)?(0,i.U2)(e,n):e.__data[n],t.negate&&(a=!a),a}}return b=n,n}));const U=new class{constructor(){this.stack=[]}registerHost(e){if(this.stack.length){this.stack[this.stack.length-1]._enqueueClient(e)}}beginHosting(e){this.stack.push(e)}endHosting(e){let t=this.stack.length;t&&this.stack[t-1]==e&&this.stack.pop()}}},4507:(e,t,n)=>{"use strict";n.d(t,{c:()=>o});n(56646);function r(e,t,n){return{index:e,removed:t,addedCount:n}}function i(e,t,n,i,o,a){let l,c=0,d=0,u=Math.min(n-t,a-o);if(0==t&&0==o&&(c=function(e,t,n){for(let r=0;r<n;r++)if(!s(e[r],t[r]))return r;return n}(e,i,u)),n==e.length&&a==i.length&&(d=function(e,t,n){let r=e.length,i=t.length,o=0;for(;o<n&&s(e[--r],t[--i]);)o++;return o}(e,i,u-c)),o+=c,a-=d,(n-=d)-(t+=c)==0&&a-o==0)return[];if(t==n){for(l=r(t,[],0);o<a;)l.removed.push(i[o++]);return[l]}if(o==a)return[r(t,[],n-t)];let p=function(e){let t=e.length-1,n=e[0].length-1,r=e[t][n],i=[];for(;t>0||n>0;){if(0==t){i.push(2),n--;continue}if(0==n){i.push(3),t--;continue}let o,s=e[t-1][n-1],a=e[t-1][n],l=e[t][n-1];o=a<l?a<s?a:s:l<s?l:s,o==s?(s==r?i.push(0):(i.push(1),r=s),t--,n--):o==a?(i.push(3),t--,r=a):(i.push(2),n--,r=l)}return i.reverse(),i}(function(e,t,n,r,i,o){let a=o-i+1,l=n-t+1,c=new Array(a);for(let s=0;s<a;s++)c[s]=new Array(l),c[s][0]=s;for(let s=0;s<l;s++)c[0][s]=s;for(let d=1;d<a;d++)for(let n=1;n<l;n++)if(s(e[t+n-1],r[i+d-1]))c[d][n]=c[d-1][n-1];else{let e=c[d-1][n]+1,t=c[d][n-1]+1;c[d][n]=e<t?e:t}return c}(e,t,n,i,o,a));l=void 0;let h=[],f=t,m=o;for(let s=0;s<p.length;s++)switch(p[s]){case 0:l&&(h.push(l),l=void 0),f++,m++;break;case 1:l||(l=r(f,[],0)),l.addedCount++,f++,l.removed.push(i[m]),m++;break;case 2:l||(l=r(f,[],0)),l.addedCount++,f++;break;case 3:l||(l=r(f,[],0)),l.removed.push(i[m]),m++}return l&&h.push(l),h}function o(e,t){return i(e,0,e.length,t,0,t.length)}function s(e,t){return e===t}},21683:(e,t,n)=>{"use strict";n.d(t,{Wc:()=>l,rs:()=>c,t$:()=>d,YA:()=>u});n(56646);let r=0,i=0,o=[],s=0,a=document.createTextNode("");new window.MutationObserver((function(){const e=o.length;for(let n=0;n<e;n++){let e=o[n];if(e)try{e()}catch(t){setTimeout((()=>{throw t}))}}o.splice(0,e),i+=e})).observe(a,{characterData:!0});const l={after:e=>({run:t=>window.setTimeout(t,e),cancel(e){window.clearTimeout(e)}}),run:(e,t)=>window.setTimeout(e,t),cancel(e){window.clearTimeout(e)}},c={run:e=>window.requestAnimationFrame(e),cancel(e){window.cancelAnimationFrame(e)}},d={run:e=>window.requestIdleCallback?window.requestIdleCallback(e):window.setTimeout(e,16),cancel(e){window.cancelIdleCallback?window.cancelIdleCallback(e):window.clearTimeout(e)}},u={run:e=>(a.textContent=s++,o.push(e),r++),cancel(e){const t=e-i;if(t>=0){if(!o[t])throw new Error("invalid async handle: "+e);o[t]=null}}}},56646:()=>{"use strict";window.JSCompiler_renameProperty=function(e,t){return e}},67130:(e,t,n)=>{"use strict";n.d(t,{z:()=>s,n:()=>a});n(56646);const r={},i=/-[a-z]/g,o=/([A-Z])/g;function s(e){return r[e]||(r[e]=e.indexOf("-")<0?e:e.replace(i,(e=>e[1].toUpperCase())))}function a(e){return r[e]||(r[e]=e.replace(o,"-$1").toLowerCase())}},78956:(e,t,n)=>{"use strict";n.d(t,{d:()=>r});n(56646),n(76389),n(21683);class r{constructor(){this._asyncModule=null,this._callback=null,this._timer=null}setConfig(e,t){this._asyncModule=e,this._callback=t,this._timer=this._asyncModule.run((()=>{this._timer=null,this._callback()}))}cancel(){this.isActive()&&(this._asyncModule.cancel(this._timer),this._timer=null)}flush(){this.isActive()&&(this.cancel(),this._callback())}isActive(){return null!=this._timer}static debounce(e,t,n){return e instanceof r?e.cancel():e=new r,e.setConfig(t,n),e}}},20723:(e,t,n)=>{"use strict";n.d(t,{o:()=>s});n(56646);var r=n(4507),i=n(21683);function o(e){return"slot"===e.localName}class s{static getFlattenedNodes(e){return o(e)?(e=e).assignedNodes({flatten:!0}):Array.from(e.childNodes).map((e=>o(e)?(e=e).assignedNodes({flatten:!0}):[e])).reduce(((e,t)=>e.concat(t)),[])}constructor(e,t){this._shadyChildrenObserver=null,this._nativeChildrenObserver=null,this._connected=!1,this._target=e,this.callback=t,this._effectiveNodes=[],this._observer=null,this._scheduled=!1,this._boundSchedule=()=>{this._schedule()},this.connect(),this._schedule()}connect(){o(this._target)?this._listenSlots([this._target]):this._target.children&&(this._listenSlots(this._target.children),window.ShadyDOM?this._shadyChildrenObserver=ShadyDOM.observeChildren(this._target,(e=>{this._processMutations(e)})):(this._nativeChildrenObserver=new MutationObserver((e=>{this._processMutations(e)})),this._nativeChildrenObserver.observe(this._target,{childList:!0}))),this._connected=!0}disconnect(){o(this._target)?this._unlistenSlots([this._target]):this._target.children&&(this._unlistenSlots(this._target.children),window.ShadyDOM&&this._shadyChildrenObserver?(ShadyDOM.unobserveChildren(this._shadyChildrenObserver),this._shadyChildrenObserver=null):this._nativeChildrenObserver&&(this._nativeChildrenObserver.disconnect(),this._nativeChildrenObserver=null)),this._connected=!1}_schedule(){this._scheduled||(this._scheduled=!0,i.YA.run((()=>this.flush())))}_processMutations(e){this._processSlotMutations(e),this.flush()}_processSlotMutations(e){if(e)for(let t=0;t<e.length;t++){let n=e[t];n.addedNodes&&this._listenSlots(n.addedNodes),n.removedNodes&&this._unlistenSlots(n.removedNodes)}}flush(){if(!this._connected)return!1;window.ShadyDOM&&ShadyDOM.flush(),this._nativeChildrenObserver?this._processSlotMutations(this._nativeChildrenObserver.takeRecords()):this._shadyChildrenObserver&&this._processSlotMutations(this._shadyChildrenObserver.takeRecords()),this._scheduled=!1;let e={target:this._target,addedNodes:[],removedNodes:[]},t=this.constructor.getFlattenedNodes(this._target),n=(0,r.c)(t,this._effectiveNodes);for(let r,o=0;o<n.length&&(r=n[o]);o++)for(let t,n=0;n<r.removed.length&&(t=r.removed[n]);n++)e.removedNodes.push(t);for(let r,o=0;o<n.length&&(r=n[o]);o++)for(let n=r.index;n<r.index+r.addedCount;n++)e.addedNodes.push(t[n]);this._effectiveNodes=t;let i=!1;return(e.addedNodes.length||e.removedNodes.length)&&(i=!0,this.callback.call(this._target,e)),i}_listenSlots(e){for(let t=0;t<e.length;t++){let n=e[t];o(n)&&n.addEventListener("slotchange",this._boundSchedule)}}_unlistenSlots(e){for(let t=0;t<e.length;t++){let n=e[t];o(n)&&n.removeEventListener("slotchange",this._boundSchedule)}}}},93252:(e,t,n)=>{"use strict";n.d(t,{E:()=>i,y:()=>s});n(56646),n(78956);let r=[];const i=function(e){r.push(e)};function o(){const e=Boolean(r.length);for(;r.length;)try{r.shift().flush()}catch(t){setTimeout((()=>{throw t}))}return e}const s=function(){let e,t;do{e=window.ShadyDOM&&ShadyDOM.flush(),window.ShadyCSS&&window.ShadyCSS.ScopingShim&&window.ShadyCSS.ScopingShim.flush(),t=o()}while(e||t)}},81668:(e,t,n)=>{"use strict";n.d(t,{NH:()=>N,ys:()=>I,BP:()=>D,nJ:()=>B,IH:()=>V});n(56646);var r=n(21683),i=n(78956),o=n(74460);let s="string"==typeof document.head.style.touchAction,a="__polymerGestures",l="__polymerGesturesHandled",c="__polymerGesturesTouchAction",d=["mousedown","mousemove","mouseup","click"],u=[0,1,4,2],p=function(){try{return 1===new MouseEvent("test",{buttons:1}).buttons}catch(e){return!1}}();function h(e){return d.indexOf(e)>-1}let f=!1;function m(e){if(!h(e)&&"touchend"!==e)return s&&f&&o.f6?{passive:!0}:void 0}!function(){try{let e=Object.defineProperty({},"passive",{get(){f=!0}});window.addEventListener("test",null,e),window.removeEventListener("test",null,e)}catch(e){}}();let y=navigator.userAgent.match(/iP(?:[oa]d|hone)|Android/);const g=[],b={button:!0,input:!0,keygen:!0,meter:!0,output:!0,textarea:!0,progress:!0,select:!0},_={button:!0,command:!0,fieldset:!0,input:!0,keygen:!0,optgroup:!0,option:!0,select:!0,textarea:!0};function v(e){let t=Array.prototype.slice.call(e.labels||[]);if(!t.length){t=[];let n=e.getRootNode();if(e.id){let r=n.querySelectorAll(`label[for = ${e.id}]`);for(let e=0;e<r.length;e++)t.push(r[e])}}return t}let w=function(e){let t=e.sourceCapabilities;var n;if((!t||t.firesTouchEvents)&&(e[l]={skip:!0},"click"===e.type)){let t=!1,r=e.composedPath&&e.composedPath();if(r)for(let e=0;e<r.length;e++){if(r[e].nodeType===Node.ELEMENT_NODE)if("label"===r[e].localName)g.push(r[e]);else if(n=r[e],b[n.localName]){let n=v(r[e]);for(let e=0;e<n.length;e++)t=t||g.indexOf(n[e])>-1}if(r[e]===C.mouse.target)return}if(t)return;e.preventDefault(),e.stopPropagation()}};function x(e){let t=y?["click"]:d;for(let n,r=0;r<t.length;r++)n=t[r],e?(g.length=0,document.addEventListener(n,w,!0)):document.removeEventListener(n,w,!0)}function k(e){let t=e.type;if(!h(t))return!1;if("mousemove"===t){let t=void 0===e.buttons?1:e.buttons;return e instanceof window.MouseEvent&&!p&&(t=u[e.which]||0),Boolean(1&t)}return 0===(void 0===e.button?0:e.button)}let C={mouse:{target:null,mouseIgnoreJob:null},touch:{x:0,y:0,id:-1,scrollDecided:!1}};function E(e,t,n){e.movefn=t,e.upfn=n,document.addEventListener("mousemove",t),document.addEventListener("mouseup",n)}function S(e){document.removeEventListener("mousemove",e.movefn),document.removeEventListener("mouseup",e.upfn),e.movefn=null,e.upfn=null}document.addEventListener("touchend",(function(e){C.mouse.mouseIgnoreJob||x(!0),C.mouse.target=e.composedPath()[0],C.mouse.mouseIgnoreJob=i.d.debounce(C.mouse.mouseIgnoreJob,r.Wc.after(2500),(function(){x(),C.mouse.target=null,C.mouse.mouseIgnoreJob=null}))}),!!f&&{passive:!0});const P={},A=[];function T(e){if(e.composedPath){const t=e.composedPath();return t.length>0?t[0]:e.target}return e.target}function O(e){let t,n=e.type,r=e.currentTarget[a];if(!r)return;let i=r[n];if(i){if(!e[l]&&(e[l]={},"touch"===n.slice(0,5))){let t=(e=e).changedTouches[0];if("touchstart"===n&&1===e.touches.length&&(C.touch.id=t.identifier),C.touch.id!==t.identifier)return;s||"touchstart"!==n&&"touchmove"!==n||function(e){let t=e.changedTouches[0],n=e.type;if("touchstart"===n)C.touch.x=t.clientX,C.touch.y=t.clientY,C.touch.scrollDecided=!1;else if("touchmove"===n){if(C.touch.scrollDecided)return;C.touch.scrollDecided=!0;let n=function(e){let t="auto",n=e.composedPath&&e.composedPath();if(n)for(let r,i=0;i<n.length;i++)if(r=n[i],r[c]){t=r[c];break}return t}(e),r=!1,i=Math.abs(C.touch.x-t.clientX),o=Math.abs(C.touch.y-t.clientY);e.cancelable&&("none"===n?r=!0:"pan-x"===n?r=o>i:"pan-y"===n&&(r=i>o)),r?e.preventDefault():F("track")}}(e)}if(t=e[l],!t.skip){for(let n,r=0;r<A.length;r++)n=A[r],i[n.name]&&!t[n.name]&&n.flow&&n.flow.start.indexOf(e.type)>-1&&n.reset&&n.reset();for(let r,o=0;o<A.length;o++)r=A[o],i[r.name]&&!t[r.name]&&(t[r.name]=!0,r[n](e))}}}function N(e,t,n){return!!P[t]&&(function(e,t,n){let r=P[t],i=r.deps,o=r.name,s=e[a];s||(e[a]=s={});for(let a,l,c=0;c<i.length;c++)a=i[c],y&&h(a)&&"click"!==a||(l=s[a],l||(s[a]=l={_count:0}),0===l._count&&e.addEventListener(a,O,m(a)),l[o]=(l[o]||0)+1,l._count=(l._count||0)+1);e.addEventListener(t,n),r.touchAction&&D(e,r.touchAction)}(e,t,n),!0)}function I(e,t,n){return!!P[t]&&(function(e,t,n){let r=P[t],i=r.deps,o=r.name,s=e[a];if(s)for(let a,l,c=0;c<i.length;c++)a=i[c],l=s[a],l&&l[o]&&(l[o]=(l[o]||1)-1,l._count=(l._count||1)-1,0===l._count&&e.removeEventListener(a,O,m(a)));e.removeEventListener(t,n)}(e,t,n),!0)}function R(e){A.push(e);for(let t=0;t<e.emits.length;t++)P[e.emits[t]]=e}function D(e,t){s&&e instanceof HTMLElement&&r.YA.run((()=>{e.style.touchAction=t})),e[c]=t}function z(e,t,n){let r=new Event(t,{bubbles:!0,cancelable:!0,composed:!0});if(r.detail=n,e.dispatchEvent(r),r.defaultPrevented){let e=n.preventer||n.sourceEvent;e&&e.preventDefault&&e.preventDefault()}}function F(e){let t=function(e){for(let t,n=0;n<A.length;n++){t=A[n];for(let n,r=0;r<t.emits.length;r++)if(n=t.emits[r],n===e)return t}return null}(e);t.info&&(t.info.prevent=!0)}function L(e,t,n,r){t&&z(t,e,{x:n.clientX,y:n.clientY,sourceEvent:n,preventer:r,prevent:function(e){return F(e)}})}function M(e,t,n){if(e.prevent)return!1;if(e.started)return!0;let r=Math.abs(e.x-t),i=Math.abs(e.y-n);return r>=5||i>=5}function H(e,t,n){if(!t)return;let r,i=e.moves[e.moves.length-2],o=e.moves[e.moves.length-1],s=o.x-e.x,a=o.y-e.y,l=0;i&&(r=o.x-i.x,l=o.y-i.y),z(t,"track",{state:e.state,x:n.clientX,y:n.clientY,dx:s,dy:a,ddx:r,ddy:l,sourceEvent:n,hover:function(){return function(e,t){let n=document.elementFromPoint(e,t),r=n;for(;r&&r.shadowRoot&&!window.ShadyDOM;){let i=r;if(r=r.shadowRoot.elementFromPoint(e,t),i===r)break;r&&(n=r)}return n}(n.clientX,n.clientY)}})}function j(e,t,n){let r=Math.abs(t.clientX-e.x),i=Math.abs(t.clientY-e.y),o=T(n||t);!o||_[o.localName]&&o.hasAttribute("disabled")||(isNaN(r)||isNaN(i)||r<=25&&i<=25||function(e){if("click"===e.type){if(0===e.detail)return!0;let t=T(e);if(!t.nodeType||t.nodeType!==Node.ELEMENT_NODE)return!0;let n=t.getBoundingClientRect(),r=e.pageX,i=e.pageY;return!(r>=n.left&&r<=n.right&&i>=n.top&&i<=n.bottom)}return!1}(t))&&(e.prevent||z(o,"tap",{x:t.clientX,y:t.clientY,sourceEvent:t,preventer:n}))}R({name:"downup",deps:["mousedown","touchstart","touchend"],flow:{start:["mousedown","touchstart"],end:["mouseup","touchend"]},emits:["down","up"],info:{movefn:null,upfn:null},reset:function(){S(this.info)},mousedown:function(e){if(!k(e))return;let t=T(e),n=this;E(this.info,(function(e){k(e)||(L("up",t,e),S(n.info))}),(function(e){k(e)&&L("up",t,e),S(n.info)})),L("down",t,e)},touchstart:function(e){L("down",T(e),e.changedTouches[0],e)},touchend:function(e){L("up",T(e),e.changedTouches[0],e)}}),R({name:"track",touchAction:"none",deps:["mousedown","touchstart","touchmove","touchend"],flow:{start:["mousedown","touchstart"],end:["mouseup","touchend"]},emits:["track"],info:{x:0,y:0,state:"start",started:!1,moves:[],addMove:function(e){this.moves.length>2&&this.moves.shift(),this.moves.push(e)},movefn:null,upfn:null,prevent:!1},reset:function(){this.info.state="start",this.info.started=!1,this.info.moves=[],this.info.x=0,this.info.y=0,this.info.prevent=!1,S(this.info)},mousedown:function(e){if(!k(e))return;let t=T(e),n=this,r=function(e){let r=e.clientX,i=e.clientY;M(n.info,r,i)&&(n.info.state=n.info.started?"mouseup"===e.type?"end":"track":"start","start"===n.info.state&&F("tap"),n.info.addMove({x:r,y:i}),k(e)||(n.info.state="end",S(n.info)),t&&H(n.info,t,e),n.info.started=!0)};E(this.info,r,(function(e){n.info.started&&r(e),S(n.info)})),this.info.x=e.clientX,this.info.y=e.clientY},touchstart:function(e){let t=e.changedTouches[0];this.info.x=t.clientX,this.info.y=t.clientY},touchmove:function(e){let t=T(e),n=e.changedTouches[0],r=n.clientX,i=n.clientY;M(this.info,r,i)&&("start"===this.info.state&&F("tap"),this.info.addMove({x:r,y:i}),H(this.info,t,n),this.info.state="track",this.info.started=!0)},touchend:function(e){let t=T(e),n=e.changedTouches[0];this.info.started&&(this.info.state="end",this.info.addMove({x:n.clientX,y:n.clientY}),H(this.info,t,n))}}),R({name:"tap",deps:["mousedown","click","touchstart","touchend"],flow:{start:["mousedown","touchstart"],end:["click","touchend"]},emits:["tap"],info:{x:NaN,y:NaN,prevent:!1},reset:function(){this.info.x=NaN,this.info.y=NaN,this.info.prevent=!1},mousedown:function(e){k(e)&&(this.info.x=e.clientX,this.info.y=e.clientY)},click:function(e){k(e)&&j(this.info,e)},touchstart:function(e){const t=e.changedTouches[0];this.info.x=t.clientX,this.info.y=t.clientY},touchend:function(e){j(this.info,e.changedTouches[0],e)}});const B=T,V=N},50856:(e,t,n)=>{"use strict";n.d(t,{d:()=>o});n(56646);class r{constructor(e){this.value=e.toString()}toString(){return this.value}}function i(e){if(e instanceof r)return e.value;throw new Error("non-literal value passed to Polymer's htmlLiteral function: "+e)}const o=function(e,...t){const n=document.createElement("template");return n.innerHTML=t.reduce(((t,n,o)=>t+function(e){if(e instanceof HTMLTemplateElement)return e.innerHTML;if(e instanceof r)return i(e);throw new Error("non-template value passed to Polymer's html function: "+e)}(n)+e[o+1]),e[0]),n}},76389:(e,t,n)=>{"use strict";n.d(t,{o:()=>o});n(56646);let r=0;function i(){}i.prototype.__mixinApplications,i.prototype.__mixinSet;const o=function(e){let t=e.__mixinApplications;t||(t=new WeakMap,e.__mixinApplications=t);let n=r++;return function(r){let i=r.__mixinSet;if(i&&i[n])return r;let o=t,s=o.get(r);s||(s=e(r),o.set(r,s));let a=Object.create(s.__mixinSet||i||null);return a[n]=!0,s.__mixinSet=a,s}}},4059:(e,t,n)=>{"use strict";n.d(t,{AZ:()=>r,Jz:()=>i,jg:()=>o,SG:()=>s,Iu:()=>a,wB:()=>l,Fv:()=>c,U2:()=>u,t8:()=>p});n(56646);function r(e){return e.indexOf(".")>=0}function i(e){let t=e.indexOf(".");return-1===t?e:e.slice(0,t)}function o(e,t){return 0===e.indexOf(t+".")}function s(e,t){return 0===t.indexOf(e+".")}function a(e,t,n){return t+n.slice(e.length)}function l(e,t){return e===t||o(e,t)||s(e,t)}function c(e){if(Array.isArray(e)){let t=[];for(let n=0;n<e.length;n++){let r=e[n].toString().split(".");for(let e=0;e<r.length;e++)t.push(r[e])}return t.join(".")}return e}function d(e){return Array.isArray(e)?c(e).split("."):e.toString().split(".")}function u(e,t,n){let r=e,i=d(t);for(let o=0;o<i.length;o++){if(!r)return;r=r[i[o]]}return n&&(n.path=i.join(".")),r}function p(e,t,n){let r=e,i=d(t),o=i[i.length-1];if(i.length>1){for(let e=0;e<i.length-1;e++){if(r=r[i[e]],!r)return}r[o]=n}else r[t]=n;return i.join(".")}},87529:(e,t,n)=>{"use strict";n.d(t,{T8:()=>c});n(56646);let r=!1,i=[],o=[];function s(){r=!0,requestAnimationFrame((function(){r=!1,a(i),setTimeout((function(){!function(e){for(let t=0,n=e.length;t<n;t++)l(e.shift())}(o)}))}))}function a(e){for(;e.length;)l(e.shift())}function l(e){const t=e[0],n=e[1],r=e[2];try{n.apply(t,r)}catch(i){setTimeout((()=>{throw i}))}}function c(e,t,n){r||s(),o.push([e,t,n])}},42687:(e,t,n)=>{"use strict";n.d(t,{Kk:()=>a,Rq:()=>l,iY:()=>c});n(56646);let r,i,o=/(url\()([^)]*)(\))/g,s=/(^\/)|(^#)|(^[\w-\d]*:)/;function a(e,t){if(e&&s.test(e))return e;if(void 0===r){r=!1;try{const e=new URL("b","http://a");e.pathname="c%20d",r="http://a/c%20d"===e.href}catch(n){}}return t||(t=document.baseURI||window.location.href),r?new URL(e,t).href:(i||(i=document.implementation.createHTMLDocument("temp"),i.base=i.createElement("base"),i.head.appendChild(i.base),i.anchor=i.createElement("a"),i.body.appendChild(i.anchor)),i.base.href=t,i.anchor.href=e,i.anchor.href||e)}function l(e,t){return e.replace(o,(function(e,n,r,i){return n+"'"+a(r.replace(/["']/g,""),t)+"'"+i}))}function c(e){return e.substring(0,e.lastIndexOf("/")+1)}},74460:(e,t,n)=>{"use strict";n.d(t,{my:()=>i,sM:()=>o,v1:()=>s,f6:()=>a,XN:()=>l,ZN:()=>c});n(56646);var r=n(42687);const i=!window.ShadyDOM;Boolean(!window.ShadyCSS||window.ShadyCSS.nativeCss),window.customElements.polyfillWrapFlushCallback;let o=(0,r.iY)(document.baseURI||window.location.href);let s=window.Polymer&&window.Polymer.sanitizeDOMValue||void 0;let a=!1;let l=!1;let c=!1},15392:(e,t,n)=>{"use strict";n.d(t,{uT:()=>d,lx:()=>u,jv:()=>h});var r=n(21384),i=n(42687);const o="shady-unscoped";function s(e){return r.t.import(e)}function a(e){let t=e.body?e.body:e;const n=(0,i.Rq)(t.textContent,e.baseURI),r=document.createElement("style");return r.textContent=n,r}function l(e){const t=e.trim().split(/\s+/),n=[];for(let r=0;r<t.length;r++)n.push(...c(t[r]));return n}function c(e){const t=s(e);if(!t)return console.warn("Could not find style data in module named",e),[];if(void 0===t._styles){const e=[];e.push(...p(t));const n=t.querySelector("template");n&&e.push(...d(n,t.assetpath)),t._styles=e}return t._styles}function d(e,t){if(!e._styles){const n=[],r=e.content.querySelectorAll("style");for(let e=0;e<r.length;e++){let o=r[e],s=o.getAttribute("include");s&&n.push(...l(s).filter((function(e,t,n){return n.indexOf(e)===t}))),t&&(o.textContent=(0,i.Rq)(o.textContent,t)),n.push(o)}e._styles=n}return e._styles}function u(e){let t=s(e);return t?p(t):[]}function p(e){const t=[],n=e.querySelectorAll("link[rel=import][type~=css]");for(let r=0;r<n.length;r++){let e=n[r];if(e.import){const n=e.import,r=e.hasAttribute(o);if(r&&!n._unscopedStyle){const e=a(n);e.setAttribute(o,""),n._unscopedStyle=e}else n._style||(n._style=a(n));t.push(r?n._unscopedStyle:n._style)}}return t}function h(e){let t=e.trim().split(/\s+/),n="";for(let r=0;r<t.length;r++)n+=f(t[r]);return n}function f(e){let t=s(e);if(t&&void 0===t._cssText){let e=m(t),n=t.querySelector("template");n&&(e+=function(e,t){let n="";const r=d(e,t);for(let i=0;i<r.length;i++){let e=r[i];e.parentNode&&e.parentNode.removeChild(e),n+=e.textContent}return n}(n,t.assetpath)),t._cssText=e||null}return t||console.warn("Could not find style data in module named",e),t&&t._cssText||""}function m(e){let t="",n=p(e);for(let r=0;r<n.length;r++)t+=n[r].textContent;return t}},52521:(e,t,n)=>{"use strict";n.d(t,{Uv:()=>b,GJ:()=>_});n(56646);var r=n(40729),i=n(18691),o=n(74460);let s=null;function a(){return s}a.prototype=Object.create(HTMLTemplateElement.prototype,{constructor:{value:a,writable:!0}});const l=(0,r.q)(a),c=(0,i.E)(l);const d=(0,r.q)(class{});class u extends d{constructor(e){super(),this._configureProperties(e),this.root=this._stampTemplate(this.__dataHost);let t=this.children=[];for(let r=this.root.firstChild;r;r=r.nextSibling)t.push(r),r.__templatizeInstance=this;this.__templatizeOwner&&this.__templatizeOwner.__hideTemplateChildren__&&this._showHideChildren(!0);let n=this.__templatizeOptions;(e&&n.instanceProps||!n.instanceProps)&&this._enableProperties()}_configureProperties(e){if(this.__templatizeOptions.forwardHostProp)for(let t in this.__hostProps)this._setPendingProperty(t,this.__dataHost["_host_"+t]);for(let t in e)this._setPendingProperty(t,e[t])}forwardHostProp(e,t){this._setPendingPropertyOrPath(e,t,!1,!0)&&this.__dataHost._enqueueClient(this)}_addEventListenerToNode(e,t,n){if(this._methodHost&&this.__templatizeOptions.parentModel)this._methodHost._addEventListenerToNode(e,t,(e=>{e.model=this,n(e)}));else{let r=this.__dataHost.__dataHost;r&&r._addEventListenerToNode(e,t,n)}}_showHideChildren(e){let t=this.children;for(let n=0;n<t.length;n++){let r=t[n];if(Boolean(e)!=Boolean(r.__hideTemplateChildren__))if(r.nodeType===Node.TEXT_NODE)e?(r.__polymerTextContent__=r.textContent,r.textContent=""):r.textContent=r.__polymerTextContent__;else if("slot"===r.localName)if(e)r.__polymerReplaced__=document.createComment("hidden-slot"),r.parentNode.replaceChild(r.__polymerReplaced__,r);else{const e=r.__polymerReplaced__;e&&e.parentNode.replaceChild(r,e)}else r.style&&(e?(r.__polymerDisplay__=r.style.display,r.style.display="none"):r.style.display=r.__polymerDisplay__);r.__hideTemplateChildren__=e,r._showHideChildren&&r._showHideChildren(e)}}_setUnmanagedPropertyToNode(e,t,n){e.__hideTemplateChildren__&&e.nodeType==Node.TEXT_NODE&&"textContent"==t?e.__polymerTextContent__=n:super._setUnmanagedPropertyToNode(e,t,n)}get parentModel(){let e=this.__parentModel;if(!e){let t;e=this;do{e=e.__dataHost.__dataHost}while((t=e.__templatizeOptions)&&!t.parentModel);this.__parentModel=e}return e}dispatchEvent(e){return!0}}u.prototype.__dataHost,u.prototype.__templatizeOptions,u.prototype._methodHost,u.prototype.__templatizeOwner,u.prototype.__hostProps;const p=(0,i.E)(u);function h(e){let t=e.__dataHost;return t&&t._methodHost||t}function f(e,t,n){let r=n.mutableData?p:u,i=class extends r{};return i.prototype.__templatizeOptions=n,i.prototype._bindTemplate(e),function(e,t,n,r){let i=n.hostProps||{};for(let o in r.instanceProps){delete i[o];let t=r.notifyInstanceProp;t&&e.prototype._addPropertyEffect(o,e.prototype.PROPERTY_EFFECT_TYPES.NOTIFY,{fn:g(o,t)})}if(r.forwardHostProp&&t.__dataHost)for(let o in i)e.prototype._addPropertyEffect(o,e.prototype.PROPERTY_EFFECT_TYPES.NOTIFY,{fn:function(e,t,n){e.__dataHost._setPendingPropertyOrPath("_host_"+t,n[t],!0,!0)}})}(i,e,t,n),i}function m(e,t,n){let r=n.forwardHostProp;if(r){let i=t.templatizeTemplateClass;if(!i){let e=n.mutableData?c:l;i=t.templatizeTemplateClass=class extends e{};let o=t.hostProps;for(let t in o)i.prototype._addPropertyEffect("_host_"+t,i.prototype.PROPERTY_EFFECT_TYPES.PROPAGATE,{fn:y(t,r)}),i.prototype._createNotifyingProperty("_host_"+t)}!function(e,t){s=e,Object.setPrototypeOf(e,t.prototype),new t,s=null}(e,i),e.__dataProto&&Object.assign(e.__data,e.__dataProto),e.__dataTemp={},e.__dataPending=null,e.__dataOld=null,e._enableProperties()}}function y(e,t){return function(e,n,r){t.call(e.__templatizeOwner,n.substring("_host_".length),r[n])}}function g(e,t){return function(e,n,r){t.call(e.__templatizeOwner,e,n,r[n])}}function b(e,t,n){if(o.XN&&!h(e))throw new Error("strictTemplatePolicy: template owner not trusted");if(n=n||{},e.__templatizeOwner)throw new Error("A <template> can only be templatized once");e.__templatizeOwner=t;let r=(t?t.constructor:u)._parseTemplate(e),i=r.templatizeInstanceClass;i||(i=f(e,r,n),r.templatizeInstanceClass=i),m(e,r,n);let s=class extends i{};return s.prototype._methodHost=h(e),s.prototype.__dataHost=e,s.prototype.__templatizeOwner=t,s.prototype.__hostProps=r.hostProps,s=s,s}function _(e,t){let n;for(;t;)if(n=t.__templatizeInstance){if(n.__dataHost==e)return n;t=n.__dataHost}else t=t.parentNode;return null}},28426:(e,t,n)=>{"use strict";n.d(t,{H3:()=>i});var r=n(36608);n(50856);const i=(0,r.SH)(HTMLElement)},43437:(e,t,n)=>{"use strict";n.d(t,{XY:()=>y,dy:()=>m.d});var r=n(81850),i=(n(9672),n(37692),n(56646),n(40729)),o=n(18691),s=n(60995),a=n(74460);const l=(0,s._)((0,o.w)((0,i.q)(HTMLElement)));customElements.define("dom-bind",class extends l{static get observedAttributes(){return["mutable-data"]}constructor(){if(super(),a.XN)throw new Error("strictTemplatePolicy: dom-bind not allowed");this.root=null,this.$=null,this.__children=null}attributeChangedCallback(){this.mutableData=!0}connectedCallback(){this.style.display="none",this.render()}disconnectedCallback(){this.__removeChildren()}__insertChildren(){this.parentNode.insertBefore(this.root,this)}__removeChildren(){if(this.__children)for(let e=0;e<this.__children.length;e++)this.root.appendChild(this.__children[e])}render(){let e;if(!this.__children){if(e=e||this.querySelector("template"),!e){let t=new MutationObserver((()=>{if(e=this.querySelector("template"),!e)throw new Error("dom-bind requires a <template> child");t.disconnect(),this.render()}));return void t.observe(this,{childList:!0})}this.root=this._stampTemplate(e),this.$=this.root.$,this.__children=[];for(let e=this.root.firstChild;e;e=e.nextSibling)this.__children[this.__children.length]=e;this._enableProperties()}this.__insertChildren(),this.dispatchEvent(new CustomEvent("dom-change",{bubbles:!0,composed:!0}))}});n(42173),n(26047);var c=n(28426),d=n(76389),u=n(4507),p=n(36608);let h=(0,d.o)((e=>{let t=(0,p.SH)(e);return class extends t{static get properties(){return{items:{type:Array},multi:{type:Boolean,value:!1},selected:{type:Object,notify:!0},selectedItem:{type:Object,notify:!0},toggle:{type:Boolean,value:!1}}}static get observers(){return["__updateSelection(multi, items.*)"]}constructor(){super(),this.__lastItems=null,this.__lastMulti=null,this.__selectedMap=null}__updateSelection(e,t){let n=t.path;if("items"==n){let n=t.base||[],r=this.__lastItems;if(e!==this.__lastMulti&&this.clearSelection(),r){let e=(0,u.c)(n,r);this.__applySplices(e)}this.__lastItems=n,this.__lastMulti=e}else if("items.splices"==t.path)this.__applySplices(t.value.indexSplices);else{let e=n.slice("items.".length),t=parseInt(e,10);e.indexOf(".")<0&&e==t&&this.__deselectChangedIdx(t)}}__applySplices(e){let t=this.__selectedMap;for(let r=0;r<e.length;r++){let n=e[r];t.forEach(((e,r)=>{e<n.index||(e>=n.index+n.removed.length?t.set(r,e+n.addedCount-n.removed.length):t.set(r,-1))}));for(let e=0;e<n.addedCount;e++){let r=n.index+e;t.has(this.items[r])&&t.set(this.items[r],r)}}this.__updateLinks();let n=0;t.forEach(((e,r)=>{e<0?(this.multi?this.splice("selected",n,1):this.selected=this.selectedItem=null,t.delete(r)):n++}))}__updateLinks(){if(this.__dataLinkedPaths={},this.multi){let e=0;this.__selectedMap.forEach((t=>{t>=0&&this.linkPaths("items."+t,"selected."+e++)}))}else this.__selectedMap.forEach((e=>{this.linkPaths("selected","items."+e),this.linkPaths("selectedItem","items."+e)}))}clearSelection(){this.__dataLinkedPaths={},this.__selectedMap=new Map,this.selected=this.multi?[]:null,this.selectedItem=null}isSelected(e){return this.__selectedMap.has(e)}isIndexSelected(e){return this.isSelected(this.items[e])}__deselectChangedIdx(e){let t=this.__selectedIndexForItemIndex(e);if(t>=0){let e=0;this.__selectedMap.forEach(((n,r)=>{t==e++&&this.deselect(r)}))}}__selectedIndexForItemIndex(e){let t=this.__dataLinkedPaths["items."+e];if(t)return parseInt(t.slice("selected.".length),10)}deselect(e){let t=this.__selectedMap.get(e);if(t>=0){let n;this.__selectedMap.delete(e),this.multi&&(n=this.__selectedIndexForItemIndex(t)),this.__updateLinks(),this.multi?this.splice("selected",n,1):this.selected=this.selectedItem=null}}deselectIndex(e){this.deselect(this.items[e])}select(e){this.selectIndex(this.items.indexOf(e))}selectIndex(e){let t=this.items[e];this.isSelected(t)?this.toggle&&this.deselectIndex(e):(this.multi||this.__selectedMap.clear(),this.__selectedMap.set(t,e),this.__updateLinks(),this.multi?this.push("selected",t):this.selected=this.selectedItem=t)}}}))(c.H3);class f extends h{static get is(){return"array-selector"}}customElements.define(f.is,f);n(5618),n(72419);var m=n(50856);const y=(0,r.x)(HTMLElement).prototype},60309:(e,t,n)=>{"use strict";n.d(t,{CN:()=>r,$T:()=>i,mA:()=>o});const r=/(?:^|[;\s{]\s*)(--[\w-]*?)\s*:\s*(?:((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};{])+)|\{([^}]*)\}(?:(?=[;\s}])|$))/gi,i=/(?:^|\W+)@apply\s*\(?([^);\n]*)\)?/gi,o=/@media\s(.*)/},10868:(e,t,n)=>{"use strict";n.d(t,{wW:()=>i,B7:()=>o,OH:()=>s});var r=n(60309);function i(e,t){for(let n in t)null===n?e.style.removeProperty(n):e.style.setProperty(n,t[n])}function o(e,t){const n=window.getComputedStyle(e).getPropertyValue(t);return n?n.trim():""}function s(e){const t=r.$T.test(e)||r.CN.test(e);return r.$T.lastIndex=0,r.CN.lastIndex=0,t}},34816:(e,t,n)=>{"use strict";n.d(t,{ZP:()=>u});let r,i=null,o=window.HTMLImports&&window.HTMLImports.whenReady||null;function s(e){requestAnimationFrame((function(){o?o(e):(i||(i=new Promise((e=>{r=e})),"complete"===document.readyState?r():document.addEventListener("readystatechange",(()=>{"complete"===document.readyState&&r()}))),i.then((function(){e&&e()})))}))}const a="__seenByShadyCSS",l="__shadyCSSCachedStyle";let c=null,d=null;class u{constructor(){this.customStyles=[],this.enqueued=!1,s((()=>{window.ShadyCSS.flushCustomStyles&&window.ShadyCSS.flushCustomStyles()}))}enqueueDocumentValidation(){!this.enqueued&&d&&(this.enqueued=!0,s(d))}addCustomStyle(e){e[a]||(e[a]=!0,this.customStyles.push(e),this.enqueueDocumentValidation())}getStyleForCustomStyle(e){if(e[l])return e[l];let t;return t=e.getStyle?e.getStyle():e,t}processStyles(){const e=this.customStyles;for(let t=0;t<e.length;t++){const n=e[t];if(n[l])continue;const r=this.getStyleForCustomStyle(n);if(r){const e=r.__appliedElement||r;c&&c(e),n[l]=e}}return e}}u.prototype.addCustomStyle=u.prototype.addCustomStyle,u.prototype.getStyleForCustomStyle=u.prototype.getStyleForCustomStyle,u.prototype.processStyles=u.prototype.processStyles,Object.defineProperties(u.prototype,{transformCallback:{get:()=>c,set(e){c=e}},validateCallback:{get:()=>d,set(e){let t=!1;d||(t=!0),d=e,t&&this.enqueueDocumentValidation()}}})},26539:(e,t,n)=>{"use strict";n.d(t,{WA:()=>r,Cp:()=>o,jF:()=>a,rd:()=>l});const r=!(window.ShadyDOM&&window.ShadyDOM.inUse);let i,o;function s(e){i=(!e||!e.shimcssproperties)&&(r||Boolean(!navigator.userAgent.match(/AppleWebKit\/601|Edge\/15/)&&window.CSS&&CSS.supports&&CSS.supports("box-shadow","0 0 0 var(--foo)")))}window.ShadyCSS&&void 0!==window.ShadyCSS.cssBuild&&(o=window.ShadyCSS.cssBuild);const a=Boolean(window.ShadyCSS&&window.ShadyCSS.disableRuntime);window.ShadyCSS&&void 0!==window.ShadyCSS.nativeCss?i=window.ShadyCSS.nativeCss:window.ShadyCSS?(s(window.ShadyCSS),window.ShadyCSS=void 0):s(window.WebComponents&&window.WebComponents.flags);const l=i},95282:(e,t,n)=>{"use strict";n.d(t,{_:()=>i,B:()=>o});var r=n(12902);const i=(e,t,n,i)=>{if(e[t])return e[t];let o,s=0,a=(0,r.M)();const l=()=>n(e).then((e=>a.setState(e,!0))),c=()=>l().catch((t=>{if(e.connected)throw t}));return e[t]={get state(){return a.state},refresh:l,subscribe(t){s++,1===s&&(i&&(o=i(e,a)),e.addEventListener("ready",c),c());const n=a.subscribe(t);return void 0!==a.state&&setTimeout((()=>t(a.state)),0),()=>{n(),s--,s||(o&&o.then((e=>{e()})),e.removeEventListener("ready",l))}}},e[t]},o=(e,t,n,r,o)=>i(r,e,t,n).subscribe(o)},23553:(e,t,n)=>{"use strict";n.d(t,{Pz:()=>i,U2:()=>o,iE:()=>s,PR:()=>a,_D:()=>l});var r=n(36007);const i=e=>e.sendMessagePromise(r.$q()),o=e=>e.sendMessagePromise(r.uZ()),s=e=>e.sendMessagePromise(r.vc()),a=e=>e.sendMessagePromise(r.EA()),l=(e,t,n,i)=>e.sendMessagePromise(r._D(t,n,i))},4915:(e,t,n)=>{"use strict";n.d(t,{wQ:()=>l,UE:()=>c,dL:()=>d,u5:()=>u});var r=n(95282),i=n(23553);function o(e,t){return void 0===e?null:{components:e.components.concat(t.data.component)}}const s=e=>(0,i.iE)(e),a=(e,t)=>Promise.all([e.subscribeEvents(t.action(o),"component_loaded"),e.subscribeEvents((()=>s(e).then((e=>t.setState(e,!0)))),"core_config_updated")]).then((e=>()=>e.forEach((e=>e())))),l=(e,t)=>(e=>(0,r._)(e,"_cnf",s,a))(e).subscribe(t),c="NOT_RUNNING",d="STARTING",u="RUNNING"},36007:(e,t,n)=>{"use strict";function r(e){return{type:"auth",access_token:e}}function i(){return{type:"get_states"}}function o(){return{type:"get_config"}}function s(){return{type:"get_services"}}function a(){return{type:"auth/current_user"}}function l(e,t,n){const r={type:"call_service",domain:e,service:t};return n&&(r.service_data=n),r}function c(e){const t={type:"subscribe_events"};return e&&(t.event_type=e),t}function d(e){return{type:"unsubscribe_events",subscription:e}}function u(){return{type:"ping"}}function p(e,t){return{type:"result",success:!1,error:{code:e,message:t}}}n.d(t,{I8:()=>r,$q:()=>i,vc:()=>o,uZ:()=>s,EA:()=>a,_D:()=>l,a:()=>c,Mt:()=>d,qE:()=>u,vU:()=>p})},12902:(e,t,n)=>{"use strict";n.d(t,{M:()=>r});const r=e=>{let t=[];function n(n,r){e=r?n:Object.assign(Object.assign({},e),n);let i=t;for(let t=0;t<i.length;t++)i[t](e)}return{get state(){return e},action(t){function r(e){n(e,!1)}return function(){let n=[e];for(let e=0;e<arguments.length;e++)n.push(arguments[e]);let i=t.apply(this,n);if(null!=i)return i instanceof Promise?i.then(r):r(i)}},setState:n,subscribe:e=>(t.push(e),()=>{!function(e){let n=[];for(let r=0;r<t.length;r++)t[r]===e?e=null:n.push(t[r]);t=n}(e)})}}},87466:(e,t,n)=>{"use strict";n.d(t,{Mo:()=>r,Cb:()=>o,sz:()=>s,IO:()=>a,GC:()=>l,Kt:()=>c,hO:()=>p});const r=e=>t=>"function"==typeof t?((e,t)=>(window.customElements.define(e,t),t))(e,t):((e,t)=>{const{kind:n,elements:r}=t;return{kind:n,elements:r,finisher(t){window.customElements.define(e,t)}}})(e,t),i=(e,t)=>"method"===t.kind&&t.descriptor&&!("value"in t.descriptor)?Object.assign(Object.assign({},t),{finisher(n){n.createProperty(t.key,e)}}):{kind:"field",key:Symbol(),placement:"own",descriptor:{},initializer(){"function"==typeof t.initializer&&(this[t.key]=t.initializer.call(this))},finisher(n){n.createProperty(t.key,e)}};function o(e){return(t,n)=>void 0!==n?((e,t,n)=>{t.constructor.createProperty(n,e)})(e,t,n):i(e,t)}function s(e){return o({attribute:!1,hasChanged:null==e?void 0:e.hasChanged})}function a(e,t){return(n,r)=>{const i={get(){return this.renderRoot.querySelector(e)},enumerable:!0,configurable:!0};if(t){const t="symbol"==typeof r?Symbol():"__"+r;i.get=function(){return void 0===this[t]&&(this[t]=this.renderRoot.querySelector(e)),this[t]}}return void 0!==r?d(i,n,r):u(i,n)}}function l(e){return(t,n)=>{const r={async get(){return await this.updateComplete,this.renderRoot.querySelector(e)},enumerable:!0,configurable:!0};return void 0!==n?d(r,t,n):u(r,t)}}function c(e){return(t,n)=>{const r={get(){return this.renderRoot.querySelectorAll(e)},enumerable:!0,configurable:!0};return void 0!==n?d(r,t,n):u(r,t)}}const d=(e,t,n)=>{Object.defineProperty(t,n,e)},u=(e,t)=>({kind:"method",placement:"prototype",key:t.key,descriptor:e});function p(e){return(t,n)=>void 0!==n?((e,t,n)=>{Object.assign(t[n],e)})(e,t,n):((e,t)=>Object.assign(Object.assign({},t),{finisher(n){Object.assign(n.prototype[t.key],e)}}))(e,t)}const h=Element.prototype;h.msMatchesSelector||h.webkitMatchesSelector},15652:(e,t,n)=>{"use strict";n.d(t,{oi:()=>O,f4:()=>x,iv:()=>A,Mo:()=>k.Mo,hO:()=>k.hO,dy:()=>u.dy,sz:()=>k.sz,Cb:()=>k.Cb,IO:()=>k.IO,Kt:()=>k.Kt,GC:()=>k.GC,YP:()=>u.YP,$m:()=>P});var r=n(50115),i=n(27283);function o(e,t){const{element:{content:n},parts:r}=e,i=document.createTreeWalker(n,133,null,!1);let o=a(r),s=r[o],l=-1,c=0;const d=[];let u=null;for(;i.nextNode();){l++;const e=i.currentNode;for(e.previousSibling===u&&(u=null),t.has(e)&&(d.push(e),null===u&&(u=e)),null!==u&&c++;void 0!==s&&s.index===l;)s.index=null!==u?-1:s.index-c,o=a(r,o),s=r[o]}d.forEach((e=>e.parentNode.removeChild(e)))}const s=e=>{let t=11===e.nodeType?0:1;const n=document.createTreeWalker(e,133,null,!1);for(;n.nextNode();)t++;return t},a=(e,t=-1)=>{for(let n=t+1;n<e.length;n++){const t=e[n];if((0,i.pC)(t))return n}return-1};var l=n(84677),c=n(92530),d=n(37581),u=n(94707);const p=(e,t)=>`${e}--${t}`;let h=!0;void 0===window.ShadyCSS?h=!1:void 0===window.ShadyCSS.prepareTemplateDom&&(console.warn("Incompatible ShadyCSS version detected. Please update to at least @webcomponents/webcomponentsjs@2.0.2 and @webcomponents/shadycss@1.3.1."),h=!1);const f=e=>t=>{const n=p(t.type,e);let r=c.r.get(n);void 0===r&&(r={stringsArray:new WeakMap,keyString:new Map},c.r.set(n,r));let o=r.stringsArray.get(t.strings);if(void 0!==o)return o;const s=t.strings.join(i.Jw);if(o=r.keyString.get(s),void 0===o){const n=t.getTemplateElement();h&&window.ShadyCSS.prepareTemplateDom(n,e),o=new i.YS(t,n),r.keyString.set(s,o)}return r.stringsArray.set(t.strings,o),o},m=["html","svg"],y=new Set,g=(e,t,n)=>{y.add(e);const r=n?n.element:document.createElement("template"),i=t.querySelectorAll("style"),{length:l}=i;if(0===l)return void window.ShadyCSS.prepareTemplateStyles(r,e);const d=document.createElement("style");for(let o=0;o<l;o++){const e=i[o];e.parentNode.removeChild(e),d.textContent+=e.textContent}(e=>{m.forEach((t=>{const n=c.r.get(p(t,e));void 0!==n&&n.keyString.forEach((e=>{const{element:{content:t}}=e,n=new Set;Array.from(t.querySelectorAll("style")).forEach((e=>{n.add(e)})),o(e,n)}))}))})(e);const u=r.content;n?function(e,t,n=null){const{element:{content:r},parts:i}=e;if(null==n)return void r.appendChild(t);const o=document.createTreeWalker(r,133,null,!1);let l=a(i),c=0,d=-1;for(;o.nextNode();)for(d++,o.currentNode===n&&(c=s(t),n.parentNode.insertBefore(t,n));-1!==l&&i[l].index===d;){if(c>0){for(;-1!==l;)i[l].index+=c,l=a(i,l);return}l=a(i,l)}}(n,d,u.firstChild):u.insertBefore(d,u.firstChild),window.ShadyCSS.prepareTemplateStyles(r,e);const h=u.querySelector("style");if(window.ShadyCSS.nativeShadow&&null!==h)t.insertBefore(h.cloneNode(!0),t.firstChild);else if(n){u.insertBefore(d,u.firstChild);const e=new Set;e.add(d),o(n,e)}};window.JSCompiler_renameProperty=(e,t)=>e;const b={toAttribute(e,t){switch(t){case Boolean:return e?"":null;case Object:case Array:return null==e?e:JSON.stringify(e)}return e},fromAttribute(e,t){switch(t){case Boolean:return null!==e;case Number:return null===e?null:Number(e);case Object:case Array:return JSON.parse(e)}return e}},_=(e,t)=>t!==e&&(t==t||e==e),v={attribute:!0,type:String,converter:b,reflect:!1,hasChanged:_},w="finalized";class x extends HTMLElement{constructor(){super(),this.initialize()}static get observedAttributes(){this.finalize();const e=[];return this._classProperties.forEach(((t,n)=>{const r=this._attributeNameForProperty(n,t);void 0!==r&&(this._attributeToPropertyMap.set(r,n),e.push(r))})),e}static _ensureClassProperties(){if(!this.hasOwnProperty(JSCompiler_renameProperty("_classProperties",this))){this._classProperties=new Map;const e=Object.getPrototypeOf(this)._classProperties;void 0!==e&&e.forEach(((e,t)=>this._classProperties.set(t,e)))}}static createProperty(e,t=v){if(this._ensureClassProperties(),this._classProperties.set(e,t),t.noAccessor||this.prototype.hasOwnProperty(e))return;const n="symbol"==typeof e?Symbol():"__"+e,r=this.getPropertyDescriptor(e,n,t);void 0!==r&&Object.defineProperty(this.prototype,e,r)}static getPropertyDescriptor(e,t,n){return{get(){return this[t]},set(r){const i=this[e];this[t]=r,this.requestUpdateInternal(e,i,n)},configurable:!0,enumerable:!0}}static getPropertyOptions(e){return this._classProperties&&this._classProperties.get(e)||v}static finalize(){const e=Object.getPrototypeOf(this);if(e.hasOwnProperty(w)||e.finalize(),this.finalized=!0,this._ensureClassProperties(),this._attributeToPropertyMap=new Map,this.hasOwnProperty(JSCompiler_renameProperty("properties",this))){const e=this.properties,t=[...Object.getOwnPropertyNames(e),..."function"==typeof Object.getOwnPropertySymbols?Object.getOwnPropertySymbols(e):[]];for(const n of t)this.createProperty(n,e[n])}}static _attributeNameForProperty(e,t){const n=t.attribute;return!1===n?void 0:"string"==typeof n?n:"string"==typeof e?e.toLowerCase():void 0}static _valueHasChanged(e,t,n=_){return n(e,t)}static _propertyValueFromAttribute(e,t){const n=t.type,r=t.converter||b,i="function"==typeof r?r:r.fromAttribute;return i?i(e,n):e}static _propertyValueToAttribute(e,t){if(void 0===t.reflect)return;const n=t.type,r=t.converter;return(r&&r.toAttribute||b.toAttribute)(e,n)}initialize(){this._updateState=0,this._updatePromise=new Promise((e=>this._enableUpdatingResolver=e)),this._changedProperties=new Map,this._saveInstanceProperties(),this.requestUpdateInternal()}_saveInstanceProperties(){this.constructor._classProperties.forEach(((e,t)=>{if(this.hasOwnProperty(t)){const e=this[t];delete this[t],this._instanceProperties||(this._instanceProperties=new Map),this._instanceProperties.set(t,e)}}))}_applyInstanceProperties(){this._instanceProperties.forEach(((e,t)=>this[t]=e)),this._instanceProperties=void 0}connectedCallback(){this.enableUpdating()}enableUpdating(){void 0!==this._enableUpdatingResolver&&(this._enableUpdatingResolver(),this._enableUpdatingResolver=void 0)}disconnectedCallback(){}attributeChangedCallback(e,t,n){t!==n&&this._attributeToProperty(e,n)}_propertyToAttribute(e,t,n=v){const r=this.constructor,i=r._attributeNameForProperty(e,n);if(void 0!==i){const e=r._propertyValueToAttribute(t,n);if(void 0===e)return;this._updateState=8|this._updateState,null==e?this.removeAttribute(i):this.setAttribute(i,e),this._updateState=-9&this._updateState}}_attributeToProperty(e,t){if(8&this._updateState)return;const n=this.constructor,r=n._attributeToPropertyMap.get(e);if(void 0!==r){const e=n.getPropertyOptions(r);this._updateState=16|this._updateState,this[r]=n._propertyValueFromAttribute(t,e),this._updateState=-17&this._updateState}}requestUpdateInternal(e,t,n){let r=!0;if(void 0!==e){const i=this.constructor;n=n||i.getPropertyOptions(e),i._valueHasChanged(this[e],t,n.hasChanged)?(this._changedProperties.has(e)||this._changedProperties.set(e,t),!0!==n.reflect||16&this._updateState||(void 0===this._reflectingProperties&&(this._reflectingProperties=new Map),this._reflectingProperties.set(e,n))):r=!1}!this._hasRequestedUpdate&&r&&(this._updatePromise=this._enqueueUpdate())}requestUpdate(e,t){return this.requestUpdateInternal(e,t),this.updateComplete}async _enqueueUpdate(){this._updateState=4|this._updateState;try{await this._updatePromise}catch(t){}const e=this.performUpdate();return null!=e&&await e,!this._hasRequestedUpdate}get _hasRequestedUpdate(){return 4&this._updateState}get hasUpdated(){return 1&this._updateState}performUpdate(){if(!this._hasRequestedUpdate)return;this._instanceProperties&&this._applyInstanceProperties();let e=!1;const t=this._changedProperties;try{e=this.shouldUpdate(t),e?this.update(t):this._markUpdated()}catch(n){throw e=!1,this._markUpdated(),n}e&&(1&this._updateState||(this._updateState=1|this._updateState,this.firstUpdated(t)),this.updated(t))}_markUpdated(){this._changedProperties=new Map,this._updateState=-5&this._updateState}get updateComplete(){return this._getUpdateComplete()}_getUpdateComplete(){return this._updatePromise}shouldUpdate(e){return!0}update(e){void 0!==this._reflectingProperties&&this._reflectingProperties.size>0&&(this._reflectingProperties.forEach(((e,t)=>this._propertyToAttribute(t,this[t],e))),this._reflectingProperties=void 0),this._markUpdated()}updated(e){}firstUpdated(e){}}x.finalized=!0;var k=n(87466);const C=window.ShadowRoot&&(void 0===window.ShadyCSS||window.ShadyCSS.nativeShadow)&&"adoptedStyleSheets"in Document.prototype&&"replace"in CSSStyleSheet.prototype,E=Symbol();class S{constructor(e,t){if(t!==E)throw new Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");this.cssText=e}get styleSheet(){return void 0===this._styleSheet&&(C?(this._styleSheet=new CSSStyleSheet,this._styleSheet.replaceSync(this.cssText)):this._styleSheet=null),this._styleSheet}toString(){return this.cssText}}const P=e=>new S(String(e),E),A=(e,...t)=>{const n=t.reduce(((t,n,r)=>t+(e=>{if(e instanceof S)return e.cssText;if("number"==typeof e)return e;throw new Error(`Value passed to 'css' function must be a 'css' function result: ${e}. Use 'unsafeCSS' to pass non-literal values, but\n            take care to ensure page security.`)})(n)+e[r+1]),e[0]);return new S(n,E)};(window.litElementVersions||(window.litElementVersions=[])).push("2.4.0");const T={};class O extends x{static getStyles(){return this.styles}static _getUniqueStyles(){if(this.hasOwnProperty(JSCompiler_renameProperty("_styles",this)))return;const e=this.getStyles();if(Array.isArray(e)){const t=(e,n)=>e.reduceRight(((e,n)=>Array.isArray(n)?t(n,e):(e.add(n),e)),n),n=t(e,new Set),r=[];n.forEach((e=>r.unshift(e))),this._styles=r}else this._styles=void 0===e?[]:[e];this._styles=this._styles.map((e=>{if(e instanceof CSSStyleSheet&&!C){const t=Array.prototype.slice.call(e.cssRules).reduce(((e,t)=>e+t.cssText),"");return P(t)}return e}))}initialize(){super.initialize(),this.constructor._getUniqueStyles(),this.renderRoot=this.createRenderRoot(),window.ShadowRoot&&this.renderRoot instanceof window.ShadowRoot&&this.adoptStyles()}createRenderRoot(){return this.attachShadow({mode:"open"})}adoptStyles(){const e=this.constructor._styles;0!==e.length&&(void 0===window.ShadyCSS||window.ShadyCSS.nativeShadow?C?this.renderRoot.adoptedStyleSheets=e.map((e=>e instanceof CSSStyleSheet?e:e.styleSheet)):this._needsShimAdoptedStyleSheets=!0:window.ShadyCSS.ScopingShim.prepareAdoptedCssText(e.map((e=>e.cssText)),this.localName))}connectedCallback(){super.connectedCallback(),this.hasUpdated&&void 0!==window.ShadyCSS&&window.ShadyCSS.styleElement(this)}update(e){const t=this.render();super.update(e),t!==T&&this.constructor.render(t,this.renderRoot,{scopeName:this.localName,eventContext:this}),this._needsShimAdoptedStyleSheets&&(this._needsShimAdoptedStyleSheets=!1,this.constructor._styles.forEach((e=>{const t=document.createElement("style");t.textContent=e.cssText,this.renderRoot.appendChild(t)})))}render(){return T}}O.finalized=!0,O.render=(e,t,n)=>{if(!n||"object"!=typeof n||!n.scopeName)throw new Error("The `scopeName` option is required.");const i=n.scopeName,o=l.L.has(t),s=h&&11===t.nodeType&&!!t.host,a=s&&!y.has(i),c=a?document.createDocumentFragment():t;if((0,l.s)(e,c,Object.assign({templateFactory:f(i)},n)),a){const e=l.L.get(c);l.L.delete(c);const n=e.value instanceof d.R?e.value.template:void 0;g(i,c,n),(0,r.r4)(t,t.firstChild),t.appendChild(c),l.L.set(t,e)}!o&&s&&window.ShadyCSS.styleElement(t.host)}},81471:(e,t,n)=>{"use strict";n.d(t,{$:()=>s});var r=n(94707);class i{constructor(e){this.classes=new Set,this.changed=!1,this.element=e;const t=(e.getAttribute("class")||"").split(/\s+/);for(const n of t)this.classes.add(n)}add(e){this.classes.add(e),this.changed=!0}remove(e){this.classes.delete(e),this.changed=!0}commit(){if(this.changed){let e="";this.classes.forEach((t=>e+=t+" ")),this.element.setAttribute("class",e)}}}const o=new WeakMap,s=(0,r.XM)((e=>t=>{if(!(t instanceof r._l)||t instanceof r.sL||"class"!==t.committer.name||t.committer.parts.length>1)throw new Error("The `classMap` directive must be used in the `class` attribute and must be the only part in the attribute.");const{committer:n}=t,{element:s}=n;let a=o.get(t);void 0===a&&(s.setAttribute("class",n.strings.join(" ")),o.set(t,a=new Set));const l=s.classList||new i(s);a.forEach((t=>{t in e||(l.remove(t),a.delete(t))}));for(const r in e){const t=e[r];t!=a.has(r)&&(t?(l.add(r),a.add(r)):(l.remove(r),a.delete(r)))}"function"==typeof l.commit&&l.commit()}))},79865:(e,t,n)=>{"use strict";n.d(t,{V:()=>o});var r=n(94707);const i=new WeakMap,o=(0,r.XM)((e=>t=>{if(!(t instanceof r._l)||t instanceof r.sL||"style"!==t.committer.name||t.committer.parts.length>1)throw new Error("The `styleMap` directive must be used in the style attribute and must be the only part in the attribute.");const{committer:n}=t,{style:o}=n.element;let s=i.get(t);void 0===s&&(o.cssText=n.strings.join(" "),i.set(t,s=new Set)),s.forEach((t=>{t in e||(s.delete(t),-1===t.indexOf("-")?o[t]=null:o.removeProperty(t))}));for(const r in e)s.add(r),-1===r.indexOf("-")?o[r]=e[r]:o.setProperty(r,e[r])}))},76747:(e,t,n)=>{"use strict";n.d(t,{X:()=>i,w:()=>o});const r=new WeakMap,i=e=>(...t)=>{const n=e(...t);return r.set(n,!0),n},o=e=>"function"==typeof e&&r.has(e)},50115:(e,t,n)=>{"use strict";n.d(t,{eC:()=>r,V:()=>i,r4:()=>o});const r="undefined"!=typeof window&&null!=window.customElements&&void 0!==window.customElements.polyfillWrapFlushCallback,i=(e,t,n=null,r=null)=>{for(;t!==n;){const n=t.nextSibling;e.insertBefore(t,r),t=n}},o=(e,t,n=null)=>{for(;t!==n;){const n=t.nextSibling;e.removeChild(t),t=n}}},43401:(e,t,n)=>{"use strict";n.d(t,{J:()=>r,L:()=>i});const r={},i={}},28823:(e,t,n)=>{"use strict";n.d(t,{pt:()=>c,QG:()=>u,_l:()=>p,nt:()=>h,JG:()=>f,m:()=>m,sL:()=>y,K1:()=>b});var r=n(76747),i=n(50115),o=n(43401),s=n(37581),a=n(87842),l=n(27283);const c=e=>null===e||!("object"==typeof e||"function"==typeof e),d=e=>Array.isArray(e)||!(!e||!e[Symbol.iterator]);class u{constructor(e,t,n){this.dirty=!0,this.element=e,this.name=t,this.strings=n,this.parts=[];for(let r=0;r<n.length-1;r++)this.parts[r]=this._createPart()}_createPart(){return new p(this)}_getValue(){const e=this.strings,t=e.length-1,n=this.parts;if(1===t&&""===e[0]&&""===e[1]){const e=n[0].value;if("symbol"==typeof e)return String(e);if("string"==typeof e||!d(e))return e}let r="";for(let i=0;i<t;i++){r+=e[i];const t=n[i];if(void 0!==t){const e=t.value;if(c(e)||!d(e))r+="string"==typeof e?e:String(e);else for(const t of e)r+="string"==typeof t?t:String(t)}}return r+=e[t],r}commit(){this.dirty&&(this.dirty=!1,this.element.setAttribute(this.name,this._getValue()))}}class p{constructor(e){this.value=void 0,this.committer=e}setValue(e){e===o.J||c(e)&&e===this.value||(this.value=e,(0,r.w)(e)||(this.committer.dirty=!0))}commit(){for(;(0,r.w)(this.value);){const e=this.value;this.value=o.J,e(this)}this.value!==o.J&&this.committer.commit()}}class h{constructor(e){this.value=void 0,this.__pendingValue=void 0,this.options=e}appendInto(e){this.startNode=e.appendChild((0,l.IW)()),this.endNode=e.appendChild((0,l.IW)())}insertAfterNode(e){this.startNode=e,this.endNode=e.nextSibling}appendIntoPart(e){e.__insert(this.startNode=(0,l.IW)()),e.__insert(this.endNode=(0,l.IW)())}insertAfterPart(e){e.__insert(this.startNode=(0,l.IW)()),this.endNode=e.endNode,e.endNode=this.startNode}setValue(e){this.__pendingValue=e}commit(){if(null===this.startNode.parentNode)return;for(;(0,r.w)(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=o.J,e(this)}const e=this.__pendingValue;e!==o.J&&(c(e)?e!==this.value&&this.__commitText(e):e instanceof a.j?this.__commitTemplateResult(e):e instanceof Node?this.__commitNode(e):d(e)?this.__commitIterable(e):e===o.L?(this.value=o.L,this.clear()):this.__commitText(e))}__insert(e){this.endNode.parentNode.insertBefore(e,this.endNode)}__commitNode(e){this.value!==e&&(this.clear(),this.__insert(e),this.value=e)}__commitText(e){const t=this.startNode.nextSibling,n="string"==typeof(e=null==e?"":e)?e:String(e);t===this.endNode.previousSibling&&3===t.nodeType?t.data=n:this.__commitNode(document.createTextNode(n)),this.value=e}__commitTemplateResult(e){const t=this.options.templateFactory(e);if(this.value instanceof s.R&&this.value.template===t)this.value.update(e.values);else{const n=new s.R(t,e.processor,this.options),r=n._clone();n.update(e.values),this.__commitNode(r),this.value=n}}__commitIterable(e){Array.isArray(this.value)||(this.value=[],this.clear());const t=this.value;let n,r=0;for(const i of e)n=t[r],void 0===n&&(n=new h(this.options),t.push(n),0===r?n.appendIntoPart(this):n.insertAfterPart(t[r-1])),n.setValue(i),n.commit(),r++;r<t.length&&(t.length=r,this.clear(n&&n.endNode))}clear(e=this.startNode){(0,i.r4)(this.startNode.parentNode,e.nextSibling,this.endNode)}}class f{constructor(e,t,n){if(this.value=void 0,this.__pendingValue=void 0,2!==n.length||""!==n[0]||""!==n[1])throw new Error("Boolean attributes can only contain a single expression");this.element=e,this.name=t,this.strings=n}setValue(e){this.__pendingValue=e}commit(){for(;(0,r.w)(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=o.J,e(this)}if(this.__pendingValue===o.J)return;const e=!!this.__pendingValue;this.value!==e&&(e?this.element.setAttribute(this.name,""):this.element.removeAttribute(this.name),this.value=e),this.__pendingValue=o.J}}class m extends u{constructor(e,t,n){super(e,t,n),this.single=2===n.length&&""===n[0]&&""===n[1]}_createPart(){return new y(this)}_getValue(){return this.single?this.parts[0].value:super._getValue()}commit(){this.dirty&&(this.dirty=!1,this.element[this.name]=this._getValue())}}class y extends p{}let g=!1;(()=>{try{const e={get capture(){return g=!0,!1}};window.addEventListener("test",e,e),window.removeEventListener("test",e,e)}catch(e){}})();class b{constructor(e,t,n){this.value=void 0,this.__pendingValue=void 0,this.element=e,this.eventName=t,this.eventContext=n,this.__boundHandleEvent=e=>this.handleEvent(e)}setValue(e){this.__pendingValue=e}commit(){for(;(0,r.w)(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=o.J,e(this)}if(this.__pendingValue===o.J)return;const e=this.__pendingValue,t=this.value,n=null==e||null!=t&&(e.capture!==t.capture||e.once!==t.once||e.passive!==t.passive),i=null!=e&&(null==t||n);n&&this.element.removeEventListener(this.eventName,this.__boundHandleEvent,this.__options),i&&(this.__options=_(e),this.element.addEventListener(this.eventName,this.__boundHandleEvent,this.__options)),this.value=e,this.__pendingValue=o.J}handleEvent(e){"function"==typeof this.value?this.value.call(this.eventContext||this.element,e):this.value.handleEvent(e)}}const _=e=>e&&(g?{capture:e.capture,passive:e.passive,once:e.once}:e.capture)},84677:(e,t,n)=>{"use strict";n.d(t,{L:()=>s,s:()=>a});var r=n(50115),i=n(28823),o=n(92530);const s=new WeakMap,a=(e,t,n)=>{let a=s.get(t);void 0===a&&((0,r.r4)(t,t.firstChild),s.set(t,a=new i.nt(Object.assign({templateFactory:o.t},n))),a.appendInto(t)),a.setValue(e),a.commit()}},92530:(e,t,n)=>{"use strict";n.d(t,{t:()=>i,r:()=>o});var r=n(27283);function i(e){let t=o.get(e.type);void 0===t&&(t={stringsArray:new WeakMap,keyString:new Map},o.set(e.type,t));let n=t.stringsArray.get(e.strings);if(void 0!==n)return n;const i=e.strings.join(r.Jw);return n=t.keyString.get(i),void 0===n&&(n=new r.YS(e,e.getTemplateElement()),t.keyString.set(i,n)),t.stringsArray.set(e.strings,n),n}const o=new Map},37581:(e,t,n)=>{"use strict";n.d(t,{R:()=>o});var r=n(50115),i=n(27283);class o{constructor(e,t,n){this.__parts=[],this.template=e,this.processor=t,this.options=n}update(e){let t=0;for(const n of this.__parts)void 0!==n&&n.setValue(e[t]),t++;for(const n of this.__parts)void 0!==n&&n.commit()}_clone(){const e=r.eC?this.template.element.content.cloneNode(!0):document.importNode(this.template.element.content,!0),t=[],n=this.template.parts,o=document.createTreeWalker(e,133,null,!1);let s,a=0,l=0,c=o.nextNode();for(;a<n.length;)if(s=n[a],(0,i.pC)(s)){for(;l<s.index;)l++,"TEMPLATE"===c.nodeName&&(t.push(c),o.currentNode=c.content),null===(c=o.nextNode())&&(o.currentNode=t.pop(),c=o.nextNode());if("node"===s.type){const e=this.processor.handleTextExpression(this.options);e.insertAfterNode(c.previousSibling),this.__parts.push(e)}else this.__parts.push(...this.processor.handleAttributeExpressions(c,s.name,s.strings,this.options));a++}else this.__parts.push(void 0),a++;return r.eC&&(document.adoptNode(e),customElements.upgrade(e)),e}}},87842:(e,t,n)=>{"use strict";n.d(t,{j:()=>a,C:()=>l});var r=n(50115),i=n(27283);const o=window.trustedTypes&&trustedTypes.createPolicy("lit-html",{createHTML:e=>e}),s=` ${i.Jw} `;class a{constructor(e,t,n,r){this.strings=e,this.values=t,this.type=n,this.processor=r}getHTML(){const e=this.strings.length-1;let t="",n=!1;for(let r=0;r<e;r++){const e=this.strings[r],o=e.lastIndexOf("\x3c!--");n=(o>-1||n)&&-1===e.indexOf("--\x3e",o+1);const a=i.W5.exec(e);t+=null===a?e+(n?s:i.N):e.substr(0,a.index)+a[1]+a[2]+i.$E+a[3]+i.Jw}return t+=this.strings[e],t}getTemplateElement(){const e=document.createElement("template");let t=this.getHTML();return void 0!==o&&(t=o.createHTML(t)),e.innerHTML=t,e}}class l extends a{getHTML(){return`<svg>${super.getHTML()}</svg>`}getTemplateElement(){const e=super.getTemplateElement(),t=e.content,n=t.firstChild;return t.removeChild(n),(0,r.V)(t,n.firstChild),e}}},27283:(e,t,n)=>{"use strict";n.d(t,{Jw:()=>r,N:()=>i,$E:()=>s,YS:()=>a,pC:()=>c,IW:()=>d,W5:()=>u});const r=`{{lit-${String(Math.random()).slice(2)}}}`,i=`\x3c!--${r}--\x3e`,o=new RegExp(`${r}|${i}`),s="$lit$";class a{constructor(e,t){this.parts=[],this.element=t;const n=[],i=[],a=document.createTreeWalker(t.content,133,null,!1);let c=0,p=-1,h=0;const{strings:f,values:{length:m}}=e;for(;h<m;){const e=a.nextNode();if(null!==e){if(p++,1===e.nodeType){if(e.hasAttributes()){const t=e.attributes,{length:n}=t;let r=0;for(let e=0;e<n;e++)l(t[e].name,s)&&r++;for(;r-- >0;){const t=f[h],n=u.exec(t)[2],r=n.toLowerCase()+s,i=e.getAttribute(r);e.removeAttribute(r);const a=i.split(o);this.parts.push({type:"attribute",index:p,name:n,strings:a}),h+=a.length-1}}"TEMPLATE"===e.tagName&&(i.push(e),a.currentNode=e.content)}else if(3===e.nodeType){const t=e.data;if(t.indexOf(r)>=0){const r=e.parentNode,i=t.split(o),a=i.length-1;for(let t=0;t<a;t++){let n,o=i[t];if(""===o)n=d();else{const e=u.exec(o);null!==e&&l(e[2],s)&&(o=o.slice(0,e.index)+e[1]+e[2].slice(0,-s.length)+e[3]),n=document.createTextNode(o)}r.insertBefore(n,e),this.parts.push({type:"node",index:++p})}""===i[a]?(r.insertBefore(d(),e),n.push(e)):e.data=i[a],h+=a}}else if(8===e.nodeType)if(e.data===r){const t=e.parentNode;null!==e.previousSibling&&p!==c||(p++,t.insertBefore(d(),e)),c=p,this.parts.push({type:"node",index:p}),null===e.nextSibling?e.data="":(n.push(e),p--),h++}else{let t=-1;for(;-1!==(t=e.data.indexOf(r,t+1));)this.parts.push({type:"node",index:-1}),h++}}else a.currentNode=i.pop()}for(const r of n)r.parentNode.removeChild(r)}}const l=(e,t)=>{const n=e.length-t.length;return n>=0&&e.slice(n)===t},c=e=>-1!==e.index,d=()=>document.createComment(""),u=/([ \x09\x0a\x0c\x0d])([^\0-\x1F\x7F-\x9F "'>=/]+)([ \x09\x0a\x0c\x0d]*=[ \x09\x0a\x0c\x0d]*(?:[^ \x09\x0a\x0c\x0d"'`<>=]*|"[^"]*|'[^']*))$/},94707:(e,t,n)=>{"use strict";n.d(t,{_l:()=>r._l,nt:()=>r.nt,sL:()=>r.sL,js:()=>o.j,IW:()=>d.IW,XM:()=>s.X,dy:()=>u,Jb:()=>l.J,r4:()=>a.r4,V:()=>a.V,YP:()=>p,ty:()=>c.t});var r=n(28823);const i=new class{handleAttributeExpressions(e,t,n,i){const o=t[0];if("."===o){return new r.m(e,t.slice(1),n).parts}if("@"===o)return[new r.K1(e,t.slice(1),i.eventContext)];if("?"===o)return[new r.JG(e,t.slice(1),n)];return new r.QG(e,t,n).parts}handleTextExpression(e){return new r.nt(e)}};var o=n(87842),s=n(76747),a=n(50115),l=n(43401),c=(n(84677),n(92530)),d=(n(37581),n(27283));"undefined"!=typeof window&&(window.litHtmlVersions||(window.litHtmlVersions=[])).push("1.3.0");const u=(e,...t)=>new o.j(e,t,"html",i),p=(e,...t)=>new o.C(e,t,"svg",i)},87480:(e,t,n)=>{"use strict";n.d(t,{ZT:()=>i,pi:()=>o,gn:()=>s,XA:()=>a,CR:()=>l});var r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(e,t)};function i(e,t){function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}var o=function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function s(e,t,n,r){var i,o=arguments.length,s=o<3?t:null===r?r=Object.getOwnPropertyDescriptor(t,n):r;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)s=Reflect.decorate(e,t,n,r);else for(var a=e.length-1;a>=0;a--)(i=e[a])&&(s=(o<3?i(s):o>3?i(t,n,s):i(t,n))||s);return o>3&&s&&Object.defineProperty(t,n,s),s}function a(e){var t="function"==typeof Symbol&&e[Symbol.iterator],n=0;return t?t.call(e):{next:function(){return e&&n>=e.length&&(e=void 0),{value:e&&e[n++],done:!e}}}}function l(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),s=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)s.push(r.value)}catch(a){i={error:a}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return s}},66386:(e,t,n)=>{"use strict";n.d(t,{IO:()=>o,ed:()=>s});const r=window.localStorage||{};let i=window.__tokenCache;function o(){return void 0!==i.tokens&&void 0===i.writeEnabled}function s(){i.writeEnabled=!0,i.tokens&&function(e){if(i.tokens=e,i.writeEnabled)try{r.hassTokens=JSON.stringify(e)}catch(t){}}(i.tokens)}i||(i=window.__tokenCache={tokens:void 0,writeEnabled:void 0})},43260:(e,t,n)=>{"use strict";n.d(t,{R:()=>x,p:()=>C});var r=n(11654);const i=e=>{if(6===(e=e.replace("#","")).length)return e;let t="";for(const n of e)t+=n+n;return t},o=e=>{const t=Math.round(Math.min(Math.max(e,0),255)).toString(16);return 1===t.length?"0"+t:t},s=e=>(e=i(e),[parseInt(e.substring(0,2),16),parseInt(e.substring(2,4),16),parseInt(e.substring(4,6),16)]),a=e=>`#${o(e[0])}${o(e[1])}${o(e[2])}`,l=.95047,c=1.08883,d=.137931034,u=.12841855,p=e=>(e/=255)<=.04045?e/12.92:((e+.055)/1.055)**2.4,h=e=>e>.008856452?e**(1/3):e/u+d,f=e=>255*(e<=.00304?12.92*e:1.055*e**(1/2.4)-.055),m=e=>e>.206896552?e*e*e:u*(e-d),y=e=>{const[t,n,r]=(e=>{let[t,n,r]=e;return t=p(t),n=p(n),r=p(r),[h((.4124564*t+.3575761*n+.1804375*r)/l),h((.2126729*t+.7151522*n+.072175*r)/1),h((.0193339*t+.119192*n+.9503041*r)/c)]})(e),i=116*n-16;return[i<0?0:i,500*(t-n),200*(n-r)]},g=e=>{const[t,n,r]=e;let i=(t+16)/116,o=isNaN(n)?i:i+n/500,s=isNaN(r)?i:i-r/200;i=1*m(i),o=l*m(o),s=c*m(s);return[f(3.2404542*o-1.5371385*i-.4985314*s),f(-.969266*o+1.8760108*i+.041556*s),f(.0556434*o-.2040259*i+1.0572252*s)]},b=(e,t=1)=>[e[0]-18*t,e[1],e[2]],_=e=>{const t=[0,0,0];for(let n=0;n<e.length;n++){const r=e[n]/255;t[n]=r<=.03928?r/12.92:((r+.055)/1.055)**2.4}return.2126*t[0]+.7152*t[1]+.0722*t[2]},v=(e,t)=>{const n=_(e),r=_(t);return n>r?(n+.05)/(r+.05):(r+.05)/(n+.05)};let w={};const x=(e,t,n,o)=>{let l=n,c={};if("default"===n&&o){if(o.dark&&(l+="__dark",c=r._l,o.primaryColor&&(c["app-header-background-color"]=((e,t,n=50)=>{let r="";e=i(e),t=i(t);for(let i=0;i<=5;i+=2){const o=parseInt(e.substr(i,2),16),s=parseInt(t.substr(i,2),16);let a=Math.floor(s+n/100*(o-s)).toString(16);for(;a.length<2;)a="0"+a;r+=a}return"#"+r})(o.primaryColor,"#121212",8))),o.primaryColor){l=`${l}__primary_${o.primaryColor}`;const e=s(o.primaryColor),t=y(e);c["primary-color"]=o.primaryColor;const n=g(((e,t=1)=>b(e,-t))(t));c["light-primary-color"]=a(n),c["dark-primary-color"]=(e=>{const t=g(e);return a(t)})(b(t)),c["text-primary-color"]=v(e,[33,33,33])<6?"#fff":"#212121",c["text-light-primary-color"]=v(n,[33,33,33])<6?"#fff":"#212121",c["state-icon-color"]=c["dark-primary-color"]}if(o.accentColor){l=`${l}__accent_${o.accentColor}`,c["accent-color"]=o.accentColor;const e=s(o.accentColor);c["text-accent-color"]=v(e,[33,33,33])<6?"#fff":"#212121"}}if(n&&t.themes[n]&&(c=t.themes[n]),!e._themes&&!Object.keys(c).length)return;const d=c&&l?w[l]||k(l,c):void 0,u={...e._themes,...null==d?void 0:d.styles};e._themes=null==d?void 0:d.keys,e.updateStyles?e.updateStyles(u):window.ShadyCSS&&window.ShadyCSS.styleSubtree(e,u)},k=(e,t)=>{if(!t||!Object.keys(t).length)return;const n={...r.q0,...t},i={},o={};for(const r of Object.keys(n)){const e="--"+r,t=String(n[r]);if(i[e]=t,o[e]="",!t.startsWith("#"))continue;const l="rgb-"+r;if(void 0===n[l])try{const e=s(t).join(","),n="--"+l;i[n]=e,o[n]=""}catch(a){continue}}return w[e]={styles:i,keys:o},{styles:i,keys:o}},C=()=>{w={}}},47181:(e,t,n)=>{"use strict";n.d(t,{B:()=>r});const r=(e,t,n,r)=>{r=r||{},n=null==n?{}:n;const i=new Event(t,{bubbles:void 0===r.bubbles||r.bubbles,cancelable:Boolean(r.cancelable),composed:void 0===r.composed||r.composed});return i.detail=n,e.dispatchEvent(i),i}},35359:(e,t,n)=>{"use strict";var r,i;function o(e){return e.type===r.literal}function s(e){return e.type===r.argument}function a(e){return e.type===r.number}function l(e){return e.type===r.date}function c(e){return e.type===r.time}function d(e){return e.type===r.select}function u(e){return e.type===r.plural}function p(e){return e.type===r.pound}function h(e){return e.type===r.tag}function f(e){return!(!e||"object"!=typeof e||0!==e.type)}function m(e){return!(!e||"object"!=typeof e||1!==e.type)}n.d(t,{X:()=>X,I:()=>Z}),function(e){e[e.literal=0]="literal",e[e.argument=1]="argument",e[e.number=2]="number",e[e.date=3]="date",e[e.time=4]="time",e[e.select=5]="select",e[e.plural=6]="plural",e[e.pound=7]="pound",e[e.tag=8]="tag"}(r||(r={})),function(e){e[e.number=0]="number",e[e.dateTime=1]="dateTime"}(i||(i={}));var y,g=(y=function(e,t){return(y=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(e,t)},function(e,t){function n(){this.constructor=e}y(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),b=function(){return(b=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},_=function(e){function t(n,r,i,o){var s=e.call(this)||this;return s.message=n,s.expected=r,s.found=i,s.location=o,s.name="SyntaxError","function"==typeof Error.captureStackTrace&&Error.captureStackTrace(s,t),s}return g(t,e),t.buildMessage=function(e,t){function n(e){return e.charCodeAt(0).toString(16).toUpperCase()}function r(e){return e.replace(/\\/g,"\\\\").replace(/"/g,'\\"').replace(/\0/g,"\\0").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/[\x00-\x0F]/g,(function(e){return"\\x0"+n(e)})).replace(/[\x10-\x1F\x7F-\x9F]/g,(function(e){return"\\x"+n(e)}))}function i(e){return e.replace(/\\/g,"\\\\").replace(/\]/g,"\\]").replace(/\^/g,"\\^").replace(/-/g,"\\-").replace(/\0/g,"\\0").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/[\x00-\x0F]/g,(function(e){return"\\x0"+n(e)})).replace(/[\x10-\x1F\x7F-\x9F]/g,(function(e){return"\\x"+n(e)}))}function o(e){switch(e.type){case"literal":return'"'+r(e.text)+'"';case"class":var t=e.parts.map((function(e){return Array.isArray(e)?i(e[0])+"-"+i(e[1]):i(e)}));return"["+(e.inverted?"^":"")+t+"]";case"any":return"any character";case"end":return"end of input";case"other":return e.description}}return"Expected "+function(e){var t,n,r=e.map(o);if(r.sort(),r.length>0){for(t=1,n=1;t<r.length;t++)r[t-1]!==r[t]&&(r[n]=r[t],n++);r.length=n}switch(r.length){case 1:return r[0];case 2:return r[0]+" or "+r[1];default:return r.slice(0,-1).join(", ")+", or "+r[r.length-1]}}(e)+" but "+(((s=t)?'"'+r(s)+'"':"end of input")+" found.");var s},t}(Error);var v=function(e,t){t=void 0!==t?t:{};var n,i={},o={start:Ke},s=Ke,a=je("#",!1),l=Ve("tagElement"),c="<",d=je("<",!1),u="/>",p=je("/>",!1),h=">",f=je(">",!1),m=function(e){return mt.pop(),!0},y="</",g=je("</",!1),v=Ve("argumentElement"),w="{",x=je("{",!1),k="}",C=je("}",!1),E=Ve("numberSkeletonId"),S=/^['\/{}]/,P=Be(["'","/","{","}"],!1,!1),A={type:"any"},T=Ve("numberSkeletonTokenOption"),O=je("/",!1),N=Ve("numberSkeletonToken"),I="::",R=je("::",!1),D=function(e){return mt.pop(),e.replace(/\s*$/,"")},z=",",F=je(",",!1),L="number",M=je("number",!1),H=function(e,t,n){return b({type:"number"===t?r.number:"date"===t?r.date:r.time,style:n&&n[2],value:e},bt())},j="'",B=je("'",!1),V=/^[^']/,$=Be(["'"],!0,!1),U=/^[^a-zA-Z'{}]/,q=Be([["a","z"],["A","Z"],"'","{","}"],!0,!1),Y=/^[a-zA-Z]/,K=Be([["a","z"],["A","Z"]],!1,!1),J="date",W=je("date",!1),G="time",X=je("time",!1),Z="plural",Q=je("plural",!1),ee="selectordinal",te=je("selectordinal",!1),ne="offset:",re=je("offset:",!1),ie="select",oe=je("select",!1),se=je("=",!1),ae=Ve("whitespace"),le=/^[\t-\r \x85\xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000]/,ce=Be([["\t","\r"]," ",""," "," ",[" "," "],"\u2028","\u2029"," "," ","　"],!1,!1),de=Ve("syntax pattern"),ue=/^[!-\/:-@[-\^`{-~\xA1-\xA7\xA9\xAB\xAC\xAE\xB0\xB1\xB6\xBB\xBF\xD7\xF7\u2010-\u2027\u2030-\u203E\u2041-\u2053\u2055-\u205E\u2190-\u245F\u2500-\u2775\u2794-\u2BFF\u2E00-\u2E7F\u3001-\u3003\u3008-\u3020\u3030\uFD3E\uFD3F\uFE45\uFE46]/,pe=Be([["!","/"],[":","@"],["[","^"],"`",["{","~"],["¡","§"],"©","«","¬","®","°","±","¶","»","¿","×","÷",["‐","‧"],["‰","‾"],["⁁","⁓"],["⁕","⁞"],["←","⑟"],["─","❵"],["➔","⯿"],["⸀","⹿"],["、","〃"],["〈","〠"],"〰","﴾","﴿","﹅","﹆"],!1,!1),he=Ve("optional whitespace"),fe=Ve("number"),me="-",ye=je("-",!1),ge=(Ve("apostrophe"),Ve("double apostrophes")),be="''",_e=je("''",!1),ve=je("\n",!1),we=Ve("argNameOrNumber"),xe=Ve("validTag"),ke=Ve("argNumber"),Ce=je("0",!1),Ee=/^[1-9]/,Se=Be([["1","9"]],!1,!1),Pe=/^[0-9]/,Ae=Be([["0","9"]],!1,!1),Te=Ve("argName"),Oe=Ve("tagName"),Ne=0,Ie=0,Re=[{line:1,column:1}],De=0,ze=[],Fe=0;if(void 0!==t.startRule){if(!(t.startRule in o))throw new Error("Can't start parsing from rule \""+t.startRule+'".');s=o[t.startRule]}function Le(){return e.substring(Ie,Ne)}function Me(){return Ue(Ie,Ne)}function He(e,t){throw function(e,t){return new _(e,[],"",t)}(e,t=void 0!==t?t:Ue(Ie,Ne))}function je(e,t){return{type:"literal",text:e,ignoreCase:t}}function Be(e,t,n){return{type:"class",parts:e,inverted:t,ignoreCase:n}}function Ve(e){return{type:"other",description:e}}function $e(t){var n,r=Re[t];if(r)return r;for(n=t-1;!Re[n];)n--;for(r={line:(r=Re[n]).line,column:r.column};n<t;)10===e.charCodeAt(n)?(r.line++,r.column=1):r.column++,n++;return Re[t]=r,r}function Ue(e,t){var n=$e(e),r=$e(t);return{start:{offset:e,line:n.line,column:n.column},end:{offset:t,line:r.line,column:r.column}}}function qe(e){Ne<De||(Ne>De&&(De=Ne,ze=[]),ze.push(e))}function Ye(e,t,n){return new _(_.buildMessage(e,t),e,t,n)}function Ke(){return Je()}function Je(){var e,t;for(e=[],t=We();t!==i;)e.push(t),t=We();return e}function We(){var t;return(t=function(){var e,t;e=Ne,(t=Ge())!==i&&(Ie=e,n=t,t=b({type:r.literal,value:n},bt()));var n;return e=t}())===i&&(t=function(){var t,n,o,s;Fe++,t=Ne,123===e.charCodeAt(Ne)?(n=w,Ne++):(n=i,0===Fe&&qe(x));n!==i&&st()!==i&&(o=ut())!==i&&st()!==i?(125===e.charCodeAt(Ne)?(s=k,Ne++):(s=i,0===Fe&&qe(C)),s!==i?(Ie=t,a=o,t=n=b({type:r.argument,value:a},bt())):(Ne=t,t=i)):(Ne=t,t=i);var a;Fe--,t===i&&(n=i,0===Fe&&qe(v));return t}())===i&&(t=function(){var t;(t=function(){var t,n,r,o,s,a,l,c,d;t=Ne,123===e.charCodeAt(Ne)?(n=w,Ne++):(n=i,0===Fe&&qe(x));n!==i&&st()!==i&&(r=ut())!==i&&st()!==i?(44===e.charCodeAt(Ne)?(o=z,Ne++):(o=i,0===Fe&&qe(F)),o!==i&&st()!==i?(e.substr(Ne,6)===L?(s=L,Ne+=6):(s=i,0===Fe&&qe(M)),s!==i&&st()!==i?(a=Ne,44===e.charCodeAt(Ne)?(l=z,Ne++):(l=i,0===Fe&&qe(F)),l!==i&&(c=st())!==i&&(d=function(){var t,n,r;t=Ne,e.substr(Ne,2)===I?(n=I,Ne+=2):(n=i,0===Fe&&qe(R));n!==i&&(r=function(){var e,t,n;if(e=Ne,t=[],(n=Qe())!==i)for(;n!==i;)t.push(n),n=Qe();else t=i;t!==i&&(Ie=e,t=b({type:0,tokens:t},bt()));return e=t}())!==i?(Ie=t,t=n=r):(Ne=t,t=i);t===i&&(t=Ne,Ie=Ne,mt.push("numberArgStyle"),(n=(n=!0)?void 0:i)!==i&&(r=Ge())!==i?(Ie=t,t=n=D(r)):(Ne=t,t=i));return t}())!==i?a=l=[l,c,d]:(Ne=a,a=i),a===i&&(a=null),a!==i&&(l=st())!==i?(125===e.charCodeAt(Ne)?(c=k,Ne++):(c=i,0===Fe&&qe(C)),c!==i?(Ie=t,t=n=H(r,s,a)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i);return t}())===i&&(t=function(){var t,n,r,o,s,a,l,c,d;t=Ne,123===e.charCodeAt(Ne)?(n=w,Ne++):(n=i,0===Fe&&qe(x));n!==i&&st()!==i&&(r=ut())!==i&&st()!==i?(44===e.charCodeAt(Ne)?(o=z,Ne++):(o=i,0===Fe&&qe(F)),o!==i&&st()!==i?(e.substr(Ne,4)===J?(s=J,Ne+=4):(s=i,0===Fe&&qe(W)),s===i&&(e.substr(Ne,4)===G?(s=G,Ne+=4):(s=i,0===Fe&&qe(X))),s!==i&&st()!==i?(a=Ne,44===e.charCodeAt(Ne)?(l=z,Ne++):(l=i,0===Fe&&qe(F)),l!==i&&(c=st())!==i&&(d=function(){var t,n,r;t=Ne,e.substr(Ne,2)===I?(n=I,Ne+=2):(n=i,0===Fe&&qe(R));n!==i&&(r=function(){var t,n,r,o;t=Ne,n=Ne,r=[],(o=et())===i&&(o=tt());if(o!==i)for(;o!==i;)r.push(o),(o=et())===i&&(o=tt());else r=i;n=r!==i?e.substring(n,Ne):r;n!==i&&(Ie=t,n=b({type:1,pattern:n},bt()));return t=n}())!==i?(Ie=t,t=n=r):(Ne=t,t=i);t===i&&(t=Ne,Ie=Ne,mt.push("dateOrTimeArgStyle"),(n=(n=!0)?void 0:i)!==i&&(r=Ge())!==i?(Ie=t,t=n=D(r)):(Ne=t,t=i));return t}())!==i?a=l=[l,c,d]:(Ne=a,a=i),a===i&&(a=null),a!==i&&(l=st())!==i?(125===e.charCodeAt(Ne)?(c=k,Ne++):(c=i,0===Fe&&qe(C)),c!==i?(Ie=t,t=n=H(r,s,a)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i);return t}());return t}())===i&&(t=function(){var t,n,o,s,a,l,c,d,u,p,h;t=Ne,123===e.charCodeAt(Ne)?(n=w,Ne++):(n=i,0===Fe&&qe(x));if(n!==i)if(st()!==i)if((o=ut())!==i)if(st()!==i)if(44===e.charCodeAt(Ne)?(s=z,Ne++):(s=i,0===Fe&&qe(F)),s!==i)if(st()!==i)if(e.substr(Ne,6)===Z?(a=Z,Ne+=6):(a=i,0===Fe&&qe(Q)),a===i&&(e.substr(Ne,13)===ee?(a=ee,Ne+=13):(a=i,0===Fe&&qe(te))),a!==i)if(st()!==i)if(44===e.charCodeAt(Ne)?(l=z,Ne++):(l=i,0===Fe&&qe(F)),l!==i)if(st()!==i)if(c=Ne,e.substr(Ne,7)===ne?(d=ne,Ne+=7):(d=i,0===Fe&&qe(re)),d!==i&&(u=st())!==i&&(p=at())!==i?c=d=[d,u,p]:(Ne=c,c=i),c===i&&(c=null),c!==i)if((d=st())!==i){if(u=[],(p=rt())!==i)for(;p!==i;)u.push(p),p=rt();else u=i;u!==i&&(p=st())!==i?(125===e.charCodeAt(Ne)?(h=k,Ne++):(h=i,0===Fe&&qe(C)),h!==i?(Ie=t,t=n=function(e,t,n,i){return b({type:r.plural,pluralType:"plural"===t?"cardinal":"ordinal",value:e,offset:n?n[2]:0,options:i.reduce((function(e,t){var n=t.id,r=t.value,i=t.location;return n in e&&He('Duplicate option "'+n+'" in plural element: "'+Le()+'"',Me()),e[n]={value:r,location:i},e}),{})},bt())}(o,a,c,u)):(Ne=t,t=i)):(Ne=t,t=i)}else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;return t}())===i&&(t=function(){var t,n,o,s,a,l,c,d,u;t=Ne,123===e.charCodeAt(Ne)?(n=w,Ne++):(n=i,0===Fe&&qe(x));if(n!==i)if(st()!==i)if((o=ut())!==i)if(st()!==i)if(44===e.charCodeAt(Ne)?(s=z,Ne++):(s=i,0===Fe&&qe(F)),s!==i)if(st()!==i)if(e.substr(Ne,6)===ie?(a=ie,Ne+=6):(a=i,0===Fe&&qe(oe)),a!==i)if(st()!==i)if(44===e.charCodeAt(Ne)?(l=z,Ne++):(l=i,0===Fe&&qe(F)),l!==i)if(st()!==i){if(c=[],(d=nt())!==i)for(;d!==i;)c.push(d),d=nt();else c=i;c!==i&&(d=st())!==i?(125===e.charCodeAt(Ne)?(u=k,Ne++):(u=i,0===Fe&&qe(C)),u!==i?(Ie=t,t=n=function(e,t){return b({type:r.select,value:e,options:t.reduce((function(e,t){var n=t.id,r=t.value,i=t.location;return n in e&&He('Duplicate option "'+n+'" in select element: "'+Le()+'"',Me()),e[n]={value:r,location:i},e}),{})},bt())}(o,c)):(Ne=t,t=i)):(Ne=t,t=i)}else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;else Ne=t,t=i;return t}())===i&&(t=function(){var t,n,o,s,a,_;Fe++,t=Ne,n=Ne,60===e.charCodeAt(Ne)?(o="<",Ne++):(o=i,0===Fe&&qe(d));o!==i&&(s=pt())!==i&&(a=st())!==i?(e.substr(Ne,2)===u?(_=u,Ne+=2):(_=i,0===Fe&&qe(p)),_!==i?n=o=[o,s,a,_]:(Ne=n,n=i)):(Ne=n,n=i);n!==i&&(Ie=t,v=n,n=b({type:r.literal,value:v.join("")},bt()));var v;(t=n)===i&&(t=Ne,(n=function(){var t,n,r,o;t=Ne,60===e.charCodeAt(Ne)?(n=c,Ne++):(n=i,0===Fe&&qe(d));n!==i?(Ie=Ne,mt.push("openingTag"),(!0?void 0:i)!==i&&(r=pt())!==i?(62===e.charCodeAt(Ne)?(o=">",Ne++):(o=i,0===Fe&&qe(f)),o!==i?(Ie=Ne,(m()?void 0:i)!==i?(Ie=t,t=n=r):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i);return t}())!==i&&(o=Je())!==i&&(s=function(){var t,n,r,o;t=Ne,e.substr(Ne,2)===y?(n=y,Ne+=2):(n=i,0===Fe&&qe(g));n!==i?(Ie=Ne,mt.push("closingTag"),(!0?void 0:i)!==i&&(r=pt())!==i?(62===e.charCodeAt(Ne)?(o=h,Ne++):(o=i,0===Fe&&qe(f)),o!==i?(Ie=Ne,(m()?void 0:i)!==i?(Ie=t,t=n=r):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i);return t}())!==i?(Ie=t,x=o,(w=n)!==(k=s)&&He('Mismatch tag "'+w+'" !== "'+k+'"',Me()),t=n=b({type:r.tag,value:w,children:x},bt())):(Ne=t,t=i));var w,x,k;Fe--,t===i&&(n=i,0===Fe&&qe(l));return t}())===i&&(t=function(){var t,n;t=Ne,35===e.charCodeAt(Ne)?(n="#",Ne++):(n=i,0===Fe&&qe(a));n!==i&&(Ie=t,n=b({type:r.pound},bt()));return t=n}()),t}function Ge(){var e,t,n;if(e=Ne,t=[],(n=lt())===i&&(n=ct())===i&&(n=dt()),n!==i)for(;n!==i;)t.push(n),(n=lt())===i&&(n=ct())===i&&(n=dt());else t=i;return t!==i&&(Ie=e,t=t.join("")),e=t}function Xe(){var t,n,r,o,s;if(Fe++,t=Ne,n=[],r=Ne,o=Ne,Fe++,(s=it())===i&&(S.test(e.charAt(Ne))?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(P))),Fe--,s===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(A)),s!==i?r=o=[o,s]:(Ne=r,r=i)):(Ne=r,r=i),r!==i)for(;r!==i;)n.push(r),r=Ne,o=Ne,Fe++,(s=it())===i&&(S.test(e.charAt(Ne))?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(P))),Fe--,s===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(A)),s!==i?r=o=[o,s]:(Ne=r,r=i)):(Ne=r,r=i);else n=i;return t=n!==i?e.substring(t,Ne):n,Fe--,t===i&&(n=i,0===Fe&&qe(E)),t}function Ze(){var t,n,r;return Fe++,t=Ne,47===e.charCodeAt(Ne)?(n="/",Ne++):(n=i,0===Fe&&qe(O)),n!==i&&(r=Xe())!==i?(Ie=t,t=n=r):(Ne=t,t=i),Fe--,t===i&&(n=i,0===Fe&&qe(T)),t}function Qe(){var e,t,n,r;if(Fe++,e=Ne,st()!==i)if((t=Xe())!==i){for(n=[],r=Ze();r!==i;)n.push(r),r=Ze();n!==i?(Ie=e,e=function(e,t){return{stem:e,options:t}}(t,n)):(Ne=e,e=i)}else Ne=e,e=i;else Ne=e,e=i;return Fe--,e===i&&(i,0===Fe&&qe(N)),e}function et(){var t,n,r,o;if(t=Ne,39===e.charCodeAt(Ne)?(n=j,Ne++):(n=i,0===Fe&&qe(B)),n!==i){if(r=[],(o=lt())===i&&(V.test(e.charAt(Ne))?(o=e.charAt(Ne),Ne++):(o=i,0===Fe&&qe($))),o!==i)for(;o!==i;)r.push(o),(o=lt())===i&&(V.test(e.charAt(Ne))?(o=e.charAt(Ne),Ne++):(o=i,0===Fe&&qe($)));else r=i;r!==i?(39===e.charCodeAt(Ne)?(o=j,Ne++):(o=i,0===Fe&&qe(B)),o!==i?t=n=[n,r,o]:(Ne=t,t=i)):(Ne=t,t=i)}else Ne=t,t=i;if(t===i)if(t=[],(n=lt())===i&&(U.test(e.charAt(Ne))?(n=e.charAt(Ne),Ne++):(n=i,0===Fe&&qe(q))),n!==i)for(;n!==i;)t.push(n),(n=lt())===i&&(U.test(e.charAt(Ne))?(n=e.charAt(Ne),Ne++):(n=i,0===Fe&&qe(q)));else t=i;return t}function tt(){var t,n;if(t=[],Y.test(e.charAt(Ne))?(n=e.charAt(Ne),Ne++):(n=i,0===Fe&&qe(K)),n!==i)for(;n!==i;)t.push(n),Y.test(e.charAt(Ne))?(n=e.charAt(Ne),Ne++):(n=i,0===Fe&&qe(K));else t=i;return t}function nt(){var t,n,r,o,s,a,l;return t=Ne,st()!==i&&(n=ft())!==i&&st()!==i?(123===e.charCodeAt(Ne)?(r=w,Ne++):(r=i,0===Fe&&qe(x)),r!==i?(Ie=Ne,mt.push("select"),(!0?void 0:i)!==i&&(o=Je())!==i?(125===e.charCodeAt(Ne)?(s=k,Ne++):(s=i,0===Fe&&qe(C)),s!==i?(Ie=t,a=n,l=o,mt.pop(),t=b({id:a,value:l},bt())):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i),t}function rt(){var t,n,r,o,s,a,l;return t=Ne,st()!==i&&(n=function(){var t,n,r,o;return t=Ne,n=Ne,61===e.charCodeAt(Ne)?(r="=",Ne++):(r=i,0===Fe&&qe(se)),r!==i&&(o=at())!==i?n=r=[r,o]:(Ne=n,n=i),(t=n!==i?e.substring(t,Ne):n)===i&&(t=ft()),t}())!==i&&st()!==i?(123===e.charCodeAt(Ne)?(r=w,Ne++):(r=i,0===Fe&&qe(x)),r!==i?(Ie=Ne,mt.push("plural"),(!0?void 0:i)!==i&&(o=Je())!==i?(125===e.charCodeAt(Ne)?(s=k,Ne++):(s=i,0===Fe&&qe(C)),s!==i?(Ie=t,a=n,l=o,mt.pop(),t=b({id:a,value:l},bt())):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i)):(Ne=t,t=i),t}function it(){var t;return Fe++,le.test(e.charAt(Ne))?(t=e.charAt(Ne),Ne++):(t=i,0===Fe&&qe(ce)),Fe--,t===i&&(i,0===Fe&&qe(ae)),t}function ot(){var t;return Fe++,ue.test(e.charAt(Ne))?(t=e.charAt(Ne),Ne++):(t=i,0===Fe&&qe(pe)),Fe--,t===i&&(i,0===Fe&&qe(de)),t}function st(){var t,n,r;for(Fe++,t=Ne,n=[],r=it();r!==i;)n.push(r),r=it();return t=n!==i?e.substring(t,Ne):n,Fe--,t===i&&(n=i,0===Fe&&qe(he)),t}function at(){var t,n,r,o,s;return Fe++,t=Ne,45===e.charCodeAt(Ne)?(n="-",Ne++):(n=i,0===Fe&&qe(ye)),n===i&&(n=null),n!==i&&(r=ht())!==i?(Ie=t,o=n,t=n=(s=r)?o?-s:s:0):(Ne=t,t=i),Fe--,t===i&&(n=i,0===Fe&&qe(fe)),t}function lt(){var t,n;return Fe++,t=Ne,e.substr(Ne,2)===be?(n=be,Ne+=2):(n=i,0===Fe&&qe(_e)),n!==i&&(Ie=t,n="'"),Fe--,(t=n)===i&&(n=i,0===Fe&&qe(ge)),t}function ct(){var t,n,r,o,s,a;if(t=Ne,39===e.charCodeAt(Ne)?(n=j,Ne++):(n=i,0===Fe&&qe(B)),n!==i)if((r=function(){var t,n,r,o;t=Ne,n=Ne,e.length>Ne?(r=e.charAt(Ne),Ne++):(r=i,0===Fe&&qe(A));r!==i?(Ie=Ne,(o=(o="<"===(s=r)||">"===s||"{"===s||"}"===s||gt()&&"#"===s)?void 0:i)!==i?n=r=[r,o]:(Ne=n,n=i)):(Ne=n,n=i);var s;t=n!==i?e.substring(t,Ne):n;return t}())!==i){for(o=Ne,s=[],e.substr(Ne,2)===be?(a=be,Ne+=2):(a=i,0===Fe&&qe(_e)),a===i&&(V.test(e.charAt(Ne))?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe($)));a!==i;)s.push(a),e.substr(Ne,2)===be?(a=be,Ne+=2):(a=i,0===Fe&&qe(_e)),a===i&&(V.test(e.charAt(Ne))?(a=e.charAt(Ne),Ne++):(a=i,0===Fe&&qe($)));(o=s!==i?e.substring(o,Ne):s)!==i?(39===e.charCodeAt(Ne)?(s=j,Ne++):(s=i,0===Fe&&qe(B)),s===i&&(s=null),s!==i?(Ie=t,t=n=r+o.replace("''","'")):(Ne=t,t=i)):(Ne=t,t=i)}else Ne=t,t=i;else Ne=t,t=i;return t}function dt(){var t,n,r,o,s;return t=Ne,n=Ne,e.length>Ne?(r=e.charAt(Ne),Ne++):(r=i,0===Fe&&qe(A)),r!==i?(Ie=Ne,(o=(o=!("<"===(s=r)||"{"===s||gt()&&"#"===s||yt()&&"}"===s||yt()&&">"===s))?void 0:i)!==i?n=r=[r,o]:(Ne=n,n=i)):(Ne=n,n=i),n===i&&(10===e.charCodeAt(Ne)?(n="\n",Ne++):(n=i,0===Fe&&qe(ve))),t=n!==i?e.substring(t,Ne):n}function ut(){var t,n;return Fe++,t=Ne,(n=ht())===i&&(n=ft()),t=n!==i?e.substring(t,Ne):n,Fe--,t===i&&(n=i,0===Fe&&qe(we)),t}function pt(){var t,n;return Fe++,t=Ne,(n=ht())===i&&(n=function(){var t,n,r,o,s;Fe++,t=Ne,n=[],45===e.charCodeAt(Ne)?(r=me,Ne++):(r=i,0===Fe&&qe(ye));r===i&&(r=Ne,o=Ne,Fe++,(s=it())===i&&(s=ot()),Fe--,s===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(A)),s!==i?r=o=[o,s]:(Ne=r,r=i)):(Ne=r,r=i));if(r!==i)for(;r!==i;)n.push(r),45===e.charCodeAt(Ne)?(r=me,Ne++):(r=i,0===Fe&&qe(ye)),r===i&&(r=Ne,o=Ne,Fe++,(s=it())===i&&(s=ot()),Fe--,s===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(A)),s!==i?r=o=[o,s]:(Ne=r,r=i)):(Ne=r,r=i));else n=i;t=n!==i?e.substring(t,Ne):n;Fe--,t===i&&(n=i,0===Fe&&qe(Oe));return t}()),t=n!==i?e.substring(t,Ne):n,Fe--,t===i&&(n=i,0===Fe&&qe(xe)),t}function ht(){var t,n,r,o,s;if(Fe++,t=Ne,48===e.charCodeAt(Ne)?(n="0",Ne++):(n=i,0===Fe&&qe(Ce)),n!==i&&(Ie=t,n=0),(t=n)===i){if(t=Ne,n=Ne,Ee.test(e.charAt(Ne))?(r=e.charAt(Ne),Ne++):(r=i,0===Fe&&qe(Se)),r!==i){for(o=[],Pe.test(e.charAt(Ne))?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(Ae));s!==i;)o.push(s),Pe.test(e.charAt(Ne))?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(Ae));o!==i?n=r=[r,o]:(Ne=n,n=i)}else Ne=n,n=i;n!==i&&(Ie=t,n=parseInt(n.join(""),10)),t=n}return Fe--,t===i&&(n=i,0===Fe&&qe(ke)),t}function ft(){var t,n,r,o,s;if(Fe++,t=Ne,n=[],r=Ne,o=Ne,Fe++,(s=it())===i&&(s=ot()),Fe--,s===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(A)),s!==i?r=o=[o,s]:(Ne=r,r=i)):(Ne=r,r=i),r!==i)for(;r!==i;)n.push(r),r=Ne,o=Ne,Fe++,(s=it())===i&&(s=ot()),Fe--,s===i?o=void 0:(Ne=o,o=i),o!==i?(e.length>Ne?(s=e.charAt(Ne),Ne++):(s=i,0===Fe&&qe(A)),s!==i?r=o=[o,s]:(Ne=r,r=i)):(Ne=r,r=i);else n=i;return t=n!==i?e.substring(t,Ne):n,Fe--,t===i&&(n=i,0===Fe&&qe(Te)),t}var mt=["root"];function yt(){return mt.length>1}function gt(){return"plural"===mt[mt.length-1]}function bt(){return t&&t.captureLocation?{location:Me()}:{}}if((n=s())!==i&&Ne===e.length)return n;throw n!==i&&Ne<e.length&&qe({type:"end"}),Ye(ze,De<e.length?e.charAt(De):null,De<e.length?Ue(De,De+1):Ue(De,De))},w=function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],s=0,a=o.length;s<a;s++,i++)r[i]=o[s];return r},x=/(^|[^\\])#/g;function k(e){e.forEach((function(e){(u(e)||d(e))&&Object.keys(e.options).forEach((function(t){for(var n,r=e.options[t],i=-1,s=void 0,a=0;a<r.value.length;a++){var l=r.value[a];if(o(l)&&x.test(l.value)){i=a,s=l;break}}if(s){var c=s.value.replace(x,"$1{"+e.value+", number}"),d=v(c);(n=r.value).splice.apply(n,w([i,1],d))}k(r.value)}))}))}function C(e,t){var n=v(e,t);return t&&!1===t.normalizeHashtagInPlural||k(n),n}var E=function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],s=0,a=o.length;s<a;s++,i++)r[i]=o[s];return r};function S(e){return JSON.stringify(e.map((function(e){return e&&"object"==typeof e?(t=e,Object.keys(t).sort().map((function(e){var n;return(n={})[e]=t[e],n}))):e;var t})))}const P=function(e,t){return void 0===t&&(t={}),function(){for(var n,r=[],i=0;i<arguments.length;i++)r[i]=arguments[i];var o=S(r),s=o&&t[o];return s||(s=new((n=e).bind.apply(n,E([void 0],r))),o&&(t[o]=s)),s}};var A=function(){return(A=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},T=/(?:[Eec]{1,6}|G{1,5}|[Qq]{1,5}|(?:[yYur]+|U{1,5})|[ML]{1,5}|d{1,2}|D{1,3}|F{1}|[abB]{1,5}|[hkHK]{1,2}|w{1,2}|W{1}|m{1,2}|s{1,2}|[zZOvVxX]{1,4})(?=([^']*'[^']*')*[^']*$)/g;function O(e){var t={};return e.replace(T,(function(e){var n=e.length;switch(e[0]){case"G":t.era=4===n?"long":5===n?"narrow":"short";break;case"y":t.year=2===n?"2-digit":"numeric";break;case"Y":case"u":case"U":case"r":throw new RangeError("`Y/u/U/r` (year) patterns are not supported, use `y` instead");case"q":case"Q":throw new RangeError("`q/Q` (quarter) patterns are not supported");case"M":case"L":t.month=["numeric","2-digit","short","long","narrow"][n-1];break;case"w":case"W":throw new RangeError("`w/W` (week) patterns are not supported");case"d":t.day=["numeric","2-digit"][n-1];break;case"D":case"F":case"g":throw new RangeError("`D/F/g` (day) patterns are not supported, use `d` instead");case"E":t.weekday=4===n?"short":5===n?"narrow":"short";break;case"e":if(n<4)throw new RangeError("`e..eee` (weekday) patterns are not supported");t.weekday=["short","long","narrow","short"][n-4];break;case"c":if(n<4)throw new RangeError("`c..ccc` (weekday) patterns are not supported");t.weekday=["short","long","narrow","short"][n-4];break;case"a":t.hour12=!0;break;case"b":case"B":throw new RangeError("`b/B` (period) patterns are not supported, use `a` instead");case"h":t.hourCycle="h12",t.hour=["numeric","2-digit"][n-1];break;case"H":t.hourCycle="h23",t.hour=["numeric","2-digit"][n-1];break;case"K":t.hourCycle="h11",t.hour=["numeric","2-digit"][n-1];break;case"k":t.hourCycle="h24",t.hour=["numeric","2-digit"][n-1];break;case"j":case"J":case"C":throw new RangeError("`j/J/C` (hour) patterns are not supported, use `h/H/K/k` instead");case"m":t.minute=["numeric","2-digit"][n-1];break;case"s":t.second=["numeric","2-digit"][n-1];break;case"S":case"A":throw new RangeError("`S/A` (second) pattenrs are not supported, use `s` instead");case"z":t.timeZoneName=n<4?"short":"long";break;case"Z":case"O":case"v":case"V":case"X":case"x":throw new RangeError("`Z/O/v/V/X/x` (timeZone) pattenrs are not supported, use `z` instead")}return""})),t}var N=/^\.(?:(0+)(\*)?|(#+)|(0+)(#+))$/g,I=/^(@+)?(\+|#+)?$/g;function R(e){var t={};return e.replace(I,(function(e,n,r){return"string"!=typeof r?(t.minimumSignificantDigits=n.length,t.maximumSignificantDigits=n.length):"+"===r?t.minimumSignificantDigits=n.length:"#"===n[0]?t.maximumSignificantDigits=n.length:(t.minimumSignificantDigits=n.length,t.maximumSignificantDigits=n.length+("string"==typeof r?r.length:0)),""})),t}function D(e){switch(e){case"sign-auto":return{signDisplay:"auto"};case"sign-accounting":return{currencySign:"accounting"};case"sign-always":return{signDisplay:"always"};case"sign-accounting-always":return{signDisplay:"always",currencySign:"accounting"};case"sign-except-zero":return{signDisplay:"exceptZero"};case"sign-accounting-except-zero":return{signDisplay:"exceptZero",currencySign:"accounting"};case"sign-never":return{signDisplay:"never"}}}function z(e){var t=D(e);return t||{}}function F(e){for(var t={},n=0,r=e;n<r.length;n++){var i=r[n];switch(i.stem){case"percent":t.style="percent";continue;case"currency":t.style="currency",t.currency=i.options[0];continue;case"group-off":t.useGrouping=!1;continue;case"precision-integer":case".":t.maximumFractionDigits=0;continue;case"measure-unit":t.style="unit",t.unit=i.options[0].replace(/^(.*?)-/,"");continue;case"compact-short":t.notation="compact",t.compactDisplay="short";continue;case"compact-long":t.notation="compact",t.compactDisplay="long";continue;case"scientific":t=A(A(A({},t),{notation:"scientific"}),i.options.reduce((function(e,t){return A(A({},e),z(t))}),{}));continue;case"engineering":t=A(A(A({},t),{notation:"engineering"}),i.options.reduce((function(e,t){return A(A({},e),z(t))}),{}));continue;case"notation-simple":t.notation="standard";continue;case"unit-width-narrow":t.currencyDisplay="narrowSymbol",t.unitDisplay="narrow";continue;case"unit-width-short":t.currencyDisplay="code",t.unitDisplay="short";continue;case"unit-width-full-name":t.currencyDisplay="name",t.unitDisplay="long";continue;case"unit-width-iso-code":t.currencyDisplay="symbol";continue}if(N.test(i.stem)){if(i.options.length>1)throw new RangeError("Fraction-precision stems only accept a single optional option");i.stem.replace(N,(function(e,n,r,i,o,s){return"*"===r?t.minimumFractionDigits=n.length:i&&"#"===i[0]?t.maximumFractionDigits=i.length:o&&s?(t.minimumFractionDigits=o.length,t.maximumFractionDigits=o.length+s.length):(t.minimumFractionDigits=n.length,t.maximumFractionDigits=n.length),""})),i.options.length&&(t=A(A({},t),R(i.options[0])))}else if(I.test(i.stem))t=A(A({},t),R(i.stem));else{var o=D(i.stem);o&&(t=A(A({},t),o))}}return t}var L,M=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}();!function(e){e.MISSING_VALUE="MISSING_VALUE",e.INVALID_VALUE="INVALID_VALUE",e.MISSING_INTL_API="MISSING_INTL_API"}(L||(L={}));var H,j=function(e){function t(t,n,r){var i=e.call(this,t)||this;return i.code=n,i.originalMessage=r,i}return M(t,e),t.prototype.toString=function(){return"[formatjs Error: "+this.code+"] "+this.message},t}(Error),B=function(e){function t(t,n,r,i){return e.call(this,'Invalid values for "'+t+'": "'+n+'". Options are "'+Object.keys(r).join('", "')+'"',"INVALID_VALUE",i)||this}return M(t,e),t}(j),V=function(e){function t(t,n,r){return e.call(this,'Value for "'+t+'" must be of type '+n,"INVALID_VALUE",r)||this}return M(t,e),t}(j),$=function(e){function t(t,n){return e.call(this,'The intl string context variable "'+t+'" was not provided to the string "'+n+'"',"MISSING_VALUE",n)||this}return M(t,e),t}(j);function U(e){return"function"==typeof e}function q(e,t,n,r,i,y,g){if(1===e.length&&o(e[0]))return[{type:0,value:e[0].value}];for(var b=[],_=0,v=e;_<v.length;_++){var w=v[_];if(o(w))b.push({type:0,value:w.value});else if(p(w))"number"==typeof y&&b.push({type:0,value:n.getNumberFormat(t).format(y)});else{var x=w.value;if(!i||!(x in i))throw new $(x,g);var k=i[x];if(s(w))k&&"string"!=typeof k&&"number"!=typeof k||(k="string"==typeof k||"number"==typeof k?String(k):""),b.push({type:"string"==typeof k?0:1,value:k});else if(l(w)){var C="string"==typeof w.style?r.date[w.style]:m(w.style)?O(w.style.pattern):void 0;b.push({type:0,value:n.getDateTimeFormat(t,C).format(k)})}else if(c(w)){C="string"==typeof w.style?r.time[w.style]:m(w.style)?O(w.style.pattern):void 0;b.push({type:0,value:n.getDateTimeFormat(t,C).format(k)})}else if(a(w)){C="string"==typeof w.style?r.number[w.style]:f(w.style)?F(w.style.tokens):void 0;b.push({type:0,value:n.getNumberFormat(t,C).format(k)})}else{if(h(w)){var E=w.children,S=w.value,P=i[S];if(!U(P))throw new V(S,"function",g);var A=q(E,t,n,r,i),T=P.apply(void 0,A.map((function(e){return e.value})));Array.isArray(T)||(T=[T]),b.push.apply(b,T.map((function(e){return{type:"string"==typeof e?0:1,value:e}})))}if(d(w)){if(!(N=w.options[k]||w.options.other))throw new B(w.value,k,Object.keys(w.options),g);b.push.apply(b,q(N.value,t,n,r,i))}else if(u(w)){var N;if(!(N=w.options["="+k])){if(!Intl.PluralRules)throw new j('Intl.PluralRules is not available in this environment.\nTry polyfilling it using "@formatjs/intl-pluralrules"\n',"MISSING_INTL_API",g);var I=n.getPluralRules(t,{type:w.pluralType}).select(k-(w.offset||0));N=w.options[I]||w.options.other}if(!N)throw new B(w.value,k,Object.keys(w.options),g);b.push.apply(b,q(N.value,t,n,r,i,k-(w.offset||0)))}else;}}}return function(e){return e.length<2?e:e.reduce((function(e,t){var n=e[e.length-1];return n&&0===n.type&&0===t.type?n.value+=t.value:e.push(t),e}),[])}(b)}!function(e){e[e.literal=0]="literal",e[e.object=1]="object"}(H||(H={}));var Y=function(){return(Y=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function K(e,t){return t?Object.keys(e).reduce((function(n,r){var i,o;return n[r]=(i=e[r],(o=t[r])?Y(Y(Y({},i||{}),o||{}),Object.keys(i).reduce((function(e,t){return e[t]=Y(Y({},i[t]),o[t]||{}),e}),{})):i),n}),Y({},e)):e}const J=function(){function e(t,n,r,i){var o,s=this;if(void 0===n&&(n=e.defaultLocale),this.formatterCache={number:{},dateTime:{},pluralRules:{}},this.format=function(e){var t=s.formatToParts(e);if(1===t.length)return t[0].value;var n=t.reduce((function(e,t){return e.length&&0===t.type&&"string"==typeof e[e.length-1]?e[e.length-1]+=t.value:e.push(t.value),e}),[]);return n.length<=1?n[0]||"":n},this.formatToParts=function(e){return q(s.ast,s.locales,s.formatters,s.formats,e,void 0,s.message)},this.resolvedOptions=function(){return{locale:Intl.NumberFormat.supportedLocalesOf(s.locales)[0]}},this.getAst=function(){return s.ast},"string"==typeof t){if(this.message=t,!e.__parse)throw new TypeError("IntlMessageFormat.__parse must be set to process `message` of type `string`");this.ast=e.__parse(t,{normalizeHashtagInPlural:!1})}else this.ast=t;if(!Array.isArray(this.ast))throw new TypeError("A message must be provided as a String or AST.");this.formats=K(e.formats,r),this.locales=n,this.formatters=i&&i.formatters||(void 0===(o=this.formatterCache)&&(o={number:{},dateTime:{},pluralRules:{}}),{getNumberFormat:P(Intl.NumberFormat,o.number),getDateTimeFormat:P(Intl.DateTimeFormat,o.dateTime),getPluralRules:P(Intl.PluralRules,o.pluralRules)})}return Object.defineProperty(e,"defaultLocale",{get:function(){return e.memoizedDefaultLocale||(e.memoizedDefaultLocale=(new Intl.NumberFormat).resolvedOptions().locale),e.memoizedDefaultLocale},enumerable:!0,configurable:!0}),e.memoizedDefaultLocale=null,e.__parse=C,e.formats={number:{currency:{style:"currency"},percent:{style:"percent"}},date:{short:{month:"numeric",day:"numeric",year:"2-digit"},medium:{month:"short",day:"numeric",year:"numeric"},long:{month:"long",day:"numeric",year:"numeric"},full:{weekday:"long",month:"long",day:"numeric",year:"numeric"}},time:{short:{hour:"numeric",minute:"numeric"},medium:{hour:"numeric",minute:"numeric",second:"numeric"},long:{hour:"numeric",minute:"numeric",second:"numeric",timeZoneName:"short"},full:{hour:"numeric",minute:"numeric",second:"numeric",timeZoneName:"short"}}},e}();let W=!(0,n(27815).shouldPolyfill)();const G=W?void 0:n.e(113).then(n.t.bind(n,50113,7)).then((()=>{W=!0})),X=async(e,t,n,r)=>(W||await G,e._localizationCache={},(i,...o)=>{if(!(i&&n&&t&&n[t]))return"";const s=n[t][i];if(!s)return"";const a=i+s;let l=e._localizationCache[a];l||(l=new J(s,t,r),e._localizationCache[a]=l);const c={};for(let e=0;e<o.length;e+=2)c[o[e]]=o[e+1];try{return l.format(c)}catch(d){return"Translation "+d}}),Z=(e,t,n)=>{const r=[t];return n&&Object.keys(n).forEach((e=>{r.push(e),r.push(n[e])})),e(...r)}},87744:(e,t,n)=>{"use strict";function r(e){const t=e.language||"en";return e.translationMetadata.translations[t]&&e.translationMetadata.translations[t].isRTL||!1}function i(e){return o(r(e))}function o(e){return e?"rtl":"ltr"}n.d(t,{HE:()=>r,Zu:()=>i,$3:()=>o})},38346:(e,t,n)=>{"use strict";n.d(t,{D:()=>r});const r=(e,t,n=!1)=>{let r;return function(...i){const o=this,s=n&&!r;clearTimeout(r),r=setTimeout((()=>{r=null,n||e.apply(o,i)}),t),s&&e.apply(o,i)}}},22814:(e,t,n)=>{"use strict";n.d(t,{uw:()=>r,iI:()=>i});const r=`${location.protocol}//${location.host}`,i=(e,t)=>e.callWS({type:"auth/sign_path",path:t})},62359:(e,t,n)=>{"use strict";n.d(t,{j:()=>i});var r=n(47181);const i=e=>{(0,r.B)(window,"haptic",e)}},76307:(e,t,n)=>{"use strict";n.d(t,{pM:()=>i,k1:()=>o,Rj:()=>s,ec:()=>a});var r=n(53775);const i=()=>fetch("/api/onboarding",{credentials:"same-origin"}),o=e=>(0,r.h)(fetch("/api/onboarding/users",{method:"POST",credentials:"same-origin",body:JSON.stringify(e)})),s=e=>e.callApi("POST","onboarding/core_config"),a=(e,t)=>e.callApi("POST","onboarding/integration",t)},74265:(e,t,n)=>{"use strict";n.d(t,{vC:()=>i,gk:()=>o,lD:()=>s});const r={},i=async(e,t,n,i,o)=>{var s,a;if(!(n in r)){if(!o)return;r[n]=o().then((()=>{const r=document.createElement(n);return e.provideHass(r),t.appendChild(r),r}))}history.replaceState({dialog:n,open:!1,oldState:(null===(s=history.state)||void 0===s?void 0:s.open)&&(null===(a=history.state)||void 0===a?void 0:a.dialog)!==n?history.state:null},"");try{history.pushState({dialog:n,dialogParams:i,open:!0},"")}catch(l){history.pushState({dialog:n,dialogParams:null,open:!0},"")}(await r[n]).showDialog(i)},o=async e=>{if(!(e in r))return!0;const t=await r[e];return!t.closeDialog||!1!==t.closeDialog()},s=(e,t)=>{e.addEventListener("show-dialog",(n=>{const{dialogTag:r,dialogImport:o,dialogParams:s}=n.detail;i(e,t,r,s,o)}))}},38544:(e,t,n)=>{"use strict";var r=n(15652);function i(){i=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(n){t.forEach((function(t){t.kind===n&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var n=e.prototype;["method","field"].forEach((function(r){t.forEach((function(t){var i=t.placement;if(t.kind===r&&("static"===i||"prototype"===i)){var o="static"===i?e:n;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var n=t.descriptor;if("field"===t.kind){var r=t.initializer;n={enumerable:n.enumerable,writable:n.writable,configurable:n.configurable,value:void 0===r?void 0:r.call(e)}}Object.defineProperty(e,t.key,n)},decorateClass:function(e,t){var n=[],r=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!a(e))return n.push(e);var t=this.decorateElement(e,i);n.push(t.element),n.push.apply(n,t.extras),r.push.apply(r,t.finishers)}),this),!t)return{elements:n,finishers:r};var o=this.decorateConstructor(n,t);return r.push.apply(r,o.finishers),o.finishers=r,o},addElementPlacement:function(e,t,n){var r=t[e.placement];if(!n&&-1!==r.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");r.push(e.key)},decorateElement:function(e,t){for(var n=[],r=[],i=e.decorators,o=i.length-1;o>=0;o--){var s=t[e.placement];s.splice(s.indexOf(e.key),1);var a=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(a)||a);e=l.element,this.addElementPlacement(e,t),l.finisher&&r.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);n.push.apply(n,c)}}return{element:e,finishers:r,extras:n}},decorateConstructor:function(e,t){for(var n=[],r=t.length-1;r>=0;r--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[r])(i)||i);if(void 0!==o.finisher&&n.push(o.finisher),void 0!==o.elements){e=o.elements;for(var s=0;s<e.length-1;s++)for(var a=s+1;a<e.length;a++)if(e[s].key===e[a].key&&e[s].placement===e[a].placement)throw new TypeError("Duplicated element ("+e[s].key+")")}}return{elements:e,finishers:n}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return u(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?u(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var n=d(e.key),r=String(e.placement);if("static"!==r&&"prototype"!==r&&"own"!==r)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+r+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:n,placement:r,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:c(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var n=c(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:n}},runClassFinishers:function(e,t){for(var n=0;n<t.length;n++){var r=(0,t[n])(e);if(void 0!==r){if("function"!=typeof r)throw new TypeError("Finishers must return a constructor.");e=r}}return e},disallowProperty:function(e,t,n){if(void 0!==e[t])throw new TypeError(n+" can't have a ."+t+" property.")}};return e}function o(e){var t,n=d(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var r={kind:"field"===e.kind?"field":"method",key:n,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(r.decorators=e.decorators),"field"===e.kind&&(r.initializer=e.value),r}function s(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function a(e){return e.decorators&&e.decorators.length}function l(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function c(e,t){var n=e[t];if(void 0!==n&&"function"!=typeof n)throw new TypeError("Expected '"+t+"' to be a function");return n}function d(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var n=e[Symbol.toPrimitive];if(void 0!==n){var r=n.call(e,t||"default");if("object"!=typeof r)return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function u(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}!function(e,t,n,r){var c=i();if(r)for(var d=0;d<r.length;d++)c=r[d](c);var u=t((function(e){c.initializeInstanceElements(e,p.elements)}),n),p=c.decorateClass(function(e){for(var t=[],n=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},r=0;r<e.length;r++){var i,o=e[r];if("method"===o.kind&&(i=t.find(n)))if(l(o.descriptor)||l(i.descriptor)){if(a(o)||a(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(a(o)){if(a(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}s(o,i)}else t.push(o)}return t}(u.d.map(o)),e);c.initializeClassElements(u.F,p.elements),c.runClassFinishers(u.F,p.finishers)}([(0,r.Mo)("onboarding-loading")],(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"method",key:"render",value:function(){return r.dy` <div class="loader"></div> `}},{kind:"get",static:!0,key:"styles",value:function(){return r.iv`
      /* MIT License (MIT). Copyright (c) 2014 Luke Haas */
      .loader,
      .loader:after {
        border-radius: 50%;
        width: 40px;
        height: 40px;
      }
      .loader {
        margin: 60px auto;
        font-size: 4px;
        position: relative;
        text-indent: -9999em;
        border-top: 1.1em solid rgba(3, 169, 244, 0.2);
        border-right: 1.1em solid rgba(3, 169, 244, 0.2);
        border-bottom: 1.1em solid rgba(3, 169, 244, 0.2);
        border-left: 1.1em solid rgb(3, 168, 244);
        -webkit-transform: translateZ(0);
        -ms-transform: translateZ(0);
        transform: translateZ(0);
        -webkit-animation: load8 1.4s infinite linear;
        animation: load8 1.4s infinite linear;
      }
      @-webkit-keyframes load8 {
        0% {
          -webkit-transform: rotate(0deg);
          transform: rotate(0deg);
        }
        100% {
          -webkit-transform: rotate(360deg);
          transform: rotate(360deg);
        }
      }
      @keyframes load8 {
        0% {
          -webkit-transform: rotate(0deg);
          transform: rotate(0deg);
        }
        100% {
          -webkit-transform: rotate(360deg);
          transform: rotate(360deg);
        }
      }
    `}}]}}),r.oi)},64702:()=>{const e=document.createElement("template");e.setAttribute("style","display: none;"),e.innerHTML='<style>\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Thin"),\n  local("Roboto-Thin"),\n  url(/static/fonts/roboto/Roboto-Thin.woff2) format("woff2");\nfont-weight: 100;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Thin Italic"),\n  local("Roboto-ThinItalic"),\n  url(/static/fonts/roboto/Roboto-ThinItalic.woff2) format("woff2");\nfont-weight: 100;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Light"),\n  local("Roboto-Light"),\n  url(/static/fonts/roboto/Roboto-Light.woff2) format("woff2");\nfont-weight: 300;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Light Italic"),\n  local("Roboto-LightItalic"),\n  url(/static/fonts/roboto/Roboto-LightItalic.woff2) format("woff2");\nfont-weight: 300;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Regular"),\n  local("Roboto-Regular"),\n  url(/static/fonts/roboto/Roboto-Regular.woff2) format("woff2");\nfont-weight: 400;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Italic"),\n  local("Roboto-Italic"),\n  url(/static/fonts/roboto/Roboto-RegularItalic.woff2) format("woff2");\nfont-weight: 400;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Medium"),\n  local("Roboto-Medium"),\n  url(/static/fonts/roboto/Roboto-Medium.woff2) format("woff2");\nfont-weight: 500;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Medium Italic"),\n  local("Roboto-MediumItalic"),\n  url(/static/fonts/roboto/Roboto-MediumItalic.woff2) format("woff2");\nfont-weight: 500;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Bold"),\n  local("Roboto-Bold"),\n  url(/static/fonts/roboto/Roboto-Bold.woff2) format("woff2");\nfont-weight: 700;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Bold Italic"),\n  local("Roboto-BoldItalic"),\n  url(/static/fonts/roboto/Roboto-BoldItalic.woff2) format("woff2");\nfont-weight: 700;\nfont-style: italic;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Black"),\n  local("Roboto-Black"),\n  url(/static/fonts/roboto/Roboto-Black.woff2) format("woff2");\nfont-weight: 900;\nfont-style: normal;\n}\n@font-face {\nfont-family: "Roboto";\nsrc:\n  local("Roboto Black Italic"),\n  local("Roboto-BlackItalic"),\n  url(/static/fonts/roboto/Roboto-BlackItalic.woff2) format("woff2");\nfont-weight: 900;\nfont-style: italic;\n}\n</style>',document.head.appendChild(e.content)},37846:()=>{if(/^((?!chrome|android).)*version\/14\.0.*safari/i.test(navigator.userAgent)){const e=window.Element.prototype.attachShadow;window.Element.prototype.attachShadow=function(t){return t&&t.delegatesFocus&&delete t.delegatesFocus,e.apply(this,[t])}}},11654:(e,t,n)=>{"use strict";n.d(t,{_l:()=>i,q0:()=>o,Qx:()=>s,yu:()=>a,$c:()=>l});var r=n(15652);const i={"primary-background-color":"#111111","card-background-color":"#1c1c1c","secondary-background-color":"#202020","primary-text-color":"#e1e1e1","secondary-text-color":"#9b9b9b","disabled-text-color":"#6f6f6f","app-header-text-color":"#e1e1e1","app-header-background-color":"#101e24","switch-unchecked-button-color":"#999999","switch-unchecked-track-color":"#9b9b9b","divider-color":"rgba(225, 225, 225, .12)","mdc-ripple-color":"#AAAAAA","codemirror-keyword":"#C792EA","codemirror-operator":"#89DDFF","codemirror-variable":"#f07178","codemirror-variable-2":"#EEFFFF","codemirror-variable-3":"#DECB6B","codemirror-builtin":"#FFCB6B","codemirror-atom":"#F78C6C","codemirror-number":"#FF5370","codemirror-def":"#82AAFF","codemirror-string":"#C3E88D","codemirror-string-2":"#f07178","codemirror-comment":"#545454","codemirror-tag":"#FF5370","codemirror-meta":"#FFCB6B","codemirror-attribute":"#C792EA","codemirror-property":"#C792EA","codemirror-qualifier":"#DECB6B","codemirror-type":"#DECB6B"},o={"error-state-color":"var(--error-color)","state-icon-unavailable-color":"var(--disabled-text-color)","sidebar-text-color":"var(--primary-text-color)","sidebar-background-color":"var(--card-background-color)","sidebar-selected-text-color":"var(--primary-color)","sidebar-selected-icon-color":"var(--primary-color)","sidebar-icon-color":"rgba(var(--rgb-primary-text-color), 0.6)","switch-checked-color":"var(--primary-color)","switch-checked-button-color":"var(--switch-checked-color, var(--primary-background-color))","switch-checked-track-color":"var(--switch-checked-color, #000000)","switch-unchecked-button-color":"var(--switch-unchecked-color, var(--primary-background-color))","switch-unchecked-track-color":"var(--switch-unchecked-color, #000000)","slider-color":"var(--primary-color)","slider-secondary-color":"var(--light-primary-color)","slider-bar-color":"var(--disabled-text-color)","label-badge-grey":"var(--paper-grey-500)","label-badge-background-color":"var(--card-background-color)","label-badge-text-color":"rgba(var(--rgb-primary-text-color), 0.8)","paper-listbox-background-color":"var(--card-background-color)","paper-item-icon-color":"var(--state-icon-color)","paper-item-icon-active-color":"var(--state-icon-active-color)","table-row-background-color":"var(--primary-background-color)","table-row-alternative-background-color":"var(--secondary-background-color)","paper-slider-knob-color":"var(--slider-color)","paper-slider-knob-start-color":"var(--slider-color)","paper-slider-pin-color":"var(--slider-color)","paper-slider-pin-start-color":"var(--slider-color)","paper-slider-active-color":"var(--slider-color)","paper-slider-secondary-color":"var(--slider-secondary-color)","paper-slider-container-color":"var(--slider-bar-color)","data-table-background-color":"var(--card-background-color)","markdown-code-background-color":"var(--primary-background-color)","mdc-theme-primary":"var(--primary-color)","mdc-theme-secondary":"var(--accent-color)","mdc-theme-background":"var(--primary-background-color)","mdc-theme-surface":"var(--card-background-color)","mdc-theme-on-primary":"var(--text-primary-color)","mdc-theme-on-secondary":"var(--text-primary-color)","mdc-theme-on-surface":"var(--primary-text-color)","mdc-theme-text-primary-on-background":"var(--primary-text-color)","mdc-theme-text-secondary-on-background":"var(--secondary-text-color)","mdc-theme-text-icon-on-background":"var(--secondary-text-color)","app-header-text-color":"var(--text-primary-color)","app-header-background-color":"var(--primary-color)","material-body-text-color":"var(--primary-text-color)","material-background-color":"var(--card-background-color)","material-secondary-background-color":"var(--secondary-background-color)","material-secondary-text-color":"var(--secondary-text-color)","mdc-checkbox-unchecked-color":"rgba(var(--rgb-primary-text-color), 0.54)","mdc-checkbox-disabled-color":"var(--disabled-text-color)","mdc-radio-unchecked-color":"rgba(var(--rgb-primary-text-color), 0.54)","mdc-radio-disabled-color":"var(--disabled-text-color)","mdc-tab-text-label-color-default":"var(--primary-text-color)","mdc-button-disabled-ink-color":"var(--disabled-text-color)","mdc-button-outline-color":"var(--divider-color)","mdc-dialog-scroll-divider-color":"var(--divider-color)"},s=r.iv`
  :host {
    font-family: var(--paper-font-body1_-_font-family);
    -webkit-font-smoothing: var(--paper-font-body1_-_-webkit-font-smoothing);
    font-size: var(--paper-font-body1_-_font-size);
    font-weight: var(--paper-font-body1_-_font-weight);
    line-height: var(--paper-font-body1_-_line-height);
  }

  app-header-layout,
  ha-app-layout {
    background-color: var(--primary-background-color);
  }

  app-header,
  app-toolbar {
    background-color: var(--app-header-background-color);
    font-weight: 400;
    color: var(--app-header-text-color, white);
  }

  app-toolbar {
    height: var(--header-height);
  }

  app-header div[sticky] {
    height: 48px;
  }

  app-toolbar [main-title] {
    margin-left: 20px;
  }

  h1 {
    font-family: var(--paper-font-headline_-_font-family);
    -webkit-font-smoothing: var(--paper-font-headline_-_-webkit-font-smoothing);
    white-space: var(--paper-font-headline_-_white-space);
    overflow: var(--paper-font-headline_-_overflow);
    text-overflow: var(--paper-font-headline_-_text-overflow);
    font-size: var(--paper-font-headline_-_font-size);
    font-weight: var(--paper-font-headline_-_font-weight);
    line-height: var(--paper-font-headline_-_line-height);
  }

  h2 {
    font-family: var(--paper-font-title_-_font-family);
    -webkit-font-smoothing: var(--paper-font-title_-_-webkit-font-smoothing);
    white-space: var(--paper-font-title_-_white-space);
    overflow: var(--paper-font-title_-_overflow);
    text-overflow: var(--paper-font-title_-_text-overflow);
    font-size: var(--paper-font-title_-_font-size);
    font-weight: var(--paper-font-title_-_font-weight);
    line-height: var(--paper-font-title_-_line-height);
  }

  h3 {
    font-family: var(--paper-font-subhead_-_font-family);
    -webkit-font-smoothing: var(--paper-font-subhead_-_-webkit-font-smoothing);
    white-space: var(--paper-font-subhead_-_white-space);
    overflow: var(--paper-font-subhead_-_overflow);
    text-overflow: var(--paper-font-subhead_-_text-overflow);
    font-size: var(--paper-font-subhead_-_font-size);
    font-weight: var(--paper-font-subhead_-_font-weight);
    line-height: var(--paper-font-subhead_-_line-height);
  }

  a {
    color: var(--primary-color);
  }

  .secondary {
    color: var(--secondary-text-color);
  }

  .error {
    color: var(--error-color);
  }

  .warning {
    color: var(--error-color);
  }

  mwc-button.warning {
    --mdc-theme-primary: var(--error-color);
  }

  button.link {
    background: none;
    color: inherit;
    border: none;
    padding: 0;
    font: inherit;
    text-align: left;
    text-decoration: underline;
    cursor: pointer;
  }

  .card-actions a {
    text-decoration: none;
  }

  .card-actions .warning {
    --mdc-theme-primary: var(--error-color);
  }

  .layout.horizontal,
  .layout.vertical {
    display: flex;
  }
  .layout.inline {
    display: inline-flex;
  }
  .layout.horizontal {
    flex-direction: row;
  }
  .layout.vertical {
    flex-direction: column;
  }
  .layout.wrap {
    flex-wrap: wrap;
  }
  .layout.no-wrap {
    flex-wrap: nowrap;
  }
  .layout.center,
  .layout.center-center {
    align-items: center;
  }
  .layout.bottom {
    align-items: flex-end;
  }
  .layout.center-justified,
  .layout.center-center {
    justify-content: center;
  }
  .flex {
    flex: 1;
    flex-basis: 0.000000001px;
  }
  .flex-auto {
    flex: 1 1 auto;
  }
  .flex-none {
    flex: none;
  }
  .layout.justified {
    justify-content: space-between;
  }
`,a=r.iv`
  /* prevent clipping of positioned elements */
  paper-dialog-scrollable {
    --paper-dialog-scrollable: {
      -webkit-overflow-scrolling: auto;
    }
  }

  /* force smooth scrolling for iOS 10 */
  paper-dialog-scrollable.can-scroll {
    --paper-dialog-scrollable: {
      -webkit-overflow-scrolling: touch;
    }
  }

  .paper-dialog-buttons {
    align-items: flex-end;
    padding: 8px;
    padding-bottom: max(env(safe-area-inset-bottom), 8px);
  }

  @media all and (min-width: 450px) and (min-height: 500px) {
    ha-paper-dialog {
      min-width: 400px;
    }
  }

  @media all and (max-width: 450px), all and (max-height: 500px) {
    paper-dialog,
    ha-paper-dialog {
      margin: 0;
      width: calc(
        100% - env(safe-area-inset-right) - env(safe-area-inset-left)
      ) !important;
      min-width: calc(
        100% - env(safe-area-inset-right) - env(safe-area-inset-left)
      ) !important;
      max-width: calc(
        100% - env(safe-area-inset-right) - env(safe-area-inset-left)
      ) !important;
      max-height: calc(100% - var(--header-height));

      position: fixed !important;
      bottom: 0px;
      left: env(safe-area-inset-left);
      right: env(safe-area-inset-right);
      overflow: scroll;
      border-bottom-left-radius: 0px;
      border-bottom-right-radius: 0px;
    }
  }

  /* mwc-dialog (ha-dialog) styles */
  ha-dialog {
    --mdc-dialog-min-width: 400px;
    --mdc-dialog-max-width: 600px;
    --mdc-dialog-heading-ink-color: var(--primary-text-color);
    --mdc-dialog-content-ink-color: var(--primary-text-color);
    --justify-action-buttons: space-between;
  }

  ha-dialog .form {
    padding-bottom: 24px;
    color: var(--primary-text-color);
  }

  a {
    color: var(--primary-color);
  }

  /* make dialog fullscreen on small screens */
  @media all and (max-width: 450px), all and (max-height: 500px) {
    ha-dialog {
      --mdc-dialog-min-width: calc(
        100vw - env(safe-area-inset-right) - env(safe-area-inset-left)
      );
      --mdc-dialog-max-width: calc(
        100vw - env(safe-area-inset-right) - env(safe-area-inset-left)
      );
      --mdc-dialog-min-height: 100%;
      --mdc-dialog-max-height: 100%;
      --mdc-shape-medium: 0px;
      --vertial-align-dialog: flex-end;
    }
  }
  mwc-button.warning {
    --mdc-theme-primary: var(--error-color);
  }
  .error {
    color: var(--error-color);
  }
`,l=r.iv`
  .ha-scrollbar::-webkit-scrollbar {
    width: 0.4rem;
    height: 0.4rem;
  }

  .ha-scrollbar::-webkit-scrollbar-thumb {
    -webkit-border-radius: 4px;
    border-radius: 4px;
    background: var(--scrollbar-thumb-color);
  }

  .ha-scrollbar {
    overflow-y: auto;
    scrollbar-color: var(--scrollbar-thumb-color) transparent;
    scrollbar-width: thin;
  }
`},30320:(e,t,n)=>{"use strict";n.d(t,{r:()=>r});const r=async(e,t,n={})=>(e.expired&&await e.refreshAccessToken(),n.credentials="same-origin",n.headers||(n.headers={}),n.headers||(n.headers={}),n.headers.authorization="Bearer "+e.accessToken,fetch(t,n))},53775:(e,t,n)=>{"use strict";n.d(t,{h:()=>i,Z:()=>o});var r=n(30320);const i=async e=>{let t;try{t=await e}catch(i){throw{error:"Request error",status_code:void 0,body:void 0}}let n=null;const r=t.headers.get("content-type");if(r&&r.includes("application/json"))try{n=await t.json()}catch(i){throw{error:"Unable to parse JSON response",status_code:i.status,body:null}}else n=await t.text();if(!t.ok)throw{error:"Response error: "+t.status,status_code:t.status,body:n};return n};async function o(e,t,n,o){const s=`${e.data.hassUrl}/api/${n}`,a={method:t,headers:{}};return o&&(a.headers["Content-Type"]="application/json;charset=UTF-8",a.body=JSON.stringify(o)),i((0,r.r)(e,s,a))}}},r={};function i(e){if(r[e])return r[e].exports;var t=r[e]={id:e,loaded:!1,exports:{}};return n[e].call(t.exports,t,t.exports,i),t.loaded=!0,t.exports}i.m=n,i.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return i.d(t,{a:t}),t},i.t=function(e,t){if(1&t&&(e=this(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var n=Object.create(null);i.r(n);var r={};if(2&t&&"object"==typeof e&&e)for(const i in e)r[i]=()=>e[i];return r.default=()=>e,i.d(n,r),n},i.d=(e,t)=>{for(var n in t)i.o(t,n)&&!i.o(e,n)&&Object.defineProperty(e,n,{enumerable:!0,get:t[n]})},i.f={},i.e=e=>Promise.all(Object.keys(i.f).reduce(((t,n)=>(i.f[n](e,t),t)),[])),i.u=e=>"chunk."+{76:"2f92b4fc017e062e1e51",113:"07da1a1b6a89c74d66cc",256:"8ba360333d40a3f10510",258:"55b685461c605a3ff8f1",287:"cbef588efbe0197300fd",319:"36b0722b88395b178fa2",349:"9e1a785d2add7e1b52b4",362:"4eb034eaf957ba63876c",486:"18a71eb0bcb1bcd6e005",528:"dbcb924dc742756a2965",664:"6df6afb98603abed1443",681:"bf4457277bbdfd90ae6a",851:"3446ec11cdccb5fbfe2d",875:"5937d8ae8cd966b34207",879:"0a259816609a91ec31fc",1002:"f9c67349d47b1153a766",1041:"1ad6c34ebede1b556627",1063:"9824599669ed42c617ac",1102:"e946c54ff9c67c8ef669",1139:"39b043328199a9225242",1177:"91d49569b0c017bc18b5",1203:"f10f46e0016840123c17",1206:"bbbc455680e926297d21",1209:"13adcaf03c930b1544dc",1267:"ab841fd96ca07c173806",1294:"b276b1de502b62c1536c",1458:"e0088213ece5478ec5f2",1480:"024d8ad29f6dfba3bcd9",1482:"619401985e41c6ed7f65",1527:"2aea2970162be10244b3",1534:"60fe4b4359116320a567",1572:"69cf6d8118efd7068758",1593:"d291dd0a805d22074612",1596:"920d5ea7912d7bfa5db4",1644:"97ef1885dd57b663e74d",1668:"fdde129cc9c70a0cc0af",1785:"35a407ea4a0d45be6a11",1790:"f5ab5005b6f6a22ea003",1803:"43448baddf12a1db288a",1838:"4bde96d21398cd1db0bc",1850:"90390804a81d8132c0d1",1878:"b48b17fa08b4b6830435",1882:"a8258987c8a49a549844",1885:"e331bd8c94dec0f21a43",1895:"efd4200d4f7e021e80b6",1927:"55d63054d97c84e43bc2",1930:"ab1cc9edc5db70a62a88",2034:"7705836290e5e03df669",2036:"788b7ca59e1ca314f65f",2137:"65d6a5387a32c5250cb1",2174:"bbcc2a5bd6323d64f317",2231:"004ca47d7fae03aacbfc",2247:"1575354ed2db51bce001",2296:"d38c313b8b08b8da7c81",2335:"87a00894ba7e2e74a138",2371:"ddd88031c5e7e2591f56",2374:"63cc75821e77a36e06c9",2509:"a775a41068785899d9d8",2528:"58a71803cf6640d61e27",2587:"143ee728bc69ad7ab610",2725:"6c438fdff96507217f95",2858:"181502389d190a42642a",2926:"9aad43331b777abd6328",2954:"17883569f959c045c08a",2955:"284d4d4c3564d89a768b",2979:"b0c4aa7f4b5c1d1a0c7f",2994:"5deb2f435c633eeab050",3098:"744dbe433c86453550c5",3099:"974bd772d4dab067bfcf",3122:"b1924913e442db4df100",3202:"32fb8cb68d45a82757f7",3284:"afd41d6d925be75ffd83",3329:"7dbf8bc633ff6efcb5ea",3376:"d8b71bf35f1d3cdb25a9",3459:"6102c028ea47ad665c6f",3499:"3c632461fc71da483c97",3688:"d6605bfd042d4896e3b5",3822:"f289da82f90e03f9a691",3943:"a4f5dc7b5296194f557a",4077:"bcf13c82c31349454157",4144:"899dad533b631f583aca",4266:"130f7e73c95a21268c84",4325:"d169b53c93c84e2c72bf",4411:"4ce1cf441ad8c54912d6",4503:"469394fa0f7d125d9c50",4507:"ba22f8d574dc47b52d20",4535:"07c189e569a45485e4ec",4564:"53c6d7eb3cbc54a73305",4570:"a841aeae0598eb3e361c",4642:"6c7ddcb7775cd3381932",4659:"6358d270a94780318f51",4689:"d464ab573d719abc12cc",4832:"daf7dbdd9dd01231184b",4909:"d1d3882b90c9e2537db9",4920:"ae4ef2a25fc043f5cb66",4930:"2ea6f1c3bfdf85b0fdf7",4940:"586ca6c4b96a016e9c57",4971:"134b77516ea3a448309e",5009:"62df7d9c20e9f4a2c62e",5018:"46d43383719e4dd5b5c6",5083:"c67ef35985135590afd6",5145:"cd31e8352e45bd17babb",5212:"bf51628a042baf6c451c",5317:"9d93e0ac57aeea6446a5",5338:"f0e500645a5953b9235f",5397:"4997acf956928f46168c",5475:"69bb12fac2d178069b8d",5513:"d4ace9e6734e05f168f4",5570:"dc90aab54789c2ceca27",5632:"77d6f46afaf4781d03c6",5636:"f5f56897e3782044e66e",5642:"be913f2c8f6f5b05d1d6",5675:"f1d93980732f27d16feb",5741:"732e39eb2d8bc507b315",5773:"3155f1fc7f87fda0608b",5823:"7da52dd676695fac576a",5840:"4e1df79efed384139b8c",5861:"69fea1085f800b48efa3",6016:"7a68cc1a6ab590b51d74",6087:"0c2a9d2cd3cdd7b6ae81",6130:"981bc0543afb2be96881",6169:"17018aa8d46871a263a0",6187:"75910367afa078032832",6369:"c1fb16996a6f9499c1fd",6443:"73f218cb3036c6c595ad",6467:"981e96ca950979601cb6",6474:"35b6ad69c0d1c7fb33ec",6498:"16079015e6622dece9e9",6509:"e733e495ed2792d82f51",6523:"8820748b897ca2ca0e0e",6532:"1cb0fe69d2e8de98b0b6",6567:"d7ce65414e9c07df6f20",6576:"307788ca8a11762197df",6614:"93f09f6831bb3c227445",6619:"55e54f842a127ff54d37",6684:"df1fbef21f11ea88c5aa",6755:"d1c59b13b6a5755bf167",6758:"672e389eb769b95f1f2b",6830:"4e7360654b6c45f36e53",6850:"68a1b5b201365c3bcc56",6863:"71f753bf4eb8ce47a237",6902:"a19d461d34789a150d91",6938:"c626bb785264cafac782",6952:"04a8b03ff63fbb4ec1c1",6955:"344339fec68aa9871c3a",7065:"b87f71bb1c01c1addea5",7078:"55aabc833f69d53e9be7",7130:"c0165bdb8eb951f2a5aa",7212:"cc99861a182e57b314ed",7230:"bc13c678475f8ccc4458",7282:"d8abadd2ab8153aa57bf",7284:"7491ba1072cc35ee2565",7306:"1c485777f79429c5f934",7321:"9f75098a3e7c309fdd4b",7393:"8689799bbbc609ce279d",7415:"f1be2b1b6180afb0d588",7440:"36605eb43d321c20396c",7482:"91d3eefdd25a9b3189b0",7523:"5980bfc2f8a72c10b713",7636:"50cf63c4d2e80758243b",7693:"ff89642f1c8b7b8f58a6",7717:"f9de575a489fc2928dbe",7749:"c8d567c84bd0f3305549",7770:"a769873393b2614ee3e8",7791:"ba844074d40f4ccabbea",7820:"2c06f2e3dae9d28ab535",7845:"0cf4d927107111759540",7873:"f275805ccfc85514dee2",7951:"6948f07643791629be4e",7987:"5c3eede5768074b62c3d",7992:"a3931ab80d586e0d1d43",8045:"53b7826946c8a2f39c87",8101:"65fd61a4191a28ef4608",8161:"4c86c87674ae79593778",8230:"495866c8c0ecd6a9f6ae",8251:"4e8f0ea08e9499058bd8",8317:"70162c9124b2689ae690",8331:"9ebb44fc7d511e0975df",8360:"2095065f8001f3cc9399",8374:"750581c590a7745e6815",8394:"2d08fdb3b1fdcf0da783",8491:"1d978b1e2a21d1ee6663",8558:"a2efae591786921bba5c",8559:"108425b9234c1d436b24",8585:"65189f45c70d870fa12e",8626:"028e22bcc23bb1883079",8705:"43b95ea8632f2b29d50b",8723:"c638e5051bc3888ea880",8800:"6ac9889759032cccae8f",8857:"02d3c569f9d218ba8e62",8914:"30a754ab574506cdd659",8941:"16873654eb78dff52531",9001:"0e67c855e6a029a1cb1c",9033:"5890ac6a54cd2f090927",9123:"30480d53712b2e3469a3",9130:"f7fd815399629f0ab051",9160:"eaa22e25f2245fe9176c",9235:"2c9a655d19cc27fc04b0",9277:"b57a6a76653043597d97",9290:"9f0f063aeb9762599f83",9448:"22206cd8ee7813ccb315",9491:"cf5920ee23bb8711aec4",9626:"61b3a766547fe85a7afb",9680:"ce8d64fd1ea7a5a70114",9810:"d705a9174a599821d58f",9813:"1a9b4dfa57f0574bc6b7",9824:"36467d145b5224c8d3b0",9902:"c824bdf38b84802ad8c1",9986:"7d33037757f046c10da7"}[e]+".js",i.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),e={},t="home-assistant-frontend:",i.l=(n,r,o)=>{if(e[n])e[n].push(r);else{var s,a;if(void 0!==o)for(var l=document.getElementsByTagName("script"),c=0;c<l.length;c++){var d=l[c];if(d.getAttribute("src")==n||d.getAttribute("data-webpack")==t+o){s=d;break}}s||(a=!0,(s=document.createElement("script")).charset="utf-8",s.timeout=120,i.nc&&s.setAttribute("nonce",i.nc),s.setAttribute("data-webpack",t+o),s.src=n),e[n]=[r];var u=(t,r)=>{s.onerror=s.onload=null,clearTimeout(p);var i=e[n];if(delete e[n],s.parentNode&&s.parentNode.removeChild(s),i&&i.forEach((e=>e(r))),t)return t(r)},p=setTimeout(u.bind(null,void 0,{type:"timeout",target:s}),12e4);s.onerror=u.bind(null,s.onerror),s.onload=u.bind(null,s.onload),a&&document.head.appendChild(s)}},i.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},i.nmd=e=>(e.paths=[],e.children||(e.children=[]),e),i.p="/frontend_latest/",(()=>{i.b=document.baseURI||self.location.href;var e={2343:0,8941:0,879:0,1900:0};i.f.j=(t,n)=>{var r=i.o(e,t)?e[t]:void 0;if(0!==r)if(r)n.push(r[2]);else{var o=new Promise(((n,i)=>{r=e[t]=[n,i]}));n.push(r[2]=o);var s=i.p+i.u(t),a=new Error;i.l(s,(n=>{if(i.o(e,t)&&(0!==(r=e[t])&&(e[t]=void 0),r)){var o=n&&("load"===n.type?"missing":n.type),s=n&&n.target&&n.target.src;a.message="Loading chunk "+t+" failed.\n("+o+": "+s+")",a.name="ChunkLoadError",a.type=o,a.request=s,r[1](a)}}),"chunk-"+t)}};var t=self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[],n=t.push.bind(t);t.push=t=>{for(var r,o,[s,a,l]=t,c=0,d=[];c<s.length;c++)o=s[c],i.o(e,o)&&e[o]&&d.push(e[o][0]),e[o]=0;for(r in a)i.o(a,r)&&(i.m[r]=a[r]);for(l&&l(i),n(t);d.length;)d.shift()()}})(),(()=>{"use strict";i(37846);var e=i(36007);const t=!1;function n(n){if(!n.auth)throw 4;const r=n.auth;let i=r.expired?r.refreshAccessToken().then((()=>{i=void 0}),(()=>{i=void 0})):void 0;const o=r.wsUrl;function s(n,a,l){const c=new WebSocket(o);let d=!1;const u=()=>{if(c.removeEventListener("close",u),d)return void l(2);if(0===n)return void l(1);const e=-1===n?-1:n-1;setTimeout((()=>s(e,a,l)),1e3)},p=async t=>{try{r.expired&&await(i||r.refreshAccessToken()),c.send(JSON.stringify(e.I8(r.accessToken)))}catch(n){d=2===n,c.close()}},h=async e=>{const n=JSON.parse(e.data);switch(n.type){case"auth_invalid":d=!0,c.close();break;case"auth_ok":c.removeEventListener("open",p),c.removeEventListener("message",h),c.removeEventListener("close",u),c.removeEventListener("error",u),c.haVersion=n.ha_version,a(c);break;default:t}};c.addEventListener("open",p),c.addEventListener("message",h),c.addEventListener("close",u),c.addEventListener("error",u)}return new Promise(((e,t)=>s(n.setupRetry,e,t)))}const r=!1;class o{constructor(e,t){this.options=t,this.commandId=1,this.commands=new Map,this.eventListeners=new Map,this.closeRequested=!1,this.setSocket(e)}get haVersion(){return this.socket.haVersion}get connected(){return this.socket.readyState==this.socket.OPEN}setSocket(e){const t=this.socket;if(this.socket=e,e.addEventListener("message",(e=>this._handleMessage(e))),e.addEventListener("close",(e=>this._handleClose(e))),t){const e=this.commands;this.commandId=1,this.commands=new Map,e.forEach((e=>{"subscribe"in e&&e.subscribe().then((t=>{e.unsubscribe=t,e.resolve()}))}));const t=this._queuedMessages;if(t){this._queuedMessages=void 0;for(const e of t)e.resolve()}this.fireEvent("ready")}}addEventListener(e,t){let n=this.eventListeners.get(e);n||(n=[],this.eventListeners.set(e,n)),n.push(t)}removeEventListener(e,t){const n=this.eventListeners.get(e);if(!n)return;const r=n.indexOf(t);-1!==r&&n.splice(r,1)}fireEvent(e,t){(this.eventListeners.get(e)||[]).forEach((e=>e(this,t)))}suspendReconnectUntil(e){this.suspendReconnectPromise=e}suspend(){if(!this.suspendReconnectPromise)throw new Error("Suspend promise not set");this.socket.close()}close(){this.closeRequested=!0,this.socket.close()}async subscribeEvents(t,n){return this.subscribeMessage(t,e.a(n))}ping(){return this.sendMessagePromise(e.qE())}sendMessage(e,t){if(this._queuedMessages){if(t)throw new Error("Cannot queue with commandId");this._queuedMessages.push({resolve:()=>this.sendMessage(e)})}else t||(t=this._genCmdId()),e.id=t,this.socket.send(JSON.stringify(e))}sendMessagePromise(e){return new Promise(((t,n)=>{if(this._queuedMessages)return void this._queuedMessages.push({reject:n,resolve:async()=>{try{t(await this.sendMessagePromise(e))}catch(r){n(r)}}});const r=this._genCmdId();this.commands.set(r,{resolve:t,reject:n}),this.sendMessage(e,r)}))}async subscribeMessage(t,n){let r;return this._queuedMessages&&await new Promise(((e,t)=>{this._queuedMessages.push({resolve:e,reject:t})})),await new Promise(((i,o)=>{const s=this._genCmdId();r={resolve:i,reject:o,callback:t,subscribe:()=>this.subscribeMessage(t,n),unsubscribe:async()=>{this.connected&&await this.sendMessagePromise(e.Mt(s)),this.commands.delete(s)}},this.commands.set(s,r);try{this.sendMessage(n,s)}catch(a){}})),()=>r.unsubscribe()}_handleMessage(t){const n=JSON.parse(t.data);const i=this.commands.get(n.id);switch(n.type){case"event":i?i.callback(n.event):(console.warn(`Received event for unknown subscription ${n.id}. Unsubscribing.`),this.sendMessagePromise(e.Mt(n.id)));break;case"result":i&&(n.success?(i.resolve(n.result),"subscribe"in i||this.commands.delete(n.id)):(i.reject(n.error),this.commands.delete(n.id)));break;case"pong":i?(i.resolve(),this.commands.delete(n.id)):console.warn("Received unknown pong response "+n.id);break;default:r}}async _handleClose(t){if(this.commands.forEach((t=>{"subscribe"in t||t.reject(e.vU(3,"Connection lost"))})),this.closeRequested)return;this.fireEvent("disconnected");const n=Object.assign(Object.assign({},this.options),{setupRetry:0}),r=e=>{setTimeout((async()=>{try{const e=await n.createSocket(n);this.setSocket(e)}catch(t){if(this._queuedMessages){const e=this._queuedMessages;this._queuedMessages=void 0;for(const t of e)t.reject&&t.reject(3)}2===t?this.fireEvent("reconnect-error",t):r(e+1)}}),1e3*Math.min(e,5))};this.suspendReconnectPromise&&(await this.suspendReconnectPromise,this.suspendReconnectPromise=void 0,this._queuedMessages=[]),r(0)}_genCmdId(){return++this.commandId}}const s=()=>`${location.protocol}//${location.host}/`;function a(e,t,n,r){n+=(n.includes("?")?"&":"?")+"auth_callback=1",document.location.href=function(e,t,n,r){let i=`${e}/auth/authorize?response_type=code&redirect_uri=${encodeURIComponent(n)}`;return null!==t&&(i+="&client_id="+encodeURIComponent(t)),r&&(i+="&state="+encodeURIComponent(r)),i}(e,t,n,r)}async function l(e,t,n){const r="undefined"!=typeof location&&location;if(r&&"https:"===r.protocol){const t=document.createElement("a");if(t.href=e,"http:"===t.protocol&&"localhost"!==t.hostname)throw 5}const i=new FormData;null!==t&&i.append("client_id",t),Object.keys(n).forEach((e=>{i.append(e,n[e])}));const o=await fetch(e+"/auth/token",{method:"POST",credentials:"same-origin",body:i});if(!o.ok)throw 400===o.status||403===o.status?2:new Error("Unable to fetch tokens");const s=await o.json();return s.hassUrl=e,s.clientId=t,s.expires=1e3*s.expires_in+Date.now(),s}function c(e,t,n){return l(e,t,{code:n,grant_type:"authorization_code"})}class d{constructor(e,t){this.data=e,this._saveTokens=t}get wsUrl(){return`ws${this.data.hassUrl.substr(4)}/api/websocket`}get accessToken(){return this.data.access_token}get expired(){return Date.now()>this.data.expires}async refreshAccessToken(){if(!this.data.refresh_token)throw new Error("No refresh_token");const e=await l(this.data.hassUrl,this.data.clientId,{grant_type:"refresh_token",refresh_token:this.data.refresh_token});e.refresh_token=this.data.refresh_token,this.data=e,this._saveTokens&&this._saveTokens(e)}async revoke(){if(!this.data.refresh_token)throw new Error("No refresh_token to revoke");const e=new FormData;e.append("action","revoke"),e.append("token",this.data.refresh_token),await fetch(this.data.hassUrl+"/auth/token",{method:"POST",credentials:"same-origin",body:e}),this._saveTokens&&this._saveTokens(null)}}async function u(e={}){let t,n=e.hassUrl;n&&"/"===n[n.length-1]&&(n=n.substr(0,n.length-1));const r=void 0!==e.clientId?e.clientId:s();if(!t&&e.authCode&&n&&(t=await c(n,r,e.authCode),e.saveTokens&&e.saveTokens(t)),!t){const n=function(e){const t={},n=e.split("&");for(let r=0;r<n.length;r++){const e=n[r].split("="),i=decodeURIComponent(e[0]),o=e.length>1?decodeURIComponent(e[1]):void 0;t[i]=o}return t}(location.search.substr(1));if("auth_callback"in n){const r=(i=n.state,JSON.parse(atob(i)));t=await c(r.hassUrl,r.clientId,n.code),e.saveTokens&&e.saveTokens(t)}}var i,o;if(!t&&e.loadTokens&&(t=await e.loadTokens()),t)return new d(t,e.saveTokens);if(void 0===n)throw 4;return a(n,r,e.redirectUrl||function(){const{protocol:e,host:t,pathname:n,search:r}=location;return`${e}//${t}${n}${r}`}(),(o={hassUrl:n,clientId:r},btoa(JSON.stringify(o)))),new Promise((()=>{}))}var p=i(4915),h=i(15652);const f=async(e,t)=>new Promise((n=>{const r=t(e,(e=>{r(),n(e)}))}));var m=i(22814);var y=i(76307),g=i(95282),b=i(23553);const _=e=>(0,g._)(e,"_usr",(()=>(0,b.PR)(e)),void 0),v=(e,t)=>_(e).subscribe(t);var w=i(35359);const x=async(e,t)=>(await e.sendMessagePromise({type:"frontend/get_user_data",key:t})).value,k=async(e,t,n)=>e.sendMessagePromise({type:"frontend/set_user_data",key:t,value:n}),C=(e,t)=>((e,t,n,r,i)=>{const o=n+"-optimistic";return{...(0,g._)(t,n,r,(async(e,n)=>{const r=i?i(t,n):void 0;return t[o]=n,()=>{r&&r.then((e=>e())),t[o]=void 0}})),async save(n){const r=t[o];let i;r&&(i=r.state,r.setState(n,!0));try{return await e(t,n)}catch(s){throw r&&r.setState(i,!0),s}}}})(((n,r)=>k(e,t,r)),e,"_frontendUserData-"+t,(()=>x(e,t))),E=JSON.parse('{"fragments":["config","history","logbook","mailbox","profile","shopping-list","page-authorize","page-demo","page-onboarding","developer-tools"],"translations":{"af":{"nativeName":"Afrikaans","hash":"2cb285a51c91187fee376a394373126a"},"ar":{"nativeName":"العربية","isRTL":true,"hash":"0b07d133f4f86354f1c1a93a9fa9fe66"},"bg":{"nativeName":"Български","hash":"a2a7033336164342e46e4dd7957698da"},"bs":{"nativeName":"Bosanski","hash":"893093f845665a479b155b93cdff8a2c"},"ca":{"nativeName":"Català","hash":"9695e910f926b8dfd971a4fdc454c0a7"},"cs":{"nativeName":"Čeština","hash":"70dea9b28658eb6c2b8321dc8493cf09"},"cy":{"nativeName":"Cymraeg","hash":"ac33542af3aad9f3815895c001e03a17"},"da":{"nativeName":"Dansk","hash":"7841e8289103d13b78692d6208c891cd"},"de":{"nativeName":"Deutsch","hash":"5423509eb9d8c6e6da073affc941ead6"},"el":{"nativeName":"Ελληνικά","hash":"86cf1efd6c1b332d00b5b90c9b5f3c93"},"en":{"nativeName":"English","hash":"b1e8cb73139376f8196901fb576acf56"},"en-GB":{"nativeName":"English (GB)","hash":"b1e8cb73139376f8196901fb576acf56"},"eo":{"nativeName":"Esperanto","hash":"8b58f0d629ca3c207c1017038c2a555d"},"es":{"nativeName":"Español","hash":"3bd3d074b7ff869ce4d33982328f30a2"},"es-419":{"nativeName":"Español (Latin America)","hash":"1dcff3221e29183d2726ad8553f5e005"},"et":{"nativeName":"Eesti","hash":"6c69bea971bde9b9d50c4a59ee59b913"},"eu":{"nativeName":"Euskara","hash":"c8c578b2709f737ce691c6455b4f5608"},"fa":{"nativeName":"فارسی","isRTL":true,"hash":"6bdb7b62ee4fad025736768458b83220"},"fi":{"nativeName":"Suomi","hash":"301dd7f8bc07f0a353a31ff876f6fd3e"},"fy":{"nativeName":"Frysk","hash":"dca4b6c954ad56a20d0fe85e1a5dc20a"},"fr":{"nativeName":"Français","hash":"acfcf4484d332306d81888dcec2afed6"},"gl":{"nativeName":"Galego","hash":"b1e8cb73139376f8196901fb576acf56"},"gsw":{"nativeName":"Schwiizerdütsch","hash":"bdc6b3e06523e716aadebf5686faadde"},"he":{"nativeName":"עברית","isRTL":true,"hash":"d8ada3467898c7e4c0ce2e35efc97206"},"hi":{"nativeName":"हिन्दी","hash":"e1cf46a77572c1636ebe8308a0799393"},"hr":{"nativeName":"Hrvatski","hash":"116117327bf3b4212359aedd87be54d2"},"hu":{"nativeName":"Magyar","hash":"91644efc70511b1348d60d59ae6350b3"},"hy":{"nativeName":"Հայերեն","hash":"8c32069d7b040dc9899baaf0680c5d77"},"id":{"nativeName":"Indonesia","hash":"4e6bf6128416f563990a443f0bb33248"},"it":{"nativeName":"Italiano","hash":"6b0f5752db5cb109cbaa5dea3c5bcfde"},"is":{"nativeName":"Íslenska","hash":"50637c875b016fe26cebc3c2bcc2997b"},"ja":{"nativeName":"日本語","hash":"9e84e56680ef678667290ca6634e239c"},"ko":{"nativeName":"한국어","hash":"535abfd262648fc12599088902593ffa"},"lb":{"nativeName":"Lëtzebuergesch","hash":"b4d9a8ff8ef7d3e977ff4fe96da84e71"},"lt":{"nativeName":"Lietuvių","hash":"63b6f255768ccf64aef9685b5378405f"},"lv":{"nativeName":"Latviešu","hash":"4b5788ffc9a2eb038ca2208c1941487a"},"nl":{"nativeName":"Nederlands","hash":"b87d75e124d9e35b35dafe27048a7dfe"},"nb":{"nativeName":"Norsk Bokmål","hash":"9277c3c4bc96f208677cbbd7a1b04ed6"},"nn":{"nativeName":"Norsk Nynorsk","hash":"b0e726f44f5eb77047b36b6d20f32019"},"pl":{"nativeName":"Polski","hash":"35415353acf565a4a463c4343da59cff"},"pt":{"nativeName":"Português","hash":"473c7e279e71ecd9352a3d14fdc69f0a"},"pt-BR":{"nativeName":"Português (BR)","hash":"904c4549bcd48a5d2ebf8befc23c489d"},"ro":{"nativeName":"Română","hash":"0dbca599e8301cc2d8ae6a2971d8fcf8"},"ru":{"nativeName":"Русский","hash":"ec71bb75076ab28eb7c9a2be4dee482c"},"sk":{"nativeName":"Slovenčina","hash":"708513ce5cfc4a519cb8499811454c9e"},"sl":{"nativeName":"Slovenščina","hash":"9c33cc1f2025b589defa276999391f8a"},"sr":{"nativeName":"Српски","hash":"122bc4f46e49cf418100a4ee3d0b763f"},"sr-Latn":{"nativeName":"Srpski","hash":"2c8ad9564215cf9ec28f431b32b320f7"},"sv":{"nativeName":"Svenska","hash":"8331d89773adff83459bcc1c8fcf9cd4"},"ta":{"nativeName":"தமிழ்","hash":"58cb4f4c5e78acce2022d2c0b7ff265f"},"te":{"nativeName":"తెలుగు","hash":"c07375ef62bc316fa00e4a6ee65196c3"},"th":{"nativeName":"ภาษาไทย","hash":"4309919e45b5ebbd984e2f8b0faac9ad"},"tr":{"nativeName":"Türkçe","hash":"d0928b73929b86f9bb1604ac10a261b5"},"uk":{"nativeName":"Українська","hash":"411b6e180566ed7e5877acfda17bbb95"},"ur":{"nativeName":"اُردُو","hash":"e19fb9e5173fd234a0079287934902f3"},"vi":{"nativeName":"Tiếng Việt","hash":"e9325b59e18cfb257ef4ce35808f0ff7"},"zh-Hans":{"nativeName":"简体中文","hash":"2abc75f52143b070d61bdaaf691db74c"},"zh-Hant":{"nativeName":"繁體中文","hash":"bf46614331a8e56b1650c457894fc84e"},"test":{"nativeName":"Test","hash":"45f6f22d37dfd5473eea91fa62fa5b46"}}}'),S=window.localStorage||{},P={"zh-cn":"zh-Hans","zh-sg":"zh-Hans","zh-my":"zh-Hans","zh-tw":"zh-Hant","zh-hk":"zh-Hant","zh-mo":"zh-Hant",zh:"zh-Hant"};function A(e){if(e in E.translations)return e;const t=e.toLowerCase();return t in P?P[t]:Object.keys(E.translations).find((e=>e.toLowerCase()===t))}async function T(e){const t=await(e=>x(e.connection,"language"))(e),n=t?t.language:null;if(n){const e=A(n);if(e)return e}return null}function O(){let e=null;if(S.selectedLanguage)try{const t=JSON.parse(S.selectedLanguage);if(t&&(e=A(t),e))return e}catch(t){}if(navigator.languages)for(const n of navigator.languages)if(e=A(n),e)return e;return e=A(navigator.language),e||(navigator.language&&navigator.language.includes("-")&&(e=A(navigator.language.split("-")[0]),e)?e:"en")}const N={};async function I(e,t){const n=E.translations[t];if(!n){if("en"!==t)return I(e,"en");throw new Error("Language en is not found in metadata")}const r=`${e?e+"/":""}${t}-${n.hash}.json`;return N[r]||(N[r]=async function(e){const t=await fetch("/static/translations/"+e,{credentials:"same-origin"});if(!t.ok)throw new Error(`Fail to fetch translation ${e}: HTTP response status is ${t.status}`);return t.json()}(r).then((e=>({language:t,data:e}))).catch((n=>(delete N[r],"en"!==t?I(e,"en"):Promise.reject(n))))),N[r]}function R(e,t,n,r){var i=D();if(r)for(var o=0;o<r.length;o++)i=r[o](i);var s=t((function(e){i.initializeInstanceElements(e,a.elements)}),n),a=i.decorateClass(function(e){for(var t=[],n=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},r=0;r<e.length;r++){var i,o=e[r];if("method"===o.kind&&(i=t.find(n)))if(M(o.descriptor)||M(i.descriptor)){if(L(o)||L(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(L(o)){if(L(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}F(o,i)}else t.push(o)}return t}(s.d.map(z)),e);return i.initializeClassElements(s.F,a.elements),i.runClassFinishers(s.F,a.finishers)}function D(){D=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(n){t.forEach((function(t){t.kind===n&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var n=e.prototype;["method","field"].forEach((function(r){t.forEach((function(t){var i=t.placement;if(t.kind===r&&("static"===i||"prototype"===i)){var o="static"===i?e:n;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var n=t.descriptor;if("field"===t.kind){var r=t.initializer;n={enumerable:n.enumerable,writable:n.writable,configurable:n.configurable,value:void 0===r?void 0:r.call(e)}}Object.defineProperty(e,t.key,n)},decorateClass:function(e,t){var n=[],r=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!L(e))return n.push(e);var t=this.decorateElement(e,i);n.push(t.element),n.push.apply(n,t.extras),r.push.apply(r,t.finishers)}),this),!t)return{elements:n,finishers:r};var o=this.decorateConstructor(n,t);return r.push.apply(r,o.finishers),o.finishers=r,o},addElementPlacement:function(e,t,n){var r=t[e.placement];if(!n&&-1!==r.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");r.push(e.key)},decorateElement:function(e,t){for(var n=[],r=[],i=e.decorators,o=i.length-1;o>=0;o--){var s=t[e.placement];s.splice(s.indexOf(e.key),1);var a=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(a)||a);e=l.element,this.addElementPlacement(e,t),l.finisher&&r.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);n.push.apply(n,c)}}return{element:e,finishers:r,extras:n}},decorateConstructor:function(e,t){for(var n=[],r=t.length-1;r>=0;r--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[r])(i)||i);if(void 0!==o.finisher&&n.push(o.finisher),void 0!==o.elements){e=o.elements;for(var s=0;s<e.length-1;s++)for(var a=s+1;a<e.length;a++)if(e[s].key===e[a].key&&e[s].placement===e[a].placement)throw new TypeError("Duplicated element ("+e[s].key+")")}}return{elements:e,finishers:n}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return B(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?B(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var n=j(e.key),r=String(e.placement);if("static"!==r&&"prototype"!==r&&"own"!==r)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+r+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:n,placement:r,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:H(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var n=H(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:n}},runClassFinishers:function(e,t){for(var n=0;n<t.length;n++){var r=(0,t[n])(e);if(void 0!==r){if("function"!=typeof r)throw new TypeError("Finishers must return a constructor.");e=r}}return e},disallowProperty:function(e,t,n){if(void 0!==e[t])throw new TypeError(n+" can't have a ."+t+" property.")}};return e}function z(e){var t,n=j(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var r={kind:"field"===e.kind?"field":"method",key:n,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(r.decorators=e.decorators),"field"===e.kind&&(r.initializer=e.value),r}function F(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function L(e){return e.decorators&&e.decorators.length}function M(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function H(e,t){var n=e[t];if(void 0!==n&&"function"!=typeof n)throw new TypeError("Expected '"+t+"' to be a function");return n}function j(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var n=e[Symbol.toPrimitive];if(void 0!==n){var r=n.call(e,t||"default");if("object"!=typeof r)return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function B(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function V(e,t,n){return(V="undefined"!=typeof Reflect&&Reflect.get?Reflect.get:function(e,t,n){var r=function(e,t){for(;!Object.prototype.hasOwnProperty.call(e,t)&&null!==(e=$(e)););return e}(e,t);if(r){var i=Object.getOwnPropertyDescriptor(r,t);return i.get?i.get.call(n):i.value}})(e,t,n||e)}function $(e){return($=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}I(null,O());const U=()=>"";var q=i(66386);const Y=["dockedSidebar","selectedTheme","selectedLanguage","vibrate","suspendWhenHidden","enableShortcuts","defaultPanel"],K=window.localStorage||{};function J(e){try{Y.forEach((t=>{const n=e[t];K[t]=JSON.stringify(void 0===n?null:n)}))}catch(t){}}function W(){const e={};return Y.forEach((t=>{if(t in K){let n=JSON.parse(K[t]);"selectedTheme"===t&&"string"==typeof n&&(n={theme:n}),"dockedSidebar"===t&&"boolean"==typeof n&&(n=n?"docked":"auto"),e[t]=n}})),e}const G=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-logout",(()=>this._handleLogout())),this.addEventListener("hass-refresh-current-user",(()=>{_(this.hass.connection).refresh()}))}hassConnected(){super.hassConnected(),v(this.hass.connection,(e=>this._updateHass({user:e}))),(0,q.IO)()&&this.updateComplete.then((()=>i.e(7951).then(i.bind(i,41041)))).then((()=>{const e=document.createElement("ha-store-auth-card");this.shadowRoot.appendChild(e),this.provideHass(e)}))}async _handleLogout(){try{await this.hass.auth.revoke(),this.hass.connection.close(),K.clear&&K.clear(),document.location.href="/"}catch(e){console.error(e),alert("Log out failed")}}};async function X(e){const t=await(0,b.Pz)(e),n={};for(let r=0;r<t.length;r++){const e=t[r];n[e.entity_id]=e}return n}const Z=(e,t)=>e.subscribeEvents((e=>function(e,t){const n=e.state;if(void 0===n)return;const{entity_id:r,new_state:i}=t.data;if(i)e.setState({[i.entity_id]:i});else{const t=Object.assign({},n);delete t[r],e.setState(t,!0)}}(t,e)),"state_changed"),Q=(e,t)=>(e=>(0,g._)(e,"_ent",X,Z))(e).subscribe(t);function ee(e,t){if(void 0===e)return null;const{domain:n,service:r}=t.data;return{[n]:Object.assign({},e[n],{[r]:{description:"",fields:{}}})}}function te(e,t){if(void 0===e)return null;const{domain:n,service:r}=t.data,i=e[n];if(!i||!(r in i))return null;const o={};return Object.keys(i).forEach((e=>{e!==r&&(o[e]=i[e])})),{[n]:o}}const ne=e=>(0,b.U2)(e),re=(e,t)=>Promise.all([e.subscribeEvents(t.action(ee),"service_registered"),e.subscribeEvents(t.action(te),"service_removed")]).then((e=>()=>e.forEach((e=>e())))),ie=(e,t)=>(e=>(0,g._)(e,"_srv",ne,re))(e).subscribe(t);var oe=i(47181);const se=e=>{(0,oe.B)(window,"connection-status",e)};var ae=i(62359);const le="lovelace",ce=e=>e.sendMessagePromise({type:"get_panels"}),de=(e,t)=>e.subscribeEvents((()=>ce(e).then((e=>t.setState(e,!0)))),"panels_updated");var ue=i(30320),pe=i(53775);const he=e=>class extends e{initializeHass(e,t){this.hass={auth:e,connection:t,connected:!0,states:null,config:null,themes:null,panels:null,services:null,user:null,panelUrl:this._panelUrl,defaultPanel:le,language:O(),selectedLanguage:null,resources:null,localize:()=>"",translationMetadata:E,dockedSidebar:"docked",vibrate:!0,suspendWhenHidden:!0,enableShortcuts:!0,moreInfoEntityId:null,hassUrl:(t="")=>new URL(t,e.data.hassUrl).toString(),callService:async(e,n,r={})=>{try{return await(0,b._D)(t,e,n,r)}catch(i){0,(0,ae.j)("failure");const t=this.hass.localize("ui.notification_toast.service_call_failed","service",`${e}/${n}`)+" "+i.message;throw(0,oe.B)(this,"hass-notification",{message:t}),i}},callApi:async(t,n,r)=>(0,pe.Z)(e,t,n,r),fetchWithAuth:(t,n)=>(0,ue.r)(e,`${e.data.hassUrl}${t}`,n),sendWS:e=>{t.sendMessage(e)},callWS:e=>{return t.sendMessagePromise(e)},loadBackendTranslation:(e,t,n)=>{var r;return this._loadHassTranslations(null===(r=this.hass)||void 0===r?void 0:r.language,e,t,n)},...W(),...this._pendingHass},this.hassConnected()}hassConnected(){super.hassConnected();const e=this.hass.connection;se("connected"),e.addEventListener("ready",(()=>this.hassReconnected())),e.addEventListener("disconnected",(()=>this.hassDisconnected())),e.addEventListener("reconnect-error",((e,t)=>{2===t&&(se("auth-invalid"),location.reload())})),Q(e,(e=>this._updateHass({states:e}))),(0,p.wQ)(e,(e=>this._updateHass({config:e}))),ie(e,(e=>this._updateHass({services:e}))),((e,t)=>{(0,g.B)("_pnl",ce,de,e,t)})(e,(e=>this._updateHass({panels:e}))),((e,t,n)=>{C(e,t).subscribe(n)})(e,"core",(e=>this._updateHass({userData:e})))}hassReconnected(){super.hassReconnected(),this._updateHass({connected:!0}),se("connected"),this.hass.callWS({type:"get_config"}).then((e=>{this._updateHass({config:e})}))}hassDisconnected(){super.hassDisconnected(),this._updateHass({connected:!1}),se("disconnected")}};var fe=i(74265);const me=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("register-dialog",(e=>this.registerDialog(e.detail))),(0,fe.lD)(this,this.shadowRoot)}registerDialog({dialogShowEvent:e,dialogTag:t,dialogImport:n}){this.addEventListener(e,(e=>{(0,fe.vC)(this,this.shadowRoot,t,e.detail,n)}))}},ye=(e,t)=>(0,oe.B)(e,"hass-notification",t),ge=e=>class extends e{firstUpdated(e){super.firstUpdated(e),Promise.all([i.e(5009),i.e(1209)]).then(i.bind(i,35003))}updated(e){var t;super.updated(e);const n=e.get("hass");e.has("hass")&&this.hass.config&&(null==n||null===(t=n.config)||void 0===t?void 0:t.state)!==this.hass.config.state&&(this.hass.config.state===p.UE?ye(this,{message:this.hass.localize("ui.notification_toast.starting")||"Home Assistant is starting, not everything will be available until it is finished.",duration:0,dismissable:!1,action:{text:this.hass.localize("ui.notification_toast.dismiss"),action:()=>{}}}):!(null==n?void 0:n.config)||n.config.state!==p.UE||this.hass.config.state!==p.dL&&this.hass.config.state!==p.u5||ye(this,{message:this.hass.localize("ui.notification_toast.started"),duration:5e3}))}hassReconnected(){super.hassReconnected(),ye(this,{message:"",duration:1})}hassDisconnected(){super.hassDisconnected(),ye(this,{message:this.hass.localize("ui.notification_toast.connection_lost"),duration:0,dismissable:!1})}},be={success:[50,50,50],warning:[100,50,100],failure:[200,100,200],light:[50],medium:[100],heavy:[200],selection:[20]},_e=e=>{navigator.vibrate(be[e.detail])},ve=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-vibrate",(e=>{const t=e.detail.vibrate;navigator.vibrate&&t?window.addEventListener("haptic",_e):window.removeEventListener("haptic",_e),this._updateHass({vibrate:t}),J(this.hass)}))}hassConnected(){super.hassConnected(),navigator.vibrate&&this.hass.vibrate&&window.addEventListener("haptic",_e)}};function we(){we=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(n){t.forEach((function(t){t.kind===n&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var n=e.prototype;["method","field"].forEach((function(r){t.forEach((function(t){var i=t.placement;if(t.kind===r&&("static"===i||"prototype"===i)){var o="static"===i?e:n;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var n=t.descriptor;if("field"===t.kind){var r=t.initializer;n={enumerable:n.enumerable,writable:n.writable,configurable:n.configurable,value:void 0===r?void 0:r.call(e)}}Object.defineProperty(e,t.key,n)},decorateClass:function(e,t){var n=[],r=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!Ce(e))return n.push(e);var t=this.decorateElement(e,i);n.push(t.element),n.push.apply(n,t.extras),r.push.apply(r,t.finishers)}),this),!t)return{elements:n,finishers:r};var o=this.decorateConstructor(n,t);return r.push.apply(r,o.finishers),o.finishers=r,o},addElementPlacement:function(e,t,n){var r=t[e.placement];if(!n&&-1!==r.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");r.push(e.key)},decorateElement:function(e,t){for(var n=[],r=[],i=e.decorators,o=i.length-1;o>=0;o--){var s=t[e.placement];s.splice(s.indexOf(e.key),1);var a=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(a)||a);e=l.element,this.addElementPlacement(e,t),l.finisher&&r.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);n.push.apply(n,c)}}return{element:e,finishers:r,extras:n}},decorateConstructor:function(e,t){for(var n=[],r=t.length-1;r>=0;r--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[r])(i)||i);if(void 0!==o.finisher&&n.push(o.finisher),void 0!==o.elements){e=o.elements;for(var s=0;s<e.length-1;s++)for(var a=s+1;a<e.length;a++)if(e[s].key===e[a].key&&e[s].placement===e[a].placement)throw new TypeError("Duplicated element ("+e[s].key+")")}}return{elements:e,finishers:n}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return Ae(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Ae(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var n=Pe(e.key),r=String(e.placement);if("static"!==r&&"prototype"!==r&&"own"!==r)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+r+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:n,placement:r,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:Se(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var n=Se(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:n}},runClassFinishers:function(e,t){for(var n=0;n<t.length;n++){var r=(0,t[n])(e);if(void 0!==r){if("function"!=typeof r)throw new TypeError("Finishers must return a constructor.");e=r}}return e},disallowProperty:function(e,t,n){if(void 0!==e[t])throw new TypeError(n+" can't have a ."+t+" property.")}};return e}function xe(e){var t,n=Pe(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var r={kind:"field"===e.kind?"field":"method",key:n,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(r.decorators=e.decorators),"field"===e.kind&&(r.initializer=e.value),r}function ke(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function Ce(e){return e.decorators&&e.decorators.length}function Ee(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function Se(e,t){var n=e[t];if(void 0!==n&&"function"!=typeof n)throw new TypeError("Expected '"+t+"' to be a function");return n}function Pe(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var n=e[Symbol.toPrimitive];if(void 0!==n){var r=n.call(e,t||"default");if("object"!=typeof r)return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function Ae(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}let Te,Oe=function(e,t,n,r){var i=we();if(r)for(var o=0;o<r.length;o++)i=r[o](i);var s=t((function(e){i.initializeInstanceElements(e,a.elements)}),n),a=i.decorateClass(function(e){for(var t=[],n=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},r=0;r<e.length;r++){var i,o=e[r];if("method"===o.kind&&(i=t.find(n)))if(Ee(o.descriptor)||Ee(i.descriptor)){if(Ce(o)||Ce(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(Ce(o)){if(Ce(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}ke(o,i)}else t.push(o)}return t}(s.d.map(xe)),e);return i.initializeClassElements(s.F,a.elements),i.runClassFinishers(s.F,a.finishers)}(null,(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"field",decorators:[(0,h.Cb)({attribute:!1})],key:"hass",value:void 0},{kind:"field",key:"_pendingHass",value:()=>({})},{kind:"field",key:"__provideHass",value:()=>[]},{kind:"method",key:"provideHass",value:function(e){this.__provideHass.push(e),e.hass=this.hass}},{kind:"method",key:"initializeHass",value:function(e,t){}},{kind:"method",key:"hassConnected",value:function(){}},{kind:"method",key:"hassReconnected",value:function(){}},{kind:"method",key:"hassDisconnected",value:function(){}},{kind:"method",key:"panelUrlChanged",value:function(e){}},{kind:"method",key:"hassChanged",value:function(e,t){this.__provideHass.forEach((t=>{t.hass=e}))}},{kind:"method",key:"_updateHass",value:function(e){this.hass?this.hass={...this.hass,...e}:this._pendingHass={...this._pendingHass,...e}}}]}}),h.oi);const Ne=()=>(Te||(Te=Promise.all([i.e(5009),i.e(2955),i.e(8161),i.e(8941),i.e(879),i.e(1458),i.e(9160),i.e(486),i.e(6443),i.e(1668),i.e(6619),i.e(4930),i.e(6863),i.e(362),i.e(3329),i.e(6509),i.e(1927),i.e(4909),i.e(8705),i.e(319),i.e(9123),i.e(1177),i.e(7282),i.e(9448),i.e(1206),i.e(9810),i.e(5475),i.e(4077),i.e(6576),i.e(7306),i.e(9235)]).then(i.bind(i,7001))),Te),Ie=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-more-info",(e=>this._handleMoreInfo(e))),Ne()}async _handleMoreInfo(e){(0,fe.vC)(this,this.shadowRoot,"ha-more-info-dialog",{entityId:e.detail.entityId},Ne)}},Re=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.registerDialog({dialogShowEvent:"hass-notification",dialogTag:"notification-manager",dialogImport:()=>Promise.all([i.e(5009),i.e(1209)]).then(i.bind(i,35003))})}},De=e=>class extends e{updated(e){if(super.updated(e),!e.has("hass")||!this.hass)return;const t=e.get("hass");var n;t&&t.panels===this.hass.panels&&t.panelUrl===this.hass.panelUrl||(n=(e=>{if(!e.panels)return;const t=Object.values(e.panels).find((t=>t.url_path===e.panelUrl));if(!t)return;const n=(e=>"lovelace"===e.url_path?"panel.states":"profile"===e.url_path?"panel.profile":"panel."+e.title)(t);return e.localize(n)||t.title||void 0})(this.hass),document.title=n?n+" - Home Assistant":"Home Assistant")}},ze=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-dock-sidebar",(e=>{this._updateHass({dockedSidebar:e.detail.dock}),J(this.hass)})),this.addEventListener("hass-default-panel",(e=>{this._updateHass({defaultPanel:e.detail.defaultPanel}),J(this.hass)}))}};var Fe=i(43260);const Le=e=>e.sendMessagePromise({type:"frontend/get_themes"}),Me=(e,t)=>e.subscribeEvents((()=>Le(e).then((e=>t.setState(e,!0)))),"themes_updated"),He=matchMedia("(prefers-color-scheme: dark)"),je=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("settheme",(e=>{this._updateHass({selectedTheme:{...this.hass.selectedTheme,...e.detail}}),this._applyTheme(He.matches),J(this.hass)})),He.addListener((e=>this._applyTheme(e.matches)))}hassConnected(){var e,t;super.hassConnected(),e=this.hass.connection,t=e=>{this._updateHass({themes:e}),(0,Fe.p)(),this._applyTheme(He.matches)},(0,g.B)("_thm",Le,Me,e,t)}_applyTheme(e){var t,n,r;if(!this.hass)return;const i=(null===(t=this.hass.selectedTheme)||void 0===t?void 0:t.theme)||(e&&this.hass.themes.default_dark_theme?this.hass.themes.default_dark_theme:this.hass.themes.default_theme);let o=this.hass.selectedTheme;"default"===i&&void 0===(null===(n=o)||void 0===n?void 0:n.dark)&&(o={...this.hass.selectedTheme,dark:e}),(0,Fe.R)(document.documentElement,this.hass.themes,i,o);const s="default"===i?!!(null===(r=o)||void 0===r?void 0:r.dark):!(!e||!this.hass.themes.default_dark_theme);if(s!==this.hass.themes.darkMode){this._updateHass({themes:{...this.hass.themes,darkMode:s}});const e=document.querySelector("meta[name=color-scheme]");e&&e.setAttribute("content",s?"dark":"default"===i?"light":"dark light")}const a=document.querySelector("meta[name=theme-color]"),l=getComputedStyle(document.documentElement),c=l.getPropertyValue("--app-header-background-color");if(document.documentElement.style.backgroundColor=l.getPropertyValue("--primary-background-color"),a){a.hasAttribute("default-content")||a.setAttribute("default-content",a.getAttribute("content"));const e=(null==c?void 0:c.trim())||a.getAttribute("default-content");a.setAttribute("content",e)}}};var Be=i(87744),Ve=i(38346);function $e(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}const Ue=e=>class extends e{constructor(...e){super(...e),$e(this,"__coreProgress",void 0),$e(this,"__loadedTranslations",{})}firstUpdated(e){super.firstUpdated(e),this.addEventListener("hass-language-select",(e=>this._selectLanguage(e.detail.language,!0))),this._loadCoreTranslations(O())}hassConnected(){super.hassConnected(),T(this.hass).then((e=>{e&&this.hass.language!==e&&this._selectLanguage(e,!1)})),this.hass.connection.subscribeEvents((0,Ve.D)((()=>{this._refetchCachedHassTranslations(!1,!1)}),500),"component_loaded"),this._applyTranslations(this.hass)}hassReconnected(){super.hassReconnected(),this._refetchCachedHassTranslations(!0,!1),this._applyTranslations(this.hass)}panelUrlChanged(e){super.panelUrlChanged(e),this._loadFragmentTranslations(this.hass?this.hass.language:O(),e)}_selectLanguage(e,t){var n,r;this.hass&&(this._updateHass({language:e,selectedLanguage:e}),J(this.hass),t&&(n=this.hass,r={language:e},k(n.connection,"language",r)),this._applyTranslations(this.hass),this._refetchCachedHassTranslations(!0,!0))}_applyTranslations(e){document.querySelector("html").setAttribute("lang",e.language),this.style.direction=(0,Be.HE)(e)?"rtl":"ltr",this._loadCoreTranslations(e.language),this._loadFragmentTranslations(e.language,e.panelUrl)}async _loadHassTranslations(e,t,n,r,i=!1){let o;if(o=t in this.__loadedTranslations?this.__loadedTranslations[t]:this.__loadedTranslations[t]={integrations:[],setup:!1,configFlow:!1},!i)if(n){if(o.integrations.includes(n))return this.hass.localize}else if(r?o.configFlow:o.setup)return this.hass.localize;n?o.integrations.includes(n)||o.integrations.push(n):(o.setup=!0,r&&(o.configFlow=!0));const s=await(async(e,t,n,r,i)=>(await e.callWS({type:"frontend/get_translations",language:t,category:n,integration:r,config_flow:i})).resources)(this.hass,e,t,n,r);return this.hass.language!==e||await this._updateResources(e,s),this.hass.localize}async _loadFragmentTranslations(e,t){if(E.fragments.includes(t)){const n=await I(t,e);this._updateResources(n.language,n.data)}}async _loadCoreTranslations(e){if(this.__coreProgress!==e){this.__coreProgress=e;try{const t=await I(null,e);this._updateResources(t.language,t.data)}finally{this.__coreProgress=void 0}}}async _updateResources(e,t){var n,r;const i=null!==(n=this.hass)&&void 0!==n?n:this._pendingHass,o={[e]:{...null==i||null===(r=i.resources)||void 0===r?void 0:r[e],...t}},s={resources:o};this.hass&&e===this.hass.language&&(s.localize=await(0,w.X)(this,e,o)),this._updateHass(s)}_refetchCachedHassTranslations(e,t){for(const[n,r]of Object.entries(this.__loadedTranslations))t&&(r.integrations=[]),r.setup&&this._loadHassTranslations(this.hass.language,n,void 0,e&&r.configFlow,!0)}};function qe(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}const Ye=e=>class extends e{constructor(...e){super(...e),qe(this,"_ignoreNextPopState",!1),qe(this,"_dialogClosedListener",(e=>{var t,n;(null===(t=history.state)||void 0===t?void 0:t.open)&&(null===(n=history.state)||void 0===n?void 0:n.dialog)===e.detail.dialog&&(this._ignoreNextPopState=!0,history.back())})),qe(this,"_popstateChangeListener",(e=>{this._ignoreNextPopState?this._ignoreNextPopState=!1:e.state&&"dialog"in e.state&&this._handleDialogStateChange(e.state)}))}connectedCallback(){super.connectedCallback(),window.addEventListener("popstate",this._popstateChangeListener),this.addEventListener("dialog-closed",this._dialogClosedListener)}disconnectedCallback(){super.disconnectedCallback(),window.removeEventListener("popstate",this._popstateChangeListener),this.removeEventListener("dialog-closed",this._dialogClosedListener)}async _handleDialogStateChange(e){if(!e.open){return await(0,fe.gk)(e.dialog)?void(e.oldState&&this._handleDialogStateChange(e.oldState)):void history.pushState({dialog:e.dialog,open:!0,dialogParams:null,oldState:null},"")}null!==e.dialogParams&&(0,fe.vC)(this,this.shadowRoot,e.dialog,e.dialogParams)}},Ke=e=>class extends e{firstUpdated(e){super.firstUpdated(e),this.addEventListener("write_log",(e=>{this._writeLog(e.detail)}))}_writeLog(e){var t;null===(t=this.hass)||void 0===t||t.callService("system_log","write",{logger:"frontend.js.latest."+"20201111.1".replace(".",""),message:e.message,level:e.level||"error"})}};class Je extends(((e,t)=>t.reduceRight(((e,t)=>t(e)),e))(Oe,[G,je,Ue,Ie,ze,ge,he,Re,me,Ye,ve,De,Ke])){}const We=async(e,t=!0)=>{if(!("serviceWorker"in navigator)||"https:"!==location.protocol&&"localhost"!==location.hostname)return;navigator.serviceWorker.addEventListener("controllerchange",(()=>{location.reload()}));const n=await navigator.serviceWorker.register("/service_worker.js");t&&n.addEventListener("updatefound",(()=>{const t=n.installing;t&&t.addEventListener("statechange",(()=>{"installed"===t.state&&navigator.serviceWorker.controller&&ye(e,{message:"A new version of the frontend is available.",action:{action:()=>t.postMessage({type:"skipWaiting"}),text:"reload"},duration:0,dismissable:!1})}))}))};i(53918),i(30879);function Ge(){Ge=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(n){t.forEach((function(t){t.kind===n&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var n=e.prototype;["method","field"].forEach((function(r){t.forEach((function(t){var i=t.placement;if(t.kind===r&&("static"===i||"prototype"===i)){var o="static"===i?e:n;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var n=t.descriptor;if("field"===t.kind){var r=t.initializer;n={enumerable:n.enumerable,writable:n.writable,configurable:n.configurable,value:void 0===r?void 0:r.call(e)}}Object.defineProperty(e,t.key,n)},decorateClass:function(e,t){var n=[],r=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!Qe(e))return n.push(e);var t=this.decorateElement(e,i);n.push(t.element),n.push.apply(n,t.extras),r.push.apply(r,t.finishers)}),this),!t)return{elements:n,finishers:r};var o=this.decorateConstructor(n,t);return r.push.apply(r,o.finishers),o.finishers=r,o},addElementPlacement:function(e,t,n){var r=t[e.placement];if(!n&&-1!==r.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");r.push(e.key)},decorateElement:function(e,t){for(var n=[],r=[],i=e.decorators,o=i.length-1;o>=0;o--){var s=t[e.placement];s.splice(s.indexOf(e.key),1);var a=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(a)||a);e=l.element,this.addElementPlacement(e,t),l.finisher&&r.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);n.push.apply(n,c)}}return{element:e,finishers:r,extras:n}},decorateConstructor:function(e,t){for(var n=[],r=t.length-1;r>=0;r--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[r])(i)||i);if(void 0!==o.finisher&&n.push(o.finisher),void 0!==o.elements){e=o.elements;for(var s=0;s<e.length-1;s++)for(var a=s+1;a<e.length;a++)if(e[s].key===e[a].key&&e[s].placement===e[a].placement)throw new TypeError("Duplicated element ("+e[s].key+")")}}return{elements:e,finishers:n}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return rt(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?rt(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var n=nt(e.key),r=String(e.placement);if("static"!==r&&"prototype"!==r&&"own"!==r)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+r+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:n,placement:r,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:tt(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var n=tt(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:n}},runClassFinishers:function(e,t){for(var n=0;n<t.length;n++){var r=(0,t[n])(e);if(void 0!==r){if("function"!=typeof r)throw new TypeError("Finishers must return a constructor.");e=r}}return e},disallowProperty:function(e,t,n){if(void 0!==e[t])throw new TypeError(n+" can't have a ."+t+" property.")}};return e}function Xe(e){var t,n=nt(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var r={kind:"field"===e.kind?"field":"method",key:n,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(r.decorators=e.decorators),"field"===e.kind&&(r.initializer=e.value),r}function Ze(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function Qe(e){return e.decorators&&e.decorators.length}function et(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function tt(e,t){var n=e[t];if(void 0!==n&&"function"!=typeof n)throw new TypeError("Expected '"+t+"' to be a function");return n}function nt(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var n=e[Symbol.toPrimitive];if(void 0!==n){var r=n.call(e,t||"default");if("object"!=typeof r)return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function rt(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function it(e,t,n){return(it="undefined"!=typeof Reflect&&Reflect.get?Reflect.get:function(e,t,n){var r=function(e,t){for(;!Object.prototype.hasOwnProperty.call(e,t)&&null!==(e=ot(e)););return e}(e,t);if(r){var i=Object.getOwnPropertyDescriptor(r,t);return i.get?i.get.call(n):i.value}})(e,t,n||e)}function ot(e){return(ot=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}!function(e,t,n,r){var i=Ge();if(r)for(var o=0;o<r.length;o++)i=r[o](i);var s=t((function(e){i.initializeInstanceElements(e,a.elements)}),n),a=i.decorateClass(function(e){for(var t=[],n=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},r=0;r<e.length;r++){var i,o=e[r];if("method"===o.kind&&(i=t.find(n)))if(et(o.descriptor)||et(i.descriptor)){if(Qe(o)||Qe(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(Qe(o)){if(Qe(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}Ze(o,i)}else t.push(o)}return t}(s.d.map(Xe)),e);i.initializeClassElements(s.F,a.elements),i.runClassFinishers(s.F,a.finishers)}([(0,h.Mo)("onboarding-create-user")],(function(e,t){class n extends t{constructor(...t){super(...t),e(this)}}return{F:n,d:[{kind:"field",decorators:[(0,h.Cb)()],key:"localize",value:void 0},{kind:"field",decorators:[(0,h.Cb)()],key:"language",value:void 0},{kind:"field",decorators:[(0,h.sz)()],key:"_name",value:()=>""},{kind:"field",decorators:[(0,h.sz)()],key:"_username",value:()=>""},{kind:"field",decorators:[(0,h.sz)()],key:"_password",value:()=>""},{kind:"field",decorators:[(0,h.sz)()],key:"_passwordConfirm",value:()=>""},{kind:"field",decorators:[(0,h.sz)()],key:"_loading",value:()=>!1},{kind:"field",decorators:[(0,h.sz)()],key:"_errorMsg",value(){}},{kind:"method",key:"render",value:function(){return h.dy`
    <p>
      ${this.localize("ui.panel.page-onboarding.intro")}
    </p>

    <p>
      ${this.localize("ui.panel.page-onboarding.user.intro")}
    </p>

    ${this._errorMsg?h.dy`
            <p class="error">
              ${this.localize("ui.panel.page-onboarding.user.error."+this._errorMsg)||this._errorMsg}
            </p>
          `:""}

    <form>
      <paper-input
        name="name"
        label="${this.localize("ui.panel.page-onboarding.user.data.name")}"
        .value=${this._name}
        @value-changed=${this._handleValueChanged}
        required
        auto-validate
        autocapitalize='on'
        .errorMessage="${this.localize("ui.panel.page-onboarding.user.required_field")}"
        @blur=${this._maybePopulateUsername}
      ></paper-input>

      <paper-input
        name="username"
        label="${this.localize("ui.panel.page-onboarding.user.data.username")}"
        value=${this._username}
        @value-changed=${this._handleValueChanged}
        required
        auto-validate
        autocapitalize='none'
        .errorMessage="${this.localize("ui.panel.page-onboarding.user.required_field")}"
      ></paper-input>

      <paper-input
        name="password"
        label="${this.localize("ui.panel.page-onboarding.user.data.password")}"
        value=${this._password}
        @value-changed=${this._handleValueChanged}
        required
        type='password'
        auto-validate
        .errorMessage="${this.localize("ui.panel.page-onboarding.user.required_field")}"
      ></paper-input>

      <paper-input
        name="passwordConfirm"
        label="${this.localize("ui.panel.page-onboarding.user.data.password_confirm")}"
        value=${this._passwordConfirm}
        @value-changed=${this._handleValueChanged}
        required
        type='password'
        .invalid=${""!==this._password&&""!==this._passwordConfirm&&this._passwordConfirm!==this._password}
        .errorMessage="${this.localize("ui.panel.page-onboarding.user.error.password_not_match")}"
      ></paper-input>

      <p class="action">
        <mwc-button
          raised
          @click=${this._submitForm}
          .disabled=${this._loading}
        >
          ${this.localize("ui.panel.page-onboarding.user.create_account")}
        </mwc-button>
      </p>
    </div>
  </form>
`}},{kind:"method",key:"firstUpdated",value:function(e){it(ot(n.prototype),"firstUpdated",this).call(this,e),setTimeout((()=>this.shadowRoot.querySelector("paper-input").focus()),100),this.addEventListener("keypress",(e=>{13===e.keyCode&&this._submitForm(e)}))}},{kind:"method",key:"_handleValueChanged",value:function(e){this["_"+e.target.name]=e.detail.value}},{kind:"method",key:"_maybePopulateUsername",value:function(){if(this._username)return;const e=this._name.split(" ");e.length&&(this._username=e[0].toLowerCase())}},{kind:"method",key:"_submitForm",value:async function(e){if(e.preventDefault(),this._name&&this._username&&this._password)if(this._password===this._passwordConfirm){this._loading=!0,this._errorMsg="";try{const e=s(),t=await(0,y.k1)({client_id:e,name:this._name,username:this._username,password:this._password,language:this.language});(0,oe.B)(this,"onboarding-step",{type:"user",result:t})}catch(t){console.error(t),this._loading=!1,this._errorMsg=t.body.message}}else this._errorMsg="password_not_match";else this._errorMsg="required_fields"}},{kind:"get",static:!0,key:"styles",value:function(){return h.iv`
      .error {
        color: red;
      }

      .action {
        margin: 32px 0;
        text-align: center;
      }
    `}}]}}),h.oi);i(38544);function st(){st=function(){return e};var e={elementsDefinitionOrder:[["method"],["field"]],initializeInstanceElements:function(e,t){["method","field"].forEach((function(n){t.forEach((function(t){t.kind===n&&"own"===t.placement&&this.defineClassElement(e,t)}),this)}),this)},initializeClassElements:function(e,t){var n=e.prototype;["method","field"].forEach((function(r){t.forEach((function(t){var i=t.placement;if(t.kind===r&&("static"===i||"prototype"===i)){var o="static"===i?e:n;this.defineClassElement(o,t)}}),this)}),this)},defineClassElement:function(e,t){var n=t.descriptor;if("field"===t.kind){var r=t.initializer;n={enumerable:n.enumerable,writable:n.writable,configurable:n.configurable,value:void 0===r?void 0:r.call(e)}}Object.defineProperty(e,t.key,n)},decorateClass:function(e,t){var n=[],r=[],i={static:[],prototype:[],own:[]};if(e.forEach((function(e){this.addElementPlacement(e,i)}),this),e.forEach((function(e){if(!ct(e))return n.push(e);var t=this.decorateElement(e,i);n.push(t.element),n.push.apply(n,t.extras),r.push.apply(r,t.finishers)}),this),!t)return{elements:n,finishers:r};var o=this.decorateConstructor(n,t);return r.push.apply(r,o.finishers),o.finishers=r,o},addElementPlacement:function(e,t,n){var r=t[e.placement];if(!n&&-1!==r.indexOf(e.key))throw new TypeError("Duplicated element ("+e.key+")");r.push(e.key)},decorateElement:function(e,t){for(var n=[],r=[],i=e.decorators,o=i.length-1;o>=0;o--){var s=t[e.placement];s.splice(s.indexOf(e.key),1);var a=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,i[o])(a)||a);e=l.element,this.addElementPlacement(e,t),l.finisher&&r.push(l.finisher);var c=l.extras;if(c){for(var d=0;d<c.length;d++)this.addElementPlacement(c[d],t);n.push.apply(n,c)}}return{element:e,finishers:r,extras:n}},decorateConstructor:function(e,t){for(var n=[],r=t.length-1;r>=0;r--){var i=this.fromClassDescriptor(e),o=this.toClassDescriptor((0,t[r])(i)||i);if(void 0!==o.finisher&&n.push(o.finisher),void 0!==o.elements){e=o.elements;for(var s=0;s<e.length-1;s++)for(var a=s+1;a<e.length;a++)if(e[s].key===e[a].key&&e[s].placement===e[a].placement)throw new TypeError("Duplicated element ("+e[s].key+")")}}return{elements:e,finishers:n}},fromElementDescriptor:function(e){var t={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),"field"===e.kind&&(t.initializer=e.initializer),t},toElementDescriptors:function(e){var t;if(void 0!==e)return(t=e,function(e){if(Array.isArray(e))return e}(t)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(t)||function(e,t){if(e){if("string"==typeof e)return ht(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?ht(e,t):void 0}}(t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()).map((function(e){var t=this.toElementDescriptor(e);return this.disallowProperty(e,"finisher","An element descriptor"),this.disallowProperty(e,"extras","An element descriptor"),t}),this)},toElementDescriptor:function(e){var t=String(e.kind);if("method"!==t&&"field"!==t)throw new TypeError('An element descriptor\'s .kind property must be either "method" or "field", but a decorator created an element descriptor with .kind "'+t+'"');var n=pt(e.key),r=String(e.placement);if("static"!==r&&"prototype"!==r&&"own"!==r)throw new TypeError('An element descriptor\'s .placement property must be one of "static", "prototype" or "own", but a decorator created an element descriptor with .placement "'+r+'"');var i=e.descriptor;this.disallowProperty(e,"elements","An element descriptor");var o={kind:t,key:n,placement:r,descriptor:Object.assign({},i)};return"field"!==t?this.disallowProperty(e,"initializer","A method descriptor"):(this.disallowProperty(i,"get","The property descriptor of a field descriptor"),this.disallowProperty(i,"set","The property descriptor of a field descriptor"),this.disallowProperty(i,"value","The property descriptor of a field descriptor"),o.initializer=e.initializer),o},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:ut(e,"finisher"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var t={kind:"class",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(t,Symbol.toStringTag,{value:"Descriptor",configurable:!0}),t},toClassDescriptor:function(e){var t=String(e.kind);if("class"!==t)throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator created a class descriptor with .kind "'+t+'"');this.disallowProperty(e,"key","A class descriptor"),this.disallowProperty(e,"placement","A class descriptor"),this.disallowProperty(e,"descriptor","A class descriptor"),this.disallowProperty(e,"initializer","A class descriptor"),this.disallowProperty(e,"extras","A class descriptor");var n=ut(e,"finisher");return{elements:this.toElementDescriptors(e.elements),finisher:n}},runClassFinishers:function(e,t){for(var n=0;n<t.length;n++){var r=(0,t[n])(e);if(void 0!==r){if("function"!=typeof r)throw new TypeError("Finishers must return a constructor.");e=r}}return e},disallowProperty:function(e,t,n){if(void 0!==e[t])throw new TypeError(n+" can't have a ."+t+" property.")}};return e}function at(e){var t,n=pt(e.key);"method"===e.kind?t={value:e.value,writable:!0,configurable:!0,enumerable:!1}:"get"===e.kind?t={get:e.value,configurable:!0,enumerable:!1}:"set"===e.kind?t={set:e.value,configurable:!0,enumerable:!1}:"field"===e.kind&&(t={configurable:!0,writable:!0,enumerable:!0});var r={kind:"field"===e.kind?"field":"method",key:n,placement:e.static?"static":"field"===e.kind?"own":"prototype",descriptor:t};return e.decorators&&(r.decorators=e.decorators),"field"===e.kind&&(r.initializer=e.value),r}function lt(e,t){void 0!==e.descriptor.get?t.descriptor.get=e.descriptor.get:t.descriptor.set=e.descriptor.set}function ct(e){return e.decorators&&e.decorators.length}function dt(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function ut(e,t){var n=e[t];if(void 0!==n&&"function"!=typeof n)throw new TypeError("Expected '"+t+"' to be a function");return n}function pt(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var n=e[Symbol.toPrimitive];if(void 0!==n){var r=n.call(e,t||"default");if("object"!=typeof r)return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}(e,"string");return"symbol"==typeof t?t:String(t)}function ht(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function ft(e,t,n){return(ft="undefined"!=typeof Reflect&&Reflect.get?Reflect.get:function(e,t,n){var r=function(e,t){for(;!Object.prototype.hasOwnProperty.call(e,t)&&null!==(e=mt(e)););return e}(e,t);if(r){var i=Object.getOwnPropertyDescriptor(r,t);return i.get?i.get.call(n):i.value}})(e,t,n||e)}function mt(e){return(mt=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}!function(e,t,n,r){var i=st();if(r)for(var o=0;o<r.length;o++)i=r[o](i);var s=t((function(e){i.initializeInstanceElements(e,a.elements)}),n),a=i.decorateClass(function(e){for(var t=[],n=function(e){return"method"===e.kind&&e.key===o.key&&e.placement===o.placement},r=0;r<e.length;r++){var i,o=e[r];if("method"===o.kind&&(i=t.find(n)))if(dt(o.descriptor)||dt(i.descriptor)){if(ct(o)||ct(i))throw new ReferenceError("Duplicated methods ("+o.key+") can't be decorated.");i.descriptor=o.descriptor}else{if(ct(o)){if(ct(i))throw new ReferenceError("Decorators can't be placed on different accessors with for the same property ("+o.key+").");i.decorators=o.decorators}lt(o,i)}else t.push(o)}return t}(s.d.map(at)),e);i.initializeClassElements(s.F,a.elements),i.runClassFinishers(s.F,a.finishers)}([(0,h.Mo)("ha-onboarding")],(function(e,t){class r extends t{constructor(...t){super(...t),e(this)}}return{F:r,d:[{kind:"field",decorators:[(0,h.Cb)({attribute:!1})],key:"hass",value:void 0},{kind:"field",key:"translationFragment",value:()=>"page-onboarding"},{kind:"field",decorators:[(0,h.sz)()],key:"_loading",value:()=>!1},{kind:"field",decorators:[(0,h.sz)()],key:"_restoring",value:()=>!1},{kind:"field",decorators:[(0,h.sz)()],key:"_supervisor",value:void 0},{kind:"field",decorators:[(0,h.sz)()],key:"_steps",value:void 0},{kind:"method",key:"render",value:function(){const e=this._curStep();return this._loading||!e?h.dy` <onboarding-loading></onboarding-loading> `:"user"===e.step?h.dy`
        ${this._restoring?"":h.dy`<onboarding-create-user
              .localize=${this.localize}
              .language=${this.language}
            >
            </onboarding-create-user>`}
        ${this._supervisor?h.dy`<onboarding-restore-snapshot
              .localize=${this.localize}
              .restoring=${this._restoring}
              @restoring=${this._restoringSnapshot}
            >
            </onboarding-restore-snapshot>`:""}
      `:"core_config"===e.step?h.dy`
        <onboarding-core-config
          .hass=${this.hass}
          .onboardingLocalize=${this.localize}
        ></onboarding-core-config>
      `:"integration"===e.step?h.dy`
        <onboarding-integrations
          .hass=${this.hass}
          .onboardingLocalize=${this.localize}
        ></onboarding-integrations>
      `:h.dy``}},{kind:"method",key:"firstUpdated",value:function(e){ft(mt(r.prototype),"firstUpdated",this).call(this,e),this._fetchOnboardingSteps(),this._fetchDiscoveryInformation(),Promise.all([i.e(6509),i.e(4642)]).then(i.bind(i,74561)),Promise.all([i.e(8161),i.e(1895),i.e(1482),i.e(7393)]).then(i.bind(i,58404)),We(this,!1),this.addEventListener("onboarding-step",(e=>this._handleStepDone(e)))}},{kind:"method",key:"updated",value:function(e){ft(mt(r.prototype),"updated",this).call(this,e),e.has("language")&&document.querySelector("html").setAttribute("lang",this.language),e.has("hass")&&this.hassChanged(this.hass,e.get("hass"))}},{kind:"method",key:"_curStep",value:function(){return this._steps?this._steps.find((e=>!e.done)):void 0}},{kind:"method",key:"_restoringSnapshot",value:function(){this._restoring=!0}},{kind:"method",key:"_fetchDiscoveryInformation",value:async function(){try{const e=await(async()=>{const e=await fetch("/api/discovery_info",{method:"GET"});return await e.json()})();this._supervisor=["Home Assistant OS","Home Assistant Supervised"].includes(e.installation_type),this._supervisor&&Promise.all([i.e(4930),i.e(2247),i.e(1206),i.e(8230)]).then(i.bind(i,88894))}catch(e){console.error("Something went wrong loading onboarding-restore-snapshot",e)}}},{kind:"method",key:"_fetchOnboardingSteps",value:async function(){try{const e=await(window.stepsPromise||(0,y.pM)());if(404===e.status)return void document.location.assign("/");const t=await e.json();if(t.every((e=>e.done)))return void document.location.assign("/");if(t[0].done){const e=await u({hassUrl:m.uw});history.replaceState(null,"",location.pathname),await this._connectHass(e)}this._steps=t}catch(e){alert("Something went wrong loading onboarding, try refreshing")}}},{kind:"method",key:"_handleStepDone",value:async function(e){const t=e.detail;if(this._steps=this._steps.map((e=>e.step===t.type?{...e,done:!0}:e)),"user"===t.type){const e=t.result;this._loading=!0;try{const t=await u({hassUrl:m.uw,authCode:e.auth_code});await this._connectHass(t)}catch(n){alert("Ah snap, something went wrong!"),location.reload()}finally{this._loading=!1}}else if("core_config"===t.type);else if("integration"===t.type){this._loading=!0;const e=(()=>{const e={},t=new URLSearchParams(location.search);for(const[n,r]of t.entries())e[n]=r;return e})(),t=e.client_id&&e.redirect_uri?e:{client_id:s(),redirect_uri:`${location.protocol}//${location.host}/?auth_callback=1`,state:btoa(JSON.stringify({hassUrl:`${location.protocol}//${location.host}`,clientId:s()}))};let r;try{r=await(0,y.ec)(this.hass,{client_id:t.client_id,redirect_uri:t.redirect_uri})}catch(n){return this.hass.connection.close(),await this.hass.auth.revoke(),alert("Unable to finish onboarding: "+n.message),void document.location.assign("/?")}this.hass.connection.close(),await this.hass.auth.revoke();let i=t.redirect_uri;i+=(i.includes("?")?"&":"?")+"code="+encodeURIComponent(r.auth_code),t.state&&(i+="&state="+encodeURIComponent(t.state)),document.location.assign(i)}}},{kind:"method",key:"_connectHass",value:async function(e){const t=await async function(e){const t=Object.assign({setupRetry:0,createSocket:n},e),r=await t.createSocket(t);return new o(r,t)}({auth:e});await Promise.all([f(t,p.wQ),f(t,v)]),this.initializeHass(e,t),this._loadFragmentTranslations(this.hass.language,"config"),await new Promise((e=>setTimeout(e,0)))}}]}}),R(null,(function(e,t){class n extends t{constructor(...t){super(...t),e(this)}}return{F:n,d:[{kind:"field",decorators:[(0,h.Cb)()],key:"localize",value:()=>U},{kind:"field",decorators:[(0,h.Cb)()],key:"resources",value:void 0},{kind:"field",decorators:[(0,h.Cb)()],key:"language",value:()=>O()},{kind:"field",decorators:[(0,h.Cb)()],key:"translationFragment",value:void 0},{kind:"method",key:"connectedCallback",value:function(){V($(n.prototype),"connectedCallback",this).call(this),this._initializeLocalizeLite()}},{kind:"method",key:"updated",value:function(e){V($(n.prototype),"updated",this).call(this,e),e.get("translationFragment")&&this._initializeLocalizeLite(),this.language&&this.resources&&(e.has("language")||e.has("resources"))&&(0,w.X)(this.constructor.prototype,this.language,this.resources).then((e=>{this.localize=e}))}},{kind:"method",key:"_initializeLocalizeLite",value:async function(){if(this.resources)return;if(!this.translationFragment)return;const{language:e,data:t}=await I(this.translationFragment,this.language);this.resources={[e]:t}}}]}}),Je));i(65660),i(54242),i(70019),i(5618);var yt=i(11654);const gt=document.createElement("template");gt.setAttribute("style","display: none;"),gt.innerHTML=`<custom-style>\n  <style>\n    /*\n      Home Assistant default styles.\n\n      In Polymer 2.0, default styles should to be set on the html selector.\n      (Setting all default styles only on body breaks shadyCSS polyfill.)\n      See: https://github.com/home-assistant/home-assistant-polymer/pull/901\n    */\n    html {\n      font-size: 14px;\n      height: 100vh;\n\n      /* text */\n      --primary-text-color: #212121;\n      --secondary-text-color: #727272;\n      --text-primary-color: #ffffff;\n      --text-light-primary-color: #212121;\n      --disabled-text-color: #bdbdbd;\n\n      /* main interface colors */\n      --primary-color: #03a9f4;\n      --dark-primary-color: #0288d1;\n      --light-primary-color: #b3e5fC;\n      --accent-color: #ff9800;\n      --divider-color: rgba(0, 0, 0, .12);\n\n      --scrollbar-thumb-color: rgb(194, 194, 194);\n\n      --error-color: #db4437;\n      --warning-color: #FF9800;\n      --success-color: #0f9d58;\n      --info-color: #4285f4;\n\n      /* states and badges */\n      --state-icon-color: #44739e;\n      --state-icon-active-color: #FDD835;\n\n      /* background and sidebar */\n      --card-background-color: #ffffff;\n      --primary-background-color: #fafafa;\n      --secondary-background-color: #e5e5e5; /* behind the cards on state */\n\n      /* for header */\n      --header-height: 56px;\n\n      /* for label-badge */\n      --label-badge-red: #DF4C1E;\n      --label-badge-blue: #039be5;\n      --label-badge-green: #0DA035;\n      --label-badge-yellow: #f4b400;\n\n      /*\n        Paper-styles color.html dependency is stripped on build.\n        When a default paper-style color is used, it needs to be copied\n        from paper-styles/color.html to here.\n      */\n\n      --paper-grey-50: #fafafa; /* default for: --mwc-switch-unchecked-button-color */\n      --paper-grey-200: #eeeeee;  /* for ha-date-picker-style */\n      --paper-grey-500: #9e9e9e;  /* --label-badge-grey */\n\n      /* for paper-slider */\n      --paper-green-400: #66bb6a;\n      --paper-blue-400: #42a5f5;\n      --paper-orange-400: #ffa726;\n\n      /* opacity for dark text on a light background */\n      --dark-divider-opacity: 0.12;\n      --dark-disabled-opacity: 0.38; /* or hint text or icon */\n      --dark-secondary-opacity: 0.54;\n      --dark-primary-opacity: 0.87;\n\n      /* opacity for light text on a dark background */\n      --light-divider-opacity: 0.12;\n      --light-disabled-opacity: 0.3; /* or hint text or icon */\n      --light-secondary-opacity: 0.7;\n      --light-primary-opacity: 1.0;\n\n      /* set our slider style */\n      --ha-slider-pin-font-size: 15px;\n\n      /* rgb */\n      --rgb-primary-color: 3, 169, 244;\n      --rgb-accent-color: 255, 152, 0;\n      --rgb-primary-text-color: 33, 33, 33;\n      --rgb-secondary-text-color: 114, 114, 114;\n      --rgb-text-primary-color: 255, 255, 255;\n      --rgb-card-background-color: 255, 255, 255;\n\n      ${Object.entries(yt.q0).map((([e,t])=>`--${e}: ${t};`)).join("")}\n    }\n\n    /*\n      prevent clipping of positioned elements in a small scrollable\n      force smooth scrolling if can scroll\n      use non-shady selectors so this only targets iOS 9\n      conditional mixin set in ha-style-dialog does not work with shadyCSS\n    */\n    paper-dialog-scrollable:not(.can-scroll) > .scrollable {\n      -webkit-overflow-scrolling: auto !important;\n    }\n\n    paper-dialog-scrollable.can-scroll > .scrollable {\n      -webkit-overflow-scrolling: touch !important;\n    }\n\n    /* for paper-dialog */\n    iron-overlay-backdrop {\n      backdrop-filter: var(--dialog-backdrop-filter, none);\n    }\n  </style>\n</custom-style>`,document.head.appendChild(gt.content);i(64702)})()})();
//# sourceMappingURL=onboarding.55147b52.js.map